@@ -1,21 +1,12 @@
 // Copyright (c) 2006-2009 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Bitstream_descartes_E08_tree.h $
+// $Id: Bitstream_descartes_E08_tree.h 0ff7882997b 2022-12-06T22:21:06+01:00 Mael
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Bitstream_descartes_E08_tree.h $
-// $Id: Bitstream_descartes_E08_tree.h 5c4e0a3 2019-01-31T14:09:42+01:00 Andreas Fabri
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Arno Eigenwillig <arno@mpi-inf.mpg.de>
 //
@@ -135,7 +126,7 @@ void Power_to_Bernstein_pm1_nofrac_matrix<Integer_>::init_m() {
                 else              { sum += term; }
             }
             m_[ij_to_idx(i,j)] =
-                sum 
+                sum
               * CGAL::internal::caching_factorial<Integer>(i)
               * CGAL::internal::caching_factorial<Integer>(degree - i);
         }
@@ -213,7 +204,7 @@ Bitstream_bernstein_from_power<Traits_>::Bitstream_bernstein_from_power(
     log_radius_(log_radius),
     approximator_(traits.approximator_object()),
     lower_bound_log2_abs_(traits.lower_bound_log2_abs_object())
-{ 
+{
     CGAL_assertion(degree_ >= 0);
     lbd_log_lcoeff_ = lower_bound_log2_abs_(input_power_coeff_[degree_]);
     if (degree_ == 2) {
@@ -416,7 +407,7 @@ template <class BitstreamDescartesE08TreeTraits>
   typedef CGAL::internal::Sign_eps_log2                                 \
   <Integer, Abs_le_pow2, Sign>                                          \
   Sign_eps_log2                                                         \
-  
+
 // end #define
 
 // typedefs for Bitstream_descartes_E08_tree{,_rep}
@@ -424,7 +415,7 @@ template <class BitstreamDescartesE08TreeTraits>
   CGAL_BITSTREAM_DESCARTES_E08_TREE_COMMON_TYPEDEFS;                   \
   typedef CGAL::internal::Bitstream_descartes_E08_node<TRAITS> Node;   \
   typedef std::list<Node> Node_list                                    \
-  
+
 // end #define
 
 
@@ -441,10 +432,13 @@ struct Bitstream_descartes_E08_node {
 public:
   typedef Bitstream_descartes_E08_node Self;
   CGAL_BITSTREAM_DESCARTES_E08_TREE_COMMON_TYPEDEFS;
-  
+
   friend class CGAL::internal::Bitstream_descartes_E08_tree<TRAITS>;
   friend class CGAL::internal::Bitstream_descartes_E08_tree_rep<TRAITS>;
 
+  Bitstream_descartes_E08_node(const Self&) = default;
+  Self& operator= (const Self&) = delete;
+
 private:
     // "node data" (set individually in subdivision)
     Integer lower_num_, upper_num_; // TODO use lower_num_, width_num_ instead
@@ -452,7 +446,7 @@ private:
     Integer_vector coeff_; // wrt [lower_, upper_], approximate
     int min_var_, max_var_;
     bool coeff_update_delayed_;
-    // "state data" (copied en bloc by .copy_state_from())
+    // "state data" (copied en block by .copy_state_from())
     long subdepth_bound_, subdepth_current_;
     long log_eps_;   // $q - p$
     long log_C_eps_; // $q - p + 4n$
@@ -475,10 +469,6 @@ private:
         log_eps_          = n.log_eps_;
         log_C_eps_        = n.log_C_eps_;
     }
-
-#ifndef CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS
-    Self& operator= (const Self&) = delete;
-#endif
 }; // struct Bitstream_descartes_E08_node
 
 
@@ -577,11 +567,11 @@ public:
     Bitstream_descartes_E08_tree() : Base(Rep()) { }
 
     //! copy constructor
-#ifdef DOXYGEN_RUNNING  
+#ifdef DOXYGEN_RUNNING
     Bitstream_descartes_E08_tree(const Self& p)
         : Base(static_cast<const Base&>(p))
     { }
-#endif  
+#endif
 
     /*! \brief construct from initial interval and coefficients
      *
@@ -718,13 +708,13 @@ public:
         this->ptr()->node_list_.erase(n);
     }
 
-    /*! \brief Replace traits class
+    /*! \brief replaces traits class
      */
     void set_traits(TRAITS& traits) {
         this->ptr()->b_from_p_.set_traits(traits);
     }
 
-    /*! \brief Returns a copy of this with its own representation
+    /*! \brief returns a copy of this with its own representation
      */
     Self make_unique() const {
       Self tmp = *this;
@@ -899,7 +889,7 @@ Bitstream_descartes_E08_tree<BitstreamDescartesE08TreeTraits>
     int l_min_var, l_max_var, r_min_var, r_max_var;
     internal::var_eps(this->ptr()->tmp1_coeff_.begin(),
                                      this->ptr()->tmp1_coeff_.end(),
-                                     l_min_var, l_max_var, 
+                                     l_min_var, l_max_var,
                                      Sign_eps_log2(n->log_eps_)
     );
     internal::var_eps(this->ptr()->tmp2_coeff_.begin(),
@@ -916,7 +906,7 @@ Bitstream_descartes_E08_tree<BitstreamDescartesE08TreeTraits>
         int children = 1;
         if (r_min_var > 0) {
             // create new node for right child
-            Node_iterator r = 
+            Node_iterator r =
                 this->ptr()->node_list_.insert(beyond, Node(degree(),
                             this->ptr()->splitpoint_num_,        // lower
                             n->upper_num_ << delta_log_bdry_den, // upper
