@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Apollonius_graph_2/include/CGAL/Apollonius_graph_2.h $
+// $Id: Apollonius_graph_2.h 98e471849bd 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Apollonius_graph_2/include/CGAL/Apollonius_graph_2.h $
-// $Id: Apollonius_graph_2.h a6c528c 2019-06-18T13:18:25+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
@@ -46,7 +37,7 @@
 #include <CGAL/Apollonius_graph_vertex_base_2.h>
 
 #include <CGAL/in_place_edge_list.h>
-#include <CGAL/internal/TDS_2/edge_list.h>
+#include <CGAL/TDS_2/internal/edge_list.h>
 #include <CGAL/Apollonius_graph_2/Traits_wrapper_2.h>
 
 #include <CGAL/Apollonius_graph_2/Constructions_C2.h>
@@ -99,10 +90,10 @@ template<class Gt,class Agds,class LTag>
 class Apollonius_graph_hierarchy_2;
 
 template < class Gt,
-	   class Agds = Triangulation_data_structure_2 < 
+           class Agds = Triangulation_data_structure_2 <
                Apollonius_graph_vertex_base_2<Gt,true>,
                Triangulation_face_base_2<Gt> >,
-	   class LTag = Tag_false>
+           class LTag = Tag_false>
 class Apollonius_graph_2
   : private Triangulation_2
   <CGAL_APOLLONIUS_GRAPH_2_NS::Apollonius_graph_traits_wrapper_2<Gt>,Agds>
@@ -142,17 +133,17 @@ private:
   }
 
   Construct_Apollonius_bisector_segment_2
-  construct_Apollonius_bisector_segment_2_object() const { 
-    return Construct_Apollonius_bisector_segment_2(); 
+  construct_Apollonius_bisector_segment_2_object() const {
+    return Construct_Apollonius_bisector_segment_2();
   }
 
   Construct_Apollonius_primal_ray_2
   construct_Apollonius_primal_ray_2_object() const {
-    return Construct_Apollonius_primal_ray_2(); 
+    return Construct_Apollonius_primal_ray_2();
   }
 
   Construct_Apollonius_primal_segment_2
-  construct_Apollonius_primal_segment_2_object() const { 
+  construct_Apollonius_primal_segment_2_object() const {
     return Construct_Apollonius_primal_segment_2();
   }
 
@@ -199,24 +190,24 @@ public:
   // Auxiliary iterators for convenience
   // do not use default template argument to please VC++
   typedef internal::Project_site_2<Vertex>                   Proj_site;
-  typedef Iterator_project<Finite_vertices_iterator, 
+  typedef Iterator_project<Finite_vertices_iterator,
                            Proj_site>
   /*                                           */ Visible_sites_iterator;
 
   typedef
   Apollonius_graph_vertex_base_nested_iterator_traits<
     Finite_vertices_iterator>  Hidden_sites_nested_iterator_traits;
-  
+
 
   typedef Nested_iterator<Finite_vertices_iterator,
-			  Hidden_sites_nested_iterator_traits>
+                          Hidden_sites_nested_iterator_traits>
   /*                                            */ Hidden_sites_iterator;
 
   typedef Concatenate_iterator<Visible_sites_iterator,
-			       Hidden_sites_iterator>     Sites_iterator;
+                               Hidden_sites_iterator>     Sites_iterator;
 
   typedef Site_2               value_type; // to have a back_inserter
-  typedef const value_type&    const_reference; 
+  typedef const value_type&    const_reference;
   typedef value_type&          reference;
 
 public:
@@ -245,7 +236,7 @@ protected:
   typedef typename internal::AG2_which_list<Edge,LTag>::List  List;
 
   typedef enum { NO_CONFLICT = -1, INTERIOR, LEFT_VERTEX,
-		 RIGHT_VERTEX, BOTH_VERTICES, ENTIRE_EDGE }
+                 RIGHT_VERTEX, BOTH_VERTICES, ENTIRE_EDGE }
   Conflict_type;
 
   static Conflict_type opposite(const Conflict_type& ct) {
@@ -266,7 +257,7 @@ protected:
     Site_less_than_comparator(const Gt& gt) : gt(gt) {}
 
     bool operator ()(const Site_2& p,
-		     const Site_2& q) {
+                     const Site_2& q) {
       Comparison_result result = gt.compare_weight_2_object()(p, q);
       return (result == LARGER);
     }
@@ -280,7 +271,7 @@ public:
 
   template< class Input_iterator >
   Apollonius_graph_2(Input_iterator first, Input_iterator beyond,
-		     const Gt& gt=Gt())
+                     const Gt& gt=Gt())
     : DG( Modified_traits(gt) )
   {
     insert(first, beyond);
@@ -332,7 +323,7 @@ public:
 
     size_type n_hidden(0);
     for (Finite_vertices_iterator vit = finite_vertices_begin();
-	 vit != finite_vertices_end(); ++vit) {
+         vit != finite_vertices_end(); ++vit) {
       n_hidden += vit->number_of_hidden_sites();
     }
 
@@ -375,23 +366,23 @@ public:
   }
 
   Finite_edges_iterator finite_edges_begin() const {
-    return DG::finite_edges_begin();    
+    return DG::finite_edges_begin();
   }
   Finite_edges_iterator finite_edges_end() const {
-    return DG::finite_edges_end();    
+    return DG::finite_edges_end();
   }
 
 
   Sites_iterator sites_begin() const {
     return Sites_iterator(visible_sites_end(),
-    			  hidden_sites_begin(),
-    			  visible_sites_begin());
+                              hidden_sites_begin(),
+                              visible_sites_begin());
   }
 
   Sites_iterator sites_end() const {
     return Sites_iterator(visible_sites_end(),
-    			  hidden_sites_begin(),
-    			  hidden_sites_end(),0);
+                              hidden_sites_begin(),
+                              hidden_sites_end(),0);
   }
 
   Visible_sites_iterator visible_sites_begin() const {
@@ -404,12 +395,12 @@ public:
 
   Hidden_sites_iterator hidden_sites_begin() const {
     return Hidden_sites_iterator(finite_vertices_end(),
-				 finite_vertices_begin());
+                                 finite_vertices_begin());
   }
 
   Hidden_sites_iterator hidden_sites_end() const {
     return Hidden_sites_iterator(finite_vertices_end(),
-				 finite_vertices_end());
+                                 finite_vertices_end());
   }
 
 
@@ -442,22 +433,22 @@ public:
   //------------
   Face_circulator
   incident_faces(Vertex_handle v,
-		 Face_handle f = Face_handle()) const {
+                 Face_handle f = Face_handle()) const {
     return DG::incident_faces(v, f);
   }
 
   Vertex_circulator
   incident_vertices(Vertex_handle v,
-		    Face_handle f = Face_handle()) const { 
+                    Face_handle f = Face_handle()) const {
     return DG::incident_vertices(v, f);
   }
 
   Edge_circulator
   incident_edges(Vertex_handle v,
-		 Face_handle f = Face_handle()) const {
+                 Face_handle f = Face_handle()) const {
     return DG::incident_edges(v, f);
   }
- 
+
 public:
   // PREDICATES
   //-----------
@@ -528,7 +519,7 @@ public:
   //--------------------------
   Vertex_handle  nearest_neighbor(const Point_2& p) const;
   Vertex_handle  nearest_neighbor(const Point_2& p,
-				  Vertex_handle vnear) const;
+                                  Vertex_handle vnear) const;
 
 public:
   // ACCESS TO THE DUAL
@@ -576,14 +567,14 @@ public:
       Vertex_handle v2(++finite_vertices_begin());
       Site_2 p1 = v1->site();
       Site_2 p2 = v2->site();
-      
+
 
       typename Geom_traits::Segment_2 seg =
-	construct_Apollonius_primal_segment_2_object()(p1,p2);
+        construct_Apollonius_primal_segment_2_object()(p1,p2);
       typename Geom_traits::Ray_2 ray1 =
-	construct_Apollonius_primal_ray_2_object()(p1,p2,p2);
+        construct_Apollonius_primal_ray_2_object()(p1,p2,p2);
       typename Geom_traits::Ray_2 ray2 =
-	construct_Apollonius_primal_ray_2_object()(p2,p1,p1);
+        construct_Apollonius_primal_ray_2_object()(p2,p1,p1);
 
       str << seg;
       str << ray1;
@@ -591,13 +582,13 @@ public:
     } else {
       All_edges_iterator eit = all_edges_begin();
       for (; eit != all_edges_end(); ++eit) {
-	draw_primal_edge< Stream >(eit, str);
+        draw_primal_edge< Stream >(eit, str);
       }
     }
     return str;
   }
 
-  template < class Stream > 
+  template < class Stream >
   Stream& draw_dual(Stream &str) const
   {
     Finite_edges_iterator eit = finite_edges_begin();
@@ -610,7 +601,7 @@ public:
       CGAL::Hyperbola_segment_2<Gt>    hs;
       CGAL::Hyperbola_ray_2<Gt>        hr;
       if (assign(hs, o)) hs.draw(str);
-      else if (assign(s, o))  str << s; 
+      else if (assign(s, o))  str << s;
       else if (assign(hr, o))  hr.draw(str);
       else if (assign(r, o))   str << r;
       else if (assign(h, o))  h.draw(str);
@@ -622,7 +613,7 @@ public:
 protected:
   template< class Stream >
   Stream& draw_primal_vertex(const Finite_vertices_iterator& it,
-			     Stream &str) const
+                             Stream &str) const
   {
     return str << it->site().point();
   }
@@ -630,7 +621,7 @@ protected:
 
   template< class Stream >
   Stream& draw_dual_vertex(const Finite_faces_iterator& it,
-			   Stream &str) const
+                           Stream &str) const
   {
     return str << dual(it);
   }
@@ -638,22 +629,22 @@ protected:
 public:
   template< class Stream >
   Stream& draw_primal_edge(const Finite_edges_iterator& eit,
-			   Stream &str) const
+                           Stream &str) const
   {
     return draw_primal_edge(*eit, str);
   }
 
   template< class Stream >
   Stream& draw_primal_edge(const All_edges_iterator& eit,
-			   Stream &str) const
+                           Stream &str) const
   {
     return draw_primal_edge(*eit, str);
   }
 
 
-  template < class Stream > 
+  template < class Stream >
   Stream& draw_dual_edge(const Finite_edges_iterator& eit,
-			 Stream &str) const
+                         Stream &str) const
   {
     return draw_dual_edge(*eit, str);
   }
@@ -672,14 +663,14 @@ public:
     CGAL::Hyperbola_segment_2<Gt>    hs;
     CGAL::Parabola_segment_2<Gt>     ps;
     if (assign(hs, o))  hs.draw(str);
-    if (assign(s, o))   str << s; 
+    if (assign(s, o))   str << s;
     if (assign(ps, o))  ps.draw(str);
     if (assign(r, o))   str << r;
     if (assign(s_pair, o)) str << s_pair.first << s_pair.second;
     return str;
   }
 
-  template < class Stream > 
+  template < class Stream >
   Stream& draw_dual_edge(const Edge& e, Stream &str) const
   {
     if ( is_infinite(e) ) { return str; }
@@ -691,7 +682,7 @@ public:
     CGAL::Hyperbola_segment_2<Gt>    hs;
     CGAL::Hyperbola_ray_2<Gt>        hr;
     if (assign(hs, o))  hs.draw(str);
-    if (assign(s, o))   str << s; 
+    if (assign(s, o))   str << s;
     if (assign(hr, o))  hr.draw(str);
     if (assign(r, o))   str << r;
     if (assign(h, o))   h.draw(str);
@@ -713,7 +704,7 @@ protected:
 
   template< class Stream >
   Stream& draw_dual_face(const All_vertices_iterator& vit,
-			 Stream &str) const
+                         Stream &str) const
   {
     Edge_circulator ec_start = incident_edges(Vertex_handle(vit));
     Edge_circulator ec = ec_start;
@@ -725,28 +716,28 @@ protected:
   }
 
 protected:
-  template < class Stream > 
+  template < class Stream >
   Stream& draw_dual_sites(Stream &str) const
   {
     All_faces_iterator fit = all_faces_begin();
     for (; fit != all_faces_end(); ++fit) {
       Face_handle f(fit);
       if ( is_infinite(f) ) {
-	if (  is_infinite(f->vertex(0))  ) {
-	  str << circumcircle( f->vertex(1)->site(),
-			       f->vertex(2)->site() );
-	} else if (  is_infinite(f->vertex(1))  ){
-	  str << circumcircle( f->vertex(2)->site(),
-			       f->vertex(0)->site() );
-	} else {
-	  str << circumcircle( f->vertex(0)->site(),
-			       f->vertex(1)->site() );	  
-	}
+        if (  is_infinite(f->vertex(0))  ) {
+          str << circumcircle( f->vertex(1)->site(),
+                               f->vertex(2)->site() );
+        } else if (  is_infinite(f->vertex(1))  ){
+          str << circumcircle( f->vertex(2)->site(),
+                               f->vertex(0)->site() );
+        } else {
+          str << circumcircle( f->vertex(0)->site(),
+                               f->vertex(1)->site() );
+        }
       } else {
-	Site_2 wp = circumcircle(f);
-	typename Gt::Rep::Circle_2 c(wp.point(),
-				     CGAL::square(wp.weight()));
-	str << c;
+        Site_2 wp = circumcircle(f);
+        typename Gt::Rep::Circle_2 c(wp.point(),
+                                     CGAL::square(wp.weight()));
+        str << c;
       }
     }
     return str;
@@ -791,129 +782,129 @@ protected:
   //   ON_NEGATIVE_SIDE if q is closer to p2
   //   ON_ORIENTED_BOUNDARY if q is on the bisector of p1 and p2
   Oriented_side side_of_bisector(const Site_2 &p1,
-				 const Site_2 &p2,
-				 const Point_2 &q) const;
+                                 const Site_2 &p2,
+                                 const Point_2 &q) const;
 
   Sign incircle(const Site_2 &p1, const Site_2 &p2,
-		const Site_2 &p3, const Site_2 &q) const;
+                const Site_2 &p3, const Site_2 &q) const;
 
   Sign incircle(const Site_2 &p1, const Site_2 &p2,
-		const Site_2 &q) const;
+                const Site_2 &q) const;
 
 
   Sign incircle(const Face_handle& f, const Site_2& q) const;
 
 
   Sign incircle(const Vertex_handle& v0, const Vertex_handle& v1,
-		const Vertex_handle& v) const;
+                const Vertex_handle& v) const;
 
   Sign incircle(const Vertex_handle& v0, const Vertex_handle& v1,
-		const Vertex_handle& v2, const Vertex_handle& v) const;
+                const Vertex_handle& v2, const Vertex_handle& v) const;
+
 
 
-  
   bool finite_edge_interior(const Site_2& p1,
-			    const Site_2& p2,
-			    const Site_2& p3,
-			    const Site_2& p4,
-			    const Site_2& q,
-			    bool endpoints_in_conflict) const;
+                            const Site_2& p2,
+                            const Site_2& p3,
+                            const Site_2& p4,
+                            const Site_2& q,
+                            bool endpoints_in_conflict) const;
 
   bool finite_edge_interior(const Face_handle& f, int i,
-			    const Site_2& q,
-			    bool endpoints_in_conflict) const;
+                            const Site_2& q,
+                            bool endpoints_in_conflict) const;
 
   bool finite_edge_interior(const Vertex_handle& v1,
-			    const Vertex_handle& v2,
-			    const Vertex_handle& v3,
-			    const Vertex_handle& v4,
-			    const Vertex_handle& v,
-			    bool endpoints_in_conflict) const;
+                            const Vertex_handle& v2,
+                            const Vertex_handle& v3,
+                            const Vertex_handle& v4,
+                            const Vertex_handle& v,
+                            bool endpoints_in_conflict) const;
 
   bool finite_edge_interior_degenerated(const Site_2& p1,
-					const Site_2& p2,
-					const Site_2& p3,
-					const Site_2& q,
-					bool endpoints_in_conflict) const;
+                                        const Site_2& p2,
+                                        const Site_2& p3,
+                                        const Site_2& q,
+                                        bool endpoints_in_conflict) const;
 
 
   bool finite_edge_interior_degenerated(const Site_2& p1,
-					const Site_2& p2,
-					const Site_2& q,
-					bool endpoints_in_conflict) const;
+                                        const Site_2& p2,
+                                        const Site_2& q,
+                                        bool endpoints_in_conflict) const;
 
   bool finite_edge_interior_degenerated(const Face_handle& f, int i,
-					const Site_2& p,
-					bool endpoints_in_conflict) const;
+                                        const Site_2& p,
+                                        bool endpoints_in_conflict) const;
 
   bool finite_edge_interior_degenerated(const Vertex_handle& v1,
-					const Vertex_handle& v2,
-					const Vertex_handle& v3,
-					const Vertex_handle& v4,
-					const Vertex_handle& v,
-					bool endpoints_in_conflict) const;
+                                        const Vertex_handle& v2,
+                                        const Vertex_handle& v3,
+                                        const Vertex_handle& v4,
+                                        const Vertex_handle& v,
+                                        bool endpoints_in_conflict) const;
   bool infinite_edge_interior(const Site_2& p2,
-			      const Site_2& p3,
-			      const Site_2& p4,
-			      const Site_2& q,
-			      bool endpoints_in_conflict) const;
+                              const Site_2& p3,
+                              const Site_2& p4,
+                              const Site_2& q,
+                              bool endpoints_in_conflict) const;
 
 
   bool infinite_edge_interior(const Face_handle& f, int i,
-			      const Site_2& p,
-			      bool endpoints_in_conflict) const;
+                              const Site_2& p,
+                              bool endpoints_in_conflict) const;
 
   bool infinite_edge_interior(const Vertex_handle& v1,
-			      const Vertex_handle& v2,
-			      const Vertex_handle& v3,
-			      const Vertex_handle& v4,
-			      const Vertex_handle& v,
-			      bool endpoints_in_conflict) const;
+                              const Vertex_handle& v2,
+                              const Vertex_handle& v3,
+                              const Vertex_handle& v4,
+                              const Vertex_handle& v,
+                              bool endpoints_in_conflict) const;
 
   Conflict_type
   infinite_edge_conflict_type(const Site_2& p2,
-			      const Site_2& p3,
-			      const Site_2& p4,
-			      const Site_2& q) const;
+                              const Site_2& p3,
+                              const Site_2& p4,
+                              const Site_2& q) const;
 
   Conflict_type
   finite_edge_conflict_type_degenerated(const Site_2& p1,
-					const Site_2& p2,
-					const Site_2& q) const;
+                                        const Site_2& p2,
+                                        const Site_2& q) const;
 
   bool edge_interior(const Face_handle& f, int i,
-		     const Site_2& p, bool b) const;
+                     const Site_2& p, bool b) const;
 
 
   bool edge_interior(const Edge& e,
-			    const Site_2& p, bool b) const {
+                            const Site_2& p, bool b) const {
     return edge_interior(e.first, e.second, p, b);
   }
 
   bool edge_interior(const Vertex_handle& v1,
-		     const Vertex_handle& v2,
-		     const Vertex_handle& v3,
-		     const Vertex_handle& v4,
-		     const Vertex_handle& v,
-		     bool endpoints_in_conflict) const;
+                     const Vertex_handle& v2,
+                     const Vertex_handle& v3,
+                     const Vertex_handle& v4,
+                     const Vertex_handle& v,
+                     bool endpoints_in_conflict) const;
 
   bool is_degenerate_edge(const Site_2& p1,
-				 const Site_2& p2,
-				 const Site_2& p3,
-				 const Site_2& p4) const {
+                                 const Site_2& p2,
+                                 const Site_2& p3,
+                                 const Site_2& p4) const {
     return geom_traits().is_degenerate_edge_2_object()
       (p1, p2, p3, p4);
   }
 
   bool is_degenerate_edge(const Vertex_handle& v1,
-				 const Vertex_handle& v2,
-				 const Vertex_handle& v3,
-				 const Vertex_handle& v4) const {
+                                 const Vertex_handle& v2,
+                                 const Vertex_handle& v3,
+                                 const Vertex_handle& v4) const {
     CGAL_precondition( !is_infinite(v1) && !is_infinite(v2) &&
-		       !is_infinite(v3) && !is_infinite(v4) );
+                       !is_infinite(v3) && !is_infinite(v4) );
 
     return is_degenerate_edge(v1->site(), v2->site(),
-			      v3->site(), v4->site());
+                              v3->site(), v4->site());
   }
 
   bool is_degenerate_edge(const Face_handle& f, int i) const {
@@ -933,17 +924,17 @@ protected:
 protected:
   // wrappers for constructions
   Point_2 circumcenter(const Face_handle& f) const;
-  Point_2 circumcenter(const Site_2& p0, 
-		       const Site_2& p1, 
-		       const Site_2& p2) const;
+  Point_2 circumcenter(const Site_2& p0,
+                       const Site_2& p1,
+                       const Site_2& p2) const;
 
   Site_2 circumcircle(const Face_handle& f) const;
-  Site_2 circumcircle(const Site_2& p0, 
-		      const Site_2& p1, 
-		      const Site_2& p2) const;
+  Site_2 circumcircle(const Site_2& p0,
+                      const Site_2& p1,
+                      const Site_2& p2) const;
 
   typename Gt::Line_2 circumcircle(const Site_2& p0,
-				   const Site_2& p1) const;
+                                   const Site_2& p1) const;
 
 protected:
   // wrappers for combinatorial operations on the data structure
@@ -990,11 +981,11 @@ protected:
   // methods for insertion
   void initialize_conflict_region(const Face_handle& f, List& l) const;
   bool check_edge_for_hidden_sites(const Face_handle& f, int i,
-				   const Site_2& p, Vertex_map& vm) const;
+                                   const Site_2& p, Vertex_map& vm) const;
   void expand_conflict_region(const Face_handle& f,
-			      const Site_2& p,
-			      List& l, Face_map& fm, Vertex_map& vm,
-			      std::vector<Vh_triple*>* fe);
+                              const Site_2& p,
+                              List& l, Face_map& fm, Vertex_map& vm,
+                              std::vector<Vh_triple*>* fe);
 
   Vertex_handle add_bogus_vertex(Edge e, List& l);
   Vertex_list   add_bogus_vertices(List& l);
@@ -1004,12 +995,12 @@ protected:
 
   // MK: this is not currently used
   std::vector<Face*> get_faces_for_recycling(Face_map& fm,
-					     unsigned int n_wanted);
+                                             unsigned int n_wanted);
   void remove_hidden_vertices(Vertex_map& vm);
   Vertex_handle retriangulate_conflict_region(const Site_2& p,
-					      List& l,
-					      Face_map& fm,
-					      Vertex_map& vm);
+                                              List& l,
+                                              Face_map& fm,
+                                              Vertex_map& vm);
 
 protected:
   // methods for removal
@@ -1020,10 +1011,10 @@ protected:
   void  minimize_degree(Vertex_handle v);
 
   void find_conflict_region_remove(const Vertex_handle& v,
-				   const Vertex_handle& vnearest,
-				   List& l, Face_map& fm,
-				   Vertex_map& vm,
-				   std::vector<Vh_triple*>* fe);
+                                   const Vertex_handle& vnearest,
+                                   List& l, Face_map& fm,
+                                   Vertex_map& vm,
+                                   std::vector<Vh_triple*>* fe);
 
 protected:
   // methods for I/O
@@ -1038,11 +1029,11 @@ protected:
 protected:
   template<class OutputItFaces>
   OutputItFaces find_conflicts(const Face_handle& f,
-			       const Site_2& p,
-			       List& l,
-			       Face_map& fm,
-			       Vertex_map& vm,
-			       OutputItFaces fit) const
+                               const Site_2& p,
+                               List& l,
+                               Face_map& fm,
+                               Vertex_map& vm,
+                               OutputItFaces fit) const
   {
     // setting fm[f] to true means that the face has been reached and
     // that the face is available for recycling. If we do not want the
@@ -1060,22 +1051,22 @@ protected:
       Face_handle n = f->neighbor(i);
 
       if ( !hidden_found ) {
-	Sign s = incircle(n, p);
-	if ( s != NEGATIVE ) { continue; }
+        Sign s = incircle(n, p);
+        if ( s != NEGATIVE ) { continue; }
 
-	bool interior_in_conflict = edge_interior(f, i, p, true);
+        bool interior_in_conflict = edge_interior(f, i, p, true);
 
-	if ( !interior_in_conflict ) { continue; }
+        if ( !interior_in_conflict ) { continue; }
       }
 
       if ( fm.find(n) != fm.end() ) {
-	Edge e = sym_edge(f, i);
-	if ( l.is_in_list(e) ||
-	     l.is_in_list(sym_edge(e)) ) {
-	  l.remove(e);
-	  l.remove(sym_edge(e));
-	}
-	continue;
+        Edge e = sym_edge(f, i);
+        if ( l.is_in_list(e) ||
+             l.is_in_list(sym_edge(e)) ) {
+          l.remove(e);
+          l.remove(sym_edge(e));
+        }
+        continue;
       }
 
       Edge e = sym_edge(f, i);
@@ -1085,10 +1076,10 @@ protected:
       Edge e_before = sym_edge(n, ccw(j));
       Edge e_after = sym_edge(n, cw(j));
       if ( !l.is_in_list(e_before) ) {
-	l.insert_before(e, e_before);
+        l.insert_before(e, e_before);
       }
       if ( !l.is_in_list(e_after) ) {
-	l.insert_after(e, e_after);
+        l.insert_after(e, e_after);
       }
       l.remove(e);
 
@@ -1104,15 +1095,15 @@ protected:
 
 protected:
   template<class OutputItFaces, class OutputItBoundaryEdges,
-	   class OutputItHiddenVertices>
+           class OutputItHiddenVertices>
   boost::tuples::tuple<OutputItFaces, OutputItBoundaryEdges,
-		       OutputItHiddenVertices>
+                       OutputItHiddenVertices>
   get_all(const Site_2& p,
-	  OutputItFaces fit,
-	  OutputItBoundaryEdges eit,
-	  OutputItHiddenVertices vit,
-	  Vertex_handle start,
-	  bool find_nearest) const
+          OutputItFaces fit,
+          OutputItBoundaryEdges eit,
+          OutputItHiddenVertices vit,
+          Vertex_handle start,
+          bool find_nearest) const
   {
     CGAL_precondition( dimension() == 2 );
 
@@ -1140,8 +1131,8 @@ protected:
       s = incircle(f, p);
 
       if ( s == NEGATIVE ) {
-	start_f = f;
-	break;
+        start_f = f;
+        break;
       }
       ++fc;
     } while ( fc != fc_start );
@@ -1155,11 +1146,11 @@ protected:
       bool interior_in_conflict(false);
       Edge e;
       do {
-	e = *ec;
-	interior_in_conflict = edge_interior(e, p, false);
-	
-	if ( interior_in_conflict ) { break; }
-	++ec;
+        e = *ec;
+        interior_in_conflict = edge_interior(e, p, false);
+
+        if ( interior_in_conflict ) { break; }
+        ++ec;
       } while ( ec != ec_start );
 
       CGAL_assertion( interior_in_conflict );
@@ -1169,7 +1160,7 @@ protected:
       return boost::tuples::make_tuple(fit, eit, vit);
     }
 
-    // we are in conflict with an Apollonius vertex; start from that and 
+    // we are in conflict with an Apollonius vertex; start from that and
     // find the entire conflict region and then repair the diagram
     List l;
     Face_map fm;
@@ -1187,8 +1178,8 @@ protected:
       // assignment: e = l.next(e);
       Edge e = l.front();
       do {
-	*eit++ = e;
-	e = l.next(e);
+        *eit++ = e;
+        e = l.next(e);
       } while ( !equal(e, e_front) );
     }
 
@@ -1207,15 +1198,15 @@ protected:
 
 public:
   template<class OutputItFaces, class OutputItBoundaryEdges,
-	   class OutputItHiddenVertices>
+           class OutputItHiddenVertices>
   boost::tuples::tuple<OutputItFaces, OutputItBoundaryEdges,
-		       OutputItHiddenVertices>
+                       OutputItHiddenVertices>
   get_conflicts_and_boundary_and_hidden_vertices(const Site_2& p,
-						 OutputItFaces fit,
-						 OutputItBoundaryEdges eit,
-						 OutputItHiddenVertices vit,
-						 Vertex_handle start =
-						 Vertex_handle()) const
+                                                 OutputItFaces fit,
+                                                 OutputItBoundaryEdges eit,
+                                                 OutputItHiddenVertices vit,
+                                                 Vertex_handle start =
+                                                 Vertex_handle()) const
   {
     return get_all(p, fit, eit, vit, start, true);
   }
@@ -1223,104 +1214,104 @@ public:
   template<class OutputItFaces, class OutputItBoundaryEdges>
   std::pair<OutputItFaces, OutputItBoundaryEdges>
   get_conflicts_and_boundary(const Site_2& p,
-			     OutputItFaces fit,
-			     OutputItBoundaryEdges eit,
-			     Vertex_handle start =
-			     Vertex_handle()) const {
+                             OutputItFaces fit,
+                             OutputItBoundaryEdges eit,
+                             Vertex_handle start =
+                             Vertex_handle()) const {
     boost::tuples::tuple<OutputItFaces,OutputItBoundaryEdges,Emptyset_iterator>
       tup =
       get_conflicts_and_boundary_and_hidden_vertices(p,
-						     fit,
-						     eit,
-						     Emptyset_iterator(),
-						     start);
+                                                     fit,
+                                                     eit,
+                                                     Emptyset_iterator(),
+                                                     start);
     return std::make_pair( boost::tuples::get<0>(tup),
-			   boost::tuples::get<1>(tup) );
+                           boost::tuples::get<1>(tup) );
   }
 
 
   template<class OutputItBoundaryEdges, class OutputItHiddenVertices>
   std::pair<OutputItBoundaryEdges, OutputItHiddenVertices>
   get_boundary_of_conflicts_and_hidden_vertices(const Site_2& p,
-						OutputItBoundaryEdges eit,
-						OutputItHiddenVertices vit,
-						Vertex_handle start =
-						Vertex_handle()) const {
+                                                OutputItBoundaryEdges eit,
+                                                OutputItHiddenVertices vit,
+                                                Vertex_handle start =
+                                                Vertex_handle()) const {
     boost::tuples::tuple<Emptyset_iterator,OutputItBoundaryEdges,
       OutputItHiddenVertices>
       tup =
       get_conflicts_and_boundary_and_hidden_vertices(p,
-						     Emptyset_iterator(),
-						     eit,
-						     vit,
-						     start);
+                                                     Emptyset_iterator(),
+                                                     eit,
+                                                     vit,
+                                                     start);
     return std::make_pair( boost::tuples::get<1>(tup),
-			   boost::tuples::get<2>(tup) );
+                           boost::tuples::get<2>(tup) );
   }
 
 
   template<class OutputItFaces, class OutputItHiddenVertices>
   std::pair<OutputItFaces, OutputItHiddenVertices>
   get_conflicts_and_hidden_vertices(const Site_2& p,
-				    OutputItFaces fit,
-				    OutputItHiddenVertices vit,
-				    Vertex_handle start =
-				    Vertex_handle()) const {
+                                    OutputItFaces fit,
+                                    OutputItHiddenVertices vit,
+                                    Vertex_handle start =
+                                    Vertex_handle()) const {
     boost::tuples::tuple<OutputItFaces,Emptyset_iterator,
       OutputItHiddenVertices>
       tup =
       get_conflicts_and_boundary_and_hidden_vertices(p,
-						     fit,
-						     Emptyset_iterator(),
-						     vit,
-						     start);
+                                                     fit,
+                                                     Emptyset_iterator(),
+                                                     vit,
+                                                     start);
     return std::make_pair( boost::tuples::get<0>(tup),
-			   boost::tuples::get<2>(tup) );
+                           boost::tuples::get<2>(tup) );
   }
 
   template<class OutputItFaces>
   OutputItFaces get_conflicts(const Site_2& p,
-			      OutputItFaces fit,
-			      Vertex_handle start = Vertex_handle()) const {
+                              OutputItFaces fit,
+                              Vertex_handle start = Vertex_handle()) const {
     boost::tuples::tuple<OutputItFaces,Emptyset_iterator,Emptyset_iterator>
       tup =
       get_conflicts_and_boundary_and_hidden_vertices(p,
-						     fit,
-						     Emptyset_iterator(),
-						     Emptyset_iterator(),
-						     start);
+                                                     fit,
+                                                     Emptyset_iterator(),
+                                                     Emptyset_iterator(),
+                                                     start);
     return boost::tuples::get<0>(tup);
   }
 
   template<class OutputItBoundaryEdges>
   OutputItBoundaryEdges
   get_boundary_of_conflicts(const Site_2& p,
-			    OutputItBoundaryEdges eit,
-			    Vertex_handle start = Vertex_handle()) const {
+                            OutputItBoundaryEdges eit,
+                            Vertex_handle start = Vertex_handle()) const {
     boost::tuples::tuple<Emptyset_iterator,OutputItBoundaryEdges,
       Emptyset_iterator>
       tup =
       get_conflicts_and_boundary_and_hidden_vertices(p,
-						     Emptyset_iterator(),
-						     eit,
-						     Emptyset_iterator(),
-						     start);
+                                                     Emptyset_iterator(),
+                                                     eit,
+                                                     Emptyset_iterator(),
+                                                     start);
     return boost::tuples::get<1>(tup);
   }
 
   template<class OutputItHiddenVertices>
   OutputItHiddenVertices
   get_hidden_vertices(const Site_2& p,
-		      OutputItHiddenVertices vit,
-		      Vertex_handle start = Vertex_handle()) const {
+                      OutputItHiddenVertices vit,
+                      Vertex_handle start = Vertex_handle()) const {
     boost::tuples::tuple<Emptyset_iterator,Emptyset_iterator,
       OutputItHiddenVertices>
       tup =
       get_conflicts_and_boundary_and_hidden_vertices(p,
-						     Emptyset_iterator(),
-						     Emptyset_iterator(),
-						     vit,
-						     start);
+                                                     Emptyset_iterator(),
+                                                     Emptyset_iterator(),
+                                                     vit,
+                                                     start);
     return boost::tuples::get<2>(tup);
   }
 
@@ -1329,7 +1320,7 @@ public:
 
 template<class Gt, class Agds, class LTag>
 std::ostream& operator<<(std::ostream& os,
-			 const Apollonius_graph_2<Gt,Agds,LTag>& ag)
+                         const Apollonius_graph_2<Gt,Agds,LTag>& ag)
 {
   ag.file_output(os);
   return os;
@@ -1337,7 +1328,7 @@ std::ostream& operator<<(std::ostream& os,
 
 template<class Gt, class Agds, class LTag>
 std::istream& operator>>(std::istream& is,
-			 Apollonius_graph_2<Gt,Agds,LTag>& ag)
+                         Apollonius_graph_2<Gt,Agds,LTag>& ag)
 {
   ag.file_input(is);
   return is;
