@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/Apollonius_graph_hierarchy_2_impl.h $
+// $Id: Apollonius_graph_hierarchy_2_impl.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/Apollonius_graph_hierarchy_2_impl.h $
-// $Id: Apollonius_graph_hierarchy_2_impl.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
@@ -36,7 +27,7 @@ void
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 init_hierarchy(const Geom_traits& gt)
 {
-  hierarchy[0] = this; 
+  hierarchy[0] = this;
   for(unsigned int i = 1; i < ag_hierarchy_2__maxlevel; ++i) {
     hierarchy[i] = new Apollonius_graph_base(gt);
   }
@@ -46,7 +37,7 @@ template<class Gt, class Agds, class LTag>
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 Apollonius_graph_hierarchy_2(const Geom_traits& gt)
   : Apollonius_graph_base(gt)
-{ 
+{
   init_hierarchy(gt);
 }
 
@@ -57,13 +48,13 @@ Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 Apollonius_graph_hierarchy_2
 (const Apollonius_graph_hierarchy_2<Gt,Agds,LTag>& agh)
     : Apollonius_graph_base(agh.geom_traits())
-{ 
+{
   init_hierarchy(agh.geom_traits());
   copy(agh);
-} 
- 
+}
 
-//Assignement
+
+//Assignment
 template<class Gt, class Agds, class LTag>
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag> &
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
@@ -87,14 +78,14 @@ copy
 
   //up and down have been copied in straightforward way
   // compute a map at lower level
-  for( Finite_vertices_iterator it = hierarchy[0]->finite_vertices_begin(); 
+  for( Finite_vertices_iterator it = hierarchy[0]->finite_vertices_begin();
        it != hierarchy[0]->finite_vertices_end(); ++it) {
     if ( it->up() != Vertex_handle() ) V[ it->up()->down() ] = it;
   }
 
   for(unsigned int i = 1; i < ag_hierarchy_2__maxlevel; ++i) {
-    for( Finite_vertices_iterator it = hierarchy[i]->finite_vertices_begin(); 
-	 it != hierarchy[i]->finite_vertices_end(); ++it) {
+    for( Finite_vertices_iterator it = hierarchy[i]->finite_vertices_begin();
+         it != hierarchy[i]->finite_vertices_end(); ++it) {
       // down pointer goes in original instead in copied triangulation
       it->set_down(V[it->down()]);
       // make reverse link
@@ -106,7 +97,7 @@ copy
 }
 
 template<class Gt, class Agds, class LTag>
-Apollonius_graph_hierarchy_2<Gt,Agds,LTag>:: 
+Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 ~Apollonius_graph_hierarchy_2()
 {
   clear();
@@ -117,7 +108,7 @@ Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 
 template<class Gt, class Agds, class LTag>
 void
-Apollonius_graph_hierarchy_2<Gt,Agds,LTag>:: 
+Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 clear()
 {
   for(unsigned int i = 0; i < ag_hierarchy_2__maxlevel; ++i) {
@@ -127,7 +118,7 @@ clear()
 
 template<class Gt, class Agds, class LTag>
 bool
-Apollonius_graph_hierarchy_2<Gt,Agds,LTag>:: 
+Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 is_valid(bool verbose, int level) const
 {
   bool result(true);
@@ -143,15 +134,15 @@ is_valid(bool verbose, int level) const
     }
   }
   //verify that lower level has no down pointers
-  for( Finite_vertices_iterator it = hierarchy[0]->finite_vertices_begin(); 
+  for( Finite_vertices_iterator it = hierarchy[0]->finite_vertices_begin();
        it != hierarchy[0]->finite_vertices_end(); ++it) {
     result = result && ( it->down() == 0 );
   }
 
   //verify that other levels has down pointer and reciprocal link is fine
   for(unsigned int i = 1; i < ag_hierarchy_2__maxlevel; ++i) {
-    for( Finite_vertices_iterator it = hierarchy[i]->finite_vertices_begin(); 
-	 it != hierarchy[i]->finite_vertices_end(); ++it) {
+    for( Finite_vertices_iterator it = hierarchy[i]->finite_vertices_begin();
+         it != hierarchy[i]->finite_vertices_end(); ++it) {
       result = result && ( &*it == &*(it->down()->up()) );
     }
   }
@@ -235,7 +226,7 @@ insert(const Site_2 &p)
   } while ( fc != fc_start );
 
   if ( s != NEGATIVE ) {
-    typename Apollonius_graph_base::Edge_circulator ec_start = 
+    typename Apollonius_graph_base::Edge_circulator ec_start =
       hierarchy[0]->incident_edges(vnear[0]);
     typename Apollonius_graph_base::Edge_circulator ec = ec_start;
 
@@ -244,7 +235,7 @@ insert(const Site_2 &p)
     do {
       e = *ec;
       interior_in_conflict = edge_interior(e, p, false);
-      
+
       if ( interior_in_conflict ) { break; }
       ++ec;
     } while ( ec != ec_start );
@@ -269,43 +260,43 @@ insert(const Site_2 &p)
   }
 
   initialize_conflict_region(start_f, l);
-  expand_conflict_region(start_f, p, l, fm, v_hidden, NULL);
+  expand_conflict_region(start_f, p, l, fm, v_hidden, nullptr);
   n_hidden = v_hidden.size();
 
   if ( n_hidden != 0 ) {
     std::size_t n_non_hidden = this->number_of_vertices() - n_hidden;
     if ( n_non_hidden < 2 ) {
       for(unsigned int i = 1; i < ag_hierarchy_2__maxlevel; ++i) {
-	hierarchy[i]->clear();
+        hierarchy[i]->clear();
       }
 
       if ( n_non_hidden == 1 ) {
-	Vertex_handle non_hidden;
-	Finite_vertices_iterator vit = this->finite_vertices_begin();
-	do {
-	  non_hidden = Vertex_handle(vit);
-	  ++vit;
-	} while ( v_hidden.find(non_hidden) != v_hidden.end() );
+        Vertex_handle non_hidden;
+        Finite_vertices_iterator vit = this->finite_vertices_begin();
+        do {
+          non_hidden = Vertex_handle(vit);
+          ++vit;
+        } while ( v_hidden.find(non_hidden) != v_hidden.end() );
 
-	non_hidden->set_up( Vertex_handle() );
+        non_hidden->set_up( Vertex_handle() );
       }
     } else {
       typename Apollonius_graph_base::Vertex_map::iterator it;
       for (it = v_hidden.begin(); it != v_hidden.end(); it++) {
-	Vertex_handle v = (*it).first;
-	Vertex_handle u = v->up();
-	if ( u != Vertex_handle() ) {
-	  v = u;
-	  u = v->up();
-	  unsigned int l = 1;
-	  while ( true ) {
-	    hierarchy[l++]->remove(v);
-	    if ( u == Vertex_handle() ) break; 
-	    if(l >= ag_hierarchy_2__maxlevel) { break; }
-	    v = u;
-	    u = v->up();
-	  }
-	}
+        Vertex_handle v = (*it).first;
+        Vertex_handle u = v->up();
+        if ( u != Vertex_handle() ) {
+          v = u;
+          u = v->up();
+          unsigned int l = 1;
+          while ( true ) {
+            hierarchy[l++]->remove(v);
+            if ( u == Vertex_handle() ) break;
+            if(l >= ag_hierarchy_2__maxlevel) { break; }
+            v = u;
+            u = v->up();
+          }
+        }
       }
     }
   }
@@ -324,7 +315,7 @@ insert(const Site_2 &p)
   if ( n_hidden != 0 ) {
     nearest_neighbor(p.point(), vnear);
   }
-      
+
   int level = 1;
   while (level <= vertex_level ){
     vertex = hierarchy[level]->insert(p, vnear[level]);
@@ -337,12 +328,12 @@ insert(const Site_2 &p)
 }
 
 template<class Gt, class Agds, class LTag>
-void 
+void
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 remove(Vertex_handle v)
 {
-  CGAL_triangulation_precondition( v != Vertex_handle());
-  CGAL_triangulation_precondition( !is_infinite(v));
+  CGAL_precondition( v != Vertex_handle());
+  CGAL_precondition( !is_infinite(v));
 
   // get the hidden circles
   typename Apollonius_graph_base::Site_list wp_list;
@@ -359,7 +350,7 @@ remove(Vertex_handle v)
   unsigned int l = 0;
   while ( true ) {
     hierarchy[l++]->remove(v);
-    if ( u == Vertex_handle() ) break; 
+    if ( u == Vertex_handle() ) break;
     if(l >= ag_hierarchy_2__maxlevel) break;
     v = u;
     u = v->up();
@@ -370,7 +361,7 @@ remove(Vertex_handle v)
 
 
 template<class Gt, class Agds, class LTag>
-typename Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::Vertex_handle 
+typename Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::Vertex_handle
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 nearest_neighbor(const Point_2& p) const
 {
@@ -402,14 +393,14 @@ template<class Gt, class Agds, class LTag>
 void
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 nearest_neighbor(const Point_2& p,
-		 Vertex_handle vnear[ag_hierarchy_2__maxlevel]) const
+                 Vertex_handle vnear[ag_hierarchy_2__maxlevel]) const
 {
   Vertex_handle nearest = 0;
   unsigned int level  = ag_hierarchy_2__maxlevel;
 
   // find the highest level with enough vertices
-  while ( hierarchy[--level]->number_of_vertices() 
-	  < ag_hierarchy_2__minsize ) {
+  while ( hierarchy[--level]->number_of_vertices()
+          < ag_hierarchy_2__minsize ) {
     if ( !level ) break;  // do not go below 0
   }
   for (unsigned int i = level+1; i < ag_hierarchy_2__maxlevel; ++i) {
@@ -418,7 +409,7 @@ nearest_neighbor(const Point_2& p,
 
   while ( level > 0 ) {
     vnear[level] = nearest =
-      hierarchy[level]->nearest_neighbor(p, nearest);  
+      hierarchy[level]->nearest_neighbor(p, nearest);
 
     CGAL_assertion( !hierarchy[level]->is_infinite(vnear[level]) );
     // go at the same vertex on level below
@@ -433,7 +424,7 @@ template<class Gt, class Agds, class LTag>
 int
 Apollonius_graph_hierarchy_2<Gt,Agds,LTag>::
 random_level()
-{  
+{
   boost::geometric_distribution<> proba(1.0/ag_hierarchy_2__ratio);
   boost::variate_generator<boost::rand48&, boost::geometric_distribution<> > die(random, proba);
 
@@ -460,7 +451,7 @@ file_input(std::istream& is)
     V[i].resize(hierarchy[i]->number_of_vertices());
     int j = 0;
     for (Finite_vertices_iterator vit = hierarchy[i]->finite_vertices_begin();
-	 vit != hierarchy[i]->finite_vertices_end(); ++vit, ++j) {
+         vit != hierarchy[i]->finite_vertices_end(); ++vit, ++j) {
       V[i][j] = vit;
     }
   }
@@ -493,7 +484,7 @@ file_output(std::ostream& os) const
   // write each level of the hierarchy
   for (unsigned int i = 0; i < ag_hierarchy_2__maxlevel; ++i) {
     hierarchy[i]->file_output(os);
-    if ( is_ascii(os) ) { os << std::endl << std::endl; }
+    if ( IO::is_ascii(os) ) { os << std::endl << std::endl; }
   }
 
   Vertex_map* V = new Vertex_map[ag_hierarchy_2__maxlevel];
@@ -502,7 +493,7 @@ file_output(std::ostream& os) const
   for (unsigned int i = 0; i < ag_hierarchy_2__maxlevel; ++i) {
     int inum = 0;
     for (Finite_vertices_iterator vit = hierarchy[i]->finite_vertices_begin();
-	 vit != hierarchy[i]->finite_vertices_end(); ++vit) {
+         vit != hierarchy[i]->finite_vertices_end(); ++vit) {
       V[i][vit] = inum++;
     }
   }
@@ -513,38 +504,38 @@ file_output(std::ostream& os) const
   // create the map of up and down pointers
   for (unsigned int i = 0; i < ag_hierarchy_2__maxlevel; ++i) {
     for (Finite_vertices_iterator vit = hierarchy[i]->finite_vertices_begin();
-	 vit != hierarchy[i]->finite_vertices_end(); ++vit) {
+         vit != hierarchy[i]->finite_vertices_end(); ++vit) {
       if ( vit->up() != Vertex_handle() ) {
-	V_up[i][vit] = V[i+1][vit->up()];
+        V_up[i][vit] = V[i+1][vit->up()];
       } else {
-	V_up[i][vit] = -1;
+        V_up[i][vit] = -1;
       }
 
       if ( vit->down() != Vertex_handle() ) {
-	V_down[i][vit] = V[i-1][vit->down()];
+        V_down[i][vit] = V[i-1][vit->down()];
       } else {
-	V_down[i][vit] = -1;
+        V_down[i][vit] = -1;
       }
     }
   }
 
   // write up and down pointer info
-  if ( is_ascii(os) ) { os << std::endl << std::endl; }
+  if ( IO::is_ascii(os) ) { os << std::endl << std::endl; }
   for (unsigned int i = 0; i < ag_hierarchy_2__maxlevel; ++i) {
     os << i;
-    if ( is_ascii(os) ) { os << " "; }
+    if ( IO::is_ascii(os) ) { os << " "; }
     os << hierarchy[i]->number_of_vertices();
-    if ( is_ascii(os) ) { os << std::endl; }
+    if ( IO::is_ascii(os) ) { os << std::endl; }
     for (Finite_vertices_iterator vit = hierarchy[i]->finite_vertices_begin();
-	 vit != hierarchy[i]->finite_vertices_end(); ++vit) {
+         vit != hierarchy[i]->finite_vertices_end(); ++vit) {
       os << V[i][vit];
-      if ( is_ascii(os) ) { os << " "; }
+      if ( IO::is_ascii(os) ) { os << " "; }
       os << V_down[i][vit];
-      if ( is_ascii(os) ) { os << " "; }
+      if ( IO::is_ascii(os) ) { os << " "; }
       os << V_up[i][vit];
-      if ( is_ascii(os) ) { os << std::endl; }
+      if ( IO::is_ascii(os) ) { os << std::endl; }
     }
-    if ( is_ascii(os) ) { os << std::endl << std::endl; }
+    if ( IO::is_ascii(os) ) { os << std::endl << std::endl; }
   }
 
   delete[] V;
