@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_counting_traits_2.h $
-// $Id: Arr_counting_traits_2.h 5b35b2f 2018-04-07T16:03:32+03:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_counting_traits_2.h $
+// $Id: Arr_counting_traits_2.h ae3e2b62874 2023-03-31T11:10:52+02:00 Laurent Rineau
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel      <efif@post.tau.ac.il>
 //            Eric Berberich <ericb@post.tau.ac.il>
@@ -30,14 +21,15 @@
  * A counting traits-class for the arrangement package.
  * This is a meta-traits class. It is parameterized with another traits class
  * and inherits from it. For each traits method it maintains a counter that
- * counts the number of invokations into the method.
+ * counts the number of invocations into the method.
  */
 
 #include <iostream>
 #include <string.h>
+#include <atomic>
+#include <array>
 
 #include <CGAL/basic.h>
-#include <CGAL/atomic.h>
 #include <CGAL/Arr_enums.h>
 #include <CGAL/Arr_tags.h>
 
@@ -46,7 +38,7 @@ namespace CGAL {
 /*! \class
  * A model of the ArrangementTraits_2 concept that counts the methods invoked.
  */
-template <class Base_traits>
+template <typename Base_traits>
 class Arr_counting_traits_2 : public Base_traits {
 public:
   enum Operation_id {
@@ -81,9 +73,6 @@ public:
     PARAMETER_SPACE_IN_Y_CURVE_OP,
     IS_ON_Y_IDENTIFICATION_POINT_OP,
     IS_ON_Y_IDENTIFICATION_CURVE_OP,
-    COMPARE_X_AT_LIMIT_POINT_CURVE_END_OP,
-    COMPARE_X_AT_LIMIT_CURVE_ENDS_OP,
-    COMPARE_X_NEAR_LIMIT_OP,
     COMPARE_X_ON_BOUNDARY_POINTS_OP,
     COMPARE_X_ON_BOUNDARY_POINT_CURVE_END_OP,
     COMPARE_X_ON_BOUNDARY_CURVE_ENDS_OP,
@@ -96,134 +85,124 @@ public:
   typedef Arr_counting_traits_2<Base>           Self;
 
   /*! Construct default */
-  Arr_counting_traits_2() : Base()
+  template<typename ... Args>
+  Arr_counting_traits_2(Args ... args) :
+    Base(args...)
   {
     clear_counters();
     increment();
   }
 
-  /*! Construct copy */
-  Arr_counting_traits_2(const Arr_counting_traits_2& other) : Base(other)
-  {
-    clear_counters();
-    increment();
-  }
+  /*! Disable copy constructor.
+   */
+  Arr_counting_traits_2(const Arr_counting_traits_2&) = delete;
 
   /*! Obtain the counter of the given operation */
-  unsigned int count(Operation_id id) const
+  size_t count(Operation_id id) const
   { return m_counters[id]; }
 
-  unsigned int count_compare_x() const
+  size_t count_compare_x() const
   { return m_counters[COMPARE_X_OP]; }
 
-  unsigned int count_compare_xy() const
+  size_t count_compare_xy() const
   { return m_counters[COMPARE_XY_OP]; }
 
-  unsigned int count_construct_min_vertex() const
+  size_t count_construct_min_vertex() const
   { return m_counters[CONSTRUCT_MIN_VERTEX_OP]; }
 
-  unsigned int count_construct_max_vertex() const
+  size_t count_construct_max_vertex() const
   { return m_counters[CONSTRUCT_MAX_VERTEX_OP]; }
 
-  unsigned int count_is_vertical() const
+  size_t count_is_vertical() const
   { return m_counters[IS_VERTICAL_OP]; }
 
-  unsigned int count_compare_y_at_x() const
+  size_t count_compare_y_at_x() const
   { return m_counters[COMPARE_Y_AT_X_OP]; }
 
-  unsigned int count_equal_points() const
+  size_t count_equal_points() const
   { return m_counters[EQUAL_POINTS_OP]; }
 
-  unsigned int count_equal_curves() const
+  size_t count_equal_curves() const
   { return m_counters[EQUAL_CURVES_OP]; }
 
-  unsigned int count_compare_y_at_x_left() const
+  size_t count_compare_y_at_x_left() const
   { return m_counters[COMPARE_Y_AT_X_LEFT_OP]; }
 
-  unsigned int count_compare_y_at_x_right() const
+  size_t count_compare_y_at_x_right() const
   { return m_counters[COMPARE_Y_AT_X_RIGHT_OP]; }
 
-  unsigned int count_make_x_monotone() const
+  size_t count_make_x_monotone() const
   { return m_counters[MAKE_X_MONOTONE_OP]; }
 
-  unsigned int count_split() const
+  size_t count_split() const
   { return m_counters[SPLIT_OP]; }
 
-  unsigned int count_intersect() const
+  size_t count_intersect() const
   { return m_counters[INTERSECT_OP]; }
 
-  unsigned int count_are_mergeable() const
+  size_t count_are_mergeable() const
   { return m_counters[ARE_MERGEABLE_OP]; }
 
-  unsigned int count_merge() const
+  size_t count_merge() const
   { return m_counters[MERGE_OP]; }
 
-  unsigned int count_construct_opposite() const
+  size_t count_construct_opposite() const
   { return m_counters[CONSTRUCT_OPPOSITE_OP]; }
 
-  unsigned int count_compare_endpoints_xy() const
+  size_t count_compare_endpoints_xy() const
   { return m_counters[COMPARE_ENDPOINTS_XY_OP]; }
 
   // left-right
 
-  unsigned int count_parameter_space_in_x_curve_end() const
+  size_t count_parameter_space_in_x_curve_end() const
   { return m_counters[PARAMETER_SPACE_IN_X_CURVE_END_OP]; }
 
-  unsigned int count_parameter_space_in_x_curve() const
+  size_t count_parameter_space_in_x_curve() const
   { return m_counters[PARAMETER_SPACE_IN_X_CURVE_OP]; }
 
-  unsigned int count_parameter_space_in_x_point() const
+  size_t count_parameter_space_in_x_point() const
   { return m_counters[PARAMETER_SPACE_IN_X_POINT_OP]; }
 
-  unsigned int count_is_on_x_identification_point() const
+  size_t count_is_on_x_identification_point() const
   { return m_counters[IS_ON_X_IDENTIFICATION_POINT_OP]; }
 
-  unsigned int count_is_on_x_identification_curve() const
+  size_t count_is_on_x_identification_curve() const
   { return m_counters[IS_ON_X_IDENTIFICATION_CURVE_OP]; }
 
-  unsigned int count_compare_y_on_boundary() const
+  size_t count_compare_y_on_boundary() const
   { return m_counters[COMPARE_Y_ON_BOUNDARY_OP]; }
 
-  unsigned int count_compare_y_near_boundary() const
+  size_t count_compare_y_near_boundary() const
   { return m_counters[COMPARE_Y_NEAR_BOUNDARY_OP]; }
 
 
   // bottom-top
 
-  unsigned int count_parameter_space_in_y_curve_end() const
+  size_t count_parameter_space_in_y_curve_end() const
   { return m_counters[PARAMETER_SPACE_IN_Y_CURVE_END_OP]; }
 
-  unsigned int count_parameter_space_in_y_curve() const
+  size_t count_parameter_space_in_y_curve() const
   { return m_counters[PARAMETER_SPACE_IN_Y_CURVE_OP]; }
 
-  unsigned int count_parameter_space_in_y_point() const
+  size_t count_parameter_space_in_y_point() const
   { return m_counters[PARAMETER_SPACE_IN_Y_POINT_OP]; }
 
-  unsigned int count_is_on_y_identification_point() const
+  size_t count_is_on_y_identification_point() const
   { return m_counters[IS_ON_Y_IDENTIFICATION_POINT_OP]; }
 
-  unsigned int count_is_on_y_identification_curve() const
+  size_t count_is_on_y_identification_curve() const
   { return m_counters[IS_ON_Y_IDENTIFICATION_CURVE_OP]; }
 
-  unsigned int count_compare_x_at_limit_point_curve_end() const
-  { return m_counters[COMPARE_X_AT_LIMIT_POINT_CURVE_END_OP]; }
-
-  unsigned int count_compare_x_at_limit_curve_ends() const
-  { return m_counters[COMPARE_X_AT_LIMIT_CURVE_ENDS_OP]; }
-
-  unsigned int count_compare_x_near_limit() const
-  { return m_counters[COMPARE_X_NEAR_LIMIT_OP]; }
-
-  unsigned int count_compare_x_on_boundary_points() const
+  size_t count_compare_x_on_boundary_points() const
   { return m_counters[COMPARE_X_ON_BOUNDARY_POINTS_OP]; }
 
-  unsigned int count_compare_x_on_boundary_point_curve_end() const
+  size_t count_compare_x_on_boundary_point_curve_end() const
   { return m_counters[COMPARE_X_ON_BOUNDARY_POINT_CURVE_END_OP]; }
 
-  unsigned int count_compare_x_on_boundary_curve_ends() const
+  size_t count_compare_x_on_boundary_curve_ends() const
   { return m_counters[COMPARE_X_ON_BOUNDARY_CURVE_ENDS_OP]; }
 
-  unsigned int count_compare_x_near_boundary() const
+  size_t count_compare_x_near_boundary() const
   { return m_counters[COMPARE_X_NEAR_BOUNDARY_OP]; }
 
   /// \name Types and functors inherited from the base
@@ -251,11 +230,11 @@ public:
   class Compare_x_2 {
   private:
     typename Base::Compare_x_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_x_2(const Base* base, unsigned int& counter) :
+    Compare_x_2(const Base* base, size_t& counter) :
       m_object(base->compare_x_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -267,11 +246,11 @@ public:
   class Compare_xy_2 {
   private:
     typename Base::Compare_xy_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_xy_2(const Base* base, unsigned int& counter) :
+    Compare_xy_2(const Base* base, size_t& counter) :
       m_object(base->compare_xy_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -283,11 +262,11 @@ public:
   class Construct_min_vertex_2 {
   private:
     typename Base::Construct_min_vertex_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Construct_min_vertex_2(const Base* base, unsigned int& counter) :
+    Construct_min_vertex_2(const Base* base, size_t& counter) :
       m_object(base->construct_min_vertex_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -299,11 +278,11 @@ public:
   class Construct_max_vertex_2 {
   private:
     typename Base::Construct_max_vertex_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Construct_max_vertex_2(const Base* base, unsigned int& counter) :
+    Construct_max_vertex_2(const Base* base, size_t& counter) :
       m_object(base->construct_max_vertex_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -315,11 +294,11 @@ public:
   class Is_vertical_2 {
   private:
     typename Base::Is_vertical_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Is_vertical_2(const Base* base, unsigned int& counter) :
+    Is_vertical_2(const Base* base, size_t& counter) :
       m_object(base->is_vertical_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -333,11 +312,11 @@ public:
   class Compare_y_at_x_2 {
   private:
     typename Base::Compare_y_at_x_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_at_x_2(const Base* base, unsigned int& counter) :
+    Compare_y_at_x_2(const Base* base, size_t& counter) :
       m_object(base->compare_y_at_x_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -352,12 +331,12 @@ public:
   class Equal_2 {
   private:
     typename Base::Equal_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
+    size_t& m_counter1;
+    size_t& m_counter2;
 
   public:
     /*! Construct */
-    Equal_2(const Base* base, unsigned int& counter1, unsigned int& counter2) :
+    Equal_2(const Base* base, size_t& counter1, size_t& counter2) :
       m_object(base->equal_2_object()),
       m_counter1(counter1), m_counter2(counter2)
     {}
@@ -378,11 +357,11 @@ public:
   class Compare_y_at_x_left_2 {
   private:
     typename Base::Compare_y_at_x_left_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_at_x_left_2(const Base* base, unsigned int& counter) :
+    Compare_y_at_x_left_2(const Base* base, size_t& counter) :
       m_object(base->compare_y_at_x_left_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -398,11 +377,11 @@ public:
   class Compare_y_at_x_right_2 {
   private:
     typename Base::Compare_y_at_x_right_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_at_x_right_2(const Base* base, unsigned int& counter) :
+    Compare_y_at_x_right_2(const Base* base, size_t& counter) :
       m_object(base->compare_y_at_x_right_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -412,19 +391,27 @@ public:
     { ++m_counter; return m_object(xc1, xc2, p); }
   };
 
-  /*! A functor that divides a curve into x-monotone curves. */
+  /*! \class Make_x_monotone_2
+   * A functor that subdivides a curve into x-monotone curves.
+   */
   class Make_x_monotone_2 {
   private:
     typename Base::Make_x_monotone_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Make_x_monotone_2(const Base* base, unsigned int& counter) :
+    Make_x_monotone_2(const Base* base, size_t& counter) :
       m_object(base->make_x_monotone_2_object()), m_counter(counter) {}
 
-    /*! Operate */
-    template<class OutputIterator>
+    /*! Subdivide a given curve into x-monotone subcurves and insert them into
+     * a given output iterator.
+     * \param cv the curve.
+     * \param oi the output iterator for the result. Its value type is a variant
+     *           that wraps Point_2 or an X_monotone_curve_2 objects.
+     * \return The past-the-end iterator.
+     */
+    template <typename OutputIterator>
     OutputIterator operator()(const Curve_2& cv, OutputIterator oi) const
     { ++m_counter; return m_object(cv, oi); }
   };
@@ -433,11 +420,11 @@ public:
   class Split_2 {
   private:
     typename Base::Split_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Split_2(const Base* base, unsigned int& counter) :
+    Split_2(const Base* base, size_t& counter) :
       m_object(base->split_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -450,15 +437,15 @@ public:
   class Intersect_2 {
   private:
     typename Base::Intersect_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Intersect_2(const Base* base, unsigned int& counter) :
+    Intersect_2(const Base* base, size_t& counter) :
       m_object(base->intersect_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    template<class OutputIterator>
+    template <typename OutputIterator>
     OutputIterator operator()(const X_monotone_curve_2& xc1,
                               const X_monotone_curve_2& xc2,
                               OutputIterator oi) const
@@ -469,11 +456,11 @@ public:
   class Are_mergeable_2 {
   private:
     typename Base::Are_mergeable_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Are_mergeable_2(const Base* base, unsigned int& counter) :
+    Are_mergeable_2(const Base* base, size_t& counter) :
       m_object(base->are_mergeable_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -486,11 +473,11 @@ public:
   class Merge_2 {
   private:
     typename Base::Merge_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Merge_2(const Base* base, unsigned int& counter) :
+    Merge_2(const Base* base, size_t& counter) :
       m_object(base->merge_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -504,11 +491,11 @@ public:
   class Construct_opposite_2 {
   private:
     typename Base::Construct_opposite_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Construct_opposite_2(const Base* base, unsigned int& counter) :
+    Construct_opposite_2(const Base* base, size_t& counter) :
       m_object(base->construct_opposite_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -522,11 +509,11 @@ public:
   class Compare_endpoints_xy_2 {
   private:
     typename Base::Compare_endpoints_xy_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_endpoints_xy_2(const Base* base, unsigned int& counter) :
+    Compare_endpoints_xy_2(const Base* base, size_t& counter) :
       m_object(base->compare_endpoints_xy_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -542,18 +529,19 @@ public:
   class Parameter_space_in_x_2 {
   private:
     typename Base::Parameter_space_in_x_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
-    unsigned int& m_counter3;
+    size_t& m_counter1;
+    size_t& m_counter2;
+    size_t& m_counter3;
 
   public:
     /*! Construct */
-    Parameter_space_in_x_2(const Base* base, unsigned int& counter1,
-                           unsigned int& counter2, unsigned int& counter3) :
+    Parameter_space_in_x_2(const Base* base, size_t& counter1,
+                           size_t& counter2, size_t& counter3) :
       m_object(base->parameter_space_in_x_2_object()),
       m_counter1(counter1),
       m_counter2(counter2),
-      m_counter3(counter3) {}
+      m_counter3(counter3)
+    {}
 
     /*! Operate */
     Arr_parameter_space operator()(const X_monotone_curve_2& xc,
@@ -565,11 +553,9 @@ public:
     Arr_parameter_space operator()(const Point_2& p) const
     { ++m_counter2; return m_object(p); }
 
-
     /*! Operate */
     Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
     { ++m_counter3; return m_object(xc); }
-
   };
 
   /*! A functor that determines whether a point or a curve lies on an
@@ -578,26 +564,25 @@ public:
   class Is_on_x_identification_2 {
   private:
     typename Base::Is_on_x_identificiation_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
+    size_t& m_counter1;
+    size_t& m_counter2;
 
   public:
     /*! Construct */
     Is_on_x_identification_2(const Base* base,
-                             unsigned int& counter1, unsigned int& counter2) :
+                             size_t& counter1, size_t& counter2) :
       m_object(base->is_on_x_identificiation_2_object()),
       m_counter1(counter1),
-      m_counter2(counter2) {}
+      m_counter2(counter2)
+    {}
 
     /*! Operate */
     Arr_parameter_space operator()(const Point_2& p) const
     { ++m_counter1; return m_object(p); }
 
-
     /*! Operate */
     Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
     { ++m_counter2; return m_object(xc); }
-
   };
 
   /*! A functor that compares the y-coordinate of two given points
@@ -606,11 +591,11 @@ public:
   class Compare_y_on_boundary_2 {
   private:
     typename Base::Compare_y_on_boundary_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_on_boundary_2(const Base* base, unsigned int& counter) :
+    Compare_y_on_boundary_2(const Base* base, size_t& counter) :
       m_object(base->compare_y_on_boundary_2_object()),
       m_counter(counter)
     {}
@@ -626,11 +611,11 @@ public:
   class Compare_y_near_boundary_2 {
   private:
     typename Base::Compare_y_near_boundary_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_near_boundary_2(const Base* base, unsigned int& counter) :
+    Compare_y_near_boundary_2(const Base* base, size_t& counter) :
       m_object(base->compare_y_near_boundary_2_object()), m_counter(counter) {}
 
     /*! Operate */
@@ -648,18 +633,19 @@ public:
   class Parameter_space_in_y_2 {
   private:
     typename Base::Parameter_space_in_y_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
-    unsigned int& m_counter3;
+    size_t& m_counter1;
+    size_t& m_counter2;
+    size_t& m_counter3;
 
   public:
     /*! Construct */
-    Parameter_space_in_y_2(const Base* base, unsigned int& counter1,
-                           unsigned int& counter2, unsigned int& counter3) :
+    Parameter_space_in_y_2(const Base* base, size_t& counter1,
+                           size_t& counter2, size_t& counter3) :
       m_object(base->parameter_space_in_y_2_object()),
       m_counter1(counter1),
       m_counter2(counter2),
-      m_counter3(counter3) {}
+      m_counter3(counter3)
+    {}
 
     /*! Operate */
     Arr_parameter_space operator()(const X_monotone_curve_2& xc,
@@ -673,7 +659,6 @@ public:
     /*! Operate */
     Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
     { ++m_counter3; return m_object(xc); }
-
   };
 
   /*! A functor that determines whether a point or a curve lies on an
@@ -682,16 +667,17 @@ public:
   class Is_on_y_identification_2 {
   private:
     typename Base::Is_on_y_identificiation_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
+    size_t& m_counter1;
+    size_t& m_counter2;
 
   public:
     /*! Construct */
     Is_on_y_identification_2(const Base* base,
-                             unsigned int& counter1, unsigned int& counter2) :
+                             size_t& counter1, size_t& counter2) :
       m_object(base->is_on_y_identificiation_2_object()),
       m_counter1(counter1),
-      m_counter2(counter2) {}
+      m_counter2(counter2)
+    {}
 
     /*! Operate */
     Arr_parameter_space operator()(const Point_2& p) const
@@ -701,61 +687,6 @@ public:
     /*! Operate */
     Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
     { ++m_counter2; return m_object(xc); }
-
-  };
-
-  /*! A functor that compares the x-limits of curve ends on the
-   * boundary of the parameter space.
-   */
-  class Compare_x_at_limit_2 {
-  private:
-    typename Base::Compare_x_at_limit_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
-
-  public:
-    /*! Construct */
-    Compare_x_at_limit_2(const Base* base,
-                         unsigned int& counter1, unsigned int& counter2) :
-      m_object(base->compare_x_at_limit_2_object()),
-      m_counter1(counter1),
-      m_counter2(counter2) {}
-
-    /*! Operate */
-    Comparison_result operator()(const Point_2& p,
-                                 const X_monotone_curve_2& xc,
-                                 Arr_curve_end ce) const
-    { ++m_counter1; return m_object(p, xc, ce); }
-
-    /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2& xc1,
-                                 Arr_curve_end ce1,
-                                 const X_monotone_curve_2& xc2,
-                                 Arr_curve_end ce2) const
-    { ++m_counter2; return m_object(xc1, ce1, xc2, ce2); }
-  };
-
-
-  /*! A functor that compares the x-coordinates of curve ends near the
-   * boundary of the parameter space.
-   */
-  class Compare_x_near_limit_2 {
-  private:
-    typename Base::Compare_x_near_limit_2 m_object;
-    unsigned int& m_counter;
-
-  public:
-    /*! Construct */
-    Compare_x_near_limit_2(const Base* base, unsigned int& counter) :
-      m_object(base->compare_x_near_limit_2_object()),
-      m_counter(counter) {}
-
-
-    /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2& xc1,
-                                 const X_monotone_curve_2& xc2,
-                                 Arr_curve_end ce) const
-    { ++m_counter; return m_object(xc1, xc2, ce); }
   };
 
   /*! A functor that compares the x-coordinate of two given points
@@ -764,14 +695,14 @@ public:
   class Compare_x_on_boundary_2 {
   private:
     typename Base::Compare_x_on_boundary_2 m_object;
-    unsigned int& m_counter1;
-    unsigned int& m_counter2;
-    unsigned int& m_counter3;
+    size_t& m_counter1;
+    size_t& m_counter2;
+    size_t& m_counter3;
 
   public:
     /*! Construct */
-  Compare_x_on_boundary_2(const Base* base,  unsigned int& counter1,
-                          unsigned int& counter2, unsigned int& counter3 ) :
+  Compare_x_on_boundary_2(const Base* base,  size_t& counter1,
+                          size_t& counter2, size_t& counter3 ) :
       m_object(base->compare_x_on_boundary_2_object()),
       m_counter1(counter1),
       m_counter2(counter2),
@@ -794,7 +725,6 @@ public:
                                  const X_monotone_curve_2& xcv2,
                                  Arr_curve_end ce2) const
     { ++m_counter3; return m_object(xcv1, ce1, xcv2, ce2); }
-
   };
 
   /*! A functor that compares the x-coordinates of curve ends near the
@@ -803,15 +733,14 @@ public:
   class Compare_x_near_boundary_2 {
   private:
     typename Base::Compare_x_near_boundary_2 m_object;
-    unsigned int& m_counter;
+    size_t& m_counter;
 
   public:
     /*! Construct */
-    Compare_x_near_boundary_2(const Base* base,
-                              unsigned int& counter) :
+    Compare_x_near_boundary_2(const Base* base, size_t& counter) :
       m_object(base->compare_x_near_boundary_2_object()),
-      m_counter(counter) {}
-
+      m_counter(counter)
+    {}
 
     /*! Operate */
     Comparison_result operator()(const X_monotone_curve_2& xc1,
@@ -922,17 +851,6 @@ public:
     );
   }
 
-  Compare_x_at_limit_2 compare_x_at_limit_2_object() const
-  {
-    return
-      Compare_x_at_limit_2(this,
-                           m_counters[COMPARE_X_AT_LIMIT_POINT_CURVE_END_OP],
-                           m_counters[COMPARE_X_AT_LIMIT_CURVE_ENDS_OP]);
-  }
-
-  Compare_x_near_limit_2 compare_x_near_limit_2_object() const
-  { return Compare_x_near_limit_2(this, m_counters[COMPARE_X_NEAR_LIMIT_OP]); }
-
   Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
   {
     return
@@ -954,12 +872,12 @@ public:
    * \param doit indicates whethet to actually inceremnt the counter or not
    * \return the counter at the end of the operation
    */
-  static unsigned int increment(bool doit = true)
+  static size_t increment(bool doit = true)
   {
 #ifdef CGAL_NO_ATOMIC
-    static unsigned int counter;
+    static size_t counter;
 #else
-    static CGAL::cpp11::atomic<unsigned int> counter;
+    static std::atomic<size_t> counter;
 #endif
     if (doit) ++counter;
     return counter;
@@ -967,21 +885,21 @@ public:
 
   /*! Clean all operation counters */
   void clear_counters()
-  { memset(m_counters, 0, sizeof(m_counters)); }
+  { m_counters = {}; }
 
 private:
   /*! The operation counters */
-  mutable unsigned int m_counters[NUMBER_OF_OPERATIONS];
+  mutable std::array<size_t, NUMBER_OF_OPERATIONS> m_counters;
 };
 
-template <class Out_stream, class Base_traits>
+template <typename Out_stream, class Base_traits>
 inline
 Out_stream& operator<<(Out_stream& os,
                        const Arr_counting_traits_2<Base_traits>& traits)
 {
   typedef Arr_counting_traits_2<Base_traits>            Traits;
-  unsigned int sum = 0;
-  unsigned int i;
+  size_t sum = 0;
+  size_t i;
   for (i = 0; i < Traits::NUMBER_OF_OPERATIONS; ++i)
     sum += traits.count(static_cast<typename Traits::Operation_id>(i));
   os << "# of COMPARE_X operation = "
@@ -1044,12 +962,6 @@ Out_stream& operator<<(Out_stream& os,
      << traits.count_is_on_y_identification_point() << std::endl
      << "# of IS_ON_Y_IDENTIFICATION curve operation = "
      << traits.count_is_on_y_identification_curve() << std::endl
-     << "# of COMPARE_X_AT_LIMIT point/curve-end operation = "
-     << traits.count_compare_x_at_limit_point_curve_end() << std::endl
-     << "# of COMPARE_X_AT_LIMIT curve-ends operation = "
-     << traits.count_compare_x_at_limit_curve_ends() << std::endl
-     << "# of COMPARE_X_NEAR_LIMIT operation = "
-     << traits.count_compare_x_near_limit() << std::endl
      << "# of COMPARE_X_ON_BOUNDARY points operation = "
      << traits.count_compare_x_on_boundary_points() << std::endl
      << "# of COMPARE_X_ON_BOUNDARY point/curve-end operation = "
