@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_cache.h $
+// $Id: Bezier_cache.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_cache.h $
-// $Id: Bezier_cache.h e0cb4e4 2018-02-02T07:31:11+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Ron Wein     <wein@post.tau.ac.il>
 
@@ -61,11 +52,11 @@ public:
   /// \name Type definitions for the intersection-point mapping.
   //@{
 
-  /*! \struct Intersection_point_2
+  /*! \struct Intersection_point
    * Representation of an intersection point (in both parameter and physical
    * spaces).
    */
-  struct Intersection_point_2
+  struct Intersection_point
   {
     Algebraic          s;      // The parameter for the first curve.
     Algebraic          t;      // The parameter for the second curve.
@@ -73,7 +64,7 @@ public:
     Algebraic          y;      // The y-coordinate.
 
     /*! Constructor. */
-    Intersection_point_2 (const Algebraic& _s, const Algebraic& _t,
+    Intersection_point (const Algebraic& _s, const Algebraic& _t,
                           const Algebraic& _x, const Algebraic& _y) :
       s(_s), t(_t),
       x(_x), y(_y)
@@ -82,10 +73,12 @@ public:
 
   typedef std::pair<Curve_id, Curve_id>              Curve_pair;
   typedef std::pair<Algebraic, Algebraic>            Parameter_pair;
-  typedef std::list<Intersection_point_2>            Intersection_list;
+  typedef std::list<Intersection_point>            Intersection_list;
   typedef
     typename Intersection_list::const_iterator       Intersection_iter;
 
+  //@}
+
 private:
 
   typedef std::map<Curve_id,
@@ -258,7 +251,7 @@ private:
                              const Polynomial& polyY_1, const Integer& normY_1,
                              const Polynomial& polyX_2, const Integer& normX_2,
                              const Polynomial& polyY_2, const Integer& normY_2,
-                             Parameter_list& s_vals) const;
+                             Parameter_list& s_vals, bool find_out_of_range=false) const;
 
   /*!
    * Compute all s-parameter values of the self intersection of (X(s), Y(s))
@@ -307,7 +300,7 @@ _Bezier_cache<NtTraits>::get_vertical_tangencies
   // such that X'(t) = 0, and store them in the cache.
   Vertical_tangency_list&  vert_tang_list = vert_tang_map[id];
   const Polynomial&        polyX_der = nt_traits.derive (polyX);
-  
+
   nt_traits.compute_polynomial_roots (polyX_der, 0, 1,
                                       std::back_inserter(vert_tang_list));
   return (vert_tang_list);
@@ -385,7 +378,7 @@ _Bezier_cache<NtTraits>::get_intersections
             CGAL::compare (nt_traits.evaluate_at (polyY_1, *t_it),
                            y) == EQUAL)
         {
-          info.first.push_back (Intersection_point_2 (*s_it, *t_it,
+          info.first.push_back (Intersection_point (*s_it, *t_it,
                                                       x / denX, y / denY));
         }
       }
@@ -414,14 +407,14 @@ _Bezier_cache<NtTraits>::get_intersections
 
   do_ovlp = _intersection_params (polyX_2, normX_2, polyY_2, normY_2,
                                   polyX_1, normX_1, polyY_1, normY_1,
-                                  t_vals);
+                                  t_vals, true);
 
   CGAL_assertion (! do_ovlp);
 
   // s-values and t-values reported lie in the range [0,1]. We have
   // to pair them together. Note that the numbers of s-values and t-values
   //can be different as a s-value in [0,1] may correspond to a t-values
-  //outside this range. To make the pairing correct, we choose the one with 
+  //outside this range. To make the pairing correct, we choose the one with
   //less values and look amongst other values the correct one (thus the swapt below).
 
   // Compute all points on (X_1, Y_1) that match an s-value from the list.
@@ -464,21 +457,14 @@ _Bezier_cache<NtTraits>::get_intersections
   const Algebraic           one (1);
   unsigned int              k;
 
-  //pointers are used to set the list pts1_ptr as the one with the less values
-  Point_list* pts1_ptr=&pts1;
-  Point_list* pts2_ptr=&pts2;
-  bool swapt=pts1.size() > pts2.size();
-  if (swapt)
-    std::swap(pts1_ptr,pts2_ptr);
-  
-  for (pit1 = pts1_ptr->begin(); pit1 != pts1_ptr->end(); ++pit1)
+  for (pit1 = pts1.begin(); pit1 != pts1.end(); ++pit1)
   {
     // Construct a vector of distances from the current point to all other
     // points in the pts2 list.
-    const int                     n_pts2 = static_cast<int>(pts2_ptr->size());
+    const int                     n_pts2 = static_cast<int>(pts2.size());
     std::vector<Distance_iter>    dist_vec (n_pts2);
 
-    for (k = 0, pit2 = pts2_ptr->begin(); pit2 != pts2_ptr->end(); k++, ++pit2)
+    for (k = 0, pit2 = pts2.begin(); pit2 != pts2.end(); k++, ++pit2)
     {
       // Compute the approximate distance between the teo current points.
       dx = pit1->app_x - pit2->app_x;
@@ -486,9 +472,9 @@ _Bezier_cache<NtTraits>::get_intersections
 
       dist_vec[k] = Distance_iter (dx*dx + dy*dy, pit2);
     }
-      
+
     // Sort the vector according to the distances from *pit1.
-    std::sort (dist_vec.begin(), dist_vec.end(), 
+    std::sort (dist_vec.begin(), dist_vec.end(),
                Less_distance_iter());
 
     // Go over the vector entries, starting from the most distant from *pit1
@@ -515,7 +501,7 @@ _Bezier_cache<NtTraits>::get_intersections
           pit1->y = pit2->y;
 
         // Remove this point from pts2, as we found a match for it.
-        pts2_ptr->erase (pit2);
+        pts2.erase (pit2);
         found = true;
       }
     }
@@ -535,17 +521,15 @@ _Bezier_cache<NtTraits>::get_intersections
         pit1->y = pit2->y;
 
       // Remove this point from pts2, as we found a match for it.
-      pts2_ptr->erase (pit2);
+      pts2.erase (pit2);
     }
 
     // Check that  s- and t-values both lie in the legal range of [0,1].
-    CGAL_assertion(CGAL::sign (s) != NEGATIVE && CGAL::compare (s, one) != LARGER &&
-                   CGAL::sign (t) != NEGATIVE && CGAL::compare (t, one) != LARGER);
-    
-    if (!swapt)
-      info.first.push_back (Intersection_point_2 (s, t,pit1->x, pit1->y));
-    else
-      info.first.push_back (Intersection_point_2 (t, s,pit1->x, pit1->y));
+    if(CGAL::sign (s) != NEGATIVE && CGAL::compare (s, one) != LARGER &&
+      CGAL::sign (t) != NEGATIVE && CGAL::compare (t, one) != LARGER)
+    {
+      info.first.push_back(Intersection_point(s, t,pit1->x, pit1->y));
+    }
   }
 
   info.second = false;
@@ -589,7 +573,7 @@ bool _Bezier_cache<NtTraits>::_intersection_params
          const Polynomial& polyY_1, const Integer& normY_1,
          const Polynomial& polyX_2, const Integer& normX_2,
          const Polynomial& polyY_2, const Integer& normY_2,
-         Parameter_list& s_vals) const
+         Parameter_list& s_vals, bool find_out_of_range) const
 {
   // Clear the output parameter list.
   if (! s_vals.empty())
@@ -621,7 +605,7 @@ bool _Bezier_cache<NtTraits>::_intersection_params
   // Consruct the bivariate polynomial that corresponds to Equation II.
   const int                degY_2 = nt_traits.degree (polyY_2);
   std::vector<Polynomial>  coeffsY_st (degY_2 < 0 ? 1 : (degY_2 + 1));
-    
+
   for (k = degY_2; k >= 0; k--)
   {
     coeff = nt_traits.get_coefficient (polyY_2, k) * normY_1;
@@ -640,8 +624,12 @@ bool _Bezier_cache<NtTraits>::_intersection_params
   }
 
   // Compute the roots of the resultant polynomial and mark that the curves do
-  // not overlap. The roots we are interested in must be in the interval [0,1].
-  nt_traits.compute_polynomial_roots (res,0,1,std::back_inserter (s_vals));
+  // not overlap. The roots we are interested in are usually in the interval [0,1].
+  if (find_out_of_range)
+    nt_traits.compute_polynomial_roots (res,std::back_inserter (s_vals));
+  else
+    nt_traits.compute_polynomial_roots (res,0,1,std::back_inserter (s_vals));
+
   return (false);
 }
 
@@ -665,7 +653,7 @@ void _Bezier_cache<NtTraits>::_self_intersection_params
   //   II: Y(t) - Y(s) / (t - s) = 0
   //
   Integer                 *coeffs;
-  int                      i, k;
+  int                      i;
 
   // Consruct the bivariate polynomial that corresponds to Equation I.
   // Note that we represent a bivariate polynomial as a vector of univariate
@@ -679,30 +667,28 @@ void _Bezier_cache<NtTraits>::_self_intersection_params
   coeffs = new Integer [degX];
 
   for (i = 0; i < degX; i++)
-  {
-    for (k = i + 1; k < degX; k++)
-      coeffs[k - i - 1] = nt_traits.get_coefficient (polyX, k);
+    coeffs[i] = nt_traits.get_coefficient(polyX, i + 1);
 
-    coeffsX_st[i] = nt_traits.construct_polynomial (coeffs, degX - i - 1);
-  }
+  for (i = 0; i < degX; i++)
+    coeffsX_st[degX - i - 1] =
+        nt_traits.construct_polynomial(coeffs + i, degX - i - 1);
 
   delete[] coeffs;
 
   // Consruct the bivariate polynomial that corresponds to Equation II.
   const int                degY = nt_traits.degree (polyY);
   CGAL_assertion(degY > 0);
-  if (degY <= 0) return; //no self intersection if Y is constant  
+  if (degY <= 0) return; //no self intersection if Y is constant
   std::vector<Polynomial>  coeffsY_st (degY);
-    
+
   coeffs = new Integer [degY];
 
   for (i = 0; i < degY; i++)
-  {
-    for (k = i + 1; k < degY; k++)
-      coeffs[k - i - 1] = nt_traits.get_coefficient (polyY, k);
+    coeffs[i] = nt_traits.get_coefficient(polyY, i + 1);
 
-    coeffsY_st[i] = nt_traits.construct_polynomial (coeffs, degY - i - 1);
-  }
+  for (i = 0; i < degY; i++)
+    coeffsY_st[degY - i - 1] =
+        nt_traits.construct_polynomial(coeffs + i, degY - i - 1);
 
   delete[] coeffs;
 
@@ -739,25 +725,25 @@ _Bezier_cache<NtTraits>::_compute_resultant
 
   std::vector<std::vector<Polynomial> >  mat (dim);
   std::vector <std::size_t>                      exp_fact (dim);
-  
+
   for (i = 0; i < dim; i++)
   {
     mat[i].resize (dim);
     exp_fact[i] = 0;
-    
+
     for (j = 0; j < dim; j++)
       mat[i][j] = zero_poly;
   }
-  
+
   // Initialize it with copies of the two bivariate polynomials.
   for (i = 0; i < n; i++)
     for (j = 0; j <= m; ++j)
       mat[i][i + j] = bp1[j];
-  
+
   for (i = 0; i < m; i++)
     for (j = 0; j <= n;++j)
       mat[n + i][i + j] = bp2[j];
-  
+
   // Perform Gaussian elimination on the Sylvester matrix. The goal is to
   // reach an upper-triangular matrix, whose diagonal elements are mat[0][0]
   // to mat[dim-1][dim-1], such that the determinant of the original matrix
@@ -787,7 +773,7 @@ _Bezier_cache<NtTraits>::_compute_resultant
       // If the current diagonal value is a zero polynomial, try to replace
       // the current i'th row with a row with a higher index k, such that
       // mat[k][i] is not a zero polynomial.
-      
+
       found_row = false;
       for (k = i + 1; k < dim; k++)
       {
@@ -797,7 +783,7 @@ _Bezier_cache<NtTraits>::_compute_resultant
           break;
         }
       }
-      
+
       if (found_row)
       {
         // Swap the i'th and the k'th rows (note that we start from the i'th
@@ -809,7 +795,7 @@ _Bezier_cache<NtTraits>::_compute_resultant
           mat[i][j] = mat[k][j];
           mat[k][j] = value;
         }
-        
+
         // Swapping two rows should change the sign of the determinant.
         // We therefore swap the sign of the normalization factor.
         sign_fact = -sign_fact;
@@ -821,7 +807,7 @@ _Bezier_cache<NtTraits>::_compute_resultant
         return (mat[i][i]);
       }
     }
-    
+
     // Zero the whole i'th column of the following rows.
     for (k = i + 1; k < dim; k++)
     {
@@ -829,14 +815,14 @@ _Bezier_cache<NtTraits>::_compute_resultant
       {
         value = mat[k][i];
         mat[k][i] = zero_poly;
-        
+
         for (j = i + 1; j < dim; j++)
         {
-          mat[k][j] = mat[k][j] * mat[i][i] - mat[i][j] * value; 
+          mat[k][j] = mat[k][j] * mat[i][i] - mat[i][j] * value;
         }
-        
+
         // We multiplied the current row by the i'th diagonal entry, thus
-        // multipling the determinant value by it. We therefore increment
+        // multiplying the determinant value by it. We therefore increment
         // the exponent of mat[i][i] in the normalization factor.
         exp_fact[i] = exp_fact[i] + 1;
       }
@@ -848,7 +834,7 @@ _Bezier_cache<NtTraits>::_compute_resultant
   const Integer    sgn (sign_fact);
   Polynomial       det_factor = nt_traits.construct_polynomial (&sgn, 0);
   Polynomial       diag_prod = mat[dim - 1][dim - 1];
-  
+
   CGAL_assertion (exp_fact [dim - 1] == 0);
   for (i = 0; i+2 <= dim; ++i)
   {
@@ -863,20 +849,20 @@ _Bezier_cache<NtTraits>::_compute_resultant
     {
       diag_prod *= mat[i][i];
     }
-    
+
     for (j = 0; j < exp_fact[i]; j++)
       det_factor *= mat[i][i];
   }
-  
+
   // In case of a trivial normalization factor, just return the product
   // of diagonal elements.
   if (nt_traits.degree(det_factor) == 0)
     return (diag_prod);
-  
+
   // Divide the product of diagonal elements by the normalization factor
   // and obtain the determinant (note that we should have no remainder).
   Polynomial       det, rem;
-  
+
   det = nt_traits.divide (diag_prod, det_factor, rem);
 
   CGAL_assertion (nt_traits.degree(rem) < 0);
