@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_curve_2.h $
-// $Id: Bezier_curve_2.h 769ac1a 2018-01-26T08:14:34+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_curve_2.h $
+// $Id: Bezier_curve_2.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Ron Wein     <wein@post.tau.ac.il>
@@ -117,10 +108,10 @@ public:
   /*! Default constructor. */
   _Bezier_curve_2_rep () :
     _no_self_inter (true),
-    p_polyX(NULL),
-    p_normX(NULL),
-    p_polyY(NULL),
-    p_normY(NULL)
+    p_polyX(nullptr),
+    p_normX(nullptr),
+    p_polyY(nullptr),
+    p_normY(nullptr)
   {}
 
   /*! Copy constructor (isn't really used). */
@@ -128,18 +119,18 @@ public:
     _ctrl_pts(other._ctrl_pts),
     _bbox(other._bbox),
     _no_self_inter(other._no_self_inter),
-    p_polyX(NULL),
-    p_normX(NULL),
-    p_polyY(NULL),
-    p_normY(NULL)
+    p_polyX(nullptr),
+    p_normX(nullptr),
+    p_polyY(nullptr),
+    p_normY(nullptr)
   {
-    if (other.p_polyX != NULL)
+    if (other.p_polyX != nullptr)
       p_polyX = new Polynomial(*(other.p_polyX));
-    if (other.p_polyY != NULL)
+    if (other.p_polyY != nullptr)
       p_polyY = new Polynomial(*(other.p_polyY));
-    if (other.p_normX != NULL)
+    if (other.p_normX != nullptr)
       p_normX = new Integer(*(other.p_normX));
-    if (other.p_normY != NULL)
+    if (other.p_normY != nullptr)
       p_normY = new Integer(*(other.p_normY));
   }
 
@@ -152,10 +143,10 @@ public:
    */
   template <class InputIterator>
   _Bezier_curve_2_rep (InputIterator pts_begin, InputIterator pts_end) :
-    p_polyX(NULL),
-    p_normX(NULL),
-    p_polyY(NULL),
-    p_normY(NULL)
+    p_polyX(nullptr),
+    p_normX(nullptr),
+    p_polyY(nullptr),
+    p_normY(nullptr)
   {
     // Copy the control points and compute their bounding box.
     const int   pts_size = static_cast<int>(std::distance (pts_begin, pts_end));
@@ -171,7 +162,7 @@ public:
 
     for (k = 0; pts_begin != pts_end; ++pts_begin, k++)
     {
-//SL: Acccording to the fact that all operations are based on polynomials
+//SL: According to the fact that all operations are based on polynomials
 //    duplicated control points can be allowed.
 //      // Make sure that we do not have two identical consecutive control
 //      // points.
@@ -218,13 +209,13 @@ public:
   /*! Destructor. */
   ~_Bezier_curve_2_rep ()
   {
-    if (p_polyX != NULL)
+    if (p_polyX != nullptr)
       delete p_polyX;
-    if (p_normX != NULL)
+    if (p_normX != nullptr)
       delete p_normX;
-    if (p_polyY != NULL)
+    if (p_polyY != nullptr)
       delete p_polyY;
-    if (p_normY != NULL)
+    if (p_normY != nullptr)
       delete p_normY;
   }
 
@@ -234,14 +225,14 @@ public:
   /*! Check if the polynomials are already constructed. */
   bool has_polynomials () const
   {
-    return (p_polyX != NULL && p_normX != NULL &&
-            p_polyY != NULL && p_normY != NULL);
+    return (p_polyX != nullptr && p_normX != nullptr &&
+            p_polyY != nullptr && p_normY != nullptr);
   }
 
   /*! Get the polynomial X(t). */
   const Polynomial& x_polynomial () const
   {
-    if (p_polyX == NULL)
+    if (p_polyX == nullptr)
       _construct_polynomials ();
 
     return (*p_polyX);
@@ -250,7 +241,7 @@ public:
   /*! Get the normalizing factor for X(t). */
   const Integer& x_norm () const
   {
-    if (p_normX == NULL)
+    if (p_normX == nullptr)
       _construct_polynomials ();
 
     return (*p_normX);
@@ -259,7 +250,7 @@ public:
   /*! Get the polynomial Y(t). */
   const Polynomial& y_polynomial () const
   {
-    if (p_polyY == NULL)
+    if (p_polyY == nullptr)
       _construct_polynomials ();
 
     return (*p_polyY);
@@ -268,7 +259,7 @@ public:
   /*! Get the normalizing factor for Y(t). */
   const Integer& y_norm () const
   {
-    if (p_normY == NULL)
+    if (p_normY == nullptr)
       _construct_polynomials ();
 
     return (*p_normY);
@@ -432,7 +423,7 @@ public:
   }
 
   /*!
-   * Get an interator for the first control point.
+   * Get an iterator for the first control point.
    */
   Control_point_iterator control_points_begin () const
   {
@@ -440,7 +431,7 @@ public:
   }
 
   /*!
-   * Get a past-the-end interator for control points.
+   * Get a past-the-end iterator for control points.
    */
   Control_point_iterator control_points_end () const
   {
