@@ -2,22 +2,13 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Trapezoidal_decomposition_2_iostream.h $
+// $Id: Trapezoidal_decomposition_2_iostream.h 781f9a29436 2022-11-17T10:25:10+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Trapezoidal_decomposition_2_iostream.h $
-// $Id: Trapezoidal_decomposition_2_iostream.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
-//
-// Author(s)	 : Oren Nechushtan <theoren@math.tau.ac.il>
+// Author(s)         : Oren Nechushtan <theoren@math.tau.ac.il>
 #ifndef CGAL_TRAPEZOIDAL_DECOMPOSITION_2_IOSTREAM_H
 #define CGAL_TRAPEZOIDAL_DECOMPOSITION_2_IOSTREAM_H
 
@@ -32,8 +23,8 @@ namespace CGAL {
 
 template < class Traits>
 std::ostream& operator<<(
-			 std::ostream &out,
-			 const typename Trapezoidal_decomposition_2<Traits>::In_face_iterator& it)
+                         std::ostream &out,
+                         const typename Trapezoidal_decomposition_2<Traits>::In_face_iterator& it)
 {
   out << "In_face_iterator(";
   if (it.operator->()) out << *it; else out <<"end";
@@ -42,21 +33,21 @@ std::ostream& operator<<(
 
 template < class Traits>
 std::ostream& write(
-		    std::ostream &out,const Trapezoidal_decomposition_2<Traits>& td)
+                    std::ostream &out,const Trapezoidal_decomposition_2<Traits>& td)
 {
   return out << td;
 }
 
 template < class Traits>
 std::ostream& operator<<(
-			 std::ostream &out,const Trapezoidal_decomposition_2<Traits>& td)
+                         std::ostream &out,const Trapezoidal_decomposition_2<Traits>& td)
 {
   return write(out,td.dag_root(),td.get_traits());
 }
 
 template < class Traits>
 std::ostream& write(std::ostream &out,const Td_X_trapezoid<Traits>& t,
-		    const Traits& traits,bool validate=true)
+                    const Traits& traits,bool validate=true)
 {
   typedef Trapezoidal_decomposition_2<Traits> TD;
   typedef Td_X_trapezoid<Traits> X_trapezoid;
@@ -73,12 +64,12 @@ std::ostream& write(std::ostream &out,const Td_X_trapezoid<Traits>& t,
   if (!t.is_on_bottom_boundary()) out << t.bottom(); else out << "-oo";
   out << ",";
   if (!t.is_on_top_boundary()) out << t.top(); else out << "+oo";
-  out << ",neighbours(" << std::flush;
-	
-  // debug neighbours equivalence relation
+  out << ",neighbors(" << std::flush;
+
+  // debug neighbors equivalence relation
   int max_size=4+1;
   int null_size=2,size=null_size,i,j;
-	
+
   X_trapezoid* value[] =
     {
       0,
@@ -101,17 +92,17 @@ std::ostream& write(std::ostream &out,const Td_X_trapezoid<Traits>& t,
   for (j=null_size;j<=max_size;j++)
     {
       for (i=0;i<size;i++)
-	if (value[j]==value[i])
-	  {
-	    std::strcat(name[i],"=");
-	    std::strcat(name[i],name[j]);
-	    break;
-	  }
+        if (value[j]==value[i])
+          {
+            std::strcat(name[i],"=");
+            std::strcat(name[i],name[j]);
+            break;
+          }
       if (i==size)
-	{
-	  value[size]=value[j];
-	  std::strcpy(name[size++],name[j]);
-	}
+        {
+          value[size]=value[j];
+          std::strcpy(name[size++],name[j]);
+        }
     }
   if (size==null_size) {out << "none";}
   for(j=null_size;j<size;j++)
@@ -119,52 +110,52 @@ std::ostream& write(std::ostream &out,const Td_X_trapezoid<Traits>& t,
       if (pad) out << " ";
       else pad=true;
       out << name[j];
-      // identify neighbours
+      // identify neighbors
       if (traits.is_td_vertex(t) && value[j])
-	out << "=" << value[j]->top();
+        out << "=" << value[j]->top();
     }
   out << ")" << std::flush;
-	
+
   if (t.is_active())
     {
       if (traits.is_td_trapezoid(t))
-	{
-	  if (t.is_unbounded())
-	    {
-	      out << ",U=";
-	      if (t.is_on_left_boundary())   out << ")";
-	      if (t.is_on_bottom_boundary()) {
-		if (t.is_on_top_boundary())    
-		  out << "/\\/";
-		else 
-		  out << "/\\";
-	      }
-	      else if (t.is_on_top_boundary())    out << "\\/";
-	      if (t.is_on_right_boundary())  out << "(";
-	    }
-	  else
-	    out << ",T";
-	}
+        {
+          if (t.is_unbounded())
+            {
+              out << ",U=";
+              if (t.is_on_left_boundary())   out << ")";
+              if (t.is_on_bottom_boundary()) {
+                if (t.is_on_top_boundary())
+                  out << "/\\/";
+                else
+                  out << "/\\";
+              }
+              else if (t.is_on_top_boundary())    out << "\\/";
+              if (t.is_on_right_boundary())  out << "(";
+            }
+          else
+            out << ",T";
+        }
       else if (traits.is_td_edge(t))
-	out << ",C";
+        out << ",C";
       else // if (t.is_degenerate_point())
-	out << ",P";
+        out << ",P";
     }
   else
     out << ",D";
-	
-  /*	Calling t.is_valid requires the traits to be initialized with the proper 
+
+  /*        Calling t.is_valid requires the traits to be initialized with the proper
     bounding box */
   if (validate)
     {
       if (t.is_valid(&traits))
-	out << ",+";
+        out << ",+";
       else
-	out << ",-";
+        out << ",-";
     }
-	
+
   out << ")" << std::flush;
-	
+
   return out;
 }
 
@@ -186,12 +177,12 @@ std::ostream& operator<<(std::ostream &out,const Td_X_trapezoid<Traits>& t)
   if (!t.is_on_bottom_boundary()) out << t.bottom(); else out << "-oo";
   out << ",";
   if (!t.is_on_top_boundary()) out << t.top(); else out << "+oo";
-  out << ",neighbours(" << std::flush;
-	
-  // debug neighbours equivalence relation
+  out << ",neighbors(" << std::flush;
+
+  // debug neighbors equivalence relation
   int max_size=4+1;
   int null_size=2,size=null_size,i,j;
-	
+
   X_trapezoid* value[] =
     {
       0,
@@ -214,57 +205,57 @@ std::ostream& operator<<(std::ostream &out,const Td_X_trapezoid<Traits>& t)
   for (j=null_size;j<=max_size;j++)
     {
       for (i=0;i<size;i++)
-	if (value[j]==value[i])
-	  {
-	    std::strcat(name[i],"=");
-	    std::strcat(name[i],name[j]);
-	    break;
-	  }
+        if (value[j]==value[i])
+          {
+            std::strcat(name[i],"=");
+            std::strcat(name[i],name[j]);
+            break;
+          }
       if (i==size)
-	{
-	  value[size]=value[j];
-	  std::strcpy(name[size++],name[j]);
-	}
+        {
+          value[size]=value[j];
+          std::strcpy(name[size++],name[j]);
+        }
     }
   if (size==null_size) {out << "none";}
   for(j=null_size;j<size;j++)
     {
       out << name[j];
-      // identify neighbours
+      // identify neighbors
       if (traits.is_td_vertex(t) && value[j])
-	out << "=" << value[j]->top();
+        out << "=" << value[j]->top();
       out << " ";
     }
   out << ")" << std::flush;
-	
+
   if (t.is_active())
     {
       if (traits.is_td_trapezoid(t))
-	{
-	  if (t.is_unbounded())
-	    {
-	      out << ",U";
-	      if (t.is_on_left_boundary())
-		out << (char) 174;
-	      if (t.is_on_bottom_boundary())
-		out << (char) 25;
-	      if (t.is_on_top_boundary())
-		out << (char) 24;
-	      if (t.is_on_right_boundary())
-		out << (char) 175;
-	    }
-	  else
-	    out << ",T";
-	}
+        {
+          if (t.is_unbounded())
+            {
+              out << ",U";
+              if (t.is_on_left_boundary())
+                out << (char) 174;
+              if (t.is_on_bottom_boundary())
+                out << (char) 25;
+              if (t.is_on_top_boundary())
+                out << (char) 24;
+              if (t.is_on_right_boundary())
+                out << (char) 175;
+            }
+          else
+            out << ",T";
+        }
       else if (traits.is_td_edge(t))
-	out << ",C";
+        out << ",C";
       else // if (t.is_degenerate_point())
-	out << ",P";
+        out << ",P";
     }
   else
     out << ",D";
-	
-  /*	Calling t.is_valid requires the traits to be initialized with the proper 
+
+  /*        Calling t.is_valid requires the traits to be initialized with the proper
     bounding box
     if (traits)
     {
@@ -273,9 +264,9 @@ std::ostream& operator<<(std::ostream &out,const Td_X_trapezoid<Traits>& t)
     else
     out << ",-";
     }
-  */	
+  */
   out << ")" << std::flush;
-	
+
   return out;
 }
 
