@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_spherical_gaussian_map_3/Arr_polyhedral_sgm.h $
-// $Id: Arr_polyhedral_sgm.h ace0997 2019-01-02T12:22:58+02:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_spherical_gaussian_map_3/Arr_polyhedral_sgm.h $
+// $Id: Arr_polyhedral_sgm.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Efi Fogel         <efif@post.tau.ac.il>
 //            Naama mayer       <naamamay@post.tau.ac.il>
@@ -47,6 +38,7 @@
 #include <CGAL/aff_transformation_tags.h>
 #include <CGAL/intersections.h>
 #include <CGAL/Polygon_2_algorithms.h>
+#include <CGAL/Kernel/global_functions_3.h>
 
 #include <CGAL/Arr_overlay_2.h>
 #include <CGAL/Arr_spherical_gaussian_map_3/Arr_spherical_gaussian_map_3.h>
@@ -92,7 +84,7 @@ private:
 
   typedef typename Polyhedron::Halfedge_around_vertex_circulator
     Polyhedron_halfedge_around_vertex_circulator;
-  typedef boost::is_same<typename Polyhedron::Plane_3, Vector_3>
+  typedef std::is_same<typename Polyhedron::Plane_3, Vector_3>
     Polyhedron_has_normal;
 
   typedef typename Polyhedron::HalfedgeDS             HDS;
@@ -111,13 +103,13 @@ private:
     }
   };
 
-  void compute_planes(Polyhedron& polyhedron, boost::true_type)
+  void compute_planes(Polyhedron& polyhedron, std::true_type)
   {
     std::transform(polyhedron.facets_begin(), polyhedron.facets_end(),
                    polyhedron.planes_begin(), Normal_equation());
   }
 
-  /*! Compute the equation of the undelying plane of a facet */
+  /*! Compute the equation of the underlying plane of a facet */
   struct Plane_equation {
     template <typename Facet>
     typename Facet::Plane_3 operator()(Facet& f) {
@@ -128,7 +120,7 @@ private:
     }
   };
 
-  void compute_planes(Polyhedron& polyhedron, boost::false_type)
+  void compute_planes(Polyhedron& polyhedron, std::false_type)
   {
     std::transform(polyhedron.facets_begin(), polyhedron.facets_end(),
                    polyhedron.planes_begin(), Plane_equation());
@@ -358,12 +350,12 @@ private:
 
   /*! Obtain the normal of a facet of a polyhedron that supports normals */
   template <typename Facet>
-  const Vector_3& get_normal(const Facet& facet, boost::true_type) const
+  const Vector_3& get_normal(const Facet& facet, std::true_type) const
   { return facet->plane(); }
 
   /*! Obtain the normal of a facet of a polyhedron that supports planes */
   template <typename Facet>
-  Vector_3 get_normal(const Facet& facet, boost::false_type) const
+  Vector_3 get_normal(const Facet& facet, std::false_type) const
   { return facet->plane().orthogonal_vector(); }
 
   /*! Process a polyhedron vertex recursively constructing the Gaussian map
@@ -524,7 +516,7 @@ public:
   /*! Constructor */
   Arr_polyhedral_sgm_initializer(PolyhedralSgm& sgm) :
     Base(sgm),
-    m_visitor(NULL),
+    m_visitor(nullptr),
     m_marked_vertex_index(0),
     m_marked_edge_index(0),
     m_marked_facet_index(0)
@@ -538,7 +530,7 @@ public:
    * \param visitor
    * \pre The polyhedron polyhedron does not have coplanar facets.
    */
-  void operator()(Polyhedron& polyhedron, Visitor* visitor = NULL)
+  void operator()(Polyhedron& polyhedron, Visitor* visitor = nullptr)
   {
 #if 0
     std::copy(polyhedron.points_begin(), polyhedron.points_end(),
@@ -568,7 +560,7 @@ public:
                   const CoordIndexIter indices_begin,
                   const CoordIndexIter indices_end,
                   size_type num_facets,
-                  Visitor* visitor = NULL)
+                  Visitor* visitor = nullptr)
   {
     m_visitor = visitor;
 
@@ -717,7 +709,7 @@ public:
  // template <typename SgmIterator>
  // void minkowski_sum(SgmIterator begin, SgmIterator end)
  // {
-	//typename SgmIterator::value_type* sgm1 = *begin++;
+        //typename SgmIterator::value_type* sgm1 = *begin++;
  //   typename SgmIterator::value_type* sgm2 = *begin;
  //   minkowski_sum(sgm1, sgm2);
  // }
