@@ -2,22 +2,13 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_spherical_topology_traits_2.h $
+// $Id: Arr_spherical_topology_traits_2.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_spherical_topology_traits_2.h $
-// $Id: Arr_spherical_topology_traits_2.h 18acb2e 2018-01-18T15:05:34+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-//
-// Author(s)     : Efi Fogel         <efif@post.tau.ac.il>
-//                 Eric Berberich    <ericb@post.tau.ac.il>
+// Author(s): Efi Fogel         <efif@post.tau.ac.il>
+//            Eric Berberich    <ericb@post.tau.ac.il>
 
 #ifndef CGAL_ARR_SPHERICAL_TOPOLOGY_TRAITS_2_H
 #define CGAL_ARR_SPHERICAL_TOPOLOGY_TRAITS_2_H
@@ -100,30 +91,14 @@ public:
   typedef typename Gt_adaptor_2::Top_side_category    Top_side_category;
   typedef typename Gt_adaptor_2::Right_side_category  Right_side_category;
 
-  BOOST_MPL_ASSERT
-  (
-   (boost::mpl::or_<
-    boost::is_same< Left_side_category, Arr_oblivious_side_tag >,
-    boost::is_same< Left_side_category, Arr_identified_side_tag > >)
-  );
-  BOOST_MPL_ASSERT
-  (
-   (boost::mpl::or_<
-    boost::is_same< Bottom_side_category, Arr_oblivious_side_tag >,
-    boost::is_same< Bottom_side_category, Arr_contracted_side_tag > >)
-  );
-  BOOST_MPL_ASSERT
-  (
-   (boost::mpl::or_<
-    boost::is_same< Top_side_category, Arr_oblivious_side_tag >,
-    boost::is_same< Top_side_category, Arr_contracted_side_tag > >)
-  );
-  BOOST_MPL_ASSERT
-  (
-   (boost::mpl::or_<
-    boost::is_same< Right_side_category, Arr_oblivious_side_tag >,
-    boost::is_same< Right_side_category, Arr_identified_side_tag > >)
-  );
+  CGAL_static_assertion((std::is_same< Left_side_category, Arr_oblivious_side_tag >::value ||
+                         std::is_same< Left_side_category, Arr_identified_side_tag >::value));
+  CGAL_static_assertion((std::is_same< Bottom_side_category, Arr_oblivious_side_tag >::value ||
+                         std::is_same< Bottom_side_category, Arr_contracted_side_tag >::value));
+  CGAL_static_assertion((std::is_same< Top_side_category, Arr_oblivious_side_tag >::value ||
+                         std::is_same< Top_side_category, Arr_contracted_side_tag >::value));
+  CGAL_static_assertion((std::is_same< Right_side_category, Arr_oblivious_side_tag >::value ||
+                         std::is_same< Right_side_category, Arr_identified_side_tag >::value));
   //@}
 
   /*! \struct
@@ -139,7 +114,7 @@ private:
   //! A container of boundary vertices.
   struct Vertex_key_comparer {
     /*! Construct default */
-    Vertex_key_comparer() : m_geom_traits(NULL) {}
+    Vertex_key_comparer() : m_geom_traits(nullptr) {}
 
     /*! Construct */
     Vertex_key_comparer(const Gt_adaptor_2* geom_traits) :
@@ -179,7 +154,7 @@ protected:
   //! The geometry-traits adaptor.
   const Gt_adaptor_2* m_geom_traits;
 
-  //! Inidicates whether the traits object should evetually be freed.
+  //! Indicates whether the traits object should eventually be freed.
   bool m_own_geom_traits;
 
   // Copy constructor and assignment operator - not supported.
@@ -244,13 +219,13 @@ public:
    * \param v the vertex.
    * \todo why is this needed, and where used?
    */
-  bool is_valid_vertex (const Vertex* /* v */) const { return true; }
+  bool is_valid_vertex(const Vertex* /* v */) const { return true; }
 
   /*! Obtain the number of valid vertices. */
   Size number_of_valid_vertices() const { return (m_dcel.size_of_vertices()); }
 
   /*! Determine whether the given halfedge is valid. */
-  bool is_valid_halfedge (const Halfedge* /* he */) const { return true; }
+  bool is_valid_halfedge(const Halfedge* /* he */) const { return true; }
 
   /*! Obtain the number of valid halfedges. */
   Size number_of_valid_halfedges() const
@@ -296,16 +271,35 @@ public:
   /*! Obtain the north pole (non-const version). */
   Vertex* north_pole() { return m_north_pole; }
 
+  /*! Obtain a vertex on the line of discontinuity that corresponds to
+   *  the given point (or return NULL if no such vertex exists).
+   */
+  Vertex* discontinuity_vertex(const Point_2& pt)
+  {
+    auto it = m_boundary_vertices.find(pt);
+    return (it != m_boundary_vertices.end()) ? it->second : nullptr;
+  }
+
+  /*! Obtain a vertex on the line of discontinuity that corresponds to
+   *  the given point (or return NULL if no such vertex exists).
+   */
+  const Vertex* discontinuity_vertex(const Point_2& pt) const
+  {
+    auto it = m_boundary_vertices.find(pt);
+    return (it != m_boundary_vertices.end()) ? it->second : nullptr;
+  }
+
+  // TODO remove if all occurrences have been replaced with the new signature that queries for a point
   /*! Obtain a vertex on the line of discontinuity that corresponds to
    *  the given curve-end (or return NULL if no such vertex exists).
    */
-  Vertex* discontinuity_vertex(const X_monotone_curve_2 xc, Arr_curve_end ind)
+  Vertex* discontinuity_vertex(const X_monotone_curve_2& xc, Arr_curve_end ind)
   {
     Point_2 key = (ind == ARR_MIN_END) ?
       m_geom_traits->construct_min_vertex_2_object()(xc) :
       m_geom_traits->construct_max_vertex_2_object()(xc);
     typename Vertex_map::iterator it = m_boundary_vertices.find(key);
-    return (it != m_boundary_vertices.end()) ? it->second : NULL;
+    return (it != m_boundary_vertices.end()) ? it->second : nullptr;
   }
   //@}
 
@@ -321,7 +315,6 @@ public:
   // the non-C++11 code requires the (re)definition of all constructors of the
   // derived class. The non-C++11 code follows the commented out C++11 code.
   // When we move to C++11 we can use the more elgant code.
-#if defined(CGAL_CFG_NO_CPP0X_TEMPLATE_ALIASES)
   // Type definition for the construction surface-sweep visitor.
   template <typename Evt, typename Crv>
   struct Construction_helper :
@@ -396,47 +389,6 @@ public:
                                                                 Base;
     Overlay_helper(const ArrA* arr_a, const ArrB* arr_b) : Base(arr_a, arr_b) {}
   };
-#else
-  // Type definition for the construction surface-sweep visitor.
-  template <typename Evt, typename Crv>
-  using Construction_helper =
-    Arr_spherical_construction_helper<Gt2, Arr, Evt, Crv>;
-
-  // Type definition for the no-intersection construction surface-sweep visitor.
-  template <typename Evt, typename Crv>
-  using No_intersection_construction_helper =
-    Arr_spherical_construction_helper<Gt2, Arr, Evt, Crv>;
-
-  // Type definition for the insertion surface-sweep visitor.
-  typedef Arr_insertion_traits_2<Gt2, Arr>                      I_traits;
-  template <typename Evt, typename Crv>
-  using Insertion_helper =
-    Arr_spherical_insertion_helper<I_traits, Arr, Evt, Crv>;
-
-  // Type definition for the no-intersection insertion surface-sweep visitor.
-  typedef Arr_basic_insertion_traits_2<Gt2, Arr>                Nxi_traits;
-  template <typename Evt, typename Crv>
-  using No_intersection_insertion_helper =
-    Arr_spherical_insertion_helper<Nxi_traits, Arr, Evt, Crv>;
-
-  // Type definition for the batched point-location surface-sweep visitor.
-  typedef Arr_batched_point_location_traits_2<Arr>              Bpl_traits;
-  template <typename Evt, typename Crv>
-  using Batched_point_location_helper =
-    Arr_spherical_batched_pl_helper<Bpl_traits, Arr, Evt, Crv>;
-
-  // Type definition for the vertical decomposition surface-sweep visitor.
-  typedef Arr_batched_point_location_traits_2<Arr>              Vd_traits;
-  template <typename Evt, typename Crv>
-  using Vertical_decomposition_helper =
-    Arr_spherical_vert_decomp_helper<Vd_traits, Arr, Evt, Crv>;
-
-  // Type definition for the overlay surface-sweep visitor.
-  template <typename Gt, typename Evt, typename Crv,
-            typename ArrA, typename ArrB>
-  using Overlay_helper =
-    Arr_spherical_overlay_helper<Gt, ArrA, ArrB, Arr, Evt, Crv>;
-#endif
   //@}
 
 public:
@@ -453,7 +405,19 @@ public:
   //@{
 
   /*! Receive a notification on the creation of a new boundary vertex that
-   * corresponds to the given curve end.
+   * corresponds to a point.
+   * \param v The new boundary vertex.
+   * \param p The point.
+   * \param ps_x The boundary condition of the curve end in x.
+   * \param ps_y The boundary condition of the curve end in y.
+   */
+  void notify_on_boundary_vertex_creation(Vertex* v,
+                                          const Point_2& p,
+                                          Arr_parameter_space ps_x,
+                                          Arr_parameter_space ps_y);
+
+  /*! Receive a notification on the creation of a new boundary vertex that
+   * corresponds to a given curve end.
    * \param v The new boundary vertex.
    * \param xc The x-monotone curve.
    * \param ind The curve end.
@@ -476,8 +440,8 @@ public:
    * \param swap_predecessors Output swap predeccesors or not;
    *        set correctly only if true is returned
    */
-  bool let_me_decide_the_outer_ccb(std::pair< CGAL::Sign, CGAL::Sign> signs1,
-                                   std::pair< CGAL::Sign, CGAL::Sign> signs2,
+  bool let_me_decide_the_outer_ccb(std::pair<CGAL::Sign, CGAL::Sign> signs1,
+                                   std::pair<CGAL::Sign, CGAL::Sign> signs2,
                                    bool& swap_predecessors) const;
 
 
@@ -490,10 +454,10 @@ public:
    *         will form a hole in the original face.
    */
   std::pair<bool, bool>
-  face_split_after_edge_insertion(std::pair< CGAL::Sign,
-                                             CGAL::Sign > /* signs1 */,
-                                  std::pair< CGAL::Sign,
-                                             CGAL::Sign > /* signs2 */) const
+  face_split_after_edge_insertion(std::pair<CGAL::Sign,
+                                            CGAL::Sign> /* signs1 */,
+                                  std::pair<CGAL::Sign,
+                                            CGAL::Sign> /* signs2 */) const
   {
     // In case of a spherical topology, connecting two vertices on the same
     // inner CCB closes a new face that becomes a hole in the original face:
@@ -542,11 +506,12 @@ public:
    * \pre The curve has a boundary condition in either x or y.
    * \return An object that contains the curve end.
    */
-  CGAL::Object place_boundary_vertex(Face* f,
-                                     const X_monotone_curve_2& xc,
-                                     Arr_curve_end ind,
-                                     Arr_parameter_space ps_x,
-                                     Arr_parameter_space ps_y);
+  boost::optional<boost::variant<Vertex*, Halfedge*> >
+  place_boundary_vertex(Face* f,
+                        const X_monotone_curve_2& xc,
+                        Arr_curve_end ind,
+                        Arr_parameter_space ps_x,
+                        Arr_parameter_space ps_y);
 
   /*! Locate the predecessor halfedge for the given curve around a given
    * vertex with boundary conditions.
@@ -573,9 +538,10 @@ public:
    * \pre The curve end is incident to the boundary.
    * \return An object that contains the curve end.
    */
-  CGAL::Object locate_curve_end(const X_monotone_curve_2& xc, Arr_curve_end ce,
-                                Arr_parameter_space ps_x,
-                                Arr_parameter_space ps_y);
+  boost::variant<Vertex*, Halfedge*, Face*>
+  locate_curve_end(const X_monotone_curve_2& xc, Arr_curve_end ce,
+                   Arr_parameter_space ps_x,
+                   Arr_parameter_space ps_y);
 
   /*! Split a fictitious edge using the given vertex.
    * \param e The edge to split (one of the pair of halfedges).
@@ -588,7 +554,7 @@ public:
   {
     // There are no fictitious halfedges:
     CGAL_error();
-    return NULL;
+    return nullptr;
   }
 
   /*! Determine whether the given face is unbounded.
@@ -622,10 +588,9 @@ public:
 
   //! reference_face (non-const version).
   /*! The function returns a reference face of the arrangement.
-      All reference faces of arrangements of the same type have a common
-      point.
-      \return A pointer to the reference face.
-  */
+   * All reference faces of arrangements of the same type have a common point.
+   * \return A pointer to the reference face.
+   */
   Face* reference_face() { return spherical_face(); }
   //@}
 
@@ -662,7 +627,6 @@ protected:
    * on the line of discontinuity.
    */
   Face* _face_below_vertex_on_discontinuity(Vertex* v) const;
-
   //@}
 };
 
