@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_insertion_helper.h $
-// $Id: Arr_spherical_insertion_helper.h 7936109 2017-11-16T16:31:52+02:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_insertion_helper.h $
+// $Id: Arr_spherical_insertion_helper.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
@@ -30,6 +21,7 @@
  * Definition of the Arr_spherical_insertion_helper class-template.
  */
 
+#include <CGAL/Arr_tags.h>
 #include <CGAL/Arr_topology_traits/Arr_spherical_construction_helper.h>
 
 namespace CGAL {
@@ -59,6 +51,17 @@ private:
   typedef Arr_spherical_construction_helper<Gt2, Arrangement_2, Event, Subcurve>
                                                         Base;
 
+  typedef typename Gt2::Left_side_category              Left_side_category;
+  typedef typename Gt2::Bottom_side_category            Bottom_side_category;
+  typedef typename Gt2::Top_side_category               Top_side_category;
+  typedef typename Gt2::Right_side_category             Right_side_category;
+
+  typedef typename Arr_all_sides_oblivious_category<Left_side_category,
+                                                    Bottom_side_category,
+                                                    Top_side_category,
+                                                    Right_side_category>::result
+    All_sides_oblivious_category;
+
 public:
   typedef typename Gt2::X_monotone_curve_2              X_monotone_curve_2;
   typedef typename Gt2::Point_2                         Point_2;
@@ -91,20 +94,37 @@ public:
     this->m_spherical_face = Face_handle(this->m_top_traits->south_face());
   }
 
-  /*! A notification invoked before the sweep-line starts handling a given
+  /*! A notification invoked before the surface-sweep starts handling a given
    * event.
    */
   virtual void before_handle_event(Event* event);
 
+  //@}
+
   /*! A notification invoked when a new subcurve is created. */
   virtual void add_subcurve(Halfedge_handle he, Subcurve* sc);
 
   /*! Get the current top face. */
   virtual Face_handle top_face() const;
+
+private:
+  /* A notification invoked before the surface-sweep starts handling a given
+   * event.
+   * This is the implementation for the case where all 4 boundary sides are
+   * oblivious.
+   */
+  void before_handle_event_imp(Event* event, Arr_all_sides_oblivious_tag);
+
+  /* A notification invoked before the surface-sweep starts handling a given
+   * event.
+   * This is the implementation for the case where all 4 boundary sides are
+   * not oblivious.
+   */
+  void before_handle_event_imp(Event* event, Arr_not_all_sides_oblivious_tag);
 };
 
 //-----------------------------------------------------------------------------
-// Memeber-function definitions:
+// Member-function definitions:
 //-----------------------------------------------------------------------------
 
 //-----------------------------------------------------------------------------
@@ -114,20 +134,41 @@ public:
 template <typename Tr, typename Arr, typename Evnt, typename Sbcv>
 void Arr_spherical_insertion_helper<Tr, Arr, Evnt, Sbcv>::
 before_handle_event(Event* event)
+{ before_handle_event_imp(event, All_sides_oblivious_category()); }
+
+/* A notification invoked before the surface-sweep starts handling a given
+ * event.
+ * This is the implementation for the case where all 4 boundary sides are
+ * oblivious.
+ */
+template <typename Tr, typename Arr, typename Evnt, typename Sbcv>
+void Arr_spherical_insertion_helper<Tr, Arr, Evnt, Sbcv>::
+before_handle_event_imp(Event* /* event */, Arr_all_sides_oblivious_tag)
+{ return; }
+
+/* A notification invoked before the surface-sweep starts handling a given
+ * event.
+ * This is the implementation for the case where all 4 boundary sides are
+ * not oblivious.
+ */
+template <typename Tr, typename Arr, typename Evnt, typename Sbcv>
+void Arr_spherical_insertion_helper<Tr, Arr, Evnt, Sbcv>::
+before_handle_event_imp(Event* event, Arr_not_all_sides_oblivious_tag)
 {
   // Ignore events that do not have boundary conditions.
-  const Arr_parameter_space ps_x = event->parameter_space_in_x();
-  const Arr_parameter_space ps_y = event->parameter_space_in_y();
+  auto ps_x = event->parameter_space_in_x();
+  auto ps_y = event->parameter_space_in_y();
   if ((ps_x == ARR_INTERIOR) && (ps_y == ARR_INTERIOR)) return;
 
+  if (event->is_isolated()) return;
+
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
-    // Process bootom contraction boundary:
+    // Process bottom contraction boundary:
     // The event has only one right curve, as there is exactly one curve
     // incident to an event with boundary conditions.
     CGAL_assertion((event->number_of_left_curves() == 0) &&
                    (event->number_of_right_curves() == 1));
-    const X_monotone_curve_2& xc =
-        (*(event->right_curves_begin()))->last_curve();
+    const auto& xc = (*(event->right_curves_begin()))->last_curve();
     if (xc.halfedge_handle() != Halfedge_handle()) return;
 
     // If a vertex on the south pole does not exists, create one.
@@ -144,8 +185,7 @@ before_handle_event(Event* event)
     // incident to an event with boundary conditions.
     CGAL_assertion((event->number_of_left_curves() == 1) &&
                    (event->number_of_right_curves() == 0));
-    const X_monotone_curve_2& xc =
-      (*(event->left_curves_begin()))->last_curve();
+    const auto& xc = (*(event->left_curves_begin()))->last_curve();
 
     if (xc.halfedge_handle() != Halfedge_handle()) {
       // Update the current top face.
@@ -162,21 +202,19 @@ before_handle_event(Event* event)
   }
 
   if (ps_x == ARR_LEFT_BOUNDARY) {
-    // Process left discontinuity boundary:
-    // The event has only right curves, as there is exactly one curve
-    // incident to an event with boundary conditions.
-    CGAL_assertion((event->number_of_left_curves() == 0) &&
-                   (event->number_of_right_curves() >= 1));
-    const X_monotone_curve_2& xc =
-      (*(event->right_curves_begin()))->last_curve();
+    // If the event is an end-point of a curve that coincides with the
+    // identification boundary, it may not have right curves at all
+    if (0 == event->number_of_right_curves()) return;
 
+    // Otherwise, it may still have a left curve...
+    const auto& xc = (*(event->right_curves_begin()))->last_curve();
     if (xc.halfedge_handle() != Halfedge_handle()) {
       // Update the current top face.
       this->m_spherical_face = xc.halfedge_handle()->twin()->face();
       return;
     }
 
-    // If a vertex on the line of discontinuity does not exists. create one.
+    // If a vertex on the line of discontinuity does not exists, create one.
     DVertex* dv = this->m_top_traits->discontinuity_vertex(xc, ARR_MIN_END);
     Vertex_handle v = (dv) ? Vertex_handle(dv) :
       this->m_arr_access.create_boundary_vertex(xc, ARR_MIN_END, ps_x, ps_y);
@@ -190,8 +228,7 @@ before_handle_event(Event* event)
     // incident to an event with boundary conditions.
     CGAL_assertion((event->number_of_left_curves() >= 1) &&
                    (event->number_of_right_curves() == 0));
-    const X_monotone_curve_2& xc =
-      (*(event->left_curves_begin()))->last_curve();
+    const auto& xc = (*(event->left_curves_begin()))->last_curve();
     if (xc.halfedge_handle() != Halfedge_handle()) return;
 
     // If a vertex on the line of discontinuity does not exists. create one.
@@ -203,7 +240,8 @@ before_handle_event(Event* event)
   }
 }
 
-/*! A notification invoked when a new subcurve is created. */
+/*! A notification invoked when a new subcurve is created.
+ */
 template <typename Tr, typename Arr, typename Evnt, typename Sbcv>
 void Arr_spherical_insertion_helper<Tr, Arr, Evnt, Sbcv>::
 add_subcurve(Halfedge_handle he, Subcurve* /* sc */)
