@@ -2,22 +2,13 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_topology_traits_2_impl.h $
+// $Id: Arr_spherical_topology_traits_2_impl.h 0ea013ea121 2023-02-03T12:07:03+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_spherical_topology_traits_2_impl.h $
-// $Id: Arr_spherical_topology_traits_2_impl.h 7936109 2017-11-16T16:31:52+02:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
-//
-// Author(s)     : Efi Fogel         <efif@post.tau.ac.il>
-//                 Ron Wein          <wein@post.tau.ac.il>
+// Author(s): Efi Fogel         <efif@post.tau.ac.il>
+//            Ron Wein          <wein@post.tau.ac.il>
 
 #ifndef CGAL_ARR_SPHERICAL_TOPOLOGY_TRAITS_2_IMPL_H
 #define CGAL_ARR_SPHERICAL_TOPOLOGY_TRAITS_2_IMPL_H
@@ -32,33 +23,33 @@
 
 namespace CGAL {
 
-/*! \brief constructs default */
+  //! \brief constructs default.
 template <typename GeomTraits, typename Dcel>
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 Arr_spherical_topology_traits_2() :
-  m_spherical_face(NULL),
-  m_north_pole(NULL),
-  m_south_pole(NULL),
+  m_spherical_face(nullptr),
+  m_north_pole(nullptr),
+  m_south_pole(nullptr),
   m_own_geom_traits(true)
 {
   m_geom_traits = new Gt_adaptor_2;
   m_boundary_vertices = Vertex_map(Vertex_key_comparer(m_geom_traits));
 }
 
-/*! \brief constructs from a geometry-traits object. */
+//! \brief constructs from a geometry-traits object.
 template <typename GeomTraits, typename Dcel>
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 Arr_spherical_topology_traits_2(const Geometry_traits_2* traits) :
-  m_spherical_face(NULL),
-  m_north_pole(NULL),
-  m_south_pole(NULL),
+  m_spherical_face(nullptr),
+  m_north_pole(nullptr),
+  m_south_pole(nullptr),
   m_own_geom_traits(false)
 {
   m_geom_traits = static_cast<const Gt_adaptor_2*>(traits);
   m_boundary_vertices = Vertex_map(Vertex_key_comparer(m_geom_traits));
 }
 
-/*! \brief destructs */
+//! \brief destructs.
 template <typename GeomTraits, typename Dcel>
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 ~Arr_spherical_topology_traits_2()
@@ -66,25 +57,24 @@ Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
   // Clear the DCEL.
   m_dcel.delete_all();
 
-  if (m_own_geom_traits && (m_geom_traits != NULL)) {
+  if (m_own_geom_traits && (m_geom_traits != nullptr)) {
     delete m_geom_traits;
-    m_geom_traits = NULL;
+    m_geom_traits = nullptr;
   }
 }
 
-/*! \brief assigns the contents of another topology-traits class */
+//! \brief assigns the contents of another topology-traits class.
 template <typename GeomTraits, typename Dcel>
-void Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
-assign(const Self& other)
+void Arr_spherical_topology_traits_2<GeomTraits, Dcel>::assign(const Self& other)
 {
   // Clear the current DCEL and duplicate the other DCEL.
   m_dcel.delete_all();
   m_dcel.assign(other.m_dcel);
 
   // Take care of the traits object.
-  if (m_own_geom_traits && m_geom_traits != NULL) {
+  if (m_own_geom_traits && m_geom_traits != nullptr) {
     delete m_geom_traits;
-    m_geom_traits = NULL;
+    m_geom_traits = nullptr;
   }
 
   if (other.m_own_geom_traits) {
@@ -100,7 +90,7 @@ assign(const Self& other)
   dcel_updated();
 }
 
-/*! \brief initializes an empty DCEL structure. */
+//! \brief initializes an empty DCEL structure.
 template <typename GeomTraits_, typename Dcel_>
 void Arr_spherical_topology_traits_2<GeomTraits_, Dcel_>::dcel_updated()
 {
@@ -109,8 +99,8 @@ void Arr_spherical_topology_traits_2<GeomTraits_, Dcel_>::dcel_updated()
   // Go over the DCEL vertices and locate the south and north pole (if any)
   // and any other vertex on the line of discontinuity.
 
-  m_north_pole = NULL;
-  m_south_pole = NULL;
+  m_north_pole = nullptr;
+  m_south_pole = nullptr;
   m_boundary_vertices.clear();
 
   typename Dcel::Vertex_iterator vit = this->m_dcel.vertices_begin();
@@ -129,20 +119,20 @@ void Arr_spherical_topology_traits_2<GeomTraits_, Dcel_>::dcel_updated()
   // Go over the DCEL faces and locate the spherical face, which is the only
   // face with no outer CCB.
 
-  m_spherical_face = NULL;
+  m_spherical_face = nullptr;
   typename Dcel::Face_iterator fit = this->m_dcel.faces_begin();
   for (; fit != this->m_dcel.faces_end(); ++fit) {
     if (fit->number_of_outer_ccbs() == 0) {
-      CGAL_assertion(m_spherical_face == NULL);
+      CGAL_assertion(m_spherical_face == nullptr);
 
       m_spherical_face = &(*fit);
       break;
     }
   }
-  CGAL_assertion(m_spherical_face != NULL);
+  CGAL_assertion(m_spherical_face != nullptr);
 }
 
-/*! \brief initializes an empty DCEL structure. */
+//! \brief initializes an empty DCEL structure.
 template <typename GeomTraits, typename Dcel>
 void Arr_spherical_topology_traits_2<GeomTraits, Dcel>::init_dcel()
 {
@@ -156,18 +146,17 @@ void Arr_spherical_topology_traits_2<GeomTraits, Dcel>::init_dcel()
   m_spherical_face->set_unbounded(false);
   m_spherical_face->set_fictitious(false);
 
-  m_north_pole = NULL;
-  m_south_pole = NULL;
+  m_north_pole = nullptr;
+  m_south_pole = nullptr;
 }
 
-/*! \brief determines whether a point lies in the interior of a given face. */
+//! \brief determines whether a point lies in the interior of a given face.
 template <typename GeomTraits, typename Dcel>
 bool Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
 {
-  // std::cout << "is_in_face()" << std::endl;
-  CGAL_precondition((v == NULL) || !v->has_null_point());
-  CGAL_precondition((v == NULL) ||
+  CGAL_precondition((v == nullptr) || !v->has_null_point());
+  CGAL_precondition((v == nullptr) ||
                     m_geom_traits->equal_2_object()(p, v->point()));
 
   /* There is always one face that contains everything else. It has no
@@ -179,30 +168,29 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
    */
 #if 0
   std::cout << "p: " << p
-            << ", f->number_of_outer_ccbs(): " << f->number_of_outer_ccbs()
+            << ", # outer_ccbs: " << f->number_of_outer_ccbs()
+            << ", # inner ccbs: " << f->number_of_inner_ccbs()
             << std::endl;
 #endif
   if (f->number_of_outer_ccbs() == 0) return true;
-  if (((v != NULL) && (v->parameter_space_in_y() == ARR_TOP_BOUNDARY)) ||
+  if (((v != nullptr) && (v->parameter_space_in_y() == ARR_TOP_BOUNDARY)) ||
       (m_geom_traits->parameter_space_in_y_2_object()(p) == ARR_TOP_BOUNDARY))
     return false;
 
   /*! \todo a temporary test
-   * if (((v != NULL) && (v->parameter_space_in_y() == ARR_BOTTOM_BOUNDARY)) ||
+   * if (((v != nullptr) && (v->parameter_space_in_y() == ARR_BOTTOM_BOUNDARY)) ||
    *   (p.is_min_boundary()))
    * return false;
    */
 
-  typename Gt_adaptor_2::Parameter_space_in_x_2 ps_x_op =
-    m_geom_traits->parameter_space_in_x_2_object();
-  typename Gt_adaptor_2::Parameter_space_in_y_2 ps_y_op =
-    m_geom_traits->parameter_space_in_y_2_object();
-  typename Gt_adaptor_2::Compare_x_2 cmp_x_op =
-    m_geom_traits->compare_x_2_object();
-  typename Gt_adaptor_2::Compare_y_at_x_2 cmp_y_at_x_op =
-    m_geom_traits->compare_y_at_x_2_object();
-  typename Gt_adaptor_2::Compare_x_point_curve_end_2 cmp_x_pt_ce =
-    m_geom_traits->compare_x_point_curve_end_2_object();
+  auto ps_x_op = m_geom_traits->parameter_space_in_x_2_object();
+  auto ps_y_op = m_geom_traits->parameter_space_in_y_2_object();
+  auto cmp_x_op = m_geom_traits->compare_x_2_object();
+  auto cmp_y_at_x_op = m_geom_traits->compare_y_at_x_2_object();
+  auto cmp_x_pt_ce = m_geom_traits->compare_x_point_curve_end_2_object();
+  auto cmp_x_ce_ce = m_geom_traits->compare_x_curve_ends_2_object();
+  auto is_vertical = m_geom_traits->is_vertical_2_object();
+  auto is_on_y_identification = m_geom_traits->is_on_y_identification_2_object();
 
   // Process the input point.
   bool p_is_interior_x = !(m_geom_traits->is_on_y_identification_2_object()(p));
@@ -216,8 +204,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
   /* Traverse all outer CCBs of the face. For each boundary component go over
    * all its halfedges, and count those which are above p.
    */
-  typename Face::Outer_ccb_const_iterator oit;
-  for (oit = f->outer_ccbs_begin(); oit != f->outer_ccbs_end(); ++oit) {
+  for (auto oit = f->outer_ccbs_begin(); oit != f->outer_ccbs_end(); ++oit) {
     const Halfedge* first = *oit;
     const Halfedge* curr = first;
 
@@ -228,16 +215,16 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
 
     /*! We identify 2 main cases:
      * 1. The vertical ray intersects the boundary at a halfedge. In this
-     * case the x-possition of p is strictly larger than the x-possition of
-     * the current-curve source, and strictly smaller than x-possition of
-     * the current-curve target, or vise versa.
+     * case the x-position of p is strictly larger than the x-position of
+     * the current-curve source, and strictly smaller than x-position of
+     * the current-curve target, or vice versa.
      * 2. The vertical ray intersects the boundary at a vertex. In this case:
-     * a. the x-possition of p is strictly smaller than the x-position of the
+     * a. the x-position of p is strictly smaller than the x-position of the
      * current-curve source, and equal to the x-position of the current-curve
      * target, and
-     * b. the x-possition of p is equal to the x-position of the next-curve
+     * b. the x-position of p is equal to the x-position of the next-curve
      * source (not counting vertical curves in between), and strictly larger
-     * than the x-possition of the next-curve target, or vise verase (that is,
+     * than the x-position of the next-curve target, or vice verase (that is,
      * the "smaller" and "larger" interchanged).
      */
 
@@ -253,11 +240,16 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
      */
     bool last_pending = false;
 
-    Comparison_result res_pending = EQUAL, res_last = EQUAL,
-      res_source = EQUAL, res_target;
-    Arr_parameter_space ps_x_pending = ARR_INTERIOR, ps_x_last = ARR_INTERIOR,
-      ps_x_source, ps_x_target = ARR_INTERIOR,
-      ps_y_source, ps_y_target;
+    Comparison_result res_pending(EQUAL);
+    Comparison_result res_last(EQUAL);
+    Comparison_result res_source(EQUAL);
+    Comparison_result res_target;
+    Arr_parameter_space ps_x_pending(ARR_INTERIOR);
+    Arr_parameter_space ps_x_last(ARR_INTERIOR);
+    Arr_parameter_space ps_x_source;
+    Arr_parameter_space ps_x_target(ARR_INTERIOR);
+    Arr_parameter_space ps_y_source;
+    Arr_parameter_space ps_y_target;
 
     do {
       /* Compare p to the target vertex of the current halfedge. If the
@@ -267,22 +259,56 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
       if (curr->vertex() == v) return false;
 
       // Ignore vertical curves:
-      bool is_vertical = m_geom_traits->is_vertical_2_object()(curr->curve());
-      if (is_vertical) {
+      if (is_vertical(curr->curve())) {
         /* If this outer ccb chain contains the north pole, and our point
          * lies horizontaly between the two vertical curves that meet at
          * the north pole, increase the intersection counter
          */
         if (curr->direction() == ARR_LEFT_TO_RIGHT) {
-          Arr_parameter_space ps_y_1 = ps_y_op(curr->curve(), ARR_MAX_END);
-          Arr_parameter_space ps_y_2 = ps_y_op(curr->next()->curve(),
-                                               ARR_MAX_END);
+          const auto& cv1 = curr->curve();
+          const auto& cv2 = curr->next()->curve();
+          auto ps_y_1 = ps_y_op(cv1, ARR_MAX_END);
+          auto ps_y_2 = ps_y_op(cv2, ARR_MAX_END);
           if ((ps_y_1 == ARR_TOP_BOUNDARY) && (ps_y_2 == ARR_TOP_BOUNDARY)) {
             // Compare the x-coordinates:
-            Comparison_result rc1 =
-              cmp_x_pt_ce(p, curr->curve(), ARR_MAX_END);
-            Comparison_result rc2 =
-              cmp_x_pt_ce(p, curr->next()->curve(), ARR_MAX_END);
+            Comparison_result rc1, rc2;
+            if (is_on_y_identification(cv1)) {
+              if (is_on_y_identification(p)) return false;
+              // -----------
+              // |     |  |<---- cv1 go
+              // |     |  ||
+              // |     |   |
+              // -----------
+              // cv1 coincide with the identification curve. In this case we
+              // consider the identification to be on the right. All (interior)
+              // points are smaller then the right boundary.
+              rc1 = SMALLER;
+              rc2 = cmp_x_pt_ce(p, cv2, ARR_MAX_END);
+            }
+            else if (is_on_y_identification(cv2)) {
+              if (is_on_y_identification(p)) return false;
+              //       -----------
+              // cv2--->|  |     |
+              //       ||  |     |
+              //       |   |     |
+              //       -----------
+              // cv2 coincide with the identification curve. In this case we
+              // consider the identification to be on the left. All (interior)
+              // points are larger then the left boundary.
+              rc1 = cmp_x_pt_ce(p, cv1, ARR_MAX_END);
+              rc2 = LARGER;
+            }
+            else if (is_on_y_identification(p)) {
+              // If the max end of cv1 is smaller than the max end of cv2,
+              // the identification x-coordinate is in the x-range.
+              rc1 = cmp_x_ce_ce(cv1, ARR_MAX_END, cv2, ARR_MAX_END);
+              rc2 = LARGER;
+            }
+            else {
+              // None of p, cv1, or cv2 lie on the identification curve.
+              rc1 = cmp_x_pt_ce(p, cv1, ARR_MAX_END);
+              rc2 = cmp_x_pt_ce(p, cv2, ARR_MAX_END);
+            }
             if (rc1 == opposite(rc2)) ++num_intersections;
           }
         }
@@ -338,7 +364,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
             if (ps_x_pending == ps_x_source) {
               Comparison_result res_y_at_x = cmp_y_at_x_op(p, curr->curve());
               if (res_y_at_x == EQUAL) return false;
-              if (res_y_at_x == SMALLER) num_intersections++;
+              if (res_y_at_x == SMALLER) ++num_intersections;
             }
           } else {
             // This must be the first curve. Remember to check the last curve
@@ -381,7 +407,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
           if (res_pending == res_target) {
             Comparison_result res_y_at_x = cmp_y_at_x_op(p, curr->curve());
             if (res_y_at_x == EQUAL) return false;
-            if (res_y_at_x == SMALLER) num_intersections++;
+            if (res_y_at_x == SMALLER) ++num_intersections;
           }
         } else {
           // This must be the first curve. Remember to check the last curve
@@ -401,7 +427,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
         if (ps_x_last == ps_x_target) {
           Comparison_result res_y_at_x = cmp_y_at_x_op(p, curr->curve());
           if (res_y_at_x == EQUAL) return false;
-          if (res_y_at_x == SMALLER) num_intersections++;
+          if (res_y_at_x == SMALLER) ++num_intersections;
         }
         continue;
       }
@@ -409,7 +435,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
       if (res_last == res_source) {
         Comparison_result res_y_at_x = cmp_y_at_x_op(p, curr->curve());
         if (res_y_at_x == EQUAL) return false;
-        if (res_y_at_x == SMALLER) num_intersections++;
+        if (res_y_at_x == SMALLER) ++num_intersections;
       }
     }
   }
@@ -422,7 +448,7 @@ is_in_face(const Face* f, const Point_2& p, const Vertex* v) const
   return (num_intersections& 0x1);
 }
 
-/*! \brief compares the relative y-position of a point and a halfedge */
+//! \brief compares the relative y-position of a point and a halfedge.
 template <typename GeomTraits, typename Dcel>
 Comparison_result
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
@@ -432,7 +458,7 @@ compare_y_at_x(const Point_2& p, const Halfedge* he) const
   return m_geom_traits->compare_y_at_x_2_object()(p, he->curve());
 }
 
-/*! \brief determine whether a vertex is associated with a curve end */
+/*! \brief determines whether a vertex is associated with a curve end */
 template <typename GeomTraits, typename Dcel>
 bool Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 are_equal(const Vertex* v,
@@ -469,7 +495,29 @@ are_equal(const Vertex* v,
   return (m_geom_traits->compare_y_on_boundary_2_object()(p1, p2) == EQUAL);
 }
 
-/*! \brief receives a notification on the creation of a new boundary vertex */
+//! \brief receives a notification on the creation of a new boundary vertex.
+template <typename GeomTraits, typename Dcel>
+void
+Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
+notify_on_boundary_vertex_creation(Vertex* v,
+                                   const Point_2& p,
+                                   Arr_parameter_space
+                                     CGAL_assertion_code(ps_x),
+                                   Arr_parameter_space ps_y)
+{
+  if (ps_y == ARR_BOTTOM_BOUNDARY) {
+    m_south_pole = v;
+    return;
+  }
+  if (ps_y == ARR_TOP_BOUNDARY) {
+    m_north_pole = v;
+    return;
+  }
+  CGAL_assertion(ps_x != ARR_INTERIOR);
+  m_boundary_vertices.insert(Vertex_value(p, v));
+}
+
+//! \brief receives a notification on the creation of a new boundary vertex.
 template <typename GeomTraits, typename Dcel>
 void
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
@@ -480,7 +528,6 @@ notify_on_boundary_vertex_creation(Vertex* v,
                                      CGAL_assertion_code(ps_x),
                                    Arr_parameter_space ps_y)
 {
-  // std::cout << "notify_on_boundary_vertex_creation()" << std::endl;
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
     m_south_pole = v;
     return;
@@ -521,9 +568,13 @@ let_me_decide_the_outer_ccb(std::pair< CGAL::Sign, CGAL::Sign> signs1,
 
 /*! \brief given a curve end with boundary conditions and a face that contains
  * the interior of the curve, find a place for a boundary vertex that will
- * represent the curve end along the face boundary */
+ * represent the curve end along the face boundary.
+ */
 template <typename GeomTraits, typename Dcel>
-CGAL::Object
+boost::optional
+  <boost::variant
+    <typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Vertex*,
+     typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Halfedge*> >
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 place_boundary_vertex(Face* /* f */,
                       const X_monotone_curve_2& xc, Arr_curve_end ind,
@@ -534,15 +585,18 @@ place_boundary_vertex(Face* /* f */,
                       ,
                       Arr_parameter_space ps_y)
 {
+  typedef boost::variant<Vertex*, Halfedge*>    Non_optional_result;
+  typedef boost::optional<Non_optional_result>  Result;
+
   // std::cout << "place_boundary_vertex()" << std::endl;
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
-    if (m_south_pole == NULL) return Object();
-    return CGAL::make_object(m_south_pole);
+    if (m_south_pole == nullptr) return boost::none;
+    return Result(Non_optional_result(m_south_pole));
   }
 
   if (ps_y == ARR_TOP_BOUNDARY) {
-    if (m_north_pole == NULL) return Object();
-    return CGAL::make_object(m_north_pole);
+    if (m_north_pole == nullptr) return boost::none;
+    return Result(Non_optional_result(m_north_pole));
   }
 
   CGAL_assertion((ps_x == ARR_LEFT_BOUNDARY) || (ps_x == ARR_RIGHT_BOUNDARY));
@@ -550,19 +604,19 @@ place_boundary_vertex(Face* /* f */,
   const Point_2& key = (ind == ARR_MIN_END) ?
     m_geom_traits->construct_min_vertex_2_object()(xc) :
     m_geom_traits->construct_max_vertex_2_object()(xc);
-  typename Vertex_map::iterator it = m_boundary_vertices.find(key);
-
+  auto it = m_boundary_vertices.find(key);
   if (it != m_boundary_vertices.end()) {
     Vertex* v = it->second;
-    return CGAL::make_object(v);
+    return Result(Non_optional_result(v));
   }
 
   // The vertex hasn't been created yet, return a null object:
-  return Object();
+  return boost::none;
 }
 
 /*! \brief locate the predecessor halfedge for the given curve around a given
- * vertex with boundary conditions. */
+ * vertex with boundary conditions.
+ */
 template <typename GeomTraits, typename Dcel>
 typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Halfedge*
 Arr_spherical_topology_traits_2<GeomTraits,Dcel>::
@@ -576,7 +630,6 @@ locate_around_boundary_vertex(Vertex* v,
                               ,
                               Arr_parameter_space ps_y) const
 {
-  // std::cout << "locate_around_boundary_vertex()" << std::endl;
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
     CGAL_assertion(v == m_south_pole);
     return (_locate_around_pole(m_south_pole, xc, ind));
@@ -594,7 +647,11 @@ locate_around_boundary_vertex(Vertex* v,
 
 /*! \brief locates a DCEL feature that contains a given curve end. */
 template <typename GeomTraits, typename Dcel>
-CGAL::Object Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
+boost::variant
+<typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Vertex*,
+ typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Halfedge*,
+ typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Face*>
+Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
 locate_curve_end(const X_monotone_curve_2& xc, Arr_curve_end ind,
                  Arr_parameter_space
 #if !defined(CGAL_NO_ASSERTIONS)
@@ -603,61 +660,77 @@ locate_curve_end(const X_monotone_curve_2& xc, Arr_curve_end ind,
                  ,
                  Arr_parameter_space ps_y)
 {
+  typedef boost::variant<Vertex*, Halfedge*, Face*>     Result;
   // Act according to the boundary conditions.
   if (ps_y == ARR_TOP_BOUNDARY) {
     // In case the curve end coincides with the north pole, return the vertex
     // representing the north pole, if one exists. Otherwise, return the face
     // containing this pole (the spherical face).
-    if (m_north_pole != NULL) return CGAL::make_object(m_north_pole);
-    return CGAL::make_object(m_spherical_face);
+    if (m_north_pole != nullptr) return Result(m_north_pole);
+    return Result(m_spherical_face);
   }
 
-  typename Vertex_map::iterator it;
-  Vertex* v = NULL;
-
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
     // In case the curve end coincides with the south pole, return the vertex
     // representing the south pole, if one exists. Otherwise, search for the
     // face containing this pole.
-    if (m_south_pole != NULL) return CGAL::make_object(m_south_pole);
-    it = m_boundary_vertices.begin();
-  }
-  else {
-    CGAL_assertion((ps_x == ARR_LEFT_BOUNDARY) || (ps_x == ARR_RIGHT_BOUNDARY));
+    if (m_south_pole != nullptr) return Result(m_south_pole);
 
-    // Check if the given curve end is incident to a vertex on the line of
-    // discontinuity. If so, return this vertex. Otherwise, locate the first
-    // vertex above it.
-    const Point_2& key = (ind == ARR_MIN_END) ?
-      m_geom_traits->construct_min_vertex_2_object()(xc) :
-      m_geom_traits->construct_max_vertex_2_object()(xc);
-    it = m_boundary_vertices.find(key);
-    if (it != m_boundary_vertices.end()) {
-      v = it->second;
-      return CGAL::make_object(v);
-    }
+    // If there are no vertices on the identification curve return the spherical
+    // face.
+    if (m_boundary_vertices.empty()) return Result(m_spherical_face);
 
-    it = m_boundary_vertices.lower_bound(key);
+    Vertex* v = m_boundary_vertices.begin()->second;
+    return Result(_face_below_vertex_on_discontinuity(v));
   }
 
-  // At this point, the iterator it points to a vertex on the line of
-  // discontinuity that is strictly above the curve end. If there is none,
-  // we know the curve end is contained in the spherical face. Otherwise,
-  // we return the face that lies below the vertex v.
+  CGAL_assertion((ps_x == ARR_LEFT_BOUNDARY) || (ps_x == ARR_RIGHT_BOUNDARY));
+
+  // Check if the given curve end is incident to a vertex on the line of
+  // discontinuity. If so, return this vertex. Otherwise, locate the first
+  // vertex above it.
+  const Point_2& key = (ind == ARR_MIN_END) ?
+    m_geom_traits->construct_min_vertex_2_object()(xc) :
+    m_geom_traits->construct_max_vertex_2_object()(xc);
+
+  // Find the element the key of which is equal to or greater than 'key'
+  typename Vertex_map::iterator it = m_boundary_vertices.lower_bound(key);
+
+  // If an element with the same key or a larger key does not exist, an edge
+  // associated with a vertical curve that lies on the boundary and contains
+  // the query point cannot exist either. Return the spherical face.
   if (it == m_boundary_vertices.end())
-    return CGAL::make_object(m_spherical_face);
+    return Result(m_spherical_face);
 
-  v = it->second;
-  return CGAL::make_object(_face_below_vertex_on_discontinuity(v));
+  Vertex* v = it->second;
+
+  // If the key is equal, return the vertex.
+  if (m_geom_traits->compare_y_on_boundary_2_object()(key, v->point()) == EQUAL)
+    return Result(v);
+
+  // The vertex v lies on the identification curve and is strictly above the
+  // curve end. Search for an edge incident to v and is associated with a
+  // vertical curve that lies on the boundary.
+  Halfedge* start = v->halfedge();
+  Halfedge* he = start;
+  do {
+    const X_monotone_curve_2& curve = he->curve();
+    if ((ARR_LEFT_TO_RIGHT == he->direction()) &&
+        (m_geom_traits->is_vertical_2_object()(curve)))
+      return Result(he);
+    he = he->next()->opposite();
+  } while (he != start);
+
+  // Return the face that lies below the vertex v.
+  return Result(_face_below_vertex_on_discontinuity(v));
 }
 
-/*! \brief determines whether a given boundary vertex is redundant */
+//! \brief determines whether a given boundary vertex is redundant.
 template <typename GeomTraits, typename Dcel>
 bool Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
-is_redundant(const Vertex* v) const
-{ return (v->halfedge() == NULL); }
+is_redundant(const Vertex* v) const { return (v->halfedge() == nullptr); }
 
-/* \brief erases a given redundant vertex */
+//! \brief erases a given redundant vertex.
 template <typename GeomTraits, typename Dcel>
 typename Arr_spherical_topology_traits_2<GeomTraits, Dcel>::Halfedge*
 Arr_spherical_topology_traits_2<GeomTraits, Dcel>::
@@ -665,17 +738,17 @@ erase_redundant_vertex(Vertex* v)
 {
   const Arr_parameter_space ps_y = v->parameter_space_in_y();
   if (ps_y == ARR_BOTTOM_BOUNDARY) {
-    m_south_pole = NULL;
-    return NULL;
+    m_south_pole = nullptr;
+    return nullptr;
   }
   if (ps_y == ARR_TOP_BOUNDARY) {
-    m_north_pole = NULL;
-    return NULL;
+    m_north_pole = nullptr;
+    return nullptr;
   }
   CGAL_assertion_code(Arr_parameter_space ps_x = v->parameter_space_in_x());
   CGAL_assertion(ps_x != ARR_INTERIOR);
   m_boundary_vertices.erase(v->point());
-  return NULL;
+  return nullptr;
 }
 
 /*! \brief obtains the curve associated with a boundary vertex */
@@ -703,12 +776,12 @@ _locate_around_vertex_on_discontinuity(Vertex* v,
                                        Arr_curve_end ind) const
 {
   // If the vertex is isolated, there is no predecssor halfedge.
-  if (v->is_isolated()) return NULL;
+  if (v->is_isolated()) return nullptr;
 
   // Get the first incident halfedge around v and the next halfedge.
   Halfedge* first = v->halfedge();
   Halfedge* curr = first;
-  CGAL_assertion(curr != NULL);
+  CGAL_assertion(curr != nullptr);
   Halfedge* next = curr->next()->opposite();
 
   // If is only one halfedge incident to v, return this halfedge as xc's
@@ -756,12 +829,12 @@ _locate_around_pole(Vertex* v,
 
   // std::cout << "locate_around_pole() " << ind << std::endl;
   // If the vertex is isolated, return a null halfedge:
-  if (v->is_isolated()) return NULL;
+  if (v->is_isolated()) return nullptr;
 
   // Get the first incident halfedge around v and the next halfedge:
   Halfedge* first = v->halfedge();
   Halfedge* curr = first;
-  CGAL_assertion(curr != NULL);
+  CGAL_assertion(curr != nullptr);
   Halfedge* next = curr->next()->opposite();
 
   // If there is only one halfedge, it is the predecessor, return it:
@@ -776,19 +849,40 @@ _locate_around_pole(Vertex* v,
   // pole with the query curve xc.
   typename Gt_adaptor_2::Compare_x_curve_ends_2 cmp_x_curve_ends =
     m_geom_traits->compare_x_curve_ends_2_object();
-  Arr_curve_end curr_end, next_end;
-  Comparison_result curr_res, next_res;
-  Comparison_result curr_next_res;
+  typename Gt_adaptor_2::Parameter_space_in_x_2 ps_x_op =
+    m_geom_traits->parameter_space_in_x_2_object();
 
-  curr_end =
+  Arr_curve_end curr_end =
     (curr->direction() == ARR_RIGHT_TO_LEFT) ? ARR_MIN_END : ARR_MAX_END;
-  curr_res = cmp_x_curve_ends(xc, ind, curr->curve(), curr_end);
+  Arr_parameter_space ps_x = ps_x_op(xc, ind);
+  Arr_parameter_space curr_ps_x = ps_x_op(curr->curve(), curr_end);
+
+  Comparison_result curr_res = (ps_x != curr_ps_x) ?
+    ((ps_x == ARR_LEFT_BOUNDARY) ? SMALLER :
+     ((ps_x == ARR_RIGHT_BOUNDARY) ? LARGER :
+      ((curr_ps_x == ARR_LEFT_BOUNDARY) ? LARGER : SMALLER))) :
+    ((ps_x != ARR_INTERIOR) ? EQUAL :
+     cmp_x_curve_ends(xc, ind, curr->curve(), curr_end));
+
   do {
-    next_end =
+    Arr_curve_end next_end =
       (next->direction() == ARR_RIGHT_TO_LEFT) ? ARR_MIN_END : ARR_MAX_END;
-    next_res = cmp_x_curve_ends(xc, ind, next->curve(), next_end);
-    curr_next_res =
-      cmp_x_curve_ends(curr->curve(), curr_end, next->curve(), next_end);
+    Arr_parameter_space next_ps_x = ps_x_op(next->curve(), next_end);
+
+    Comparison_result next_res = (ps_x != next_ps_x) ?
+      ((ps_x == ARR_LEFT_BOUNDARY) ? SMALLER :
+       ((ps_x == ARR_RIGHT_BOUNDARY) ? LARGER :
+        ((next_ps_x == ARR_LEFT_BOUNDARY) ? LARGER : SMALLER))) :
+      ((ps_x != ARR_INTERIOR) ? EQUAL :
+       cmp_x_curve_ends(xc, ind, next->curve(), next_end));
+
+    Comparison_result curr_next_res = (curr_ps_x != next_ps_x) ?
+      ((curr_ps_x == ARR_LEFT_BOUNDARY) ? SMALLER :
+       ((curr_ps_x == ARR_RIGHT_BOUNDARY) ? LARGER :
+        ((next_ps_x == ARR_LEFT_BOUNDARY) ? LARGER : SMALLER))) :
+      ((curr_ps_x != ARR_INTERIOR) ? EQUAL :
+       cmp_x_curve_ends(curr->curve(), curr_end, next->curve(), next_end));
+
     if (curr_next_res == cross_res) {
       // The line of discontinuity must lie between curr and next, so the
       // comparison result of xc with the two curves should be equal:
@@ -804,15 +898,16 @@ _locate_around_pole(Vertex* v,
     curr = next;
     curr_end = next_end;
     curr_res = next_res;
+    curr_ps_x = next_ps_x;
     next = curr->next()->opposite();
   } while (curr != first);
 
-  // We sould never reach here:
+  // We should never reach here:
   CGAL_error();
-  return NULL;
+  return nullptr;
 }
 
-/*! \brief Return the face that lies below the given vertex, which lies
+/*! \brief returns the face that lies below the given vertex, which lies
  * on the line of discontinuity.
  */
 template <typename GeomTraits, typename Dcel>
@@ -826,7 +921,7 @@ _face_below_vertex_on_discontinuity(Vertex* v) const
   // Get the first incident halfedge around v and the next halfedge.
   Halfedge* first = v->halfedge();
   Halfedge* curr = first;
-  CGAL_assertion(curr != NULL);
+  CGAL_assertion(curr != nullptr);
   Halfedge* next = curr->next()->opposite();
 
   // If there is only one halfedge incident to v, return its incident face.
@@ -842,8 +937,8 @@ _face_below_vertex_on_discontinuity(Vertex* v) const
   typename Gt_adaptor_2::Compare_y_at_x_left_2  cmp_y_at_x_op_left =
     m_geom_traits->compare_y_at_x_left_2_object();
 
-  Halfedge* lowest_left = NULL;
-  Halfedge* top_right = NULL;
+  Halfedge* lowest_left = nullptr;
+  Halfedge* top_right = nullptr;
 
   do {
     // Check whether the current halfedge is defined to the left or to the
@@ -851,7 +946,7 @@ _face_below_vertex_on_discontinuity(Vertex* v) const
     if (curr->direction() == ARR_LEFT_TO_RIGHT) {
       // The curve associated with the current halfedge is defined to the left
       // of v.
-      if (lowest_left == NULL ||
+      if (lowest_left == nullptr ||
           cmp_y_at_x_op_left(curr->curve(), lowest_left->curve(), v->point())
           == SMALLER)
       {
@@ -861,7 +956,7 @@ _face_below_vertex_on_discontinuity(Vertex* v) const
     else {
       // The curve associated with the current halfedge is defined to the right
       // of v.
-      if (top_right == NULL ||
+      if (top_right == nullptr ||
           cmp_y_at_x_op_right(curr->curve(), top_right->curve(), v->point()) ==
           LARGER)
       {
@@ -878,7 +973,7 @@ _face_below_vertex_on_discontinuity(Vertex* v) const
   // right. Note that as the halfedge we located has v as its target, we now
   // have to return its twin.
   first =
-    (lowest_left != NULL) ? lowest_left->opposite() : top_right->opposite();
+    (lowest_left != nullptr) ? lowest_left->opposite() : top_right->opposite();
   // std::cout << "first: " << first->opposite()->vertex()->point() << " => "
   //           << first->vertex()->point() << std::endl;
 
