@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arr_trapezoid_ric_point_location.h $
+// $Id: Arr_trapezoid_ric_point_location.h 6642407d603 2020-07-29T18:08:32+03:00 Efi Fogel
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arr_trapezoid_ric_point_location.h $
-// $Id: Arr_trapezoid_ric_point_location.h 18acb2e 2018-01-18T15:05:34+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Idit Haran   <haranidi@post.tau.ac.il>
 //                 (based on old version by Oren Nechushtan and Iddo Hanniel)
@@ -51,28 +42,28 @@ public:
   typedef Arrangement_                          Arrangement_on_surface_2;
 
   //type of geometry traits
-  typedef typename Arrangement_on_surface_2::Geometry_traits_2		
+  typedef typename Arrangement_on_surface_2::Geometry_traits_2
                                                 Geometry_traits_2;
   //type of traits adaptor
-  typedef typename Arrangement_on_surface_2::Traits_adaptor_2		
+  typedef typename Arrangement_on_surface_2::Traits_adaptor_2
                                                 Traits_adaptor_2;
   //type of vertex handle
   typedef typename Arrangement_on_surface_2::Vertex_handle
                                                 Vertex_handle;
   //type of vertex const handle
-  typedef typename Arrangement_on_surface_2::Vertex_const_handle	
+  typedef typename Arrangement_on_surface_2::Vertex_const_handle
                                                 Vertex_const_handle;
   //type of halfedge handle
-  typedef typename Arrangement_on_surface_2::Halfedge_handle	
+  typedef typename Arrangement_on_surface_2::Halfedge_handle
                                                 Halfedge_handle;
   //type of halfedge const handle
-  typedef typename Arrangement_on_surface_2::Halfedge_const_handle	
+  typedef typename Arrangement_on_surface_2::Halfedge_const_handle
                                                 Halfedge_const_handle;
   //type of face const handle
-  typedef typename Arrangement_on_surface_2::Face_const_handle		
+  typedef typename Arrangement_on_surface_2::Face_const_handle
                                                 Face_const_handle;
   //type of edge const iterator
-  typedef typename Arrangement_on_surface_2::Edge_const_iterator	
+  typedef typename Arrangement_on_surface_2::Edge_const_iterator
                                                 Edge_const_iterator;
   //type of isolated vertex const iterator
   typedef typename Arrangement_on_surface_2::Isolated_vertex_const_iterator
@@ -81,74 +72,71 @@ public:
   typedef typename Geometry_traits_2::Point_2             Point_2;
 
   //type of x-monotone curve
-  typedef typename Geometry_traits_2::X_monotone_curve_2  
+  typedef typename Geometry_traits_2::X_monotone_curve_2
                                                 X_monotone_curve_2;
-  
+
   //type of trapezoidal decomposition traits class
-  typedef CGAL::Td_traits<Traits_adaptor_2, Arrangement_on_surface_2> 
+  typedef CGAL::Td_traits<Traits_adaptor_2, Arrangement_on_surface_2>
                                                 Td_traits;
   //type of trapezoidal decomposition class
-  typedef Trapezoidal_decomposition_2<Td_traits>    
+  typedef Trapezoidal_decomposition_2<Td_traits>
                                                 Trapezoidal_decomposition;
-  
+
   //!types of Td_map_item-s
-  typedef typename Trapezoidal_decomposition::Td_map_item       
+  typedef typename Trapezoidal_decomposition::Td_map_item
                                                 Td_map_item;
-  typedef typename Trapezoidal_decomposition::Td_active_vertex  
+  typedef typename Trapezoidal_decomposition::Td_active_vertex
                                                 Td_active_vertex;
-  typedef typename Trapezoidal_decomposition::Td_active_fictitious_vertex  
+  typedef typename Trapezoidal_decomposition::Td_active_fictitious_vertex
                                                 Td_active_fictitious_vertex;
-  typedef typename Trapezoidal_decomposition::Td_active_edge  
+  typedef typename Trapezoidal_decomposition::Td_active_edge
                                                 Td_active_edge;
-  typedef typename Trapezoidal_decomposition::Td_active_trapezoid  
+  typedef typename Trapezoidal_decomposition::Td_active_trapezoid
                                                 Td_active_trapezoid;
   //!type of side tags
-  typedef typename Traits_adaptor_2::Left_side_category   
-                                                Left_side_category;
-  typedef typename Traits_adaptor_2::Bottom_side_category 
-                                                Bottom_side_category;
-  typedef typename Traits_adaptor_2::Top_side_category    
-                                                Top_side_category;
-  typedef typename Traits_adaptor_2::Right_side_category  
-                                                Right_side_category;
- 
+  typedef typename Traits_adaptor_2::Left_side_category   Left_side_category;
+  typedef typename Traits_adaptor_2::Bottom_side_category Bottom_side_category;
+  typedef typename Traits_adaptor_2::Top_side_category    Top_side_category;
+  typedef typename Traits_adaptor_2::Right_side_category  Right_side_category;
+
 protected:
   typedef Arr_point_location_result<Arrangement_on_surface_2>        Result;
-  typedef typename Result::Type                           Result_type;
+  typedef typename Result::Type                         Result_type;
 
 public:
   // Support cpp11::result_of
-  typedef Result_type                                     result_type;
+  typedef Result_type                                   result_type;
 
 protected:
   //type of trapezoidal decomposition class
-  typedef Trapezoidal_decomposition             TD;
+  typedef Trapezoidal_decomposition                     TD;
 
-  typedef typename Arr_are_all_sides_oblivious_tag< 
-                     Left_side_category, Bottom_side_category, 
-                     Top_side_category, Right_side_category >::result
-    Are_all_sides_oblivious_category;
+  typedef typename Arr_all_sides_oblivious_category<Left_side_category,
+                                                    Bottom_side_category,
+                                                    Top_side_category,
+                                                    Right_side_category>::result
+    All_sides_oblivious_category;
 
   // Data members:
-  const Traits_adaptor_2 *m_traits;  // Its associated traits object.
-  TD  td;       // instance of trapezoidal decomposition
+  const Traits_adaptor_2* m_traits; // Its associated traits object.
+  TD  td;                           // instance of trapezoidal decomposition
   bool m_with_guarantees;
   //for the notification functions
-  X_monotone_curve_2  m_cv_before_split; 
+  X_monotone_curve_2  m_cv_before_split;
   Halfedge_handle     m_he_after_merge;
   //X_monotone_curve_2        m_cv_before_merge1;
   //X_monotone_curve_2        m_cv_before_merge2;
 
-  template<typename T>
+  template <typename T>
   Result_type make_result(T t) const { return Result::make_result(t); }
   inline Result_type default_result() const { return Result::default_result(); }
 
 public:
   /*! Default constructor. */
-  Arr_trapezoid_ric_point_location (bool with_guarantees = true, 
-                           double depth_thrs = CGAL_TD_DEFAULT_DEPTH_THRESHOLD, 
-                           double size_thrs = CGAL_TD_DEFAULT_SIZE_THRESHOLD) 
-    : m_traits (NULL), m_with_guarantees(with_guarantees)
+  Arr_trapezoid_ric_point_location(bool with_guarantees = true,
+                                   double depth_thrs = CGAL_TD_DEFAULT_DEPTH_THRESHOLD,
+                                   double size_thrs = CGAL_TD_DEFAULT_SIZE_THRESHOLD) :
+    m_traits(nullptr), m_with_guarantees(with_guarantees)
   {
     td.set_with_guarantees(with_guarantees);
     td.depth_threshold(depth_thrs);
@@ -156,11 +144,11 @@ public:
   }
 
   /*! Constructor given an arrangement. */
-  Arr_trapezoid_ric_point_location (const Arrangement_on_surface_2& arr, 
-                           bool with_guarantees = true, 
-                           double depth_thrs = CGAL_TD_DEFAULT_DEPTH_THRESHOLD, 
+  Arr_trapezoid_ric_point_location (const Arrangement_on_surface_2& arr,
+                           bool with_guarantees = true,
+                           double depth_thrs = CGAL_TD_DEFAULT_DEPTH_THRESHOLD,
                            double size_thrs = CGAL_TD_DEFAULT_SIZE_THRESHOLD) :
-    Arr_observer<Arrangement_on_surface_2> 
+    Arr_observer<Arrangement_on_surface_2>
               (const_cast<Arrangement_on_surface_2 &>(arr)),
     m_with_guarantees(with_guarantees)
   {
@@ -175,11 +163,11 @@ public:
   /*! Destructor. */
   ~Arr_trapezoid_ric_point_location () { }
 
-  /*! defines whether the underlying search structure guarantees logarithmic 
+  /*! defines whether the underlying search structure guarantees logarithmic
    *   query time and linear size */
   void with_guarantees (bool with_guarantees)
   {
-    //if with_guarantees was changed from false to true - reconstruct 
+    //if with_guarantees was changed from false to true - reconstruct
     //  the search structure with guarantees
     td.set_with_guarantees(with_guarantees);
     if (with_guarantees && !m_with_guarantees)
@@ -189,8 +177,8 @@ public:
     }
     m_with_guarantees = with_guarantees;
   }
-  
-  /*! returns the depth of the underlying search structure 
+
+  /*! returns the depth of the underlying search structure
    *    (the longest path in the DAG)
    */
   unsigned long depth() //longest_dag_path()
@@ -259,7 +247,7 @@ public:
   }
 
   virtual void after_assign ()
-  { 
+  {
     _construct_td();
   }
 
@@ -295,22 +283,22 @@ public:
     td.insert(e);
   }
 
-  //TODO IDIT OREN: what can be done in order to avoid the need 
-  //to save the original curve is to find the common endpoint of the 
-  //two new halfedges, locate it in the trapezoid in order to find the 
-  //curve it lies on, which is the curve that was split, and then remove 
+  //TODO IDIT OREN: what can be done in order to avoid the need
+  //to save the original curve is to find the common endpoint of the
+  //two new halfedges, locate it in the trapezoid in order to find the
+  //curve it lies on, which is the curve that was split, and then remove
   //this curve.
   virtual void before_split_edge (Halfedge_handle e,
-				                          Vertex_handle /* v */,
+                                                          Vertex_handle /* v */,
                                   const X_monotone_curve_2&  /* cv1 */ ,
                                   const X_monotone_curve_2&  /* cv2 */ )
   {
-  
+
     ////MICHAL: commented due to inefficient depth update, remove and insert instead
     ////save the curve for the "after" function.
     //m_cv_before_split = e->curve();
-    //td.before_split_edge(m_cv_before_split, cv1, cv2); 
-    
+    //td.before_split_edge(m_cv_before_split, cv1, cv2);
+
     td.remove(e);
   }
 
@@ -319,7 +307,7 @@ public:
   {
     //MICHAL: commented due to inefficient depth update, remove and insert instead
     //td.split_edge(m_cv_before_split,e1,e2);
-    
+
     td.insert(e1);
     td.insert(e2);
   }
@@ -360,8 +348,8 @@ protected:
   void _construct_td ()
   {
     td.clear();
- 
-    std::vector<Halfedge_const_handle> he_container; 
+
+    std::vector<Halfedge_const_handle> he_container;
     Edge_const_iterator eit;
     Halfedge_const_handle he_cst;
     Arrangement_on_surface_2 *arr = this->arrangement();
@@ -372,7 +360,7 @@ protected:
       he_container.push_back(he_cst);
     }
     //container insertion
-    td.insert(he_container.begin(), he_container.end()); 
+    td.insert(he_container.begin(), he_container.end());
   }
 
   /*! gets the unbounded face that contains the point when the trapezoid is
@@ -382,9 +370,9 @@ protected:
    * \param Arr_all_sides_oblivious_tag
    * \return A Face_const_handle representing the arrangement unbounded face in
    *         which the point p lies
-   */ 
+   */
   Face_const_handle _get_unbounded_face (const Td_map_item& tr,
-                                         const Point_2& p, 
+                                         const Point_2& p,
                                          Arr_all_sides_oblivious_tag) const;
 
   /*! gets the unbounded face that contains the point when the trapezoid is
@@ -392,11 +380,11 @@ protected:
    * \param tr The unbounded trapezoid whose face we should get
    * \param p  The query point.
    * \param Arr_not_all_sides_oblivious_tag
-   * \return A Face_const_handle representing the arrangement unbounded face in which 
+   * \return A Face_const_handle representing the arrangement unbounded face in which
    *         the point p lies
-   */ 
+   */
   Face_const_handle _get_unbounded_face (const Td_map_item& tr,
-                                         const Point_2& p, 
+                                         const Point_2& p,
                                          Arr_not_all_sides_oblivious_tag) const;
 
   /*!
@@ -414,10 +402,10 @@ protected:
    * (or unbounded face)
    * we check the isolated vertices inside the face to check whether there
    * is an isolated vertex right above/below the query point.
-   */ 
+   */
   result_type
   _check_isolated_for_vertical_ray_shoot
-                             (Halfedge_const_handle halfedge_found, 
+                             (Halfedge_const_handle halfedge_found,
                               const Point_2& p, bool shoot_up,
                               const Td_map_item& tr) const;
 };
