@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Arrangement_on_surface_2/include/CGAL/Arrangement_2/graph_traits_dual.h $
-// $Id: graph_traits_dual.h 7a4e740 2018-09-01T19:44:52+03:00 Efi Fogel
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Arrangement_on_surface_2/include/CGAL/Arrangement_2/graph_traits_dual.h $
+// $Id: graph_traits_dual.h 014c06fd19a 2022-11-14T15:32:47+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s) : Ron Wein         <wein@post.tau.ac.il>
@@ -22,7 +13,7 @@
 //             Sebastien Loriot <sebastien.loriot@cgal.org>
 //             Efi Fogel        <efifogel@gmail.com>
 
-// This file contains the follwoing three parts:
+// This file contains the following three parts:
 // 1. The common base class template of the specialized
 //      Dual<specialized-arrangement> class template.
 //
@@ -33,8 +24,8 @@
 //    the various Boost Graph concepts. There is one macro per required function
 //    template. Each macro accepts the name of a template class, an instance of
 //    which represents an arrangement data structure, e.g., Arrangement_2. The
-//    definitios of the free functions templates for a given arrangement data
-//    strcture must be present when a dual of this data structure is defined.
+//    definitions of the free functions templates for a given arrangement data
+//    structure must be present when a dual of this data structure is defined.
 
 #include <CGAL/license/Arrangement_on_surface_2.h>
 
@@ -185,7 +176,7 @@ protected:
                 _ccb_curr == it._ccb_curr)));
     }
 
-    /*! Derefernce the current circulator. */
+    /*! Dereference the current circulator. */
     Edge_handle _dereference() const
     {
       if (_out) return (_ccb_curr);
@@ -247,7 +238,7 @@ public:
   typedef Face_neighbor_iterator            Incident_edge_iterator;
 
   /*! Default constructor. */
-  Dual_arrangement_on_surface() : p_arr(NULL) {}
+  Dual_arrangement_on_surface() : p_arr(nullptr) {}
 
   /*! Constructor from an arrangement. */
   Dual_arrangement_on_surface(const Arrangement& arr) :
@@ -323,9 +314,9 @@ namespace CGAL {
 /*! \class
  * The common base class template of the specialized
  *   boost::graph_traits<Dual<specialized-arrangement> > class template.
- * The latter serves as a dual adapter for the specialied arrangment, where the
+ * The latter serves as a dual adapter for the specialied arrangement, where the
  * valid arrangement faces correspond to graph verices, and two graph vertices
- * are connected if the two corrsponding faces are adjacent.
+ * are connected if the two corresponding faces are adjacent.
  * We consider the graph as directed. We also allow parallel edges, as two
  * faces may have more than one common edges.
  */
