@@ -1,25 +1,16 @@
-// Copyright (c) 2000  
+// Copyright (c) 2000
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Cartesian_kernel/include/CGAL/Cartesian/Translation_rep_3.h $
+// $Id: Translation_rep_3.h e73b8de89fd 2021-04-22T21:17:24+01:00 Andreas Fabri
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Cartesian_kernel/include/CGAL/Cartesian/Translation_rep_3.h $
-// $Id: Translation_rep_3.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Herve Bronnimann
 
@@ -43,8 +34,9 @@ public:
   typedef typename Transformation_base_3::Point_3       Point_3;
   typedef typename Transformation_base_3::Vector_3      Vector_3;
   typedef typename Transformation_base_3::Direction_3   Direction_3;
+  typedef typename Transformation_base_3::Plane_3       Plane_3;
   typedef typename Transformation_base_3::Aff_transformation_3
-	                                                Aff_transformation_3;
+                                                        Aff_transformation_3;
 
   Translation_repC3() {}
   Translation_repC3(const Vector_3 &tv) : translationvector_(tv) {}
@@ -65,6 +57,15 @@ public:
     return d;
   }
 
+  virtual Plane_3 transform(const Plane_3 &p) const
+  {
+    // direction ( which is (p.a(), p.b(), p.c())) does not change
+    return Plane_3(p.a(),
+                   p.b(),
+                   p.c(),
+                   p.d()  - ( p.a()*translationvector_.x() + p.b()*translationvector_.y() + p.c()*translationvector_.z()));
+  }
+
   virtual Aff_transformation_3 operator*(const Transformation_base_3 &t) const
   {
     return t.compose(*this);
@@ -74,24 +75,24 @@ public:
   {
     return Aff_transformation_3(t.t11,
                                 t.t12,
-				t.t13,
-				t.t11 * translationvector_.x()
-				+ t.t12 * translationvector_.y()
-				+ t.t13 * translationvector_.z() + t.t14,
-				
-				t.t21,
+                                t.t13,
+                                t.t11 * translationvector_.x()
+                                + t.t12 * translationvector_.y()
+                                + t.t13 * translationvector_.z() + t.t14,
+
+                                t.t21,
                                 t.t22,
-				t.t23,
-				t.t21 * translationvector_.x()
-				+ t.t22 * translationvector_.y()
-				+ t.t23 * translationvector_.z() + t.t24,
-				
-				t.t31,
+                                t.t23,
+                                t.t21 * translationvector_.x()
+                                + t.t22 * translationvector_.y()
+                                + t.t23 * translationvector_.z() + t.t24,
+
+                                t.t31,
                                 t.t32,
-				t.t33,
-				t.t31 * translationvector_.x()
-				+ t.t32 * translationvector_.y()
-				+ t.t33 * translationvector_.z() + t.t34);
+                                t.t33,
+                                t.t31 * translationvector_.x()
+                                + t.t32 * translationvector_.y()
+                                + t.t33 * translationvector_.z() + t.t34);
   }
 
   virtual Aff_transformation_3 compose(const Translation_3 &t) const
@@ -105,18 +106,18 @@ public:
     FT ft0(0);
     return Aff_transformation_3(t.scalefactor_,
                                 ft0,
-				ft0,
-				t.scalefactor_ * translationvector_.x(),
-				
-				ft0,
-                                t.scalefactor_,
-				ft0,
-				t.scalefactor_ * translationvector_.y(),
-				
-				ft0,
                                 ft0,
-				t.scalefactor_,
-				t.scalefactor_ * translationvector_.z());
+                                t.scalefactor_ * translationvector_.x(),
+
+                                ft0,
+                                t.scalefactor_,
+                                ft0,
+                                t.scalefactor_ * translationvector_.y(),
+
+                                ft0,
+                                ft0,
+                                t.scalefactor_,
+                                t.scalefactor_ * translationvector_.z());
   }
 
   virtual Aff_transformation_3 inverse() const
@@ -128,12 +129,17 @@ public:
   {
     return Aff_transformation_3(TRANSLATION, translationvector_);
   }
-  
+
   virtual bool is_even() const
   {
     return true;
   }
 
+  virtual bool is_translation() const
+  {
+    return true;
+  }
+
   virtual FT cartesian(int i, int j) const
   {
     if (j==i) return FT(1);
