@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Circular_kernel_2/include/CGAL/Circular_kernel_2/internal_functions_on_line_arc_2.h $
-// $Id: internal_functions_on_line_arc_2.h 0d3ac75 2018-02-17T12:37:15+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Circular_kernel_2/include/CGAL/Circular_kernel_2/internal_functions_on_line_arc_2.h $
+// $Id: internal_functions_on_line_arc_2.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -40,11 +31,11 @@ namespace CircularFunctors {
   template < class CK >
   bool
   point_in_x_range(const typename CK::Line_arc_2 &A,
-		   const typename CK::Circular_arc_point_2 &p)
+                   const typename CK::Circular_arc_point_2 &p)
   {
     // range includes endpoints here
     return ( (CircularFunctors::compare_x<CK>(p, A.source()) != CircularFunctors::compare_x<CK>(p, A.target()))
-	     || (CircularFunctors::compare_x<CK>(p, A.source()) == CGAL::EQUAL) );
+             || (CircularFunctors::compare_x<CK>(p, A.source()) == CGAL::EQUAL) );
   }
 
   template < class CK >
@@ -57,15 +48,15 @@ namespace CircularFunctors {
       return false;
 
     return ( (equal<CK>(A1.source(), A2.source()) &&
-	      equal<CK>(A1.target(), A2.target())) ||
-	     (equal<CK>(A1.target(), A2.source()) &&
-	      equal<CK>(A1.source(), A2.target())) );
+              equal<CK>(A1.target(), A2.target())) ||
+             (equal<CK>(A1.target(), A2.source()) &&
+              equal<CK>(A1.source(), A2.target())) );
   }
 
   template < class CK >
   bool
   do_overlap(const typename CK::Line_arc_2 &A1,
-	     const typename CK::Line_arc_2 &A2)
+             const typename CK::Line_arc_2 &A2)
   {
     if (!LinearFunctors::non_oriented_equal<CK>(
       A1.supporting_line(),A2.supporting_line()))
@@ -79,7 +70,7 @@ namespace CircularFunctors {
   template < class CK >
   bool
   has_on(const typename CK::Line_arc_2 &a,
-	 const typename CK::Circular_arc_point_2 &p,
+         const typename CK::Circular_arc_point_2 &p,
          const bool has_on_supporting_line = false)
   {
     if(p.equal_ref(a.source()) || p.equal_ref(a.target())){
@@ -128,10 +119,10 @@ namespace CircularFunctors {
     //vertical case
     if (CircularFunctors::is_vertical<CK>(A1)) {
       if (p.y() <= A1.right().y()) {
-	if(A1.left().y() <= p.y()) {
-	  return CGAL::EQUAL;
-	}
-	return CGAL::SMALLER;
+        if(A1.left().y() <= p.y()) {
+          return CGAL::EQUAL;
+        }
+        return CGAL::SMALLER;
       }
       return CGAL::LARGER;
     }
@@ -151,12 +142,12 @@ namespace CircularFunctors {
   template < class CK >
   Comparison_result
   compare_y_to_right(const typename CK::Line_arc_2 &A1,
-		     const typename CK::Line_arc_2 &A2,
-		     const typename CK::Circular_arc_point_2 &/*p*/)
+                     const typename CK::Line_arc_2 &A2,
+                     const typename CK::Circular_arc_point_2 &/*p*/)
   {
     if(A1.supporting_line().is_vertical()){
       if(A2.supporting_line().is_vertical())
-	return CGAL::EQUAL;
+        return CGAL::EQUAL;
       return CGAL::LARGER;
     }
     if(A2.supporting_line().is_vertical())
@@ -171,9 +162,9 @@ namespace CircularFunctors {
       Root_of_2 y((-A1.right().x()*equation.a() - equation.c())/equation.b());
       Root_of_2 A1_right_y = A1.right().y();
       if (y == A1_right_y)
-	return CGAL::EQUAL;
+        return CGAL::EQUAL;
       if (y < A1_right_y)
-	return CGAL::LARGER;
+        return CGAL::LARGER;
       return CGAL::SMALLER;
     }
     else{
@@ -181,9 +172,9 @@ namespace CircularFunctors {
       Root_of_2 y((-A2.right().x()*equation.a() - equation.c())/equation.b());
       Root_of_2 A2_right_y = A2.right().y();
       if (y == A2_right_y)
-	return CGAL::EQUAL;
+        return CGAL::EQUAL;
       if (y < A2_right_y)
-	return CGAL::SMALLER;
+        return CGAL::SMALLER;
       return CGAL::LARGER;
     }
 
@@ -192,8 +183,8 @@ namespace CircularFunctors {
   template < class CK >
   Comparison_result
   compare_y_to_right(const typename CK::Line_arc_2 &A1,
-		     const typename CK::Circular_arc_2 &A2,
-		     const typename CK::Circular_arc_point_2 &p)
+                     const typename CK::Circular_arc_2 &A2,
+                     const typename CK::Circular_arc_point_2 &p)
   {
     //CGAL_kernel_precondition (A2.is_x_monotone());
     if(A1.supporting_line().is_vertical())
@@ -243,14 +234,14 @@ namespace CircularFunctors {
 
 
     if (((tangent_1_x < 0) && (tangent_2_x > 0)) ||
-	((tangent_1_x > 0) && (tangent_2_x < 0))){
+        ((tangent_1_x > 0) && (tangent_2_x < 0))){
       Root_of_2 prod_left = tangent_1_y * tangent_2_x;
       Root_of_2 prod_right = tangent_2_y * tangent_1_x;
       if (prod_left < prod_right){
-	return CGAL::LARGER;
+        return CGAL::LARGER;
       }
       if (prod_left == prod_right){
-	return  A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
+        return  A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
       }
       return CGAL::SMALLER;
     }
@@ -258,10 +249,10 @@ namespace CircularFunctors {
       Root_of_2 prod_left = tangent_1_y * tangent_2_x;
       Root_of_2 prod_right = tangent_2_y * tangent_1_x;
       if (prod_left < prod_right){
-	return CGAL::SMALLER;
+        return CGAL::SMALLER;
       }
       if (prod_left == prod_right){
-	return A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
+        return A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
       }
       return CGAL::LARGER;
     }
@@ -271,8 +262,8 @@ namespace CircularFunctors {
   template < class CK >
   Comparison_result
   compare_y_to_left(const typename CK::Line_arc_2 &A1,
-		    const typename CK::Circular_arc_2 &A2,
-		    const typename CK::Circular_arc_point_2 &p)
+                    const typename CK::Circular_arc_2 &A2,
+                    const typename CK::Circular_arc_point_2 &p)
   {
     //CGAL_kernel_precondition (A2.is_x_monotone());
     if(A1.supporting_line().is_vertical())
@@ -321,14 +312,14 @@ namespace CircularFunctors {
 
 
     if (((tangent_1_x < 0) && (tangent_2_x > 0)) ||
-	((tangent_1_x > 0) && (tangent_2_x < 0))){
+        ((tangent_1_x > 0) && (tangent_2_x < 0))){
       Root_of_2 prod_left = tangent_1_y * tangent_2_x;
       Root_of_2 prod_right = tangent_2_y * tangent_1_x;
       if (prod_left < prod_right){
-	return CGAL::SMALLER;
+        return CGAL::SMALLER;
       }
       if (prod_left == prod_right){
-	return  A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
+        return  A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
       }
       return CGAL::LARGER;
     }
@@ -336,10 +327,10 @@ namespace CircularFunctors {
       Root_of_2 prod_left = tangent_1_y * tangent_2_x;
       Root_of_2 prod_right = tangent_2_y * tangent_1_x;
       if (prod_left < prod_right){
-	return CGAL::LARGER;
+        return CGAL::LARGER;
       }
       if (prod_left == prod_right){
-	      return A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
+              return A2.on_upper_part() ? CGAL::LARGER : CGAL::SMALLER;
       }
       return CGAL::SMALLER;
     }
@@ -349,8 +340,8 @@ namespace CircularFunctors {
   template < class CK >
   Comparison_result
   compare_y_to_right(const typename CK::Circular_arc_2 &A1,
-		     const typename CK::Line_arc_2 &A2,
-		     const typename CK::Circular_arc_point_2 &p)
+                     const typename CK::Line_arc_2 &A2,
+                     const typename CK::Circular_arc_point_2 &p)
   {
     if (compare_y_to_right<CK>(A2, A1, p) == CGAL::LARGER)
       return CGAL::SMALLER;
@@ -361,9 +352,9 @@ namespace CircularFunctors {
   template < class CK >
   void
   split(const typename CK::Line_arc_2 &A,
-	const typename CK::Circular_arc_point_2 &p,
-	typename CK::Line_arc_2 &ca1,
-	typename CK::Line_arc_2 &ca2)
+        const typename CK::Circular_arc_point_2 &p,
+        typename CK::Line_arc_2 &ca1,
+        typename CK::Line_arc_2 &ca2)
   {
     CGAL_kernel_precondition( has_on<CK>(A, p));
 
@@ -383,8 +374,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_2 & l,
-	       const typename CK::Circle_2 & c,
-	       OutputIterator res )
+               const typename CK::Circle_2 & c,
+               OutputIterator res )
   {
     typedef typename CK2_Intersection_traits<CK, typename CK::Line_2, typename CK::Circle_2>
       ::type result_type;
@@ -406,10 +397,10 @@ namespace CircularFunctors {
     typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
 
     for ( typename solutions_container::iterator it = solutions.begin();
-	  it != solutions.end(); ++it )
+          it != solutions.end(); ++it )
       {
-	*res++ = CGAL::internal::ck2_intersection_return<result_type>
-	  (std::make_pair(Circular_arc_point_2(it->first), it->second ));
+        *res++ = CGAL::internal::ck2_intersection_return<result_type>
+          (std::make_pair(Circular_arc_point_2(it->first), it->second ));
       }
 
     return res;
@@ -418,8 +409,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_arc_2 &a1,
-	       const typename CK::Line_arc_2 &a2,
-	       OutputIterator res )
+               const typename CK::Line_arc_2 &a2,
+               OutputIterator res )
   {
     typedef typename CK2_Intersection_traits<CK, typename CK::Line_arc_2, typename CK::Line_arc_2>
       ::type result_type;
@@ -441,8 +432,8 @@ namespace CircularFunctors {
     }
     if(a1s_a2s || a1s_a2t || a1t_a2s || a1t_a2t) {
       if(! LinearFunctors::non_oriented_equal<CK>(a1.supporting_line(),a2.supporting_line())){
-	if(a1s_a2s || a1s_a2t) *res++ = CGAL::internal::ck2_intersection_return<result_type>(std::make_pair(a1.source(), 1u));
-	if(a1t_a2s || a1t_a2t) *res++ = CGAL::internal::ck2_intersection_return<result_type>(std::make_pair(a1.target(), 1u));
+        if(a1s_a2s || a1s_a2t) *res++ = CGAL::internal::ck2_intersection_return<result_type>(std::make_pair(a1.source(), 1u));
+        if(a1t_a2s || a1t_a2t) *res++ = CGAL::internal::ck2_intersection_return<result_type>(std::make_pair(a1.target(), 1u));
       return res;
       }
     }
@@ -451,39 +442,39 @@ namespace CircularFunctors {
     if(LinearFunctors::non_oriented_equal<CK>(
       a1.supporting_line(),a2.supporting_line())) {
       if(compare_xy(a1.left(),a2.left()) < 0) {
-	int comparison = compare_xy(a2.left(),a1.right());
-	if(comparison < 0){
-	  if(compare_xy(a1.right(),a2.right()) <= 0){
-	    *res++ = CGAL::internal::ck2_intersection_return<result_type>
-	      (Line_arc_2(a1.supporting_line(), a2.left(), a1.right() ));
-	  } else{
-	    *res++ = CGAL::internal::ck2_intersection_return<result_type>
-	      (Line_arc_2(a1.supporting_line(), a2.left(), a2.right() ));
-	  }
-	}
-	else if (comparison == 0){
-	  *res++ =CGAL::internal::ck2_intersection_return<result_type>
-	    ( std::make_pair(a2.left(),1u));
-	}
-	return res;
+        int comparison = compare_xy(a2.left(),a1.right());
+        if(comparison < 0){
+          if(compare_xy(a1.right(),a2.right()) <= 0){
+            *res++ = CGAL::internal::ck2_intersection_return<result_type>
+              (Line_arc_2(a1.supporting_line(), a2.left(), a1.right() ));
+          } else{
+            *res++ = CGAL::internal::ck2_intersection_return<result_type>
+              (Line_arc_2(a1.supporting_line(), a2.left(), a2.right() ));
+          }
+        }
+        else if (comparison == 0){
+          *res++ =CGAL::internal::ck2_intersection_return<result_type>
+            ( std::make_pair(a2.left(),1u));
+        }
+        return res;
       }
       else{
-	int comparison = compare_xy(a1.left(),a2.right());
-	if(comparison < 0){
-	  if(compare_xy(a1.right(),a2.right()) <= 0){
-	    *res++ = CGAL::internal::ck2_intersection_return<result_type>
-	      (Line_arc_2(a1.supporting_line(), a1.left(), a1.right() ));
-	  }
-	  else{
-	    *res++ = CGAL::internal::ck2_intersection_return<result_type>
-	      (Line_arc_2(a1.supporting_line(), a1.left(), a2.right() ));
-	  }
-	}
-	else if (comparison == 0){
-	  *res++ = CGAL::internal::ck2_intersection_return<result_type>
-	    ( std::make_pair(a1.left(),1u));
-	}
-	return res;
+        int comparison = compare_xy(a1.left(),a2.right());
+        if(comparison < 0){
+          if(compare_xy(a1.right(),a2.right()) <= 0){
+            *res++ = CGAL::internal::ck2_intersection_return<result_type>
+              (Line_arc_2(a1.supporting_line(), a1.left(), a1.right() ));
+          }
+          else{
+            *res++ = CGAL::internal::ck2_intersection_return<result_type>
+              (Line_arc_2(a1.supporting_line(), a1.left(), a2.right() ));
+          }
+        }
+        else if (comparison == 0){
+          *res++ = CGAL::internal::ck2_intersection_return<result_type>
+            ( std::make_pair(a1.left(),1u));
+        }
+        return res;
       }
     }
 
@@ -492,14 +483,14 @@ namespace CircularFunctors {
     if(!v) return res;
 
     const Point_2 *pt = CGAL::Intersections::internal::intersect_get<Point_2>(v);
-    if(pt == NULL) return res;
+    if(pt == nullptr) return res;
     Circular_arc_point_2 intersect_point = Circular_arc_point_2(*pt);
     //      (Root_for_circles_2_2(Root_of_2(pt->x()),Root_of_2(pt->y())));
 
     if ((CircularFunctors::compare_xy<CK>(intersect_point, a1.source()) !=
-	 CircularFunctors::compare_xy<CK>(intersect_point, a1.target())) &&
-	(CircularFunctors::compare_xy<CK>(intersect_point, a2.source()) !=
-	 CircularFunctors::compare_xy<CK>(intersect_point, a2.target())))
+         CircularFunctors::compare_xy<CK>(intersect_point, a1.target())) &&
+        (CircularFunctors::compare_xy<CK>(intersect_point, a2.source()) !=
+         CircularFunctors::compare_xy<CK>(intersect_point, a2.target())))
       *res++ = CGAL::internal::ck2_intersection_return<result_type>(std::make_pair(intersect_point, 1u));
 
     return res;
@@ -524,8 +515,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_arc_2 &l,
-	       const typename CK::Circle_2 &c,
-	       OutputIterator res )
+               const typename CK::Circle_2 &c,
+               OutputIterator res )
   {
     typedef std::vector<typename CK2_Intersection_traits<CK, typename CK::Line_2, typename CK::Circle_2>::type>
       solutions_container;
@@ -535,19 +526,9 @@ namespace CircularFunctors {
       ( l.supporting_line(), c, std::back_inserter(solutions) );
 
     for (typename solutions_container::iterator it = solutions.begin();
-	 it != solutions.end(); ++it) {
-      #if CGAL_INTERSECTION_VERSION  < 2
-      if(const std::pair<typename CK::Circular_arc_point_2, unsigned>* p =
-         object_cast< std::pair< typename CK::Circular_arc_point_2, unsigned> >(& (*it))) {
-        Has_on_visitor<CK, typename CK::Line_arc_2> vis(&l);
-        if(vis(*p)) {
-	*res++ = *it;
-    }
-  }
-      #else
+         it != solutions.end(); ++it) {
       if(boost::apply_visitor(Has_on_visitor<CK, typename CK::Line_arc_2>(&l), *it))
-	*res++ = *it;
-      #endif
+        *res++ = *it;
     }
 
     return res;
@@ -556,8 +537,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Circle_2 &c,
-	       const typename CK::Line_arc_2 &l,
-	       OutputIterator res )
+               const typename CK::Line_arc_2 &l,
+               OutputIterator res )
   {
     return intersect_2<CK>(l,c,res);
   }
@@ -565,8 +546,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_arc_2 &l,
-	       const typename CK::Circular_arc_2 &c,
-	       OutputIterator res )
+               const typename CK::Circular_arc_2 &c,
+               OutputIterator res )
   {
 #if defined(CGAL_CK_EXPLOIT_IDENTITY) || \
   defined(CGAL_INTERSECTION_MAP_FOR_SUPPORTING_CIRCLES)
@@ -584,88 +565,88 @@ namespace CircularFunctors {
 
     if((ls_cs && lt_ct) || (ls_ct && lt_cs)){ // Case 0
       if (compare_xy<CK>(l.source(), l.target()) == SMALLER){
-	*res++ = result_type(std::make_pair(l.source(), 1u));
-	*res++ = result_type(std::make_pair(l.target(), 1u));
+        *res++ = result_type(std::make_pair(l.source(), 1u));
+        *res++ = result_type(std::make_pair(l.target(), 1u));
       } else {
-	*res++ = result_type(std::make_pair(l.target(), 1u));
-	*res++ = result_type(std::make_pair(l.source(), 1u));
+        *res++ = result_type(std::make_pair(l.target(), 1u));
+        *res++ = result_type(std::make_pair(l.source(), 1u));
       }
       return res;
     } else if (ls_cs || lt_ct || ls_ct || lt_cs) {
       Circular_arc_point_2 p,q,r;
 
       if(ls_cs){
-	p = l.target();
-	q = l.source();
-	r = c.target();
+        p = l.target();
+        q = l.source();
+        r = c.target();
       } else if(ls_ct){
-	p = l.target();
-	q = l.source();
-	r = c.source();
+        p = l.target();
+        q = l.source();
+        r = c.source();
       } else if(lt_cs){
-	p = l.source();
-	q = l.target();
-	r = c.target();
+        p = l.source();
+        q = l.target();
+        r = c.target();
       } else { // lt_ct
-	p = l.source();
-	q = l.target();
-	r = c.source();
+        p = l.source();
+        q = l.target();
+        r = c.source();
       }
 
       if( (CircularFunctors::compare_x<CK>(p,q) == EQUAL) || CircularFunctors::point_in_x_range<CK>(p,r,q)){ // Case 1
-	*res++ = result_type(std::make_pair(q,1u));
-	return res;
+        *res++ = result_type(std::make_pair(q,1u));
+        return res;
       }
        else if(c.on_upper_part()){ // Case 2
-	if(CircularFunctors::compare_x<CK>(r,q) == LARGER){
-	  if(CircularFunctors::orientation<CK>(q,r,p) == RIGHT_TURN   // Case 2
-	     || CircularFunctors::compare_y_to_right<CK>(l,c,q) == LARGER){ // Case 3a
-	    *res++ = result_type(std::make_pair(q,1u));
-	    return res;
-	  }
-	} else {
-	  if(CircularFunctors::orientation<CK>(r,q,p) == RIGHT_TURN  // Case 2
-	  || CircularFunctors::compare_y_to_left<CK>(l,c,q) == LARGER){ // Case 3c
-	    *res++ = result_type(std::make_pair(q,1u));
-	    return res;
-	  }
-	}
+        if(CircularFunctors::compare_x<CK>(r,q) == LARGER){
+          if(CircularFunctors::orientation<CK>(q,r,p) == RIGHT_TURN   // Case 2
+             || CircularFunctors::compare_y_to_right<CK>(l,c,q) == LARGER){ // Case 3a
+            *res++ = result_type(std::make_pair(q,1u));
+            return res;
+          }
+        } else {
+          if(CircularFunctors::orientation<CK>(r,q,p) == RIGHT_TURN  // Case 2
+          || CircularFunctors::compare_y_to_left<CK>(l,c,q) == LARGER){ // Case 3c
+            *res++ = result_type(std::make_pair(q,1u));
+            return res;
+          }
+        }
        } else { // c on lower part
-	if(CircularFunctors::compare_x<CK>(r,q) == LARGER){
-	  if (CircularFunctors::orientation<CK>(q,r,p) == LEFT_TURN // Case 2
-	    || CircularFunctors::compare_y_to_right<CK>(l,c,q) == SMALLER){  // Case 3b
-	    *res++ = result_type(std::make_pair(q,1u));
-	    return res;
-	  }
-	} else {
-	  if(CircularFunctors::orientation<CK>(r,q,p) == LEFT_TURN
-	     || CircularFunctors::compare_y_to_left<CK>(l,c,q) == SMALLER){ // Case 3d
-	    *res++ = result_type(std::make_pair(q,1u));
-	    return res;
-	  }
-	}
+        if(CircularFunctors::compare_x<CK>(r,q) == LARGER){
+          if (CircularFunctors::orientation<CK>(q,r,p) == LEFT_TURN // Case 2
+            || CircularFunctors::compare_y_to_right<CK>(l,c,q) == SMALLER){  // Case 3b
+            *res++ = result_type(std::make_pair(q,1u));
+            return res;
+          }
+        } else {
+          if(CircularFunctors::orientation<CK>(r,q,p) == LEFT_TURN
+             || CircularFunctors::compare_y_to_left<CK>(l,c,q) == SMALLER){ // Case 3d
+            *res++ = result_type(std::make_pair(q,1u));
+            return res;
+          }
+        }
        }
 
       typename CK::Linear_kernel::Bounded_side bs = CircularFunctors::bounded_side<CK>(c.supporting_circle(),p);
       if(bs == ON_BOUNDED_SIDE){
-	*res++ = result_type(std::make_pair(q,1u));
-	return res;
+        *res++ = result_type(std::make_pair(q,1u));
+        return res;
       } else { //Case 4b
         typedef std::vector<typename CK2_Intersection_traits<CK, typename CK::Line_2, typename CK::Circle_2>::type>
           container;
         container solutions;
-	CGAL::CircularFunctors::intersect_2<CK>( l.supporting_line(), c.supporting_circle(),
-					       std::back_inserter(solutions) );
+        CGAL::CircularFunctors::intersect_2<CK>( l.supporting_line(), c.supporting_circle(),
+                                               std::back_inserter(solutions) );
 
-	if(CircularFunctors::compare_x<CK>(r,q) == LARGER){
-	  *res++ = result_type(std::make_pair(q,1u));
-	  *res++ = solutions.back();
-	  return res;
-	} else {
-	  *res++ = solutions.front();
-	  *res++ = result_type(std::make_pair(q,1u));
-	  return res;
-	}
+        if(CircularFunctors::compare_x<CK>(r,q) == LARGER){
+          *res++ = result_type(std::make_pair(q,1u));
+          *res++ = solutions.back();
+          return res;
+        } else {
+          *res++ = solutions.front();
+          *res++ = result_type(std::make_pair(q,1u));
+          return res;
+        }
 
       } // Case 4b
 
@@ -687,7 +668,7 @@ namespace CircularFunctors {
 
       CGAL::CircularFunctors::intersect_2<CK>
       ( l.supporting_line(), c.supporting_circle(),
-	std::back_inserter(solutions) );
+        std::back_inserter(solutions) );
 
 #ifdef CGAL_INTERSECTION_MAP_FOR_SUPPORTING_CIRCLES
         Line_arc_2::template
@@ -698,28 +679,13 @@ namespace CircularFunctors {
 
 
     for (typename solutions_container::iterator it = solutions.begin();
-	 it != solutions.end(); ++it)
+         it != solutions.end(); ++it)
     {
-      #if CGAL_INTERSECTION_VERSION  < 2
-      if(const std::pair<typename CK::Circular_arc_point_2, unsigned>* p =
-         object_cast< std::pair< typename CK::Circular_arc_point_2, unsigned> >(& (*it)))
-      {
-        #ifdef CGAL_CK_TEST_BBOX_BEFORE_HAS_ON
-        Bbox_2 rb = p->first.bbox();
-        if(!do_overlap(l.bbox(), rb) || !do_overlap(c.bbox(),rb)) continue;
-        #endif
-        Has_on_visitor<CK, typename CK::Line_arc_2> vis1(&l);
-        Has_on_visitor<CK, typename CK::Circular_arc_2> vis2(&c);
-        if(vis1(*p) && vis2(*p))
-          *res++ = *it;
-      }
-      #else
       if(boost::apply_visitor(Has_on_visitor<CK, typename CK::Line_arc_2>(&l), *it) &&
          boost::apply_visitor(Has_on_visitor<CK, typename CK::Circular_arc_2>(&c), *it) )
       {
-	*res++ = *it;
+        *res++ = *it;
       }
-      #endif
     }
     return res;
   }
@@ -730,8 +696,8 @@ namespace CircularFunctors {
   /*template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_arc_2 &l,
-	       const typename CK::Circular_arc_2 &c,
-	       OutputIterator res )
+               const typename CK::Circular_arc_2 &c,
+               OutputIterator res )
   {
     typedef typename CK::Circular_arc_2 Circular_arc_2;
     typedef std::vector<CGAL::Object > solutions_container;
@@ -739,33 +705,33 @@ namespace CircularFunctors {
     solutions_container solutions;
     CGAL::LinearFunctors::intersect_2<CK>
       ( l.supporting_line(), c.supporting_circle(),
-	std::back_inserter(solutions) );
+        std::back_inserter(solutions) );
 
     solutions_container objects_monotone;
     std::vector<const Circular_arc_2*> arcs_x_monotone;
     make_x_monotone( c, std::back_inserter(objects_monotone));
     for(typename solutions_container::iterator it2 = objects_monotone.begin();
-	it2 != objects_monotone.end(); ++it2){
+        it2 != objects_monotone.end(); ++it2){
       arcs_x_monotone.push_back(CGAL::object_cast<Circular_arc_2>(&(*it2)));
     }
 
     for (typename solutions_container::iterator it = solutions.begin();
-	 it != solutions.end(); ++it){
+         it != solutions.end(); ++it){
       const std::pair<typename CK::Circular_arc_point_2, unsigned> *result;
       result = CGAL::object_cast
-	<std::pair<typename CK::Circular_arc_point_2, unsigned> > (&(*it));
+        <std::pair<typename CK::Circular_arc_point_2, unsigned> > (&(*it));
       if ( has_on<CK>(l,result->first)) {
-	bool is_on_arc = false;
-	for(typename std::vector<const Circular_arc_2*>::iterator
-	      it2 = arcs_x_monotone.begin();
-	    it2 != arcs_x_monotone.end(); ++it2){
-	  if(has_on<CK>(**it2, result->first)){
-	    is_on_arc = true;
-	    break;
-	  }
-	}
-	if(is_on_arc)
-	  *res++ = *it;
+        bool is_on_arc = false;
+        for(typename std::vector<const Circular_arc_2*>::iterator
+              it2 = arcs_x_monotone.begin();
+            it2 != arcs_x_monotone.end(); ++it2){
+          if(has_on<CK>(**it2, result->first)){
+            is_on_arc = true;
+            break;
+          }
+        }
+        if(is_on_arc)
+          *res++ = *it;
       }
     }
     return res;
@@ -774,8 +740,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_2 &l,
-	       const typename CK::Line_arc_2 &la,
-	       OutputIterator res )
+               const typename CK::Line_arc_2 &la,
+               OutputIterator res )
   {
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
     typedef typename CK::Point_2                  Point_2;
@@ -792,12 +758,12 @@ namespace CircularFunctors {
 
     if(!v) return res;
     const Point_2 *pt = boost::get<Point_2>(&*v);
-    if(pt == NULL) return res;
+    if(pt == nullptr) return res;
 
     Circular_arc_point_2 intersect_point = Circular_arc_point_2(*pt);
 
     if (CircularFunctors::compare_xy<CK>(intersect_point, la.source()) !=
-	 CircularFunctors::compare_xy<CK>(intersect_point, la.target()))
+         CircularFunctors::compare_xy<CK>(intersect_point, la.target()))
       *res++ = result_type(std::make_pair(intersect_point, 1u));
 
     return res;
@@ -806,8 +772,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Line_2 &l,
-	       const typename CK::Circular_arc_2 &c,
-	       OutputIterator res )
+               const typename CK::Circular_arc_2 &c,
+               OutputIterator res )
   {
     typedef typename CK::Circular_arc_2 Circular_arc_2;
 
@@ -820,20 +786,12 @@ namespace CircularFunctors {
 
     CGAL::CircularFunctors::intersect_2<CK>
       ( l, c.supporting_circle(),
-	std::back_inserter(solutions) );
+        std::back_inserter(solutions) );
 
     for (typename solutions_container::const_iterator it = solutions.begin();
-	 it != solutions.end(); ++it) {
-#if CGAL_INTERSECTION_VERSION < 2
-      typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
-      const std::pair<Circular_arc_point_2, unsigned>* p =
-        object_cast<std::pair<Circular_arc_point_2, unsigned> >(& (*it));
-      Has_on_visitor<CK, Circular_arc_2> vis(&c);
-      if(vis(*p)) *res++ = *it;
-#else
+         it != solutions.end(); ++it) {
       if(boost::apply_visitor(Has_on_visitor<CK, Circular_arc_2>(&c), *it))
         *res++ = *it;
-#endif
     }
     return res;
   }
@@ -841,8 +799,8 @@ namespace CircularFunctors {
   template< class CK, class OutputIterator>
   OutputIterator
   intersect_2( const typename CK::Circular_arc_2 &c,
-	       const typename CK::Line_arc_2 &l,
-	       OutputIterator res )
+               const typename CK::Line_arc_2 &l,
+               OutputIterator res )
   {
     return intersect_2<CK>(l,c,res);
   }
@@ -850,7 +808,7 @@ namespace CircularFunctors {
   template < class CK, class OutputIterator >
   OutputIterator
   make_x_monotone( const typename CK::Line_arc_2 &A,
-		   OutputIterator res )
+                   OutputIterator res )
   {
     *res++ = make_object(A);
     return res;
