@@ -2,25 +2,16 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_circular_arc_3.h $
+// $Id: internal_functions_on_circular_arc_3.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_circular_arc_3.h $
-// $Id: internal_functions_on_circular_arc_3.h 0d3ac75 2018-02-17T12:37:15+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-//
-// Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado, 
+// Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado,
 //             Sebastien Loriot, Julien Hazebrouck, Damien Leroy
 
-// Partially supported by the IST Programme of the EU as a 
-// STREP (FET Open) Project under Contract No  IST-006413 
+// Partially supported by the IST Programme of the EU as a
+// STREP (FET Open) Project under Contract No  IST-006413
 // (ACS -- Algorithms for Complex Shapes)
 
 #ifndef CGAL_SPHERICAL_KERNEL_PREDICATES_ON_CIRCULAR_ARC_3_H
@@ -49,15 +40,15 @@ namespace CGAL {
     do_overlap(const typename SK::Circular_arc_3 &c1,
                const typename SK::Circular_arc_3 &c2,
                const bool known_equal_supporting_circle = false)
-    { 
+    {
       if(!known_equal_supporting_circle) {
-        if(!non_oriented_equal<SK>(c1.supporting_circle(), 
+        if(!non_oriented_equal<SK>(c1.supporting_circle(),
                                    c2.supporting_circle()))
           return false;
       }
       if(c1.rep().is_full()) return true;
       if(c2.rep().is_full()) return true;
-      if((SK().has_on_3_object()(c1,c2.target(),true)) || 
+      if((SK().has_on_3_object()(c1,c2.target(),true)) ||
          (SK().has_on_3_object()(c1,c2.source(),true))) return true;
       return SK().has_on_3_object()(c2,c1.source(),true);
     }
@@ -65,21 +56,21 @@ namespace CGAL {
     template < class SK >
     void
     split(const typename SK::Circular_arc_3 &c,
-	  const typename SK::Circular_arc_point_3 &p,
-	  typename SK::Circular_arc_3 &c1,
-	  typename SK::Circular_arc_3 &c2)
+          const typename SK::Circular_arc_point_3 &p,
+          typename SK::Circular_arc_3 &c1,
+          typename SK::Circular_arc_3 &c2)
     {
-      // The point must be on the circular arc 
+      // The point must be on the circular arc
       CGAL_kernel_precondition(SK().has_on_3_object()(c, p));
       typedef typename SK::Circular_arc_3  Circular_arc_3;
       // It doesn't make sense to split an arc on an extremity
       CGAL_kernel_precondition(c.source() != p);
       CGAL_kernel_precondition(c.target() != p);
-      const Circular_arc_3 &rc1 = 
+      const Circular_arc_3 &rc1 =
         Circular_arc_3(c.supporting_circle(), c.source(), p);
-      const Circular_arc_3 &rc2 = 
+      const Circular_arc_3 &rc2 =
         Circular_arc_3(c.supporting_circle(), p, c.target());
-      if ( SK().compare_xyz_3_object()(rc1.source(), rc2.source()) != 
+      if ( SK().compare_xyz_3_object()(rc1.source(), rc2.source()) !=
            SMALLER) {
         c1 = rc2; c2 = rc1;
       } else { c1 = rc1; c2 = rc2; }
@@ -87,13 +78,13 @@ namespace CGAL {
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Line_3 & l, 
-                const typename SK::Circular_arc_3 & ca, 
-	        OutputIterator res)
-    { 
+    intersect_3(const typename SK::Line_3 & l,
+                const typename SK::Circular_arc_3 & ca,
+                OutputIterator res)
+    {
       typedef typename SK::Circular_arc_point_3 Circular_arc_point_3;
       typedef std::vector<
-        typename SK3_Intersection_traits<SK, typename SK::Line_3, typename SK::Circle_3>::type 
+        typename SK3_Intersection_traits<SK, typename SK::Line_3, typename SK::Circle_3>::type
         > solutions_container;
       typedef std::pair<Circular_arc_point_3, unsigned> Solution;
 
@@ -108,7 +99,7 @@ namespace CGAL {
            *res++ = solutions[0];
       } else {
          const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);
-         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);        
+         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);
          if(SK().has_on_3_object()(ca,sol1.first,true))
            *res++ = solutions[0];
          if(SK().has_on_3_object()(ca,sol2.first,true))
@@ -119,10 +110,10 @@ namespace CGAL {
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Circle_3 & c, 
-                const typename SK::Circular_arc_3 & ca, 
-	        OutputIterator res)
-    { 
+    intersect_3(const typename SK::Circle_3 & c,
+                const typename SK::Circular_arc_3 & ca,
+                OutputIterator res)
+    {
       typedef typename SK::Circular_arc_point_3 Circular_arc_point_3;
       typedef typename SK3_Intersection_traits<SK, typename SK::Circle_3, typename SK::Circular_arc_3>::type result_type;
 
@@ -136,7 +127,7 @@ namespace CGAL {
 
       solutions_container solutions;
 
-      SK().intersect_3_object()(ca.supporting_circle(), c, 
+      SK().intersect_3_object()(ca.supporting_circle(), c,
                                 std::back_inserter(solutions) );
       if(solutions.size() == 0) return res;
       if(solutions.size() == 1) {
@@ -145,7 +136,7 @@ namespace CGAL {
            *res++ = solutions[0];
       } else {
          const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);
-         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);        
+         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);
          if(SK().has_on_3_object()(ca,sol1.first,true))
            *res++ = solutions[0];
          if(SK().has_on_3_object()(ca,sol2.first,true))
@@ -158,7 +149,7 @@ namespace CGAL {
     OutputIterator
     intersect_3(const typename SK::Sphere_3 & s,
                 const typename SK::Circular_arc_3 & c,
-	       OutputIterator res)
+               OutputIterator res)
     {
       typedef typename SK3_Intersection_traits<SK, typename SK::Sphere_3, typename SK::Circular_arc_3
         >::type result_type;
@@ -182,8 +173,8 @@ namespace CGAL {
          if(SK().has_on_3_object()(c,sol.first,true))
            *res++ = solutions[0];
       } else {
-         const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);        
-         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);        
+         const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);
+         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);
          if(SK().has_on_3_object()(c,sol1.first,true))
            *res++ = solutions[0];
          if(SK().has_on_3_object()(c,sol2.first,true))
@@ -194,9 +185,9 @@ namespace CGAL {
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Plane_3 & p, 
-                const typename SK::Circular_arc_3 & ca, 
-	        OutputIterator res)
+    intersect_3(const typename SK::Plane_3 & p,
+                const typename SK::Circular_arc_3 & ca,
+                OutputIterator res)
     {
       typedef typename SK3_Intersection_traits<SK, typename SK::Plane_3, typename SK::Circular_arc_3
         >::type result_type;
@@ -220,7 +211,7 @@ namespace CGAL {
            *res++ = CGAL::internal::sk3_intersection_return<result_type>(sol);
       } else {
          const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);
-         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);        
+         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);
          if(SK().has_on_3_object()(ca,sol1.first,true))
            *res++ = CGAL::internal::sk3_intersection_return<result_type>(sol1);
          if(SK().has_on_3_object()(ca,sol2.first,true))
@@ -231,13 +222,13 @@ namespace CGAL {
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Line_arc_3 & la, 
-                const typename SK::Circular_arc_3 & ca, 
-	        OutputIterator res)
-    { 
+    intersect_3(const typename SK::Line_arc_3 & la,
+                const typename SK::Circular_arc_3 & ca,
+                OutputIterator res)
+    {
       typedef typename SK::Circular_arc_point_3 Circular_arc_point_3;
       typedef std::vector<
-        typename SK3_Intersection_traits<SK, typename SK::Line_3, typename SK::Line_3>::type> 
+        typename SK3_Intersection_traits<SK, typename SK::Line_3, typename SK::Line_3>::type>
         solutions_container;
       typedef std::pair<Circular_arc_point_3, unsigned> Solution;
 
@@ -253,7 +244,7 @@ namespace CGAL {
            *res++ = solutions[0];
       } else {
          const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);
-         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);        
+         const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);
          if(SK().has_on_3_object()(ca,sol1.first,true) &&
             SK().has_on_3_object()(la,sol1.first,true))
            *res++ = solutions[0];
@@ -266,10 +257,10 @@ namespace CGAL {
 
     template < class SK, class OutputIterator >
     OutputIterator
-    intersect_3(const typename SK::Circular_arc_3 & a1, 
-                const typename SK::Circular_arc_3 & a2, 
-	        OutputIterator res)
-    { 
+    intersect_3(const typename SK::Circular_arc_3 & a1,
+                const typename SK::Circular_arc_3 & a2,
+                OutputIterator res)
+    {
       typedef typename SK3_Intersection_traits<SK, typename SK::Circular_arc_3, typename SK::Circular_arc_3
         >::type result_type;
       typedef typename SK::Circular_arc_point_3 Circular_arc_point_3;
@@ -281,11 +272,11 @@ namespace CGAL {
 
       if(non_oriented_equal<SK>(a1.supporting_circle(), a2.supporting_circle())) {
         if(a1.rep().is_full()) {
-          *res++ = CGAL::internal::sk3_intersection_return<result_type>(a2); 
+          *res++ = CGAL::internal::sk3_intersection_return<result_type>(a2);
           //return res;
         }
         else if(a2.rep().is_full()) {
-          *res++ = CGAL::internal::sk3_intersection_return<result_type>(a1); 
+          *res++ = CGAL::internal::sk3_intersection_return<result_type>(a1);
           //return res;
         } else {
           bool t2_in_a1 = SK().has_on_3_object()(a1,a2.target(),true);
@@ -294,68 +285,68 @@ namespace CGAL {
             bool t1_in_a2 = SK().has_on_3_object()(a2,a1.target(),true);
             bool s1_in_a2 = SK().has_on_3_object()(a2,a1.source(),true);
             if(t1_in_a2 && s1_in_a2) {
-              const Comparison_result comp = 
+              const Comparison_result comp =
                 SK().compare_xyz_3_object()(a1.source(), a2.source());
               if(comp < 0) {
                 if(a1.source() == a2.target()) {
                   *res++ = CGAL::internal::sk3_intersection_return<result_type>(std::make_pair(a1.source(),1u));
                 } else {
                   const Circular_arc_3 & arc =
-	          Circular_arc_3(a1.supporting_circle(),a1.source(),a2.target());
-	          *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
+                  Circular_arc_3(a1.supporting_circle(),a1.source(),a2.target());
+                  *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
                 }
                 if(a2.source() == a1.target()) {
                   *res++ = CGAL::internal::sk3_intersection_return<result_type>(std::make_pair(a2.source(),1u));
                 } else {
                   const Circular_arc_3 & arc =
-	          Circular_arc_3(a1.supporting_circle(),a2.source(),a1.target());
-	          *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
+                  Circular_arc_3(a1.supporting_circle(),a2.source(),a1.target());
+                  *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
                 }
               } else if(comp > 0) {
                 if(a2.source() == a1.target()) {
                   *res++ = CGAL::internal::sk3_intersection_return<result_type>(std::make_pair(a2.source(),1u));
                 } else {
                   const Circular_arc_3 & arc =
-	          Circular_arc_3(a1.supporting_circle(),a2.source(),a1.target());
-	          *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
+                  Circular_arc_3(a1.supporting_circle(),a2.source(),a1.target());
+                  *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
                 }
                 if(a1.source() == a2.target()) {
                   *res++ = CGAL::internal::sk3_intersection_return<result_type>(std::make_pair(a1.source(),1u));
                 } else {
                   const Circular_arc_3 & arc =
-	          Circular_arc_3(a1.supporting_circle(),a1.source(),a2.target());
-	          *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
-                } 
-              } else { 
+                  Circular_arc_3(a1.supporting_circle(),a1.source(),a2.target());
+                  *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
+                }
+              } else {
                 *res++ = CGAL::internal::sk3_intersection_return<result_type>(a1);
               }
             } else {
               *res++ = CGAL::internal::sk3_intersection_return<result_type>(a2);
             }
           } else if(t2_in_a1) {
-            if(a1.source() == a2.target()) 
+            if(a1.source() == a2.target())
               *res++ = CGAL::internal::sk3_intersection_return<result_type>(std::make_pair(a1.source(),1u));
             else {
               const Circular_arc_3 & arc =
-	        Circular_arc_3(a1.supporting_circle(),a1.source(),a2.target());
-	      *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
+                Circular_arc_3(a1.supporting_circle(),a1.source(),a2.target());
+              *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
             } //return res;
           } else if(s2_in_a1) {
             if(a2.source() == a1.target()) {
               *res++ = CGAL::internal::sk3_intersection_return<result_type>(std::make_pair(a2.source(),1u));
             } else {
               const Circular_arc_3 & arc =
-	        Circular_arc_3(a1.supporting_circle(),a2.source(),a1.target());
-	      *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
+                Circular_arc_3(a1.supporting_circle(),a2.source(),a1.target());
+              *res++ = CGAL::internal::sk3_intersection_return<result_type>(arc);
             }
           } else if(SK().has_on_3_object()(a2,a1.source(),true)) {
               *res++ = CGAL::internal::sk3_intersection_return<result_type>(a1);
-          } 
+          }
         }
       } else {
         solutions_container solutions;
 
-        SK().intersect_3_object()(a1.supporting_circle(), a2.supporting_circle(), 
+        SK().intersect_3_object()(a1.supporting_circle(), a2.supporting_circle(),
                                   std::back_inserter(solutions) );
         if(solutions.size() == 0) return res;
         if(solutions.size() == 1) {
@@ -365,7 +356,7 @@ namespace CGAL {
             *res++ = solutions[0];
         } else {
           const Solution& sol1=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[0]);
-          const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);          
+          const Solution& sol2=*CGAL::Intersections::internal::intersect_get<Solution>(solutions[1]);
           if(SK().has_on_3_object()(a1,sol1.first,true) &&
              SK().has_on_3_object()(a2,sol1.first,true))
             *res++ = solutions[0];
@@ -395,36 +386,36 @@ namespace CGAL {
                                                               sphere.center().z()+(circle_contains_north?1:-1)*radius
           )
         );
-        
+
         if (arc.source().z()==pole.z() || arc.target().z()==pole.z())
           return true;
-        
+
         return !has_on<SK>(arc,pole);
       }
-      
-      
+
+
       typename SK::FT z_coord=extremal_points_z_coordinate<SK>(arc.supporting_circle(),sphere);
       typename SK::Plane_3 plane(0,0,1,-z_coord);
       std::vector<typename SK3_Intersection_traits<SK, typename SK::Plane_3, typename SK::Circular_arc_3>
         ::type> inters;
-      
+
       intersect_3<SK>(plane,arc,std::back_inserter(inters));
-      
+
       if (inters.empty())
         return true;
-      
+
       //checks whether circular arc endpoints are theta extremal
       unsigned nb_extrem = (arc.source().z()-z_coord == 0)? 1:0;
       if (arc.target().z()-z_coord == 0) ++nb_extrem;
-      
+
       if (inters.size()==nb_extrem)
         return true;
-      
+
       return false;
     }
-    
+
     template < class SK,class Output_iterator>
-    Output_iterator 
+    Output_iterator
     make_circular_arc_theta_monotone( const typename SK::Circular_arc_3& arc,
                                       const typename SK::Sphere_3& sphere,
                                       Output_iterator out_it)
@@ -442,7 +433,7 @@ namespace CGAL {
                                                                 sphere.center().z()+(circle_contains_north?1:-1)*radius
             )
           );
-          
+
           if (arc.source().z()==pole.z() || arc.target().z()==pole.z())
             *out_it++=arc;
           else{
@@ -460,19 +451,19 @@ namespace CGAL {
           typename SK::Plane_3 plane(0,0,1,-z_coord);
           std::vector<typename SK3_Intersection_traits< SK, typename SK::Plane_3, typename SK::Circular_arc_3 >::type
           > inters;
-          
+
           intersect_3<SK>(plane,arc,std::back_inserter(inters));
-          
+
           //No intersection with horizontal plane: theta-monotone
           if (inters.empty()){
             *out_it++=arc;
             break;
           }
-          
+
           //check if endpoints of circular arc are theta extremal points
           unsigned nb_extrem = (arc.source().z()-z_coord == 0)? 1:0;
           if (arc.target().z()-z_coord == 0) ++nb_extrem;
-          
+
           if (inters.size()==nb_extrem){
             *out_it++=arc;
             break;
@@ -480,104 +471,104 @@ namespace CGAL {
 
           //one endpoint is extremal: just split the arc
           if (nb_extrem==1){
-            const std::pair<typename SK::Circular_arc_point_3,unsigned>* pt[2]={NULL,NULL};
+            const std::pair<typename SK::Circular_arc_point_3,unsigned>* pt[2]={nullptr,nullptr};
             pt[0]=CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[0]);
             pt[1]=CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[1]);
-            CGAL_kernel_precondition(pt[0]!=NULL);
-            CGAL_kernel_precondition(pt[1]!=NULL);
+            CGAL_kernel_precondition(pt[0]!=nullptr);
+            CGAL_kernel_precondition(pt[1]!=nullptr);
             const typename SK::Circular_arc_point_3& midpt=(arc.source()==pt[0]->first || arc.target()==pt[0]->first)?pt[1]->first:pt[0]->first;
             *out_it++=typename SK::Circular_arc_3(arc.supporting_circle(),arc.source(),midpt);
             *out_it++=typename SK::Circular_arc_3(arc.supporting_circle(),midpt,arc.target());
             break;
           }
-          
+
           CGAL_kernel_precondition(nb_extrem==0);
-          
+
           //only one intersection points
           if (inters.size()==1){
-            const std::pair<typename SK::Circular_arc_point_3,unsigned>* midpt=NULL;
+            const std::pair<typename SK::Circular_arc_point_3,unsigned>* midpt=nullptr;
             midpt=CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[0]);
-            CGAL_kernel_precondition(midpt!=NULL);
+            CGAL_kernel_precondition(midpt!=nullptr);
             *out_it++=typename SK::Circular_arc_3(arc.supporting_circle(),arc.source(),midpt->first);
             *out_it++=typename SK::Circular_arc_3(arc.supporting_circle(),midpt->first,arc.target());
             break;
           }
-          
+
           //three arcs are defined by two intersection points
-          const std::pair<typename SK::Circular_arc_point_3,unsigned>* pt[2]={NULL,NULL};
+          const std::pair<typename SK::Circular_arc_point_3,unsigned>* pt[2]={nullptr,nullptr};
           pt[0]=CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[0]);
           pt[1]=CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[1]);
-          CGAL_kernel_precondition(pt[0]!=NULL);
-          CGAL_kernel_precondition(pt[1]!=NULL);
-          
+          CGAL_kernel_precondition(pt[0]!=nullptr);
+          CGAL_kernel_precondition(pt[1]!=nullptr);
+
           typename SK::Circular_arc_3 arc1=typename SK::Circular_arc_3(arc.supporting_circle(),arc.source(),pt[0]->first);
           typename SK::Circular_arc_3 arc2=typename SK::Circular_arc_3(arc.supporting_circle(),pt[0]->first,arc.target());
           if ( has_on<SK>(arc1,pt[1]->first) ){
             *out_it++=typename SK::Circular_arc_3(arc1.supporting_circle(),arc1.source(),pt[1]->first);
-            *out_it++=typename SK::Circular_arc_3(arc1.supporting_circle(),pt[1]->first,arc1.target());            
+            *out_it++=typename SK::Circular_arc_3(arc1.supporting_circle(),pt[1]->first,arc1.target());
             *out_it++=arc2;
           }
           else{
-            *out_it++=arc1;            
+            *out_it++=arc1;
             *out_it++=typename SK::Circular_arc_3(arc2.supporting_circle(),arc2.source(),pt[1]->first);
-            *out_it++=typename SK::Circular_arc_3(arc2.supporting_circle(),pt[1]->first,arc2.target());            
+            *out_it++=typename SK::Circular_arc_3(arc2.supporting_circle(),pt[1]->first,arc2.target());
           }
           break;
         }
         case BIPOLAR:
-          CGAL_kernel_precondition(!"This function does not accept bipolar circle as input.");
+          CGAL_kernel_precondition_msg(false, "This function does not accept bipolar circle as input.");
       }
-      
+
       return out_it;
     }
-    
-    //this function indicates whether a theta monotone circular arc is 
+
+    //this function indicates whether a theta monotone circular arc is
     //included in the upper part of its supporting circle (wrt theta extremal pts)
     template <class SK>
-    bool 
+    bool
     is_upper_arc(const typename SK::Circular_arc_3& arc,
                  const typename SK::Sphere_3& sphere)
     {
       CGAL_kernel_precondition(is_theta_monotone_3<SK>(arc,sphere));
       CGAL::Circle_type type=classify_circle_3<SK>(arc.supporting_circle(),sphere);
       CGAL_kernel_precondition(type!=THREADED && type !=BIPOLAR);
-      
+
       //case of POLAR circle
       if (type==POLAR)
         return ( ( arc.supporting_circle().center().z()-sphere.center().z() ) < 0 );
-      
+
       //case of NORMAL circle
       typename SK::FT z_coord=extremal_points_z_coordinate<SK>(arc.supporting_circle(),sphere);
       if ( z_coord < arc.source().z() ) return true;
       if ( z_coord > arc.source().z() ) return false;
       if ( z_coord < arc.target().z() ) return true;
       if ( z_coord > arc.target().z() ) return false;
-      
+
       //source and target are theta extremal points
-      
+
       typename SK::Point_3 out_sphere_normal=CGAL::ORIGIN + ( arc.supporting_circle().center()-sphere.center() );
       typename SK::Point_3 ori(0,0,0);
       int wise=(out_sphere_normal > ori)? 1:-1; //check if seen ccw from the side going from the sphere center to the circle center
-      
+
       typename SK::Vector_3 cir_center(arc.supporting_circle().center().x()-sphere.center().x(),arc.supporting_circle().center().y()-sphere.center().y(),0);
       CGAL::Comparison_result source_vs_center=compare_theta_pt_vector<SK>(arc.source(),cir_center,sphere);
       CGAL::Comparison_result target_vs_center=compare_theta_pt_vector<SK>(arc.target(),cir_center,sphere);
-      
-      
+
+
       if (source_vs_center==target_vs_center){//circle is cut by meridian at theta=0
-        CGAL::Comparison_result source_vs_target=compare_theta_of_pts<SK>(arc.source(),arc.target(),sphere);  
+        CGAL::Comparison_result source_vs_target=compare_theta_of_pts<SK>(arc.source(),arc.target(),sphere);
         wise*=(source_vs_target==SMALLER)?-1:1;
       }
       else
         wise*=(source_vs_center==SMALLER)?1:-1;
-      
+
       return wise==1?false:true;
     }
 
     //compute the intersection points of a theta monotone arc with a meridian.
     //precondition: the intersection point always exists.
     template <class SK>
-    typename SK::Circular_arc_point_3 
+    typename SK::Circular_arc_point_3
     intersect_3( const typename SK::Circular_arc_3& arc,
                  const typename SK::Vector_3&m,
                  const typename SK::Sphere_3& sphere)
@@ -593,41 +584,41 @@ namespace CGAL {
             CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[0])->first;
           return pt;
       }
-      
+
       CGAL_kernel_precondition(classify_circle_3<SK>(arc.supporting_circle(),sphere)!=NORMAL);
-      
-      const typename SK::Circular_arc_point_3& pts1 = 
+
+      const typename SK::Circular_arc_point_3& pts1 =
         CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[0])->first;
       const typename SK::Circular_arc_point_3& pts2 =
         CGAL::Intersections::internal::intersect_get<std::pair<typename SK::Circular_arc_point_3,unsigned> >(inters[1])->first;
-      
-      
+
+
       //either a polar (1 pole + 1 pt) or a threaded circle (2 pts with theta-coord = +/- pi)
       if ( (pts1.x()!=0 && pts1.y()!=0) && compare_theta_pt_vector<SK>(pts1,m,sphere)==CGAL::EQUAL)
         return pts1;
       else
         return pts2;
     }
-      
-    
+
+
     template <class SK>
     //Compare the z coordinates of the intersection points with the meridian defined by m of two theta monotone arcs.
-    CGAL::Comparison_result 
+    CGAL::Comparison_result
     compare_z_at_theta_arcs( const typename SK::Circular_arc_3& arc1,
                              const typename SK::Circular_arc_3& arc2,
                              const typename SK::Vector_3& m,
-                             const typename SK::Sphere_3& sphere) 
+                             const typename SK::Sphere_3& sphere)
     {
       CGAL_kernel_precondition(is_theta_monotone_3<SK>(arc1,sphere));
       CGAL_kernel_precondition(is_theta_monotone_3<SK>(arc2,sphere));
-      
+
       typename SK::Circular_arc_point_3 pt1=intersect_3<SK>(arc1,m,sphere);
       typename SK::Circular_arc_point_3 pt2=intersect_3<SK>(arc2,m,sphere);
       return CGAL::compare(pt1.z(),pt2.z());
     }
 
     template <class SK>
-    CGAL::Comparison_result 
+    CGAL::Comparison_result
     compare_z_at_theta_pt_arc(const typename SK::Circular_arc_point_3& pt,
                               const typename SK::Circular_arc_3& arc,
                               const typename SK::Sphere_3& sphere)
@@ -635,7 +626,7 @@ namespace CGAL {
       CGAL_kernel_precondition(is_theta_monotone_3<SK>(arc,sphere));
       CGAL::Circle_type type=classify_circle_3<SK>(arc.supporting_circle(),sphere);
       CGAL_kernel_precondition(type!=BIPOLAR);
-      
+
       switch(type){
         case THREADED:
         case POLAR:
@@ -663,7 +654,7 @@ namespace CGAL {
         }
       }
     }
-    
+
   }//SphericalFunctors
 }//CGAL
 
