@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Classification/include/CGAL/Classification/Local_eigen_analysis.h $
-// $Id: Local_eigen_analysis.h 267b1f4 2018-06-28T11:13:35+02:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Classification/include/CGAL/Classification/Local_eigen_analysis.h $
+// $Id: Local_eigen_analysis.h 350b9172c56 2021-04-11T14:50:44+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
 
@@ -24,6 +15,7 @@
 #include <CGAL/license/Classification.h>
 
 #include <vector>
+#include <memory>
 
 #include <CGAL/Classification/compressed_float.h>
 #include <CGAL/Search_traits_3.h>
@@ -37,13 +29,13 @@
 #include <CGAL/boost/graph/properties.h>
 
 #include <boost/graph/graph_traits.hpp>
-#include <boost/make_shared.hpp>
 
 #ifdef CGAL_LINKED_WITH_TBB
 #include <tbb/parallel_for.h>
 #include <tbb/blocked_range.h>
 #include <tbb/scalable_allocator.h>
-#include <tbb/mutex.h>
+#include <mutex>
+
 #endif // CGAL_LINKED_WITH_TBB
 
 namespace CGAL {
@@ -65,8 +57,8 @@ namespace Classification {
 class Local_eigen_analysis
 {
 public:
-  typedef CGAL::cpp11::array<float, 3> Eigenvalues; ///< Eigenvalues (sorted in ascending order)
-  
+  using Eigenvalues = std::array<float, 3>; ///< Eigenvalues (sorted in ascending order)
+
 private:
 
 #ifdef CGAL_LINKED_WITH_TBB
@@ -78,20 +70,20 @@ private:
     PointMap m_point_map;
     const NeighborQuery& m_neighbor_query;
     float& m_mean_range;
-    tbb::mutex& m_mutex;
-    
+    std::mutex& m_mutex;
+
   public:
-    
+
     Compute_eigen_values (Local_eigen_analysis& eigen,
                           const PointRange& input,
                           PointMap point_map,
                           const NeighborQuery& neighbor_query,
                           float& mean_range,
-                          tbb::mutex& mutex)
+                          std::mutex& mutex)
       : m_eigen (eigen), m_input (input), m_point_map (point_map),
         m_neighbor_query (neighbor_query), m_mean_range (mean_range), m_mutex (mutex)
     { }
-    
+
     void operator()(const tbb::blocked_range<std::size_t>& r) const
     {
       std::vector<std::size_t> neighbors;
@@ -110,7 +102,7 @@ private:
                               (CGAL::squared_distance (get(m_point_map, *(m_input.begin() + i)),
                                                        get(m_point_map, *(m_input.begin() + neighbors.back())))));
         m_mutex.unlock();
-          
+
         m_eigen.compute<typename PointMap::value_type,
                         DiagonalizeTraits> (i, get(m_point_map, *(m_input.begin()+i)), neighbor_points);
       }
@@ -121,27 +113,27 @@ private:
   template <typename FaceListGraph, typename NeighborQuery, typename DiagonalizeTraits>
   class Compute_eigen_values_graph
   {
-    typedef typename boost::graph_traits<FaceListGraph>::face_descriptor face_descriptor;
-    typedef typename boost::property_map<FaceListGraph, CGAL::face_index_t>::type::value_type face_index;
-    typedef typename boost::graph_traits<FaceListGraph>::face_iterator face_iterator;
-    
+    using face_descriptor = typename boost::graph_traits<FaceListGraph>::face_descriptor;
+    using face_index = typename boost::property_map<FaceListGraph, CGAL::face_index_t>::type::value_type;
+    using face_iterator = typename boost::graph_traits<FaceListGraph>::face_iterator;
+
     Local_eigen_analysis& m_eigen;
     const FaceListGraph& m_input;
     const NeighborQuery& m_neighbor_query;
     float& m_mean_range;
-    tbb::mutex& m_mutex;
-    
+    std::mutex& m_mutex;
+
   public:
-    
+
     Compute_eigen_values_graph (Local_eigen_analysis& eigen,
                                 const FaceListGraph& input,
                                 const NeighborQuery& neighbor_query,
                                 float& mean_range,
-                                tbb::mutex& mutex)
+                                std::mutex& mutex)
       : m_eigen (eigen), m_input (input),
         m_neighbor_query (neighbor_query), m_mean_range (mean_range), m_mutex (mutex)
     { }
-    
+
     void operator()(const tbb::blocked_range<std::size_t>& r) const
     {
       face_iterator begin = faces(m_input).first;
@@ -154,7 +146,7 @@ private:
         m_mutex.lock();
         m_mean_range += m_eigen.face_radius(fd, m_input);
         m_mutex.unlock();
-        
+
         m_eigen.compute_triangles<FaceListGraph, DiagonalizeTraits>
           (m_input, fd, neighbors);
       }
@@ -162,15 +154,15 @@ private:
 
   };
 #endif
-  
+
   template <typename ClusterRange, typename DiagonalizeTraits>
   class Compute_clusters_eigen_values
   {
     Local_eigen_analysis& m_eigen;
     const ClusterRange& m_input;
-    
+
   public:
-    
+
     Compute_clusters_eigen_values (Local_eigen_analysis& eigen,
                                    const ClusterRange& input)
       : m_eigen (eigen), m_input (input)
@@ -186,8 +178,8 @@ private:
 
     inline void apply (std::size_t i) const
     {
-      typedef typename ClusterRange::value_type Cluster;
-      typedef typename Cluster::Item Item;
+      using Cluster = typename ClusterRange::value_type;
+      using Item = typename Cluster::Item;
       const Cluster& cluster = m_input[i];
 
       std::vector<typename ClusterRange::value_type::Item> points;
@@ -199,10 +191,10 @@ private:
 
   };
 
-  typedef CGAL::cpp11::array<float, 3> float3;
-  typedef CGAL::cpp11::array<float, 2> float2;
-  typedef CGAL::cpp11::array<compressed_float, 2> cfloat2;
-  
+  using float3 = std::array<float, 3>;
+  using float2 = std::array<float, 2>;
+  using cfloat2 = std::array<compressed_float, 2>;
+
   struct Content
   {
     std::vector<cfloat2> eigenvalues;
@@ -211,8 +203,8 @@ private:
     float mean_range;
   };
 
-  boost::shared_ptr<Content> m_content; // To avoid copies with named constructors
-  
+  std::shared_ptr<Content> m_content; // To avoid copies with named constructors
+
 public:
 
   /// \cond SKIP_IN_MANUAL
@@ -222,8 +214,8 @@ public:
   /// \name Named Constructors
   /// @{
 
-  /*! 
-    \brief Computes the local eigen analysis of an input point set
+  /*!
+    \brief computes the local eigen analysis of an input point set
     based on a local neighborhood.
 
     \tparam PointRange model of `ConstRange`. Its iterator type is
@@ -234,7 +226,7 @@ public:
     is `CGAL::Point_3`.
     \tparam NeighborQuery model of `NeighborQuery`
     \tparam ConcurrencyTag enables sequential versus parallel
-    algorithm. Possible values are `Parallel_tag` (default value is %CGAL
+    algorithm. Possible values are `Parallel_tag` (default value if \cgal
     is linked with TBB) or `Sequential_tag` (default value otherwise).
     \tparam DiagonalizeTraits model of `DiagonalizeTraits` used for
     matrix diagonalization. It can be omitted if Eigen 3 (or greater)
@@ -250,10 +242,8 @@ public:
             typename NeighborQuery,
 #if defined(DOXYGEN_RUNNING)
             typename ConcurrencyTag,
-#elif defined(CGAL_LINKED_WITH_TBB)
-            typename ConcurrencyTag = CGAL::Parallel_tag,
 #else
-            typename ConcurrencyTag = CGAL::Sequential_tag,
+            typename ConcurrencyTag = CGAL::Parallel_if_available_tag,
 #endif
 #if defined(DOXYGEN_RUNNING)
             typename DiagonalizeTraits>
@@ -267,20 +257,20 @@ public:
                                                     const DiagonalizeTraits& = DiagonalizeTraits())
   {
     Local_eigen_analysis out;
-    out.m_content = boost::make_shared<Content>();
+    out.m_content = std::make_shared<Content>();
     out.m_content->eigenvalues.resize (input.size());
     out.m_content->centroids.resize (input.size());
     out.m_content->smallest_eigenvectors.resize (input.size());
-    
+
     out.m_content->mean_range = 0.;
-      
+
 #ifndef CGAL_LINKED_WITH_TBB
-    CGAL_static_assertion_msg (!(boost::is_convertible<ConcurrencyTag, Parallel_tag>::value),
+    CGAL_static_assertion_msg (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
                                "Parallel_tag is enabled but TBB is unavailable.");
 #else
-    if (boost::is_convertible<ConcurrencyTag,Parallel_tag>::value)
+    if (std::is_convertible<ConcurrencyTag,Parallel_tag>::value)
     {
-      tbb::mutex mutex;
+      std::mutex mutex;
       Compute_eigen_values<PointRange, PointMap, NeighborQuery, DiagonalizeTraits>
         f(out, input, point_map, neighbor_query, out.m_content->mean_range, mutex);
       tbb::parallel_for(tbb::blocked_range<size_t>(0, input.size ()), f);
@@ -300,7 +290,7 @@ public:
         out.m_content->mean_range += float(CGAL::sqrt (CGAL::squared_distance
                                           (get(point_map, *(input.begin() + i)),
                                            get(point_map, *(input.begin() + neighbors.back())))));
-        
+
         out.compute<typename PointMap::value_type, DiagonalizeTraits>
           (i, get(point_map, *(input.begin()+i)), neighbor_points);
       }
@@ -309,16 +299,16 @@ public:
 
     return out;
   }
-  
-  
-  /*! 
-    \brief Computes the local eigen analysis of an input face graph
+
+
+  /*!
+    \brief computes the local eigen analysis of an input face graph
     based on a local neighborhood.
 
-    \tparam FaceListGraph model of `FaceListGraph`. 
+    \tparam FaceListGraph model of `FaceListGraph`.
     \tparam NeighborQuery model of `NeighborQuery`
     \tparam ConcurrencyTag enables sequential versus parallel
-    algorithm. Possible values are `Parallel_tag` (default value is %CGAL
+    algorithm. Possible values are `Parallel_tag` (default value if \cgal
     is linked with TBB) or `Sequential_tag` (default value otherwise).
     \tparam DiagonalizeTraits model of `DiagonalizeTraits` used for
     matrix diagonalization. It can be omitted: if Eigen 3 (or greater)
@@ -333,10 +323,8 @@ public:
             typename NeighborQuery,
 #if defined(DOXYGEN_RUNNING)
             typename ConcurrencyTag,
-#elif defined(CGAL_LINKED_WITH_TBB)
-            typename ConcurrencyTag = CGAL::Parallel_tag,
 #else
-            typename ConcurrencyTag = CGAL::Sequential_tag,
+            typename ConcurrencyTag = CGAL::Parallel_if_available_tag,
 #endif
 #if defined(DOXYGEN_RUNNING)
             typename DiagonalizeTraits>
@@ -348,29 +336,29 @@ public:
                                                       const ConcurrencyTag& = ConcurrencyTag(),
                                                       const DiagonalizeTraits& = DiagonalizeTraits())
   {
-    typedef typename boost::graph_traits<FaceListGraph>::face_descriptor face_descriptor;
-    typedef typename boost::graph_traits<FaceListGraph>::face_iterator face_iterator;
-    typedef typename CGAL::Iterator_range<face_iterator> Face_range;
-    typedef typename boost::property_map<FaceListGraph, CGAL::face_index_t>::type::value_type face_index;
+    using face_descriptor = typename boost::graph_traits<FaceListGraph>::face_descriptor;
+    using face_iterator = typename boost::graph_traits<FaceListGraph>::face_iterator;
+    using Face_range = typename CGAL::Iterator_range<face_iterator>;
+    using face_index = typename boost::property_map<FaceListGraph, CGAL::face_index_t>::type::value_type;
 
     Local_eigen_analysis out;
-    out.m_content = boost::make_shared<Content>();
-    
+    out.m_content = std::make_shared<Content>();
+
     Face_range range (faces(input));
 
     out.m_content->eigenvalues.resize (range.size());
     out.m_content->centroids.resize (range.size());
     out.m_content->smallest_eigenvectors.resize (range.size());
-    
+
     out.m_content->mean_range = 0.;
-      
+
 #ifndef CGAL_LINKED_WITH_TBB
-    CGAL_static_assertion_msg (!(boost::is_convertible<ConcurrencyTag, Parallel_tag>::value),
+    CGAL_static_assertion_msg (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
                                "Parallel_tag is enabled but TBB is unavailable.");
 #else
-    if (boost::is_convertible<ConcurrencyTag,Parallel_tag>::value)
+    if (std::is_convertible<ConcurrencyTag,Parallel_tag>::value)
     {
-      tbb::mutex mutex;
+      std::mutex mutex;
       Compute_eigen_values_graph<FaceListGraph, NeighborQuery, DiagonalizeTraits>
         f(out, input, neighbor_query, out.m_content->mean_range, mutex);
 
@@ -379,32 +367,32 @@ public:
     else
 #endif
     {
-      BOOST_FOREACH(face_descriptor fd, range)
+      for(face_descriptor fd : range)
       {
         std::vector<face_index> neighbors;
         neighbor_query (fd, std::back_inserter (neighbors));
 
         out.m_content->mean_range += out.face_radius(fd, input);
-      
+
         out.compute_triangles<FaceListGraph, DiagonalizeTraits>
           (input, fd, neighbors);
 
       }
     }
-    
+
     out.m_content->mean_range /= range.size();
     return out;
   }
-  
-  /*! 
-    \brief Computes the local eigen analysis of an input set of point
+
+  /*!
+    \brief computes the local eigen analysis of an input set of point
     clusters based on a local neighborhood.
 
     \tparam ClusterRange model of `ConstRange`. Its iterator type is
     `RandomAccessIterator` and its value type is the key type of
     `PointMap`.
     \tparam ConcurrencyTag enables sequential versus parallel
-    algorithm. Possible values are `Parallel_tag` (default value is %CGAL
+    algorithm. Possible values are `Parallel_tag` (default value if \cgal
     is linked with TBB) or `Sequential_tag` (default value otherwise).
     \tparam DiagonalizeTraits model of `DiagonalizeTraits` used for
     matrix diagonalization. It can be omitted: if Eigen 3 (or greater)
@@ -417,10 +405,8 @@ public:
   template <typename ClusterRange,
 #if defined(DOXYGEN_RUNNING)
             typename ConcurrencyTag,
-#elif defined(CGAL_LINKED_WITH_TBB)
-            typename ConcurrencyTag = CGAL::Parallel_tag,
 #else
-            typename ConcurrencyTag = CGAL::Sequential_tag,
+            typename ConcurrencyTag = CGAL::Parallel_if_available_tag,
 #endif
 #if defined(DOXYGEN_RUNNING)
             typename DiagonalizeTraits>
@@ -432,23 +418,23 @@ public:
                                                           const DiagonalizeTraits& = DiagonalizeTraits())
   {
     Local_eigen_analysis out;
-    out.m_content = boost::make_shared<Content>();
-    
+    out.m_content = std::make_shared<Content>();
+
     out.m_content->eigenvalues.resize (input.size());
     out.m_content->centroids.resize (input.size());
     out.m_content->smallest_eigenvectors.resize (input.size());
-    
+
     out.m_content->mean_range = 0.;
 
     Compute_clusters_eigen_values<ClusterRange, DiagonalizeTraits>
     f(out, input);
 
-    
+
 #ifndef CGAL_LINKED_WITH_TBB
-    CGAL_static_assertion_msg (!(boost::is_convertible<ConcurrencyTag, Parallel_tag>::value),
+    CGAL_static_assertion_msg (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
                                "Parallel_tag is enabled but TBB is unavailable.");
 #else
-    if (boost::is_convertible<ConcurrencyTag,Parallel_tag>::value)
+    if (std::is_convertible<ConcurrencyTag,Parallel_tag>::value)
     {
       tbb::parallel_for(tbb::blocked_range<size_t>(0, input.size ()), f);
     }
@@ -468,7 +454,7 @@ public:
   /// @{
 
   /*!
-    \brief Returns the estimated unoriented normal vector of the point at position `index`.
+    \brief returns the estimated unoriented normal vector of the point at position `index`.
     \tparam GeomTraits model of \cgal Kernel.
   */
   template <typename GeomTraits>
@@ -481,7 +467,7 @@ public:
   }
 
   /*!
-    \brief Returns the estimated local tangent plane of the point at position `index`.
+    \brief returns the estimated local tangent plane of the point at position `index`.
     \tparam GeomTraits model of \cgal Kernel.
   */
   template <typename GeomTraits>
@@ -495,7 +481,7 @@ public:
   }
 
   /*!
-    \brief Returns the normalized eigenvalues of the point at position `index`.
+    \brief returns the normalized eigenvalues of the point at position `index`.
   */
   Eigenvalues eigenvalue (std::size_t index) const
   {
@@ -519,10 +505,10 @@ private:
   float face_radius (typename boost::graph_traits<FaceListGraph>::face_descriptor& fd,
                      const FaceListGraph& g)
   {
-    typedef typename boost::graph_traits<FaceListGraph>::halfedge_descriptor halfedge_descriptor;
-    
+    using halfedge_descriptor = typename boost::graph_traits<FaceListGraph>::halfedge_descriptor;
+
     float out = 0.f;
-    BOOST_FOREACH(halfedge_descriptor hd, halfedges_around_face(halfedge(fd, g), g))
+    for(halfedge_descriptor hd : halfedges_around_face(halfedge(fd, g), g))
     {
       out = (std::max)(out,
                        float(CGAL::squared_distance (get(get (CGAL::vertex_point, g), source(hd,g)),
@@ -534,8 +520,8 @@ private:
   template <typename Point, typename DiagonalizeTraits>
   void compute (std::size_t index, const Point& query, std::vector<Point>& neighbor_points)
   {
-    typedef typename Kernel_traits<Point>::Kernel::Vector_3 Vector;
-      
+    using Vector = typename Kernel_traits<Point>::Kernel::Vector_3;
+
     if (neighbor_points.size() == 0)
     {
       m_content->eigenvalues[index] = make_array (compressed_float(0), compressed_float(0));
@@ -546,9 +532,9 @@ private:
 
     Point centroid = CGAL::centroid (neighbor_points.begin(), neighbor_points.end());
     m_content->centroids[index] = make_array( float(centroid.x()), float(centroid.y()), float(centroid.z()) );
-    
-    CGAL::cpp11::array<float, 6> covariance = make_array( 0.f, 0.f, 0.f, 0.f, 0.f, 0.f );
-      
+
+    std::array<float, 6> covariance = make_array( 0.f, 0.f, 0.f, 0.f, 0.f, 0.f );
+
     for (std::size_t i = 0; i < neighbor_points.size(); ++ i)
     {
       Vector d = neighbor_points[i] - centroid;
@@ -560,8 +546,8 @@ private:
       covariance[5] += float(d.z () * d.z ());
     }
 
-    CGAL::cpp11::array<float, 3> evalues = make_array( 0.f, 0.f, 0.f );
-    CGAL::cpp11::array<float, 9> evectors = make_array( 0.f, 0.f, 0.f,
+    std::array<float, 3> evalues = make_array( 0.f, 0.f, 0.f );
+    std::array<float, 9> evectors = make_array( 0.f, 0.f, 0.f,
                                                0.f, 0.f, 0.f,
                                                0.f, 0.f, 0.f );
 
@@ -573,10 +559,10 @@ private:
     if (sum > 0.f)
       for (std::size_t i = 0; i < 3; ++ i)
         evalues[i] = evalues[i] / sum;
-    
+
     m_content->eigenvalues[index] = make_array(compress_float (evalues[1]),
                                                compress_float (evalues[2]));
-    
+
     sum = evectors[0] + evectors[1] + evectors[2];
     if (sum > 0.f)
       for (std::size_t i = 0; i < 3; ++ i)
@@ -589,19 +575,19 @@ private:
                           typename boost::graph_traits<FaceListGraph>::face_descriptor& query,
                           std::vector<typename boost::property_map<FaceListGraph, CGAL::face_index_t>::type::value_type>& neighbor_faces)
   {
-    typedef typename boost::property_map<FaceListGraph, boost::vertex_point_t>::type::value_type Point;
-    typedef typename Kernel_traits<Point>::Kernel Kernel;
-    typedef typename Kernel::Triangle_3 Triangle;
-        
-    typedef typename boost::graph_traits<FaceListGraph>::face_descriptor face_descriptor;
-    typedef typename boost::graph_traits<FaceListGraph>::face_iterator face_iterator;
+    using Point = typename boost::property_map<FaceListGraph, boost::vertex_point_t>::type::value_type;
+    using Kernel = typename Kernel_traits<Point>::Kernel;
+    using Triangle = typename Kernel::Triangle_3;
+
+    using face_descriptor = typename boost::graph_traits<FaceListGraph>::face_descriptor;
+    using face_iterator = typename boost::graph_traits<FaceListGraph>::face_iterator;
 
     if (neighbor_faces.size() == 0)
     {
       m_content->eigenvalues[get(get(CGAL::face_index,g), query)]
         = make_array(compressed_float(0), compressed_float(0));
 
-      CGAL::cpp11::array<Triangle,1> tr
+      std::array<Triangle,1> tr
         = {{ Triangle (get(get (CGAL::vertex_point, g), target(halfedge(query, g), g)),
                        get(get (CGAL::vertex_point, g), target(next(halfedge(query, g), g), g)),
                        get(get (CGAL::vertex_point, g), target(next(next(halfedge(query, g), g), g), g))) }};
@@ -609,7 +595,7 @@ private:
                                tr.end(), Kernel(), CGAL::Dimension_tag<2>());
 
       m_content->centroids[get(get(CGAL::face_index,g), query)] = {{ float(c.x()), float(c.y()), float(c.z()) }};
-      
+
       m_content->smallest_eigenvectors[get(get(CGAL::face_index,g), query)] = {{ 0.f, 0.f }};
       return;
     }
@@ -627,18 +613,18 @@ private:
                    get(get (CGAL::vertex_point, g), target(next(next(halfedge(fd, g), g), g), g))));
     }
 
-    CGAL::cpp11::array<float, 6> covariance = {{ 0.f, 0.f, 0.f, 0.f, 0.f, 0.f }};
+    std::array<float, 6> covariance = {{ 0.f, 0.f, 0.f, 0.f, 0.f, 0.f }};
     Point c = CGAL::centroid(triangles.begin(),
                              triangles.end(), Kernel(), CGAL::Dimension_tag<2>());
 
     CGAL::internal::assemble_covariance_matrix_3 (triangles.begin(), triangles.end(), covariance,
-                                                  c, Kernel(), (Triangle*)NULL, CGAL::Dimension_tag<2>(),
+                                                  c, Kernel(), (Triangle*)nullptr, CGAL::Dimension_tag<2>(),
                                                   DiagonalizeTraits());
-      
+
     m_content->centroids[get(get(CGAL::face_index,g), query)] = {{ float(c.x()), float(c.y()), float(c.z()) }};
-    
-    CGAL::cpp11::array<float, 3> evalues = {{ 0.f, 0.f, 0.f }};
-    CGAL::cpp11::array<float, 9> evectors = {{ 0.f, 0.f, 0.f,
+
+    std::array<float, 3> evalues = {{ 0.f, 0.f, 0.f }};
+    std::array<float, 9> evectors = {{ 0.f, 0.f, 0.f,
                                                0.f, 0.f, 0.f,
                                                0.f, 0.f, 0.f }};
 
@@ -654,19 +640,19 @@ private:
     m_content->eigenvalues[get(get(CGAL::face_index,g), query)]
       = make_array(compress_float (evalues[1]),
                    compress_float (evalues[2]));
-    
+
     sum = evectors[0] + evectors[1] + evectors[2];
     if (sum > 0.f)
       for (std::size_t i = 0; i < 3; ++ i)
         evectors[i] = evectors[i] / sum;
     m_content->smallest_eigenvectors[get(get(CGAL::face_index,g), query)] = {{ float(evectors[0]), float(evectors[1]), }};
   }
-  
+
 };
-  
+
 
 }
-  
+
 }
 
 
