@@ -2,38 +2,30 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Triangulation_2/include/CGAL/Constrained_Delaunay_triangulation_2.h $
+// $Id: Constrained_Delaunay_triangulation_2.h dd5989d1c45 2023-03-21T16:28:53+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Triangulation_2/include/CGAL/Constrained_Delaunay_triangulation_2.h $
-// $Id: Constrained_Delaunay_triangulation_2.h 630066d 2019-01-10T17:31:54+01:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Mariette Yvinec, Jean Daniel Boissonnat
- 
+
 #ifndef CGAL_CONSTRAINED_DELAUNAY_TRIANGULATION_2_H
 #define CGAL_CONSTRAINED_DELAUNAY_TRIANGULATION_2_H
 
 #include <CGAL/license/Triangulation_2.h>
 
 
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Constrained_triangulation_2.h>
 #include <CGAL/Triangulation_2/insert_constraints.h>
 
 #ifndef CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
 #include <CGAL/Spatial_sort_traits_adapter_2.h>
-#include <CGAL/internal/info_check.h>
-#include <CGAL/is_iterator.h>
+#include <CGAL/STL_Extension/internal/info_check.h>
+#include <CGAL/type_traits/is_iterator.h>
 
+#include <boost/container/flat_set.hpp>
 #include <boost/iterator/zip_iterator.hpp>
 #include <boost/mpl/and.hpp>
 
@@ -54,14 +46,50 @@ struct Get_iterator_value_type<T,true>{
 } } //namespace CGAL::internal
 #endif //CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
 
-
-
 namespace CGAL {
+namespace internal {
 
+// Compare geometry to ensure deterministic flips
+template <class Tr>
+class Cdt_2_less_edge
+  : public CGAL::cpp98::binary_function<typename Tr::Edge, typename Tr::Edge, bool>
+{
+  const Tr* tr_ptr;
+
+  typedef typename Tr::Point  Point;
+  typedef typename Tr::Edge   Edge;
+
+public:
+  Cdt_2_less_edge(const Tr* tr_ptr) : tr_ptr(tr_ptr) { }
+
+  // just a manual lexicographical_compare
+  bool operator() (const Edge& e1, const Edge& e2) const
+  {
+    const Point& e1p1 = tr_ptr->point(e1.first, Tr::ccw(e1.second));
+    const Point& e2p1 = tr_ptr->point(e2.first, Tr::ccw(e2.second));
+
+    CGAL::Comparison_result res1 = tr_ptr->compare_xy(e1p1, e2p1);
+    if(res1 == CGAL::SMALLER)
+      return true;
+    if(res1 == CGAL::LARGER)
+      return false;
+
+    const Point& e1p2 = tr_ptr->point(e1.first, Tr::cw(e1.second));
+    const Point& e2p2 = tr_ptr->point(e2.first, Tr::cw(e2.second));
+
+    CGAL::Comparison_result res2 = tr_ptr->compare_xy(e1p2, e2p2);
+    if(res2 == CGAL::SMALLER)
+      return true;
+
+    return false;
+  }
+};
+
+} // namespace internal
 
 template <class Gt,
           class Tds_ = Default ,
-	  class Itag_ = Default>
+          class Itag_ = Default>
 class Constrained_Delaunay_triangulation_2
   : public  Constrained_triangulation_2<Gt, Tds_, Itag_>
 {
@@ -83,13 +111,14 @@ public:
   typedef typename Ctr::Face_circulator       Face_circulator;
   typedef typename Ctr::size_type             size_type;
   typedef typename Ctr::Locate_type           Locate_type;
- 
-  typedef typename Ctr::List_edges List_edges;  
+
+  typedef typename Ctr::List_edges List_edges;
   typedef typename Ctr::List_faces List_faces;
   typedef typename Ctr::List_vertices  List_vertices;
   typedef typename Ctr::List_constraints List_constraints;
-  typedef typename Ctr::Less_edge less_edge;
-  typedef typename Ctr::Edge_set Edge_set;
+
+  typedef internal::Cdt_2_less_edge<CDt> Less_edge;
+  typedef boost::container::flat_set<Edge, Less_edge> Edge_set;
 
   //Tag to distinguish Delaunay from regular triangulations
   typedef Tag_false Weighted_tag;
@@ -121,33 +150,47 @@ public:
   using Ctr::update_constraints;
   using Ctr::delete_vertex;
   using Ctr::push_back;
+  using Ctr::mirror_index;
 #endif
 
   typedef typename Geom_traits::Point_2  Point;
 
-  Constrained_Delaunay_triangulation_2(const Geom_traits& gt=Geom_traits()) 
+  Constrained_Delaunay_triangulation_2(const Geom_traits& gt=Geom_traits())
     : Ctr(gt) { }
 
   Constrained_Delaunay_triangulation_2(const List_constraints& lc,
-				       const Geom_traits& gt=Geom_traits())
-    : Ctr(gt) 
+                                       const Geom_traits& gt=Geom_traits())
+    : Ctr(gt)
     {
       insert_constraints(lc.begin(), lc.end());
-      CGAL_triangulation_postcondition( is_valid() );
+      CGAL_postcondition( is_valid() );
     }
 
   template<class InputIterator>
   Constrained_Delaunay_triangulation_2(InputIterator it,
-				       InputIterator last,
-				       const Geom_traits& gt=Geom_traits() )
-    : Ctr(gt) 
+                                       InputIterator last,
+                                       const Geom_traits& gt=Geom_traits() )
+    : Ctr(gt)
     {
       insert_constraints(it, last);
-      CGAL_triangulation_postcondition( is_valid() );
+      CGAL_postcondition( is_valid() );
     }
 
   virtual ~Constrained_Delaunay_triangulation_2() {}
-  
+
+
+  // Ensure rule-of-five: define the copy- and move- constructors
+  // as well as the copy- and move- assignment operators.
+  Constrained_Delaunay_triangulation_2(
+      const Constrained_Delaunay_triangulation_2 &) = default;
+  Constrained_Delaunay_triangulation_2(
+      Constrained_Delaunay_triangulation_2 &&) = default;
+
+  Constrained_Delaunay_triangulation_2 &
+  operator=(const Constrained_Delaunay_triangulation_2 &) = default;
+
+  Constrained_Delaunay_triangulation_2 &
+  operator=(Constrained_Delaunay_triangulation_2 &&) = default;
 
   // FLIPS
   bool is_flipable(Face_handle f, int i, bool perturb = true) const;
@@ -166,30 +209,30 @@ public:
   bool test_conflict(Face_handle fh, const Point& p) const; //deprecated
   bool test_conflict(const Point& p, Face_handle fh) const;
   void find_conflicts(const Point& p, std::list<Edge>& le,  //deprecated
-		      Face_handle hint= Face_handle()) const;
-  //  //template member functions, declared and defined at the end 
-  // template <class OutputItFaces, class OutputItBoundaryEdges> 
+                      Face_handle hint= Face_handle()) const;
+  //  //template member functions, declared and defined at the end
+  // template <class OutputItFaces, class OutputItBoundaryEdges>
   // std::pair<OutputItFaces,OutputItBoundaryEdges>
-  // get_conflicts_and_boundary(const Point  &p, 
-  // 		                OutputItFaces fit, 
-  // 		                OutputItBoundaryEdges eit,
-  // 		                Face_handle start) const;
+  // get_conflicts_and_boundary(const Point  &p,
+  //                                 OutputItFaces fit,
+  //                                 OutputItBoundaryEdges eit,
+  //                                 Face_handle start) const;
   // template <class OutputItFaces>
   // OutputItFaces
-  // get_conflicts (const Point  &p, 
-  //                OutputItFaces fit, 
-  // 		    Face_handle start ) const;
+  // get_conflicts (const Point  &p,
+  //                OutputItFaces fit,
+  //                     Face_handle start ) const;
   // template <class OutputItBoundaryEdges>
   // OutputItBoundaryEdges
-  // get_boundary_of_conflicts(const Point  &p, 
-  // 			       OutputItBoundaryEdges eit, 
-  // 			       Face_handle start ) const;
+  // get_boundary_of_conflicts(const Point  &p,
+  //                                OutputItBoundaryEdges eit,
+  //                                Face_handle start ) const;
 
   // INSERTION-REMOVAL
   Vertex_handle insert(const Point & a, Face_handle start = Face_handle());
   Vertex_handle insert(const Point& p,
-		       Locate_type lt,
-		       Face_handle loc, int li );
+                       Locate_type lt,
+                       Face_handle loc, int li );
   Vertex_handle push_back(const Point& a);
 //   template < class InputIterator >
 //   std::ptrdiff_t insert(InputIterator first, InputIterator last);
@@ -200,7 +243,7 @@ public:
 //  template <class OutputItFaces>
 //  OutputItFaces
 //  remove_constrained_edge(Face_handle f, int i, OutputItFaces out)
- 
+
   //for backward compatibility
   void insert(Point a, Point b) { insert_constraint(a, b);}
 
@@ -226,12 +269,14 @@ public:
     const Point& p0 = *first;
     Point p = p0;
     Vertex_handle v0 = insert(p0), v(v0), w(v0);
+    Face_handle hint = v0->face();
     ++first;
     for(; first!=last; ++first){
       const Point& q = *first;
       if(p != q){
-        w = insert(q);
+        w = insert(q,hint);
         insert_constraint(v,w);
+        hint = w->face();
         v = w;
         p = q;
       }
@@ -246,22 +291,22 @@ public:
 
   // CHECK
   bool is_valid(bool verbose = false, int level = 0) const;
- 
+
 protected:
-  virtual Vertex_handle virtual_insert(const Point & a, 
-				       Face_handle start = Face_handle());
+  virtual Vertex_handle virtual_insert(const Point & a,
+                                       Face_handle start = Face_handle());
   virtual Vertex_handle virtual_insert(const Point& a,
-				       Locate_type lt,
-				       Face_handle loc, 
-				       int li );
+                                       Locate_type lt,
+                                       Face_handle loc,
+                                       int li );
 //Vertex_handle special_insert_in_edge(const Point & a, Face_handle f, int i);
   void remove_2D(Vertex_handle v );
   virtual void triangulate_hole(List_faces& intersected_faces,
-				List_edges& conflict_boundary_ab,
-				List_edges& conflict_boundary_ba);
+                                List_edges& conflict_boundary_ab,
+                                List_edges& conflict_boundary_ba);
 
 public:
-  // MESHING 
+  // MESHING
   // suppressed meshing functions from here
 
   //template member functions
@@ -270,18 +315,18 @@ public:
 #ifndef CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
   std::ptrdiff_t
   insert( InputIterator first, InputIterator last,
-          typename boost::enable_if<
+          std::enable_if_t<
             boost::is_convertible<
                 typename internal::Get_iterator_value_type< InputIterator >::type,
                 Point
-            >
-          >::type* = NULL
+            >::value
+          >* = nullptr
   )
 #else
 #if defined(_MSC_VER)
   std::ptrdiff_t insert(InputIterator first, InputIterator last, int i = 0)
 #else
-    std::ptrdiff_t insert(InputIterator first, InputIterator last) 
+    std::ptrdiff_t insert(InputIterator first, InputIterator last)
 #endif
 #endif
     {
@@ -312,7 +357,7 @@ private:
   template <class Tuple_or_pair,class InputIterator>
   std::ptrdiff_t insert_with_info(InputIterator first,InputIterator last)
   {
-    size_type n = this->number_of_vertices();
+    size_type n = number_of_vertices();
     std::vector<std::size_t> indices;
     std::vector<Point> points;
     std::vector<typename Tds::Vertex::Info> infos;
@@ -343,7 +388,7 @@ private:
       }
     }
 
-    return this->number_of_vertices() - n;
+    return number_of_vertices() - n;
   }
 
 public:
@@ -352,12 +397,12 @@ public:
   std::ptrdiff_t
   insert( InputIterator first,
           InputIterator last,
-          typename boost::enable_if<
+          std::enable_if_t<
             boost::is_convertible<
               typename internal::Get_iterator_value_type< InputIterator >::type,
               std::pair<Point,typename internal::Info_check<typename Tds::Vertex>::type>
-            >
-          >::type* =NULL
+            >::value
+          >* =nullptr
   )
   {
     return insert_with_info< std::pair<Point,typename internal::Info_check<typename Tds::Vertex>::type> >(first,last);
@@ -367,12 +412,12 @@ public:
   std::ptrdiff_t
   insert( boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
           boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
-          typename boost::enable_if<
+          std::enable_if_t<
             boost::mpl::and_<
               boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
               boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Tds::Vertex>::type >
-            >
-          >::type* =NULL
+            >::value
+          >* =nullptr
   )
   {
     return insert_with_info< boost::tuple<Point,typename internal::Info_check<typename Tds::Vertex>::type> >(first,last);
@@ -386,6 +431,9 @@ public:
                                  IndicesIterator indices_first,
                                  IndicesIterator indices_beyond)
   {
+    if(indices_first == indices_beyond){
+      return insert(points_first, points_beyond);
+    }
     std::vector<Point> points(points_first, points_beyond);
     return internal::insert_constraints(*this,points, indices_first, indices_beyond);
   }
@@ -399,13 +447,13 @@ public:
   }
 
 
-  template <class OutputItFaces, class OutputItBoundaryEdges> 
+  template <class OutputItFaces, class OutputItBoundaryEdges>
   std::pair<OutputItFaces,OutputItBoundaryEdges>
-  get_conflicts_and_boundary(const Point  &p, 
-			     OutputItFaces fit, 
-			     OutputItBoundaryEdges eit,
-			     Face_handle start = Face_handle()) const {
-    CGAL_triangulation_precondition( dimension() == 2);
+  get_conflicts_and_boundary(const Point  &p,
+                             OutputItFaces fit,
+                             OutputItBoundaryEdges eit,
+                             Face_handle start = Face_handle()) const {
+    CGAL_precondition( dimension() == 2);
     int li;
     Locate_type lt;
     Face_handle fh = locate(p,lt,li, start);
@@ -418,32 +466,32 @@ public:
     case Ctr::OUTSIDE_CONVEX_HULL:
       *fit++ = fh; //put fh in OutputItFaces
       std::pair<OutputItFaces,OutputItBoundaryEdges>
-	pit = std::make_pair(fit,eit);
+        pit = std::make_pair(fit,eit);
       pit = propagate_conflicts(p,fh,0,pit);
       pit = propagate_conflicts(p,fh,1,pit);
       pit = propagate_conflicts(p,fh,2,pit);
       return pit;
     }
-    CGAL_triangulation_assertion(false);
+    CGAL_assertion(false);
     return std::make_pair(fit,eit);
-  } 
+  }
 
   template <class OutputItFaces>
   OutputItFaces
-  get_conflicts (const Point  &p, 
-		 OutputItFaces fit, 
-		 Face_handle start= Face_handle()) const {
-    std::pair<OutputItFaces,Emptyset_iterator> pp = 
+  get_conflicts (const Point  &p,
+                 OutputItFaces fit,
+                 Face_handle start= Face_handle()) const {
+    std::pair<OutputItFaces,Emptyset_iterator> pp =
       get_conflicts_and_boundary(p,fit,Emptyset_iterator(),start);
     return pp.first;
   }
 
-  template <class OutputItBoundaryEdges> 
+  template <class OutputItBoundaryEdges>
   OutputItBoundaryEdges
-  get_boundary_of_conflicts(const Point  &p, 
-			    OutputItBoundaryEdges eit, 
-			    Face_handle start= Face_handle()) const {
-    std::pair<Emptyset_iterator, OutputItBoundaryEdges> pp = 
+  get_boundary_of_conflicts(const Point  &p,
+                            OutputItBoundaryEdges eit,
+                            Face_handle start= Face_handle()) const {
+    std::pair<Emptyset_iterator, OutputItBoundaryEdges> pp =
       get_conflicts_and_boundary(p,Emptyset_iterator(),eit,start);
     return pp.second;
   }
@@ -453,15 +501,15 @@ public:
 // made  public for the need of Mesh_2
 // but not documented
 #ifdef CGAL_CDT2_USE_RECURSIVE_PROPAGATE_CONFLICTS
-  template <class OutputItFaces, class OutputItBoundaryEdges> 
+  template <class OutputItFaces, class OutputItBoundaryEdges>
   std::pair<OutputItFaces,OutputItBoundaryEdges>
   propagate_conflicts (const Point  &p,
-                      Face_handle fh, 
+                      Face_handle fh,
                       int i,
-                      std::pair<OutputItFaces,OutputItBoundaryEdges>  pit)  const 
+                      std::pair<OutputItFaces,OutputItBoundaryEdges>  pit)  const
   {
      Face_handle fn = fh->neighbor(i);
-     
+
      if ( fh->is_constrained(i) || ! test_conflict(p,fn)) {
        *(pit.second)++ = Edge(fn, fn->index(fh));
      } else {
@@ -473,12 +521,12 @@ public:
      return pit;
   }
 #else // NO CGAL_CDT2_USE_RECURSIVE_PROPAGATE_CONFLICTS
-  template <class OutputItFaces, class OutputItBoundaryEdges> 
+  template <class OutputItFaces, class OutputItBoundaryEdges>
   std::pair<OutputItFaces,OutputItBoundaryEdges>
   non_recursive_propagate_conflicts (const Point  &p,
-                                     Face_handle fh, 
+                                     Face_handle fh,
                                      int i,
-                                     std::pair<OutputItFaces,OutputItBoundaryEdges>  pit)  const 
+                                     std::pair<OutputItFaces,OutputItBoundaryEdges>  pit)  const
   {
     std::stack<std::pair<Face_handle, int> > stack;
     stack.push(std::make_pair(fh, i));
@@ -499,17 +547,17 @@ public:
     return pit;
   }
 
-  template <class OutputItFaces, class OutputItBoundaryEdges> 
+  template <class OutputItFaces, class OutputItBoundaryEdges>
   std::pair<OutputItFaces,OutputItBoundaryEdges>
   propagate_conflicts (const Point  &p,
-                      Face_handle fh, 
+                      Face_handle fh,
                       int i,
                       std::pair<OutputItFaces,OutputItBoundaryEdges>  pit,
-                      int depth=0)  const 
+                      int depth=0)  const
   {
     if ( depth==100) return non_recursive_propagate_conflicts(p,fh,i,pit);
     Face_handle fn = fh->neighbor(i);
- 
+
     if ( fh->is_constrained(i) || ! test_conflict(p,fn)) {
       *(pit.second)++ = Edge(fn, fn->index(fh));
     } else {
@@ -528,18 +576,20 @@ public:
 public:
  template <class OutputItFaces>
  OutputItFaces
- propagating_flip(List_edges & edges, 
-		  OutputItFaces out = Emptyset_iterator()) {
-  // makes the triangulation Delaunay by flipping 
+ propagating_flip(List_edges & edges,
+                  OutputItFaces out = Emptyset_iterator()) {
+  // makes the triangulation Delaunay by flipping
   // List edges contains an initial list of edges to be flipped
-  // Precondition : the output triangulation is Delaunay if the list 
+  // Precondition : the output triangulation is Delaunay if the list
   // edges contains all edges of the input triangulation that need to be
   // flipped (plus possibly others)
   int i, ii, indf, indn;
   Face_handle ni, f,ff;
-  Edge ei,eni; 
-  typename Ctr::Edge_set edge_set;
-  typename Ctr::Less_edge less_edge;
+  Edge ei,eni;
+
+  Less_edge less_edge(this);
+  Edge_set edge_set(less_edge);
+
   Edge e[4];
   typename List_edges::iterator itedge=edges.begin();
 
@@ -548,7 +598,7 @@ public:
     f=(*itedge).first;
     i=(*itedge).second;
     if (is_flipable(f,i)) {
-      eni=Edge(f->neighbor(i),this->mirror_index(f,i));
+      eni=Edge(f->neighbor(i),mirror_index(f,i));
       if (less_edge(*itedge,eni)) edge_set.insert(*itedge);
       else edge_set.insert(eni);
     }
@@ -559,13 +609,13 @@ public:
   while (!(edge_set.empty())) {
     f=(*(edge_set.begin())).first;
     indf=(*(edge_set.begin())).second;
- 
+
     // erase from edge_set the 4 edges of the wing of the edge to be
     // flipped (edge_set.begin) , i.e. the edges of the faces f and
     // f->neighbor(indf) that are distinct from the edge to be flipped
 
-    ni = f->neighbor(indf); 
-    indn=this->mirror_index(f,indf);
+    ni = f->neighbor(indf);
+    indn=mirror_index(f,indf);
     ei= Edge(f,indf);
     edge_set.erase(ei);
     e[0]= Edge(f,cw(indf));
@@ -573,38 +623,38 @@ public:
     e[2]= Edge(ni,cw(indn));
     e[3]= Edge(ni,ccw(indn));
 
-    for(i=0;i<4;i++) { 
+    for(i=0;i<4;i++) {
       ff=e[i].first;
       ii=e[i].second;
-      eni=Edge(ff->neighbor(ii),this->mirror_index(ff,ii));
+      eni=Edge(ff->neighbor(ii),mirror_index(ff,ii));
       if (less_edge(e[i],eni)) {edge_set.erase(e[i]);}
-      else { edge_set.erase(eni);} 
-    } 
+      else { edge_set.erase(eni);}
+    }
 
-    // here is the flip 
+    // here is the flip
     *out++ = f;
     *out++ = f->neighbor(indf);
-    flip(f, indf); 
-    
+    flip(f, indf);
+
 
     //insert in edge_set the 4 edges of the wing of the edge that
-    //have been flipped 
+    //have been flipped
     e[0]= Edge(f,indf);
     e[1]= Edge(f,cw(indf));
     e[2]= Edge(ni,indn);
     e[3]= Edge(ni,cw(indn));
 
-    for(i=0;i<4;i++) { 
+    for(i=0;i<4;i++) {
       ff=e[i].first;
       ii=e[i].second;
       if (is_flipable(ff,ii)) {
-	eni=Edge(ff->neighbor(ii),this->mirror_index(ff,ii));
-	if (less_edge(e[i],eni)) { 
-	  edge_set.insert(e[i]);}
-	else {
-	  edge_set.insert(eni);} 
+        eni=Edge(ff->neighbor(ii),mirror_index(ff,ii));
+        if (less_edge(e[i],eni)) {
+          edge_set.insert(e[i]);}
+        else {
+          edge_set.insert(eni);}
       }
-    } 
+    }
   }
   return out;
  }
@@ -618,71 +668,71 @@ public:
     le.push_back(Edge(f,i));
     propagating_flip(le,out);
   }
-  return out;  
+  return out;
  }
- 
+
 };
 
 
 template < class Gt, class Tds, class Itag >
-bool 
+bool
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 is_flipable(Face_handle f, int i, bool perturb /* = true */) const
-  // determines if edge (f,i) can be flipped 
+  // determines if edge (f,i) can be flipped
 {
-  Face_handle ni = f->neighbor(i); 
-  if (is_infinite(f) || is_infinite(ni)) return false; 
+  Face_handle ni = f->neighbor(i);
+  if (is_infinite(f) || is_infinite(ni)) return false;
   if (f->is_constrained(i)) return false;
-  return (side_of_oriented_circle(ni, f->vertex(i)->point(), perturb) 
+  return (side_of_oriented_circle(ni, f->vertex(i)->point(), perturb)
                                         == ON_POSITIVE_SIDE);
 }
 
 template < class Gt, class Tds, class Itag >
-void 
+void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 flip (Face_handle& f, int i)
 {
   Face_handle g = f->neighbor(i);
-  int j = this->mirror_index(f,i);
+  int j = mirror_index(f,i);
 
-  // save wings neighbors to be able to restore contraint status
+  // save wings neighbors to be able to restore constraint status
   Face_handle f1 = f->neighbor(cw(i));
-  int i1 = this->mirror_index(f,cw(i));
+  int i1 = mirror_index(f,cw(i));
   Face_handle f2 = f->neighbor(ccw(i));
-  int i2 = this->mirror_index(f,ccw(i));
+  int i2 = mirror_index(f,ccw(i));
   Face_handle f3 = g->neighbor(cw(j));
-  int i3 = this->mirror_index(g,cw(j));
+  int i3 = mirror_index(g,cw(j));
   Face_handle f4 = g->neighbor(ccw(j));
-  int i4 = this->mirror_index(g,ccw(j));
+  int i4 = mirror_index(g,ccw(j));
 
-  // The following precondition prevents the test suit 
+  // The following precondition prevents the test suit
   // of triangulation to work on constrained Delaunay triangulation
-  //CGAL_triangulation_precondition(is_flipable(f,i));
+  //CGAL_precondition(is_flipable(f,i));
   this->_tds.flip(f, i);
-   
+
   // restore constraint status
   f->set_constraint(f->index(g), false);
   g->set_constraint(g->index(f), false);
-  f1->neighbor(i1)->set_constraint(this->mirror_index(f1,i1),
-				   f1->is_constrained(i1));
-  f2->neighbor(i2)->set_constraint(this->mirror_index(f2,i2),
-				   f2->is_constrained(i2));
-  f3->neighbor(i3)->set_constraint(this->mirror_index(f3,i3),
-				   f3->is_constrained(i3));
-  f4->neighbor(i4)->set_constraint(this->mirror_index(f4,i4),
-				   f4->is_constrained(i4));
+  f1->neighbor(i1)->set_constraint(mirror_index(f1,i1),
+                                   f1->is_constrained(i1));
+  f2->neighbor(i2)->set_constraint(mirror_index(f2,i2),
+                                   f2->is_constrained(i2));
+  f3->neighbor(i3)->set_constraint(mirror_index(f3,i3),
+                                   f3->is_constrained(i3));
+  f4->neighbor(i4)->set_constraint(mirror_index(f4,i4),
+                                   f4->is_constrained(i4));
   return;
 }
 
 template < class Gt, class Tds, class Itag >
-void 
+void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 flip_around(Vertex_handle va)
   // makes the triangles incident to vertex va Delaunay using flips
 {
   if (dimension() <= 1) return;
   Face_handle f=va->face();
-  Face_handle next;    
+  Face_handle next;
   Face_handle start(f);
   int i;
   do {
@@ -694,7 +744,7 @@ flip_around(Vertex_handle va)
 }
 
 template < class Gt, class Tds, class Itag >
-void 
+void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 flip_around(List_vertices& new_vertices)
 {
@@ -752,7 +802,7 @@ propagating_flip(Face_handle f,int i, int depth)
   propagating_flip(ni,i, depth+1);
 #endif
 }
-#else 
+#else
 template < class Gt, class Tds, class Itag >
 void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
@@ -768,9 +818,9 @@ propagating_flip(Face_handle f,int i)
 }
 #endif
 
- template < class Gt, class Tds, class Itag > 
+ template < class Gt, class Tds, class Itag >
  void
- Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>:: 
+ Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
  propagating_flip(List_edges & edges) {
     propagating_flip(edges,Emptyset_iterator());
  }
@@ -787,11 +837,11 @@ test_conflict(const Point& p, Face_handle fh) const
   // halfspace or on the boundary and in the  finite edge of fh
   Oriented_side os = side_of_oriented_circle(fh,p,true);
   if (os == ON_POSITIVE_SIDE) return true;
- 
+
   if (os == ON_ORIENTED_BOUNDARY && is_infinite(fh)) {
     int i = fh->index(infinite_vertex());
     return collinear_between(fh->vertex(cw(i))->point(), p,
-			     fh->vertex(ccw(i))->point() );
+                             fh->vertex(ccw(i))->point() );
   }
 
   return false;
@@ -806,20 +856,20 @@ test_conflict(Face_handle fh, const Point& p) const
   return test_conflict(p,fh);
 }
 
-template < class Gt, class Tds, class Itag >    
-void 
+template < class Gt, class Tds, class Itag >
+void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 find_conflicts(const Point& p, std::list<Edge>& le, Face_handle hint) const
 {
-  // sets in le the counterclocwise list of the edges of the boundary of the 
+  // sets in le the counterclocwise list of the edges of the boundary of the
   // union of the faces in conflict with p
   // an edge is represented by the incident face that is not in conflict with p
   get_boundary_of_conflicts(p, std::back_inserter(le), hint);
 }
-  
-template < class Gt, class Tds, class Itag >  
-inline 
-typename Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle 
+
+template < class Gt, class Tds, class Itag >
+inline
+typename Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 virtual_insert(const Point & a, Face_handle start)
   // virtual version of the insertion
@@ -827,22 +877,22 @@ virtual_insert(const Point & a, Face_handle start)
   return insert(a,start);
 }
 
-template < class Gt, class Tds, class Itag >  
-inline 
-typename Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle 
+template < class Gt, class Tds, class Itag >
+inline
+typename Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 virtual_insert(const Point& a,
-	       Locate_type lt,
-	       Face_handle loc, 
-	       int li )
+               Locate_type lt,
+               Face_handle loc,
+               int li )
 // virtual version of insert
 {
   return insert(a,lt,loc,li);
 }
 
-template < class Gt, class Tds, class Itag >  
-inline 
-typename Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle 
+template < class Gt, class Tds, class Itag >
+inline
+typename Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 insert(const Point & a, Face_handle start)
  // inserts a in the triangulation
@@ -850,7 +900,7 @@ insert(const Point & a, Face_handle start)
 // Delaunay property is restored
 {
   Vertex_handle va= Ctr::insert(a, start);
-  flip_around(va); 
+  flip_around(va);
   return va;
 }
 
@@ -863,7 +913,7 @@ insert(const Point& a, Locate_type lt, Face_handle loc, int li)
 // Delaunay property is restored
 {
   Vertex_handle va= Ctr::insert(a,lt,loc,li);
-  flip_around(va); 
+  flip_around(va);
   return va;
 }
 
@@ -877,38 +927,38 @@ push_back(const Point &p)
 }
 
 template < class Gt, class Tds, class Itag >
-void 
+void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 triangulate_hole(List_faces& intersected_faces,
-		 List_edges& conflict_boundary_ab,
-		 List_edges& conflict_boundary_ba)
+                 List_edges& conflict_boundary_ab,
+                 List_edges& conflict_boundary_ba)
 {
   List_edges new_edges;
   Ctr::triangulate_hole(intersected_faces,
-		       conflict_boundary_ab,
-		       conflict_boundary_ba,
-		       new_edges);
+                       conflict_boundary_ab,
+                       conflict_boundary_ba,
+                       new_edges);
   propagating_flip(new_edges);
   return;
 }
 
 
-template < class Gt, class Tds, class Itag >  
-inline void 
+template < class Gt, class Tds, class Itag >
+inline void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 remove(Vertex_handle v)
   // remove a vertex and updates the constrained edges of the new faces
   // precondition : there is no incident constraints
 {
-  CGAL_triangulation_precondition( v != Vertex_handle() );
-  CGAL_triangulation_precondition( ! is_infinite(v));
-  CGAL_triangulation_precondition( ! are_there_incident_constraints(v));
+  CGAL_precondition( v != Vertex_handle() );
+  CGAL_precondition( ! is_infinite(v));
+  CGAL_precondition( ! are_there_incident_constraints(v));
   if  (dimension() <= 1)    Ctr::remove(v);
   else  remove_2D(v);
   return;
 }
 
-// template < class Gt, class Tds, class Itag >  
+// template < class Gt, class Tds, class Itag >
 // typename
 // Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::Vertex_handle
 // Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
@@ -916,16 +966,16 @@ remove(Vertex_handle v)
 //   // insert  point p in edge(f,i)
 //   // bypass the precondition for point a to be in edge(f,i)
 //   // update constrained status
-//   // this member fonction is not robust with exact predicates 
-//   // and approximate construction. Should be removed 
+//   // this member function is not robust with exact predicates
+//   // and approximate construction. Should be removed
 // {
 //   Vertex_handle vh=Ctr::special_insert_in_edge(a,f,i);
 //   flip_around(vh);
 //   return vh;
 // }
 
-template < class Gt, class Tds, class Itag >  
-void 
+template < class Gt, class Tds, class Itag >
+void
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 remove_2D(Vertex_handle v)
 {
@@ -948,7 +998,7 @@ remove_incident_constraints(Vertex_handle v)
 {
    List_edges iconstraints;
    if (are_there_incident_constraints(v,
-				      std::back_inserter(iconstraints))) {
+                                      std::back_inserter(iconstraints))) {
      Ctr::remove_incident_constraints(v);
      if (dimension()==2) propagating_flip(iconstraints);
    }
@@ -961,23 +1011,23 @@ Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 remove_constrained_edge(Face_handle f, int i)
 {
   remove_constrained_edge(f,i,Emptyset_iterator());
-  return;  
+  return;
 }
 
 
-template < class Gt, class Tds, class Itag >  
-bool 
+template < class Gt, class Tds, class Itag >
+bool
 Constrained_Delaunay_triangulation_2<Gt,Tds,Itag>::
 is_valid(bool verbose, int level) const
 {
   bool result = Ctr::is_valid(verbose, level);
-  CGAL_triangulation_assertion( result );
+  CGAL_assertion( result );
 
     Finite_faces_iterator fit= finite_faces_begin();
     for (; fit != finite_faces_end(); fit++) {
       for(int i=0;i<3;i++) {
-	result = result && !is_flipable(fit,i, false);
-	CGAL_triangulation_assertion( result );
+        result = result && !is_flipable(fit,i, false);
+        CGAL_assertion( result );
       }
     }
     return result;
