@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Convex_hull_3/include/CGAL/Convex_hull_3/dual/Convex_hull_traits_dual_2.h $
-// $Id: Convex_hull_traits_dual_2.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Convex_hull_3/include/CGAL/Convex_hull_3/dual/Convex_hull_traits_dual_2.h $
+// $Id: Convex_hull_traits_dual_2.h 711d64674a6 2022-07-02T17:19:48+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Jocelyn Meyron
@@ -123,7 +114,7 @@ namespace CGAL
                     }
                 };
 
-                struct Less_signed_distance_to_line_2 {
+                struct Compare_signed_distance_to_line_2 {
                     typedef typename R::RT        RT;
                     typedef bool result_type;
 
@@ -190,8 +181,8 @@ namespace CGAL
                     return Less_yx_2();
                 }
 
-                Less_signed_distance_to_line_2 less_signed_distance_to_line_2_object () const {
-                    return Less_signed_distance_to_line_2();
+                Compare_signed_distance_to_line_2 compare_signed_distance_to_line_2_object () const {
+                    return Compare_signed_distance_to_line_2();
                 }
 
                 Orientation_2 orientation_2_object () const {
@@ -285,7 +276,7 @@ namespace CGAL
                     }
                 };
 
-                struct Less_signed_distance_to_line_2 {
+                struct Compare_signed_distance_to_line_2 {
                     typedef typename R::RT        RT;
                     typedef bool result_type;
 
@@ -352,8 +343,8 @@ namespace CGAL
                     return Less_yx_2();
                 }
 
-                Less_signed_distance_to_line_2 less_signed_distance_to_line_2_object () const {
-                    return Less_signed_distance_to_line_2();
+                Compare_signed_distance_to_line_2 compare_signed_distance_to_line_2_object () const {
+                    return Compare_signed_distance_to_line_2();
                 }
 
                 Orientation_2 orientation_2_object () const {
@@ -447,7 +438,7 @@ namespace CGAL
                     }
                 };
 
-                struct Less_signed_distance_to_line_2 {
+                struct Compare_signed_distance_to_line_2 {
                     typedef typename R::RT        RT;
                     typedef bool result_type;
 
@@ -513,8 +504,8 @@ namespace CGAL
                     return Less_yx_2();
                 }
 
-                Less_signed_distance_to_line_2 less_signed_distance_to_line_2_object () const {
-                    return Less_signed_distance_to_line_2();
+                Compare_signed_distance_to_line_2 compare_signed_distance_to_line_2_object () const {
+                    return Compare_signed_distance_to_line_2();
                 }
 
                 Orientation_2 orientation_2_object () const {
