@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Convex_hull_3/include/CGAL/Convex_hull_3/dual/halfspace_intersection_with_constructions_3.h $
-// $Id: halfspace_intersection_with_constructions_3.h 7a62583 2022-11-14T19:14:33+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Convex_hull_3/include/CGAL/Convex_hull_3/dual/halfspace_intersection_with_constructions_3.h $
+// $Id: halfspace_intersection_with_constructions_3.h 47e728f2efd 2023-12-22T17:14:12+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -23,7 +23,9 @@
 #include <CGAL/assertions.h>
 
 // For interior_polyhedron_3
+#ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
 #include <CGAL/Convex_hull_3/dual/halfspace_intersection_interior_point_3.h>
+#endif
 #include <CGAL/Number_types/internal/Exact_type_selector.h>
 
 #include <unordered_map>
@@ -99,7 +101,9 @@ namespace CGAL
           // if a point inside is not provided find one using linear programming
           if (!origin) {
             // find a point inside the intersection
+#ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
             origin = halfspace_intersection_interior_point_3(pbegin, pend);
+#endif
 
             CGAL_assertion_msg(origin!=boost::none, "halfspace_intersection_with_constructions_3: problem when determining a point inside the intersection");
             if (origin==boost::none)
@@ -134,7 +138,11 @@ namespace CGAL
           void halfspace_intersection_with_constructions_3 (PlaneIterator pbegin,
                                                             PlaneIterator pend,
                                                             Polyhedron &P,
-                                                            boost::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> const& origin = boost::none) {
+                                                            boost::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> const& origin
+#ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
+                                                            = boost::none
+#endif
+        ) {
           typedef typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel K;
           typedef typename K::Point_3 Point_3;
           typedef typename Convex_hull_3::internal::Default_traits_for_Chull_3<Point_3>::type Traits;
