@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Convex_hull_3/include/CGAL/Convex_hull_3/dual/predicates.h $
-// $Id: predicates.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Convex_hull_3/include/CGAL/Convex_hull_3/dual/predicates.h $
+// $Id: predicates.h 46d1aea3297 2022-05-09T15:30:26+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Jocelyn Meyron
@@ -79,7 +70,7 @@ namespace CGAL
                 typedef typename K::RT        RT;
                 typedef typename K::Plane_3   Plane_3;
                 typedef typename K::Point_3   Point_3;
-                typedef bool                  result_type;
+                typedef typename K::Boolean   result_type;
 
                 Equal_3_dual_point (Point_3 const& o = Point_3(0, 0, 0)) :
                     origin(o)
@@ -113,7 +104,7 @@ namespace CGAL
                 typedef typename K::RT        RT;
                 typedef typename K::Plane_3   Plane_3;
                 typedef typename K::Point_3   Point_3;
-                typedef bool                  result_type;
+                typedef typename K::Boolean   result_type;
 
                 Collinear_3_dual_point (Point_3 const& o = Point_3(0, 0, 0)) :
                     origin(o)
@@ -160,7 +151,7 @@ namespace CGAL
                 typedef typename K::RT        RT;
                 typedef typename K::Plane_3   Plane_3;
                 typedef typename K::Point_3   Point_3;
-                typedef bool                  result_type;
+                typedef typename K::Boolean   result_type;
 
                 Coplanar_3_dual_point (Point_3 const& o = Point_3(0, 0, 0)) :
                     origin(o)
@@ -209,8 +200,8 @@ namespace CGAL
             {
                 typedef typename K::RT         RT;
                 typedef typename K::Plane_3    Plane_3;
-                typedef typename K::Point_3   Point_3;
-                typedef bool                   result_type;
+                typedef typename K::Point_3    Point_3;
+                typedef typename K::Boolean    result_type;
 
                 Has_on_positive_side_3_dual_point (Point_3 const& o =
                                                    Point_3(0, 0, 0)) :
@@ -272,7 +263,7 @@ namespace CGAL
                 typedef typename K::RT        RT;
                 typedef typename K::Plane_3   Plane_3;
                 typedef typename K::Point_3   Point_3;
-                typedef bool                  result_type;
+                typedef typename K::Boolean   result_type;
 
                 Less_distance_to_point_3_dual_point (Point_3 const& o =
                                                      Point_3(0, 0, 0)) :
@@ -321,8 +312,8 @@ namespace CGAL
             {
                 typedef typename K::RT         RT;
                 typedef typename K::Plane_3    Plane_3;
-                typedef typename K::Point_3   Point_3;
-                typedef bool                   result_type;
+                typedef typename K::Point_3    Point_3;
+                typedef typename K::Boolean    result_type;
 
                 Less_signed_distance_to_plane_3_dual_point (Point_3 const& o =
                                                             Point_3(0, 0, 0)) :
@@ -386,7 +377,7 @@ namespace CGAL
             {
                 typedef typename K::RT         RT;
                 typedef typename K::Plane_3    Plane_3;
-                typedef typename K::Point_3   Point_3;
+                typedef typename K::Point_3    Point_3;
                 typedef CGAL::Oriented_side    result_type;
 
                 Oriented_side_3_dual_point (Point_3 const& o =
@@ -458,4 +449,3 @@ namespace CGAL
 } // namespace CGAL
 
 #endif // CGAL_CH3_DUAL_PREDICATES_H
-
