@@ -1,38 +1,27 @@
-// Copyright (c) 1999  
+// Copyright (c) 1999
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Kernel_23/include/CGAL/Direction_3.h $
+// $Id: Direction_3.h 5872413f375 2022-06-10T08:48:53+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Kernel_23/include/CGAL/Direction_3.h $
-// $Id: Direction_3.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Andreas Fabri, Stefan Schirra
- 
+
 #ifndef CGAL_DIRECTION_3_H
 #define CGAL_DIRECTION_3_H
 
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/kernel_assertions.h>
 #include <CGAL/representation_tags.h>
 #include <CGAL/Dimension.h>
-#include <CGAL/result_of.h>
 #include <CGAL/IO/io.h>
 
 namespace CGAL {
@@ -48,7 +37,7 @@ class Direction_3 : public R_::Kernel_base::Direction_3
   typedef typename R_::Aff_transformation_3  Aff_transformation_3;
 
   typedef Direction_3                        Self;
-  CGAL_static_assertion((boost::is_same<Self, typename R_::Direction_3>::value));
+  CGAL_static_assertion((std::is_same<Self, typename R_::Direction_3>::value));
 
 public:
 
@@ -74,6 +63,9 @@ public:
   Direction_3(const Rep& d)
     : Rep(d) {}
 
+  Direction_3(Rep&& d)
+    : Rep(std::move(d)) {}
+
   explicit Direction_3(const Vector_3& v)
     : Rep(typename R::Construct_direction_3()(Return_base_tag(), v)) {}
 
@@ -93,13 +85,13 @@ public:
   {
     return t.transform(*this);
   }
- 
+
   Direction_3
   operator-() const
   {
     return R().construct_opposite_direction_3_object()(*this);
-  } 
-  
+  }
+
   Vector_3 to_vector() const
   {
     return R().construct_vector_3_object()(*this);
@@ -108,25 +100,25 @@ public:
   Vector_3 vector() const { return to_vector(); }
 
 
-  typename cpp11::result_of<typename R::Compute_dx_3(Direction_3)>::type
+  decltype(auto)
   dx() const
   {
     return R().compute_dx_3_object()(*this);
   }
 
-  typename cpp11::result_of<typename R::Compute_dy_3(Direction_3)>::type
+  decltype(auto)
   dy() const
   {
     return R().compute_dy_3_object()(*this);
   }
 
-  typename cpp11::result_of<typename R::Compute_dz_3(Direction_3)>::type
+  decltype(auto)
   dz() const
   {
     return R().compute_dz_3_object()(*this);
   }
 
-  typename cpp11::result_of<typename R::Compute_dx_3(Direction_3)>::type
+  decltype(auto)
   delta(int i) const
   {
     CGAL_kernel_precondition( i >= 0 && i <= 2 );
@@ -140,10 +132,10 @@ public:
 
 template <class R >
 std::ostream&
-insert(std::ostream& os, const Direction_3<R>& d, const Cartesian_tag&) 
+insert(std::ostream& os, const Direction_3<R>& d, const Cartesian_tag&)
 {
   typename R::Vector_3 v = d.to_vector();
-  switch(get_mode(os)) {
+  switch(IO::get_mode(os)) {
     case IO::ASCII :
       return os << v.x() << ' ' << v.y()  << ' ' << v.z();
     case IO::BINARY :
@@ -161,7 +153,7 @@ template <class R >
 std::ostream&
 insert(std::ostream& os, const Direction_3<R>& d, const Homogeneous_tag&)
 {
-  switch(get_mode(os))
+  switch(IO::get_mode(os))
   {
     case IO::ASCII :
         return os << d.dx() << ' ' << d.dy() << ' ' << d.dz();
@@ -187,12 +179,12 @@ operator<<(std::ostream& os, const Direction_3<R>& d)
 
 template <class R >
 std::istream&
-extract(std::istream& is, Direction_3<R>& d, const Cartesian_tag&) 
+extract(std::istream& is, Direction_3<R>& d, const Cartesian_tag&)
 {
   typename R::FT x(0), y(0), z(0);
-  switch(get_mode(is)) {
+  switch(IO::get_mode(is)) {
     case IO::ASCII :
-      is >> iformat(x) >> iformat(y) >> iformat(z);
+      is >> IO::iformat(x) >> IO::iformat(y) >> IO::iformat(z);
       break;
     case IO::BINARY :
       read(is, x);
@@ -202,7 +194,7 @@ extract(std::istream& is, Direction_3<R>& d, const Cartesian_tag&)
     default:
       is.setstate(std::ios::failbit);
       std::cerr << "" << std::endl;
-      std::cerr << "Stream must be in ascii or binary mode" << std::endl;
+      std::cerr << "Stream must be in ASCII or binary mode" << std::endl;
       break;
   }
   if (is)
@@ -212,13 +204,13 @@ extract(std::istream& is, Direction_3<R>& d, const Cartesian_tag&)
 
 template <class R >
 std::istream&
-extract(std::istream& is, Direction_3<R>& d, const Homogeneous_tag&) 
+extract(std::istream& is, Direction_3<R>& d, const Homogeneous_tag&)
 {
   typename R::RT x, y, z;
-  switch(get_mode(is))
+  switch(IO::get_mode(is))
   {
     case IO::ASCII :
-        is >> iformat(x) >> iformat(y) >> iformat(z);
+        is >> IO::iformat(x) >> IO::iformat(y) >> IO::iformat(z);
         break;
     case IO::BINARY :
         read(is, x);
@@ -228,7 +220,7 @@ extract(std::istream& is, Direction_3<R>& d, const Homogeneous_tag&)
     default:
         is.setstate(std::ios::failbit);
         std::cerr << "" << std::endl;
-        std::cerr << "Stream must be in ascii or binary mode" << std::endl;
+        std::cerr << "Stream must be in ASCII or binary mode" << std::endl;
         break;
   }
   if (is)
