@@ -1,20 +1,11 @@
 // Copyright (c) 2006  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Filtered_kernel/include/CGAL/Filtered_kernel/Cartesian_coordinate_iterator_2.h $
-// $Id: Cartesian_coordinate_iterator_2.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Filtered_kernel/include/CGAL/Filtered_kernel/Cartesian_coordinate_iterator_2.h $
+// $Id: Cartesian_coordinate_iterator_2.h 66c20ba18cb 2021-08-03T16:30:18+02:00 Dmitry Anisimov
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri, Sylvain Pion
@@ -51,11 +42,11 @@ public:
   typedef std::random_access_iterator_tag iterator_category;
   typedef FT                              value_type;
   typedef int                             difference_type;
-  typedef const value_type&               reference;
-  typedef const value_type*               pointer;
+  typedef void                            pointer;
+  typedef value_type                      reference;
 
   Cartesian_coordinate_iterator_2()
-    : var((const P*) NULL), index(0) {}
+    : var((const P*) nullptr), index(0) {}
 
   Cartesian_coordinate_iterator_2(const P * const p, int _index = 0)
     : var(p), index(_index) {}
@@ -64,7 +55,7 @@ public:
     : var(v), index(_index) {}
 
 
-  const FT
+  reference
   operator*() const {
     if (const P* const* p = boost::get<const P*>(&var))
       return (*p)->cartesian(index);
@@ -73,7 +64,8 @@ public:
     return (*v)->cartesian(index);
   }
 
-  Self&  operator++() {
+  Self&
+  operator++() {
     index++;
     return *this;
   }
@@ -100,7 +92,7 @@ public:
 
   Self&
   operator+=(difference_type i) {
-    index+=i;
+    index += i;
     return *this;
   }
 
@@ -116,7 +108,8 @@ public:
     return tmp += i;
   }
 
-  Self operator-(difference_type i) const {
+  Self
+  operator-(difference_type i) const {
     Self tmp=*this;
     return tmp -= i;
   }
@@ -127,19 +120,23 @@ public:
     return index - x.index;
   }
 
-  reference operator[](difference_type i) const {
+  reference
+  operator[](difference_type i) const {
     return *(*this + i);
   }
 
-  bool operator==(const Self& x) const {
+  bool
+  operator==(const Self& x) const {
     return (var == x.var) && (index == x.index);
   }
 
-  bool operator!=(const Self& x) const {
+  bool
+  operator!=(const Self& x) const {
     return ! (*this==x);
   }
 
-  bool operator<(const Self& x) const
+  bool
+  operator<(const Self& x) const
   {
     return (x - *this) > 0;
   }
