@@ -2,19 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Alpha_shapes_3/include/CGAL/Fixed_alpha_shape_vertex_base_3.h $
+// $Id: Fixed_alpha_shape_vertex_base_3.h 98e471849bd 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL$
-// $Id$
-// 
 //
 // Author(s)     :  Sebastien Loriot
 //
@@ -22,10 +14,12 @@
 #ifndef CGAL_FIXED_ALPHA_SHAPE_VERTEX_BASE_3_H
 #define CGAL_FIXED_ALPHA_SHAPE_VERTEX_BASE_3_H
 
+#include <CGAL/license/Alpha_shapes_3.h>
+
+
 #include <utility>
-#include <CGAL/Compact_container.h>
 #include <CGAL/Triangulation_vertex_base_3.h>
-#include <CGAL/internal/Classification_type.h>
+#include <CGAL/Alpha_shapes_3/internal/Classification_type.h>
 
 namespace CGAL {
 
@@ -43,32 +37,31 @@ public:
     typedef Fixed_alpha_shape_vertex_base_3<Gt, Vb2>              Other;
   };
 
-  typedef typename Gt::Point_3 Point;
+  typedef typename Vb::Point Point;
 
-  
 private:
-  typedef internal::Classification_type Classification_type;  
+  typedef internal::Classification_type Classification_type;
   Classification_type status_;
 
   bool is_on_chull_;
 
 public:
 
-  Fixed_alpha_shape_vertex_base_3()    
+  Fixed_alpha_shape_vertex_base_3()
     : Vb(),is_on_chull_(false) {}
-  
+
   Fixed_alpha_shape_vertex_base_3(const Point& p)
     : Vb(p),is_on_chull_(false) {}
-  
+
   Fixed_alpha_shape_vertex_base_3(const Point& p, Cell_handle c)
     : Vb(p, c),is_on_chull_(false) {}
 
   Classification_type get_classification_type() { return status_;}
   void set_classification_type(Classification_type status) {status_=status;}
-  
+
   void is_on_chull(bool b){is_on_chull_=b;};
   bool is_on_chull(){return is_on_chull_;}
-    
+
 };
 
 } //namespace CGAL
