@@ -1,19 +1,10 @@
 // Copyright (c) 2007-2010 Inria Lorraine (France). All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/GMP/Gmpfi_type.h $
-// $Id: Gmpfi_type.h a154aa1 2018-02-19T14:28:35+01:00 Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/GMP/Gmpfi_type.h $
+// $Id: Gmpfi_type.h 3674c937f76 2022-11-15T15:21:01+01:00 albert-github
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author: Luis Peñaranda <luis.penaranda@gmx.com>
 
@@ -113,7 +104,7 @@ class Gmpfi:
     CGAL_STATIC_THREAD_LOCAL_VARIABLE(mp_prec_t, Gmpfi_default_precision, CGAL_GMPFI_DEFAULT_PRECISION);
     return Gmpfi_default_precision;
   }
-        
+
 
         bool is_unique(){
 #ifdef CGAL_GMPFR_NO_REFCOUNT
@@ -312,7 +303,7 @@ CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpz);
         Gmpfi::Precision_type get_precision()const;
         Gmpfi round(Gmpfi::Precision_type)const;
 
-        // arithmetics
+        // arithmetic
 
         Gmpfi operator+()const;
         Gmpfi operator-()const;
@@ -436,7 +427,7 @@ Gmpfi Gmpfi::round(Gmpfi::Precision_type p)const{
         return Gmpfi(*this,p);
 }
 
-// arithmetics
+// arithmetic
 
 inline
 Gmpfi Gmpfi::operator+()const{
@@ -791,7 +782,7 @@ std::pair<double,double> Gmpfi::to_interval()const{
 inline
 std::pair<double,long> Gmpfi::to_double_exp()const{
         mpfr_t middle;
-        long *e=NULL;
+        long *e=nullptr;
         mpfr_init2(middle,53);
         mpfi_get_fr(middle,mpfi());
         double d=mpfr_get_d_2exp(e,middle,mpfr_get_default_rounding_mode());
@@ -801,7 +792,7 @@ std::pair<double,long> Gmpfi::to_double_exp()const{
 
 inline
 std::pair<std::pair<double,double>,long> Gmpfi::to_interval_exp()const{
-        long *e1=NULL,*e2=NULL;
+        long *e1=nullptr,*e2=nullptr;
         double d_low=mpfr_get_d_2exp(e1,left_mpfr(),GMP_RNDD);
         double d_upp=mpfr_get_d_2exp(e2,right_mpfr(),GMP_RNDU);
         if(e1<e2)
