@@ -1,19 +1,10 @@
 // Copyright (c) 2007-2010 Inria Lorraine (France). All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/GMP/Gmpfr_type.h $
-// $Id: Gmpfr_type.h a154aa1 2018-02-19T14:28:35+01:00 Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/GMP/Gmpfr_type.h $
+// $Id: Gmpfr_type.h 3674c937f76 2022-11-15T15:21:01+01:00 albert-github
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author: Luis Peñaranda <luis.penaranda@gmx.com>
 
@@ -354,7 +345,7 @@ class Gmpfr:
 #  pragma warning(push)
 #  pragma warning(disable: 4244)
         CGAL_GMPFR_CONSTRUCTOR_FROM_TYPE(long double,mpfr_set_d);
-#  pragma warning(pop)  
+#  pragma warning(pop)
 #else
         CGAL_GMPFR_CONSTRUCTOR_FROM_TYPE(long double,mpfr_set_ld);
 #endif
@@ -387,7 +378,7 @@ class Gmpfr:
 
 #undef CGAL_GMPFR_CONSTRUCTOR_FROM_OBJECT
 
-        // When Gmpfr is refence counted, we inherit the assignment
+        // When Gmpfr is reference counted, we inherit the assignment
         // operator and the copy constructor from Handle_for.
 #ifdef CGAL_GMPFR_NO_REFCOUNT
         Gmpfr& operator=(const Gmpfr &a){
@@ -464,7 +455,7 @@ class Gmpfr:
         static bool inex_flag();
         static bool erange_flag();
 
-        // arithmetics
+        // arithmetic
 
         Gmpfr operator+()const;
         Gmpfr operator-()const;
@@ -629,7 +620,7 @@ bool Gmpfr::erange_flag(){
         return mpfr_erangeflag_p()!=0;
 }
 
-// arithmetics
+// arithmetic
 
 inline
 Gmpfr Gmpfr::operator+()const{
@@ -1176,16 +1167,16 @@ std::ostream& operator<<(std::ostream& os,const Gmpfr &a){
         if(a.is_inf())
                 return os<<(a<0?"-inf":"+inf");
         // The rest of the function was written by George Tzoumas.
-        if (!is_pretty(os)) {
+        if (!IO::is_pretty(os)) {
                 std::pair<Gmpz,long> ie=a.to_integer_exp();
                 os << ie.first << 'e' << ie.second;
                 return os;
         } else {
                 // human-readable format
                 mpfr_exp_t expptr;
-                char *str = mpfr_get_str(NULL, &expptr, 10, 0, a.fr(),
+                char *str = mpfr_get_str(nullptr, &expptr, 10, 0, a.fr(),
                                 mpfr_get_default_rounding_mode());
-                if (str == NULL) return os << "@err@";
+                if (str == nullptr) return os << "@err@";
                 std::string s(str);
                 mpfr_free_str(str);
                 int i = 0;
