@@ -1,20 +1,11 @@
 // Copyright (c) 2006-2008 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/Gmpzf.h $
-// $Id: Gmpzf.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/Gmpzf.h $
+// $Id: Gmpzf.h 152a0840192 2021-09-21T13:34:58+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Michael Hemmer   <hemmer@mpi-inf.mpg.de>
@@ -74,14 +65,14 @@ public:
     public:
         Type operator()( const Type& x, const Type& y ) const {
             return Type(x).div( y );
-	}
+        }
     };
 
     typedef INTERN_AST::Mod_per_operator< Type > Mod;
-  
+
   class Is_square
     : public CGAL::cpp98::binary_function< Type, Type&, bool > {
-  public:      
+  public:
     bool operator()( const Type& x, Type& y ) const {
       y = CGAL::approximate_sqrt(x);
       return y * y == x;
@@ -102,7 +93,7 @@ class Real_embeddable_traits< Gmpzf >
     typedef Algebraic_structure_traits<Gmpzf> AST;
 public:
   typedef AST::Is_zero Is_zero;
-  
+
     struct Sgn
         : public CGAL::cpp98::unary_function< Type, ::CGAL::Sign > {
     public:
@@ -135,7 +126,7 @@ public:
         : public CGAL::cpp98::unary_function< Type, std::pair< double, double > > {
     public:
         std::pair<double, double> operator()( const Type& x ) const {
-	    return x.to_interval();
+            return x.to_interval();
         }
     };
 };
@@ -150,26 +141,26 @@ public:
     struct To_double: public CGAL::cpp98::unary_function<Quotient<Gmpzf>, double>{
         inline
         double operator()(const Quotient<Gmpzf>& q) const {
-	  std::pair<double, long> n = q.numerator().to_double_exp();
-	  std::pair<double, long> d = q.denominator().to_double_exp();
-	  double scale = std::ldexp(1.0,
+          std::pair<double, long> n = q.numerator().to_double_exp();
+          std::pair<double, long> d = q.denominator().to_double_exp();
+          double scale = std::ldexp(1.0,
                                     static_cast<int>(n.second - d.second));
-	  return (n.first / d.first) * scale;
-	}
+          return (n.first / d.first) * scale;
+        }
     };
     struct To_interval
         : public CGAL::cpp98::unary_function<Quotient<Gmpzf>, std::pair<double,double> >{
         inline
         std::pair<double,double> operator()(const Quotient<Gmpzf>& q) const {
-	  // do here as MP_Float does
-	  std::pair<std::pair<double, double>, long> n =
-	    q.numerator().to_interval_exp();
-	  std::pair<std::pair<double, double>, long> d =
-	    q.denominator().to_interval_exp();
+          // do here as MP_Float does
+          std::pair<std::pair<double, double>, long> n =
+            q.numerator().to_interval_exp();
+          std::pair<std::pair<double, double>, long> d =
+            q.denominator().to_interval_exp();
 
-	  CGAL_assertion_msg(CGAL::abs(double(n.second) - double(d.second)) < (1<<30)*2.0,
+          CGAL_assertion_msg(CGAL::abs(double(n.second) - double(d.second)) < (1<<30)*2.0,
                      "Exponent overflow in Quotient<MP_Float> to_interval");
-	  return ldexp(Interval_nt<>(n.first) / Interval_nt<>(d.first),
+          return ldexp(Interval_nt<>(n.first) / Interval_nt<>(d.first),
                        static_cast<int>(n.second - d.second)).pair();
         }
     };
@@ -180,7 +171,6 @@ public:
 //since types are included by Gmp_coercion_traits.h:
 #include <CGAL/Gmpz.h>
 #include <CGAL/Gmpq.h>
-#include <CGAL/Gmpzf.h>
 
 #endif // CGAL_GMPZF_H
 
