@@ -1,24 +1,15 @@
-// Copyright (c) 1997  
+// Copyright (c) 1997
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/HalfedgeDS/include/CGAL/HalfedgeDS_decorator.h $
-// $Id: HalfedgeDS_decorator.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/HalfedgeDS/include/CGAL/HalfedgeDS_decorator.h $
+// $Id: HalfedgeDS_decorator.h 45478184de2 2022-11-15T13:39:40+01:00 albert-github
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>
@@ -436,7 +427,7 @@ public:
         insert_tip( inew->opposite(), hnew);
         insert_tip( jnew->opposite(), inew);
         insert_tip( hnew->opposite(), jnew);
-        // Make the new incidences with the old stucture.
+        // Make the new incidences with the old structure.
         CGAL_assertion_code( std::size_t termination_count = 0;)
         if ( h->next() != i) {
             Halfedge_handle g = h->next();
@@ -704,7 +695,7 @@ public:
   protected:                               // Supports_halfedge_vertices
       void erase_connected_component_vertex( Halfedge_handle  ,Tag_false){}
       void erase_connected_component_vertex( Halfedge_handle h, Tag_true) {
-          // Erases the the vertex incident to h and sets all references
+          // Erases the vertex incident to h and sets all references
           // from halfedges around this vertex to Halfedge_handle(),
           // if the incident vertex handle is not already equal to
           // Halfedge_handle(). It is used to erase vertices as soon
@@ -804,8 +795,7 @@ public:
         Assert_compile_time_tag(Supports_vertex_halfedge(), Tag_true());
         Assert_compile_time_tag(Supports_halfedge_vertex(), Tag_true());
 
-        unsigned int nb_erased_components = 0,
-                     nb_isolated_vertices = 0;
+        unsigned int nb_erased_components = 0;
 
         // Gets list of connected components, ordered by size (i.e. number of vertices)
         std::vector<Vertex_handle> components;
@@ -819,7 +809,7 @@ public:
           // Removes component from list
           components.erase(components.begin());
 
-          if (vertex->halfedge() != NULL) // if not isolated vertex
+          if (vertex->halfedge() != nullptr) // if not isolated vertex
           {
             erase_connected_component(vertex->halfedge());
             nb_erased_components++;
@@ -827,13 +817,9 @@ public:
           else // if isolated vertex
           {
             vertices_erase(vertex);
-            nb_isolated_vertices++;
           }
         }
 
-//         if (nb_isolated_vertices > 0)
-//           std::cerr << "  Erased " << nb_isolated_vertices << " isolated vertices\n";
-
         return nb_erased_components;
     }
 
@@ -935,7 +921,7 @@ private:
                 return it;
         }
 
-        return NULL;
+        return nullptr;
     }
 
     /// Helper method for keep_largest_connected_components():
@@ -1015,8 +1001,8 @@ private:
         }
 
         // Record each component
-        Vertex_handle seed_vertex = NULL;
-        while((seed_vertex = get_any_free_vertex(tags)) != NULL)
+        Vertex_handle seed_vertex = nullptr;
+        while((seed_vertex = get_any_free_vertex(tags)) != nullptr)
         {
             // Tag it as "done" and compute its size (number of vertices)
             unsigned int number_of_vertices = tag_component(seed_vertex, tags);
