@@ -1,25 +1,16 @@
-// Copyright (c) 1997-2000  
+// Copyright (c) 1997-2000
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Hash_map/include/CGAL/Handle_hash_function.h $
+// $Id: Handle_hash_function.h cec93d0c9fd 2021-05-27T14:36:55+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Hash_map/include/CGAL/Handle_hash_function.h $
-// $Id: Handle_hash_function.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
 //                 Lutz Kettner <kettner@inf.ethz.ch>
@@ -42,16 +33,26 @@ namespace internal{
       std::size_t
       operator()(const H& h)
       {
-        return std::size_t(&*h) /
+        return std::size_t(h.operator->()) /
           sizeof( typename std::iterator_traits<H>::value_type);
       }
     };
+
+    template <class H>
+    struct Hash_functor<H*>{
+      std::size_t
+      operator()(const H* h)
+      {
+        return std::size_t(h) /
+          sizeof(H);
+      }
+    };
   }
 }
 
 struct Handle_hash_function {
     typedef std::size_t result_type;
-    template <class H> 
+    template <class H>
     std::size_t operator() (const H& h) const {
       return ::CGAL::internal::handle::Hash_functor<H>()(h);
     }
