@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Hyperbolic_triangulation_2/include/CGAL/Hyperbolic_Delaunay_triangulation_CK_traits_2.h $
-// $Id: Hyperbolic_Delaunay_triangulation_CK_traits_2.h 71327aa 2018-12-30T22:19:18+01:00 Iordan Iordanov
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Hyperbolic_triangulation_2/include/CGAL/Hyperbolic_Delaunay_triangulation_CK_traits_2.h $
+// $Id: Hyperbolic_Delaunay_triangulation_CK_traits_2.h d3fca65ae59 2022-09-23T12:49:40+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mikhail Bogdanov
 //                 Monique Teillaud <Monique.Teillaud@inria.fr>
@@ -29,13 +20,13 @@
 #include <CGAL/Algebraic_kernel_for_circles_2_2.h>
 #include <CGAL/Circular_kernel_2/Intersection_traits.h>
 #include <CGAL/Circular_kernel_2.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/determinant.h>
 
 #include <boost/tuple/tuple.hpp>
 #include <boost/variant.hpp>
 
-#include <CGAL/internal/Hyperbolic_Delaunay_triangulation_traits_2_functions.h>
+#include <CGAL/Hyperbolic_triangulation_2/internal/Hyperbolic_Delaunay_triangulation_traits_2_functions.h>
 
 namespace CGAL {
 
@@ -44,7 +35,7 @@ namespace internal {
   template <typename Traits>
   class Construct_hyperbolic_circumcenter_CK_2
   {
-    typedef typename Traits::Hyperbolic_Voronoi_point_2     Hyperbolic_Voronoi_point_2;  
+    typedef typename Traits::Hyperbolic_Voronoi_point_2     Hyperbolic_Voronoi_point_2;
     typedef typename Traits::Hyperbolic_point_2             Hyperbolic_point_2;
     typedef typename Traits::Euclidean_circle_or_line_2     Euclidean_circle_or_line_2;
     typedef typename Traits::Euclidean_line_2               Euclidean_line_2;
@@ -65,7 +56,7 @@ namespace internal {
       Hyperbolic_point_2 po(CGAL::ORIGIN);
       Circle_2 l_inf(po, FT(1));
 
-      if( _gt.compare_distance_2_object()(po, p, q) == EQUAL && 
+      if( _gt.compare_distance_2_object()(po, p, q) == EQUAL &&
           _gt.compare_distance_2_object()(po, p, r) == EQUAL)
         return po;
 
@@ -86,13 +77,13 @@ namespace internal {
           std::vector< Intersection_result > inters;
           intersection(*c_pq, *c_qr, std::back_inserter(inters));
 
-          CGAL_triangulation_assertion(assign(pair, inters[0]));
+          CGAL_assertion(assign(pair, inters[0]));
           if(pair.second == 1)
           {
             if(_gt.has_on_bounded_side_2_object()(l_inf, pair.first))
               return pair.first;
 
-            CGAL_triangulation_assertion(assign(pair, inters[1]));
+            CGAL_assertion(assign(pair, inters[1]));
             return pair.first;
           }
           return pair.first;
@@ -113,13 +104,13 @@ namespace internal {
       std::vector< Intersection_result > inters;
       intersection(*l, *c, std::back_inserter(inters));
 
-      CGAL_triangulation_assertion(assign(pair,inters[0]));
+      CGAL_assertion(assign(pair,inters[0]));
       if(pair.second == 1)
       {
         if(_gt.has_on_bounded_side_2_object()(l_inf, pair.first))
           return pair.first;
 
-        CGAL_triangulation_assertion(assign(pair, inters[1]));
+        CGAL_assertion(assign(pair, inters[1]));
         return pair.first;
       }
       return pair.first;
@@ -186,9 +177,9 @@ namespace internal {
                                     const Hyperbolic_point_2& r,
                                     const Hyperbolic_point_2& s) const
     {
-      CGAL_triangulation_precondition((_gt.orientation_2_object()(p, q, r) == ON_POSITIVE_SIDE) &&
+      CGAL_precondition((_gt.orientation_2_object()(p, q, r) == ON_POSITIVE_SIDE) &&
                                       (_gt.orientation_2_object()(p, s, q) == ON_POSITIVE_SIDE));
-      CGAL_triangulation_precondition((_gt.side_of_oriented_circle_2_object()(p, q, r,s) == ON_NEGATIVE_SIDE) &&
+      CGAL_precondition((_gt.side_of_oriented_circle_2_object()(p, q, r,s) == ON_NEGATIVE_SIDE) &&
                                       (_gt.side_of_oriented_circle_2_object()(p, s, q, r) == ON_NEGATIVE_SIDE));
 
       Construct_circle_or_line_supporting_bisector<Traits>  cclsb(_gt);
@@ -227,7 +218,7 @@ namespace internal {
                                     const Hyperbolic_point_2& q,
                                     const Hyperbolic_point_2& r) const
     {
-      CGAL_triangulation_precondition(_gt.orientation_2_object()(p, q, r) == POSITIVE);
+      CGAL_precondition(_gt.orientation_2_object()(p, q, r) == POSITIVE);
 
       Construct_circle_or_line_supporting_bisector<Traits>  cclsb(_gt);
       Construct_hyperbolic_circumcenter_CK_2<Traits>        chc(_gt);
@@ -249,13 +240,13 @@ namespace internal {
         intersection(bis_pq, l_inf, std::back_inserter(inters));
         std::pair<Circular_arc_point_2, unsigned> pair;
 
-        CGAL_triangulation_assertion(assign(pair,inters[0]));
-        CGAL_triangulation_assertion(pair.second == 1);
+        CGAL_assertion(assign(pair,inters[0]));
+        CGAL_assertion(pair.second == 1);
         if(_gt.less_y_2_object()(p, q))
           return Line_arc_2(bis_pq,a,pair.first);
 
-        CGAL_triangulation_assertion(assign(pair,inters[1]));
-        CGAL_triangulation_assertion(pair.second == 1);
+        CGAL_assertion(assign(pair,inters[1]));
+        CGAL_assertion(pair.second == 1);
         return Line_arc_2(bis_pq,a,pair.first);
       }
 
@@ -270,8 +261,8 @@ namespace internal {
       intersection(*c_pq, l_inf, std::back_inserter(inters));
       std::pair<Circular_arc_point_2, unsigned> pair;
 
-      CGAL_triangulation_assertion(assign(pair,inters[0]));
-      CGAL_triangulation_assertion(pair.second == 1);
+      CGAL_assertion(assign(pair,inters[0]));
+      CGAL_assertion(pair.second == 1);
 
       Hyperbolic_point_2 approx_pinf(to_double(pair.first.x()), to_double(pair.first.y()));
       Hyperbolic_point_2 approx_c(to_double(c_pq->center().x()),
@@ -284,7 +275,7 @@ namespace internal {
         return Circular_arc_2(*c_pq, pair.first, a);
       }
 
-      CGAL_triangulation_assertion(assign(pair,inters[1]));
+      CGAL_assertion(assign(pair,inters[1]));
       if(_gt.orientation_2_object()(approx_c,approx_a,approx_pinf) == POSITIVE)
         return Circular_arc_2(*c_pq, pair.first, a);
 
@@ -375,7 +366,7 @@ public:
   Construct_hyperbolic_circumcenter_2
   construct_hyperbolic_circumcenter_2_object() const
   { return Construct_hyperbolic_circumcenter_2(*this); }
-  
+
   Construct_hyperbolic_bisector_2
   construct_hyperbolic_bisector_2_object() const
   { return Construct_hyperbolic_bisector_2(*this); }
