@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Implicit_mesh_domain_3.h $
-// $Id: Implicit_mesh_domain_3.h d685751 2018-06-20T12:35:19+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_3/include/CGAL/Implicit_mesh_domain_3.h $
+// $Id: Implicit_mesh_domain_3.h 4ebbe922bdd 2022-11-08T16:17:33+01:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stéphane Tayeb
@@ -33,6 +24,7 @@
 
 #include <CGAL/Labeled_mesh_domain_3.h>
 #include <CGAL/Implicit_to_labeling_function_wrapper.h>
+#include <CGAL/Mesh_3/Null_subdomain_index.h>
 #include <CGAL/Random.h>
 
 namespace CGAL {
@@ -73,9 +65,9 @@ public:
   Implicit_mesh_domain_3(Function_ f,
                          const Sphere_3& bounding_sphere,
                          const FT& error_bound = FT(1e-6),
-                         CGAL::Random* p_rng = NULL)
-    : Base(Wrapper(f), bounding_sphere, error_bound,
-           Null_subdomain_index(), p_rng)  {}
+                         CGAL::Random* p_rng = nullptr)
+    : Base(parameters::function = Wrapper(f), parameters::bounding_object = bounding_sphere, parameters::relative_error_bound = error_bound,
+           parameters::null_subdomain_index = Null_subdomain_index(), parameters::p_rng = p_rng)  {}
 
   /// Destructor
   virtual ~Implicit_mesh_domain_3() {}
