@@ -1,28 +1,19 @@
-// Copyright (c) 2003-2010  
+// Copyright (c) 2003-2010
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),,
 // and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Kernel_23/include/CGAL/Kernel/global_functions_internal_2.h $
+// $Id: global_functions_internal_2.h 4f5f8341cca 2022-06-10T07:37:53+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Kernel_23/include/CGAL/Kernel/global_functions_internal_2.h $
-// $Id: global_functions_internal_2.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Sylvain Pion
- 
+
 #ifndef CGAL_KERNEL_GLOBAL_FUNCTIONS_INTERNAL_2_H
 #define CGAL_KERNEL_GLOBAL_FUNCTIONS_INTERNAL_2_H
 
@@ -33,11 +24,12 @@
 
 #include <CGAL/basic.h>
 #include <CGAL/Dimension.h>
-#include <boost/utility/enable_if.hpp>
 #include "boost/mpl/equal_to.hpp"
 #include <boost/mpl/int.hpp>
 #include <boost/mpl/integral_c.hpp>
 
+#include <type_traits>
+
 namespace CGAL {
 
 namespace internal {
@@ -282,12 +274,11 @@ compare_angle_with_x_axis(const typename K::Direction_2& d1,
 
 template <class K, class T1, class T2, class T3>
 inline
-typename boost::enable_if<
-  boost::mpl::equal_to<boost::mpl::integral_c<int, 
+std::enable_if_t<
+  boost::mpl::equal_to<boost::mpl::integral_c<int,
                                               Ambient_dimension<T1>::type::value>,
-                       boost::mpl::integral_c<int, 2> >,
+                       boost::mpl::integral_c<int, 2> >::value,
   typename K::Comparison_result>
-::type
 compare_distance(const T1 &o1,
                  const T2 &o2,
                  const T3 &o3, const K& k)
@@ -297,12 +288,11 @@ compare_distance(const T1 &o1,
 
 template <class K, class T1, class T2, class T3, class T4>
 inline
-typename boost::enable_if<
-  boost::mpl::equal_to<boost::mpl::integral_c<int, 
+std::enable_if_t<
+  boost::mpl::equal_to<boost::mpl::integral_c<int,
                                               Ambient_dimension<T1>::type::value>,
-                       boost::mpl::integral_c<int, 2> >,
+                       boost::mpl::integral_c<int, 2> >::value,
   typename K::Comparison_result>
-::type
 compare_distance(const T1 &o1,
                  const T2 &o2,
                  const T3 &o3,
@@ -345,27 +335,23 @@ template <class K>
 inline
 typename K::Comparison_result
 compare_signed_distance_to_line(const typename K::Point_2& p,
-				const typename K::Point_2& q,
-				const typename K::Point_2& r,
-				const typename K::Point_2& s,
-				const K& k)
+                                const typename K::Point_2& q,
+                                const typename K::Point_2& r,
+                                const typename K::Point_2& s,
+                                const K& k)
 {
-  if (k.less_signed_distance_to_line_2_object()(p, q, r, s)) return SMALLER;
-  if (k.less_signed_distance_to_line_2_object()(p, q, s, r)) return LARGER;
-  return EQUAL;
+  return k.compare_signed_distance_to_line_2_object()(p, q, r, s);
 }
 
 template <class K>
 inline
 typename K::Comparison_result
 compare_signed_distance_to_line(const typename K::Line_2& l,
-				const typename K::Point_2& p,
-				const typename K::Point_2& q,
-				const K& k)
+                                const typename K::Point_2& p,
+                                const typename K::Point_2& q,
+                                const K& k)
 {
-  if (k.less_signed_distance_to_line_2_object()(l, p, q)) return SMALLER;
-  if (k.less_signed_distance_to_line_2_object()(l, q, p)) return LARGER;
-  return EQUAL;
+  return k.compare_signed_distance_to_line_2_object()(l, p, q);
 }
 
 template < class K >
@@ -386,6 +372,17 @@ compare_slope(const typename K::Segment_2 &s1,
   return k.compare_slope_2_object()(s1, s2);
 }
 
+template < class K >
+inline
+typename K::Comparison_result
+compare_slope(const typename K::Point_2 &s1s,
+              const typename K::Point_2 &s1t,
+              const typename K::Point_2 &s2s,
+              const typename K::Point_2 &s2t,const K& k)
+{
+  return k.compare_slope_2_object()(s1s, s1t, s2s, s2t);
+}
+
 template < class K >
 inline
 typename K::Comparison_result
@@ -607,9 +604,9 @@ template <class K>
 inline
 typename K::Boolean
 has_larger_distance_to_point(const typename K::Point_2 &p,
-			     const typename K::Point_2 &q,
-			     const typename K::Point_2 &r,
-			     const K& k)
+                             const typename K::Point_2 &q,
+                             const typename K::Point_2 &r,
+                             const K& k)
 {
   return k.less_distance_to_point_2_object()(p, r, q);
 }
@@ -629,9 +626,9 @@ template <class K>
 inline
 typename K::Boolean
 has_smaller_signed_distance_to_line(const typename K::Line_2& l,
-				    const typename K::Point_2& p,
-				    const typename K::Point_2& q,
-				    const K& k)
+                                    const typename K::Point_2& p,
+                                    const typename K::Point_2& q,
+                                    const K& k)
 {
   return k.less_signed_distance_to_line_2_object()(l, p, q);
 }
@@ -640,9 +637,9 @@ template <class K>
 inline
 typename K::Boolean
 has_larger_signed_distance_to_line(const typename K::Line_2& l,
-				   const typename K::Point_2& p,
-				   const typename K::Point_2& q,
-				   const K& k)
+                                   const typename K::Point_2& p,
+                                   const typename K::Point_2& q,
+                                   const K& k)
 {
   return k.less_signed_distance_to_line_2_object()(l, q, p);
 }
@@ -651,10 +648,10 @@ template <class K>
 inline
 typename K::Boolean
 has_larger_signed_distance_to_line(const typename K::Point_2& p,
-				   const typename K::Point_2& q,
-				   const typename K::Point_2& r,
-				   const typename K::Point_2& s,
-				   const K& k)
+                                   const typename K::Point_2& q,
+                                   const typename K::Point_2& r,
+                                   const typename K::Point_2& s,
+                                   const K& k)
 {
   return k.less_signed_distance_to_line_2_object()(p, q, s, r);
 }
@@ -666,7 +663,7 @@ has_smaller_signed_distance_to_line(const typename K::Point_2& p,
                                     const typename K::Point_2& q,
                                     const typename K::Point_2& r,
                                     const typename K::Point_2& s,
-				    const K& k)
+                                    const K& k)
 {
   return k.less_signed_distance_to_line_2_object()(p, q, r, s);
 }
@@ -801,6 +798,14 @@ midpoint(const typename K::Point_2 &p,
   return k.construct_midpoint_2_object()(p, q);
 }
 
+template < class K >
+inline
+typename K::Point_2
+midpoint(const typename K::Segment_2 &s, const K &k)
+{
+  return k.construct_midpoint_2_object()(s);
+}
+
 template < class K >
 inline
 typename K::Point_2
