@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_2/include/CGAL/Mesh_2/Refine_faces.h $
+// $Id: Refine_faces.h 45478184de2 2022-11-15T13:39:40+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_2/include/CGAL/Mesh_2/Refine_faces.h $
-// $Id: Refine_faces.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Laurent RINEAU
 
@@ -24,7 +15,7 @@
 
 #include <CGAL/license/Mesh_2.h>
 
-
+#include <CGAL/Meshes/Triangulation_mesher_level_traits_2.h>
 #include <CGAL/Mesh_2/Face_badness.h>
 #include <CGAL/Double_map.h>
 #include <CGAL/boost/iterator/transform_iterator.hpp>
@@ -86,11 +77,11 @@ protected: // --- PROTECTED TYPES ---
       return false;
     }
   };
-  
+
   typedef CGAL::Double_map<Face_handle, Quality, Face_compare> Bad_faces;
 
 protected:
-  // --- PROTECTED MEMBER DATAS ---
+  // --- PROTECTED MEMBER DATA ---
 
   Criteria& criteria; /**<The meshing criteria */
   Previous& previous;
@@ -103,7 +94,7 @@ protected:
 public:
   /** \name CONSTRUCTORS */
 
-  Refine_faces_base(Tr& t, Criteria& criteria_, Previous& prev) 
+  Refine_faces_base(Tr& t, Criteria& criteria_, Previous& prev)
     : Triangulation_traits(t), criteria(criteria_), previous(prev)
   {
   }
@@ -120,17 +111,17 @@ public:
 #endif // CGAL_MESH_2_DEBUG_BAD_FACES
 
     for(typename Tr::Finite_faces_iterator fit =
-	  triangulation_ref_impl().finite_faces_begin();
+          triangulation_ref_impl().finite_faces_begin();
         fit != triangulation_ref_impl().finite_faces_end();
         ++fit)
     {
       if( fit->is_in_domain() )
-	{
-	  Quality q;
-	  Mesh_2::Face_badness badness = is_bad(fit, q);
-	  if( badness != Mesh_2::NOT_BAD )
-	    push_in_bad_faces(fit, q);
-	}
+        {
+          Quality q;
+          Mesh_2::Face_badness badness = is_bad(fit, q);
+          if( badness != Mesh_2::NOT_BAD )
+            push_in_bad_faces(fit, q);
+        }
     }
   }
 
@@ -146,7 +137,7 @@ public:
       get_conflicts_and_boundary(p,
                                  std::back_inserter(zone.faces),
                                  std::back_inserter(zone.boundary_edges),
-				 fh
+                                 fh
                                  );
 #ifdef CGAL_MESH_2_DEBUG_CONFLICTS_ZONE
     std::cerr << "get_conflicts_and_boundary(" << p << "):" << std::endl
@@ -187,19 +178,28 @@ public:
   /** Returns the circumcenter of the face. */
   Point refinement_point_impl(const Face_handle& f) const
   {
+#ifdef CGAL_MESH_2_DEBUG_REFINEMENT_POINTS
+    std::cerr << "refinement_point_impl("
+              << "#" << f->vertex(0)->time_stamp() << ": " << f->vertex(0)->point() << ", "
+              << "#" << f->vertex(1)->time_stamp() << ": " << f->vertex(1)->point() << ", "
+              << "#" << f->vertex(2)->time_stamp() << ": " << f->vertex(2)->point() << ") = ";
+    auto p = triangulation_ref_impl().circumcenter(f);
+    std::cerr << p << '\n';
+    return p;
+#endif // CGAL_MESH_2_DEBUG_BAD_FACES
     return triangulation_ref_impl().circumcenter(f);
   }
 
   /** \todo ?? */
   void before_conflicts_impl(const Face_handle&, const Point&)
   { /// @todo modularize
-    previous.set_imperative_refinement(current_badness == 
-				       Mesh_2::IMPERATIVELY_BAD);
+    previous.set_imperative_refinement(current_badness ==
+                                       Mesh_2::IMPERATIVELY_BAD);
   }
 
   /** Remove the conflicting faces from the bad faces map. */
   void before_insertion_impl(const Face_handle&, const Point&,
-			     Zone& zone)
+                             Zone& zone)
   {
     /** @todo Perhaps this function is useless. */
     for(typename Zone::Faces_iterator fh_it = zone.faces.begin();
@@ -212,13 +212,13 @@ public:
       }
   }
 
-  /** Restore markers in the star of \c v. */
+  /** Restore markers in the star of `v`. */
   void after_insertion_impl(const Vertex_handle& v)
   {
 #ifdef CGAL_MESH_2_VERBOSE
     std::cerr << "*";
 #endif
-    typename Tr::Face_circulator fc = 
+    typename Tr::Face_circulator fc =
       triangulation_ref_impl().incident_faces(v), fcbegin(fc);
     do {
       fc->set_in_domain(true);
@@ -254,11 +254,11 @@ public:
   Mesh_2::Face_badness is_bad(Quality q) const;
 
   /**
-   * Adds the sequence [\c begin, \c end[ to the list
+   * Adds the sequence `[begin, end[` to the list
    * of bad faces.
-   * Use this overriden function if the list of bad faces can be
+   * Use this overridden function if the list of bad faces can be
    * computed easily without testing all faces.
-   * \param Fh_it is an iterator of \c Face_Handle.
+   * \param Fh_it is an iterator of `Face_Handle`.
    */
   template <class Fh_it>
   void set_bad_faces(Fh_it begin, Fh_it end)
@@ -272,7 +272,7 @@ public:
   }
 
 }; // end class Refine_faces_base
-  
+
 // --- PRIVATE MEMBER FUNCTIONS ---
 
 template <typename Tr, typename Criteria, typename Previous>
@@ -319,12 +319,12 @@ compute_new_bad_faces(Vertex_handle v)
   do {
     if(!triangulation_ref_impl().is_infinite(fc))
       if( fc->is_in_domain() )
-	{
-	  Quality q;
-	  Mesh_2::Face_badness badness = is_bad(fc, q);
-	  if( badness != Mesh_2::NOT_BAD )
-	    push_in_bad_faces(fc, q);
-	}
+        {
+          Quality q;
+          Mesh_2::Face_badness badness = is_bad(fc, q);
+          if( badness != Mesh_2::NOT_BAD )
+            push_in_bad_faces(fc, q);
+        }
     fc++;
   } while(fc!=fcbegin);
 }
@@ -362,12 +362,12 @@ is_bad(Quality q) const
     struct Refine_faces_types
     {
       typedef Mesher_level <
-	Tr,
+        Tr,
         Self,
         typename Tr::Face_handle,
         Previous,
-	Triangulation_mesher_level_traits_2<Tr>
-	>
+        Triangulation_mesher_level_traits_2<Tr>
+        >
       Faces_mesher_level;
     }; // end Refine_faces_types
   } // end namespace details
@@ -376,9 +376,9 @@ template <typename Tr,
           typename Criteria,
           typename Previous,
           typename Base = Refine_faces_base<Tr, Criteria, Previous> >
-class Refine_faces : 
-  public Base, 
-  public details::Refine_faces_types<Tr, 
+class Refine_faces :
+  public Base,
+  public details::Refine_faces_types<Tr,
     Refine_faces<Tr, Criteria, Previous, Base>,
     Previous>::Faces_mesher_level
 {
@@ -432,14 +432,14 @@ public:
     struct Output_bad_face {
       std::string operator()(typename Tr::Face_handle fh)
       {
-	std::stringstream str;
-	
-	str << "("
-	    << fh->vertex(0)->point() << ", "
+        std::stringstream str;
+
+        str << "("
+            << fh->vertex(0)->point() << ", "
             << fh->vertex(1)->point() << ", "
             << fh->vertex(2)->point()
-	    << ")";
-	return str.str();
+            << ")";
+        return str.str();
       }
     };
 
@@ -464,7 +464,7 @@ public:
 
           return false;
         }
-    return true;  
+    return true;
   }
 
 }; // end Refine_faces
