@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/Lloyd_move.h $
-// $Id: Lloyd_move.h c28e05b 2018-02-23T12:50:06+01:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_3/include/CGAL/Mesh_3/Lloyd_move.h $
+// $Id: Lloyd_move.h cbfeb98b389 2022-10-05T15:39:04+02:00 Sebastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stephane Tayeb
@@ -32,7 +23,7 @@
 #include <CGAL/Mesh_3/config.h>
 #include <CGAL/Mesh_3/Uniform_sizing_field.h>
 
-#include <CGAL/Hash_handles_with_or_without_timestamps.h>
+#include <CGAL/Time_stamper.h>
 #include <CGAL/convex_hull_2.h>
 #include <CGAL/ch_graham_andrew.h>
 
@@ -77,7 +68,7 @@ public:
   typedef SizingField                                         Sizing_field;
 
   /**
-   * @brief Return the move to apply on \c v according to Lloyd optimization
+   * @brief Returns the move to apply on `v` according to Lloyd optimization
    * function.
    */
   Vector_3 operator()(const Vertex_handle& v,
@@ -171,7 +162,7 @@ private:
 
 
   /**
-   * Return the move for the inside vertex \c v.
+   * Returns the move for the inside vertex `v`.
    */
   Vector_3 lloyd_move_inside_domain(const Vertex_handle& v,
                                     const Cell_vector& incident_cells,
@@ -204,8 +195,8 @@ private:
       {
         const Vertex_handle& v1 = (*cit)->vertex((k+i)&3);
 
-        std::pair<VC_it, bool> is_insert_succesful = treated_vertices.insert(v1);
-        if ( ! is_insert_succesful.second ) // vertex has already been treated
+        std::pair<VC_it, bool> is_insert_successful = treated_vertices.insert(v1);
+        if ( ! is_insert_successful.second ) // vertex has already been treated
           continue;
 
         // Vertex has not been treated: turn around edge(v,v1)
@@ -219,7 +210,7 @@ private:
   }
 
   /**
-   * Return the move for the on-boundary vertex \c v.
+   * Returns the move for the on-boundary vertex `v`.
    */
   Vector_3 lloyd_move_on_boundary(const Vertex_handle& v,
                                   const C3T3& c3t3,
@@ -263,7 +254,7 @@ private:
 
   /**
    * Returns a vector containing the surface delaunay ball centers of the surface
-   * facets that are incident to vertex \c v.
+   * facets that are incident to vertex `v`.
    */
   std::vector<Bare_point> extract_lloyd_boundary_points(const Vertex_handle& v,
                                                         const C3T3& c3t3) const
@@ -307,7 +298,7 @@ private:
   }
 
   /**
-   * Return the move from \c v to the centroid of the segment [a,b].
+   * Returns the move from `v` to the centroid of the segment `[a,b]`.
    */
   Vector_3 centroid_segment_move(const Vertex_handle& v,
                                  const Bare_point& a,
@@ -329,7 +320,7 @@ private:
   }
 
   /**
-   * Return the move from \c v to the centroid of triangle [a,b,c].
+   * Returns the move from `v` to the centroid of triangle `[a,b,c]`.
    */
   Vector_3 centroid_triangle_move(const Vertex_handle& v,
                                   const Bare_point& a,
@@ -406,7 +397,7 @@ private:
   }
 
   /**
-   * Return the move from \c v to the centroid of polygon[first,last].
+   * Returns the move from `v` to the centroid of polygon `[first,last]`.
    * The polygon has to be convex.
    */
   template <typename ForwardIterator>
@@ -532,8 +523,8 @@ private:
   }
 
   /**
-   * Turn around the edge \c edge and add the values computed from tets made by
-   * `v` and the circumcenters of cells incident to \c edge.
+   * Turns around the edge `edge` and adds the values computed from tets made by
+   * `v` and the circumcenters of cells incident to `edge`.
    *
    * Note that this function abundantly uses dual() calls and using a cell base
    * which stores the circumcenter thus improves its efficiency.
@@ -560,7 +551,6 @@ private:
 
     Cell_circulator current_cell = tr.incident_cells(edge);
     Cell_circulator done = current_cell;
-    CGAL_assertion(c3t3.is_in_complex(current_cell));
 
     // a & b are fixed points
     const Weighted_point& wa = tr.point(v);
@@ -570,7 +560,6 @@ private:
     const Weighted_point& a_b = tr.point(current_cell, current_cell->index(v));
     Vector_3 ba = Vector_3(cp(a_b), b);
     ++current_cell;
-    CGAL_assertion(c3t3.is_in_complex(current_cell));
     CGAL_assertion(current_cell != done);
 
     // c & d are moving points
@@ -582,7 +571,6 @@ private:
 
     while ( current_cell != done )
     {
-      CGAL_assertion(c3t3.is_in_complex(current_cell));
       Bare_point d = tr.dual(current_cell);
       const Weighted_point& a_d = tr.point(current_cell, current_cell->index(v));
       Vector_3 da = Vector_3(cp(a_d), d);
