@@ -2,19 +2,10 @@
 // Copyright (c) 2008,2013  GeometryFactory, Sophia Antipolis (France)
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/Refine_facets_manifold_base.h $
-// $Id: Refine_facets_manifold_base.h 62a8391 2018-07-25T18:59:46+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_3/include/CGAL/Mesh_3/Refine_facets_manifold_base.h $
+// $Id: Refine_facets_manifold_base.h 17ac2551086 2021-05-18T15:43:59+02:00 Maxime Gimeno
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Steve Oudot, David Rey, Mariette Yvinec, Laurent Rineau, Andreas Fabri
@@ -28,19 +19,18 @@
 
 #include <CGAL/Mesh_facet_topology.h>
 
-#include <CGAL/Hash_handles_with_or_without_timestamps.h>
 #include <CGAL/utility.h>
-#include <CGAL/atomic.h>
+#include <CGAL/Time_stamper.h>
 
 #include <boost/bimap.hpp>
 #include <boost/bimap/unordered_set_of.hpp>
 #include <boost/bimap/multiset_of.hpp>
-#include <boost/foreach.hpp>
 #include <boost/mpl/has_xxx.hpp>
 #include <boost/unordered_set.hpp>
 
 #include <set>
 #include <vector>
+#include <atomic>
 
 namespace CGAL {
 
@@ -229,7 +219,7 @@ private:
               << biggest_sq_dist << std::endl;
 #endif // CGAL_MESHES_DEBUG_REFINEMENT_POINTS
 
-    for (++fcirc; *fcirc != first_facet; ++fcirc) 
+    for (++fcirc; *fcirc != first_facet; ++fcirc)
     {
       while(!this->r_c3t3_.is_in_complex(*fcirc)) ++fcirc;
       if(*fcirc == first_facet) break;
@@ -257,7 +247,7 @@ private:
 
   // Actions to perform on a facet inside the conflict zone
   void
-  before_insertion_handle_facet_inside_conflict_zone (const Facet& f) 
+  before_insertion_handle_facet_inside_conflict_zone (const Facet& f)
   {
 #ifdef CGAL_LINKED_WITH_TBB
     // Sequential only
@@ -318,7 +308,7 @@ public:
                               int mesh_topology,
                               std::size_t maximal_number_of_vertices
 #ifndef CGAL_NO_ATOMIC
-                              , CGAL::cpp11::atomic<bool>* stop_ptr
+                              , std::atomic<bool>* stop_ptr
 #endif
                               )
     : Base(triangulation,
@@ -431,7 +421,7 @@ public:
     std::cerr << "   -> found " << n << " bad vertices\n";
 #  ifdef CGAL_MESHES_DEBUG_REFINEMENT_POINTS
     std::cerr << "Bad vertices queue:\n";
-    BOOST_FOREACH(Vertex_handle v2, m_bad_vertices)
+    for(Vertex_handle v2 : m_bad_vertices)
     {
       std::cerr << this->r_tr_.point(v2) << std::endl;
     }
@@ -456,7 +446,7 @@ public:
 
 #ifndef CGAL_NO_ATOMIC
       if(this->m_stop_ptr != 0 &&
-         this->m_stop_ptr->load(CGAL::cpp11::memory_order_acquire) == true)
+         this->m_stop_ptr->load(std::memory_order_acquire) == true)
       {
         return true;
       }
@@ -505,7 +495,7 @@ public:
         const Vertex_handle& v = *m_bad_vertices.begin();
 #ifdef CGAL_MESHES_DEBUG_REFINEMENT_POINTS
         std::cerr << "Bad vertices queue:\n";
-        BOOST_FOREACH(Vertex_handle v2, m_bad_vertices)
+        for(Vertex_handle v2 : m_bad_vertices)
         {
           std::cerr << this->r_tr_.point(v2) << std::endl;
         }
@@ -554,7 +544,7 @@ public:
     // foreach f in star(v)
     for (typename Facets::iterator fit = facets.begin();
          fit != facets.end();
-         ++fit) 
+         ++fit)
     {
       // foreach edge of *fit
       const Cell_handle cell = fit->first;
@@ -574,7 +564,7 @@ public:
           // edges are tried to be inserted several times
           // TODO one day: test if the edge is still singular
           if ( (this->r_c3t3_.face_status(edge) == C3t3::SINGULAR) ||
-               ( (!m_with_boundary) && 
+               ( (!m_with_boundary) &&
                  (this->r_c3t3_.face_status(edge) == C3t3::BOUNDARY) )
                )
           {
