@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/Triangulation_helpers.h $
-// $Id: Triangulation_helpers.h c16c039 2019-02-13T16:18:28+01:00 Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_3/include/CGAL/Mesh_3/Triangulation_helpers.h $
+// $Id: Triangulation_helpers.h 644d6493ebf 2024-03-21T16:33:26+01:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stephane Tayeb
@@ -29,14 +20,12 @@
 #include <CGAL/license/Mesh_3.h>
 
 #include <CGAL/enum.h>
-#include <CGAL/internal/Has_nested_type_Bare_point.h>
-#include <CGAL/Hash_handles_with_or_without_timestamps.h>
+#include <CGAL/STL_Extension/internal/Has_nested_type_Bare_point.h>
+#include <CGAL/Time_stamper.h>
 
 #include <boost/mpl/if.hpp>
 #include <boost/mpl/identity.hpp>
-#include <boost/type_traits/is_same.hpp>
 #include <boost/unordered_set.hpp>
-#include <boost/utility/enable_if.hpp>
 
 #include <algorithm>
 #include <iostream>
@@ -44,6 +33,8 @@
 #include <limits>
 #include <utility>
 #include <vector>
+#include <type_traits>
+
 
 namespace CGAL {
 
@@ -118,8 +109,8 @@ public:
   ~Triangulation_helpers() {}
 
   /**
-   * Returns true if moving \c v to \c p makes no topological
-   * change in \c tr
+   * Returns `true` if moving `v` to `p` makes no topological
+   * change in `tr`.
    */
   bool no_topological_change(Tr& tr,
                              const Vertex_handle v,
@@ -146,7 +137,7 @@ public:
                                const Bare_point& p) const;
 
   /**
-   * Returns the squared distance from \c vh to its closest vertex
+   * Returns the squared distance from `vh` to its closest vertex.
    *
    * \pre `vh` is not the infinite vertex
    */
@@ -154,18 +145,18 @@ public:
   FT get_sq_distance_to_closest_vertex(const Tr& tr,
                                        const Vertex_handle& vh,
                                        const Cell_vector& incident_cells,
-                                       typename boost::enable_if_c<Tag::value>::type* = NULL) const;
+                                       typename std::enable_if_t<Tag::value>* = nullptr) const;
 
   // @todo are the two versions really worth it, I can't tell the difference from a time POV...
   template<typename Tag>
   FT get_sq_distance_to_closest_vertex(const Tr& tr,
                                        const Vertex_handle& vh,
                                        const Cell_vector& incident_cells,
-                                       typename boost::disable_if_c<Tag::value>::type* = NULL) const;
+                                       typename std::enable_if_t<!Tag::value>* = nullptr) const;
 
 private:
   /**
-   * Returns true if \c v is well_oriented on each cell of \c cell_tos
+   * Returns `true` if `v` is well_oriented on each cell of `cell_tos`.
    */
   // For sequential version
   bool well_oriented(const Tr& tr,
@@ -196,7 +187,7 @@ no_topological_change(Tr& tr,
   //
   // Note that the function was nevertheless adapted to work with periodic triangulation
   // so this hack can be disabled if one day 'side_of_power_sphere()' is improved.
-  if(boost::is_same<typename Tr::Periodic_tag, Tag_true>::value)
+  if(std::is_same<typename Tr::Periodic_tag, Tag_true>::value)
     return false;
 
   typename Gt::Construct_opposite_vector_3 cov =
@@ -391,11 +382,16 @@ inside_protecting_balls(const Tr& tr,
                         const Vertex_handle v,
                         const Bare_point& p) const
 {
+  if(tr.number_of_vertices() == 0)
+    return false;
+
   typename Gt::Compare_weighted_squared_radius_3 cwsr =
     tr.geom_traits().compare_weighted_squared_radius_3_object();
 
-  Vertex_handle nv = tr.nearest_power_vertex(p, v->cell());
+  Cell_handle hint = (v == Vertex_handle()) ? Cell_handle() : v->cell();
+  Vertex_handle nv = tr.nearest_power_vertex(p, hint);
   const Point& nvwp = tr.point(nv);
+
   if(cwsr(nvwp, FT(0)) == CGAL::SMALLER)
   {
     typename Tr::Geom_traits::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
@@ -416,14 +412,14 @@ Triangulation_helpers<Tr>::
 get_sq_distance_to_closest_vertex(const Tr& tr,
                                   const Vertex_handle& vh,
                                   const Cell_vector& incident_cells,
-                                  typename boost::enable_if_c<Tag::value>::type*) const
+                                  typename std::enable_if_t<Tag::value>*) const
 {
   CGAL_precondition(!tr.is_infinite(vh));
 
   typedef std::vector<Vertex_handle>              Vertex_container;
 
   // There is no need to use tr.min_squared_distance() here because we are computing
-  // distances between 'v' and a neighbor within their common cell, which means
+  // distances between 'v' and a neighboring vertex within a common cell, which means
   // that even if we are using a periodic triangulation, the distance is correctly computed.
   typename Gt::Compute_squared_distance_3 csqd = tr.geom_traits().compute_squared_distance_3_object();
   typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
@@ -475,7 +471,7 @@ Triangulation_helpers<Tr>::
 get_sq_distance_to_closest_vertex(const Tr& tr,
                                   const Vertex_handle& vh,
                                   const Cell_vector& incident_cells,
-                                  typename boost::disable_if_c<Tag::value>::type*) const
+                                  typename std::enable_if_t<!Tag::value>*) const
 {
   CGAL_precondition(!tr.is_infinite(vh));
 
@@ -484,7 +480,7 @@ get_sq_distance_to_closest_vertex(const Tr& tr,
   typedef typename Vertex_container::iterator                VC_it;
 
   // There is no need to use tr.min_squared_distance() here because we are computing
-  // distances between 'v' and a neighbor within their common cell, which means
+  // distances between 'v' and a neighboring vertex within a common cell, which means
   // that even if we are using a periodic triangulation, the distance is correctly computed.
   typename Gt::Compute_squared_distance_3 csqd = tr.geom_traits().compute_squared_distance_3_object();
   typename Gt::Construct_point_3 cp = tr.geom_traits().construct_point_3_object();
@@ -509,8 +505,8 @@ get_sq_distance_to_closest_vertex(const Tr& tr,
          tr.is_infinite(vn))
         continue;
 
-      std::pair<VC_it, bool> is_insert_succesful = treated_vertices.insert(vn);
-      if(! is_insert_succesful.second) // vertex has already been treated
+      std::pair<VC_it, bool> is_insert_successful = treated_vertices.insert(vn);
+      if(! is_insert_successful.second) // vertex has already been treated
         continue;
 
       const Point& wpvn = tr.point(c, n);
