@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/mesh_standard_facet_criteria.h $
-// $Id: mesh_standard_facet_criteria.h 0fcc6c0 2017-12-08T11:31:30+01:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_3/include/CGAL/Mesh_3/mesh_standard_facet_criteria.h $
+// $Id: mesh_standard_facet_criteria.h d7843a23ea9 2022-12-14T17:05:57+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stephane Tayeb
@@ -316,7 +307,7 @@ class Facet_size_criterion :
   public Mesh_3::Abstract_criterion<Tr, Visitor_>
 {
 };
-  
+
 // Variable size Criterion class
 template <typename Tr, typename Visitor_, typename SizingField>
 class Variable_size_criterion :
@@ -326,25 +317,25 @@ private:
   typedef typename Tr::Facet            Facet;
   typedef typename Tr::Geom_traits::FT  FT;
   typedef typename Tr::Vertex::Index    Index;
-  
+
   typedef Mesh_3::Abstract_criterion<Tr,Visitor_> Base;
   typedef typename Base::Quality Quality;
   typedef typename Base::Is_bad  Is_bad;
-  
+
   typedef Variable_size_criterion<Tr,Visitor_,SizingField> Self;
   typedef SizingField Sizing_field;
-  
+
 public:
   // Nb: the default bound of the criterion is such that the criterion
   // is always fulfilled
   Variable_size_criterion(const Sizing_field& s) : size_(s) {}
-  
+
 protected:
   virtual void do_accept(Visitor_& v) const
   {
     v.visit(*this);
   }
-  
+
   virtual Self* do_clone() const
   {
     // Call copy ctor on this
@@ -354,7 +345,7 @@ protected:
   virtual Is_bad do_is_bad(const Tr& tr, const Facet& f) const
   {
     CGAL_assertion (f.first->is_facet_on_surface(f.second));
-    
+
     typedef typename Tr::Geom_traits    Gt;
     typedef typename Tr::Bare_point     Bare_point;
     typedef typename Tr::Weighted_point Weighted_point;
@@ -369,7 +360,7 @@ protected:
     const FT sq_radius = tr.min_squared_distance(p1, ball_center);
     const FT sq_bound = CGAL::square(size_(ball_center, 2, index));
     CGAL_assertion(sq_bound > FT(0));
-    
+
     if ( sq_radius > sq_bound )
     {
 #ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
@@ -381,14 +372,14 @@ protected:
     else
       return Is_bad();
   }
-  
+
 private:
   Sizing_field size_;
-  
+
 };  // end Variable_size_criterion
-  
-  
-  
+
+
+
 // Uniform size Criterion class
 template <typename Tr, typename Visitor_>
 class Uniform_size_criterion :
@@ -403,11 +394,20 @@ private:
   typedef typename Base::Is_bad  Is_bad;
 
   typedef Uniform_size_criterion<Tr,Visitor_> Self;
-  
+
 public:
   // Nb: the default bound of the criterion is such that the criterion
   // is always fulfilled
-  Uniform_size_criterion(const FT b = 1e20) : B_(b * b) {}
+  Uniform_size_criterion(const FT b = 1e20,
+                         const bool is_lower_bound = false)
+   : B_(b * b)
+   , is_lower_bound_(is_lower_bound)
+   {}
+
+  bool is_lower_bound() const
+  {
+    return is_lower_bound_;
+  }
 
 protected:
   virtual void do_accept(Visitor_& v) const
@@ -438,11 +438,19 @@ protected:
 
     const FT sq_radius = tr.min_squared_distance(p1, ball_center);
 
-    if ( sq_radius > B_ )
+    if (!is_lower_bound() && sq_radius > B_ )
     {
 #ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
       std::cerr << "Bad facet (uniform size): sq_radius[" << sq_radius
                 << "] bound[" << B_ << "]\n";
+#endif
+      return Is_bad(Quality(B_/sq_radius));
+    }
+    else if(is_lower_bound() && sq_radius <= B_)
+    {
+#ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
+      std::cerr << "Facet too small (uniform size): sq_radius[" << sq_radius
+      << "] bound[" << B_ << "]\n";
 #endif
       return Is_bad(Quality(B_/sq_radius));
     }
@@ -452,6 +460,7 @@ protected:
 
 private:
   FT B_;
+  const bool is_lower_bound_;
 
 };  // end Uniform_size_criterion
 
@@ -514,20 +523,20 @@ protected:
   }
 }; // end class Facet_on_surface_criterion
 
-  
+
 template <typename Tr, typename Visitor_>
 class Facet_on_same_surface_criterion :
 public Mesh_3::Abstract_criterion<Tr, Visitor_>
 {
 private:
   typedef typename Tr::Facet Facet;
-  
+
   typedef Mesh_3::Abstract_criterion<Tr,Visitor_> Base;
   typedef typename Base::Quality Quality;
   typedef typename Base::Is_bad  Is_bad;
-  
+
   typedef Facet_on_same_surface_criterion<Tr,Visitor_> Self;
-  
+
 public:
   /// Constructor
   Facet_on_same_surface_criterion() {}
@@ -539,7 +548,7 @@ protected:
   {
     v.visit(*this);
   }
-  
+
   virtual Self* do_clone() const
   {
     // Call copy ctor on this
@@ -551,50 +560,58 @@ protected:
     typedef typename Tr::Vertex_handle  Vertex_handle;
     typedef typename Tr::Cell_handle    Cell_handle;
     typedef typename Tr::Vertex::Index  Index;
-    
+
     const Cell_handle& ch = f.first;
     const int& i = f.second;
-    
+
     const Vertex_handle& v1 = ch->vertex((i+1)&3);
     const Vertex_handle& v2 = ch->vertex((i+2)&3);
     const Vertex_handle& v3 = ch->vertex((i+3)&3);
-    
+
     Index index = Index();
     bool is_index_initialized = false;
-    
+
     if ( v1->in_dimension() == 2 )
-    { 
+    {
       index = v1->index();
       is_index_initialized = true;
     }
-    
+
     if ( v2->in_dimension() == 2 )
     {
       if ( is_index_initialized )
       {
         if ( !(v2->index() == index) )
         {
+#ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
+          std::cerr << "Bad facet (on same surface criterion: "
+                    << v2->index() << " != " << index << ")" << std::endl;
+#endif
           return Is_bad(Quality(1));
         }
       }
       else
       {
         index = v2->index();
-        is_index_initialized = true;        
+        is_index_initialized = true;
       }
     }
-    
+
     if ( v3->in_dimension() == 2 )
     {
       if ( is_index_initialized && !(v3->index() == index) )
       {
+#ifdef CGAL_MESH_3_DEBUG_FACET_CRITERIA
+          std::cerr << "Bad facet (on same surface criterion: "
+                    << v3->index() << " != " << index << ")" << std::endl;
+#endif
         return Is_bad(Quality(1));
-      } 
+      }
     }
-    
+
     return Is_bad();
   }
-  
+
 }; // end class Facet_on_same_surface_criterion
 
 
@@ -626,32 +643,25 @@ public:
   }
 
 };  // end class Facet_criterion_visitor
-  
-  
-  
+
+
+
 template <typename Tr>
 class Facet_criterion_visitor_with_features
   : public Mesh_3::Criterion_visitor<Tr, typename Tr::Facet>
 {
   typedef Mesh_3::Criterion_visitor<Tr, typename Tr::Facet> Base;
   typedef Facet_criterion_visitor_with_features<Tr> Self;
-  
-  typedef Mesh_3::Abstract_criterion<Tr, Self>                Criterion;
-  typedef Mesh_3::Curvature_size_criterion<Tr, Self>          Curvature_size_criterion;
-  typedef Mesh_3::Aspect_ratio_criterion<Tr, Self>            Aspect_ratio_criterion;
-  typedef Mesh_3::Facet_on_surface_criterion<Tr, Self>        Facet_on_surface_criterion;
-  typedef Mesh_3::Facet_size_criterion<Tr, Self>              Facet_size_criterion;
-  typedef Mesh_3::Facet_on_same_surface_criterion<Tr, Self>   Facet_on_same_surface_criterion;
 
   typedef typename Tr::Geom_traits  Gt;
   typedef typename Gt::FT           FT;
 
-public:  
+public:
   typedef typename Base::Quality  Facet_quality;
   typedef typename Base::Is_bad   Is_facet_bad;
   typedef typename Base::Handle   Handle;
   typedef Handle                  Facet;
-  
+
   // Constructor
   Facet_criterion_visitor_with_features(const Tr& tr, const Facet& fh)
     : Base(tr, fh)
@@ -675,11 +685,11 @@ public:
 
     const Cell_handle& c = fh.first;
     const int& k = fh.second;
-    
+
     int k1 = (k+1)&3;
     int k2 = (k+2)&3;
     int k3 = (k+3)&3;
-    
+
     // Get number of weighted points, and ensure that they will be accessible
     // using k1...ki, if i is the number of weighted points.
     const Weighted_point& wpk1 = tr.point(c, k1);
@@ -716,13 +726,13 @@ public:
         ratio_ = r / cw(p1);
         break;
       }
-        
+
       case 2:
       {
         FT r13 = sq_radius(p1,p3) / cw(p1);
         FT r23 = sq_radius(p2,p3) / cw(p2);
         ratio_ = (std::max)(r13, r23);
-        
+
         do_spheres_intersect_ = (compare(p1,p2,FT(0)) != CGAL::LARGER);
         break;
       }
@@ -731,28 +741,27 @@ public:
       {
         do_spheres_intersect_ = (compare(p1,p2,p3,FT(0)) != CGAL::LARGER);
         break;
-      }  
-      
+      }
+
       default: break;
     }
   }
-  
-  // Destructor
-  ~Facet_criterion_visitor_with_features() {}
 
   // visit functions
-  void visit(const Criterion& criterion)
+  template<typename T, typename V>
+  void visit(const Mesh_3::Abstract_criterion<T, V>& criterion)
   {
     if ( 3 == wp_nb_ && do_spheres_intersect_ )
-    { 
+    {
       Base::increment_counter();
       return;
     }
-    
+
     Base::do_visit(criterion);
   }
-  
-  void visit(const Curvature_size_criterion& criterion)
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Curvature_size_criterion<T, V>& criterion)
   {
     if (   ratio_ < approx_ratio_
         && (do_spheres_intersect_ || 1 == wp_nb_ ) )
@@ -760,11 +769,12 @@ public:
       Base::increment_counter();
       return;
     }
-    
+
     Base::do_visit(criterion);
   }
-  
-  void visit(const Aspect_ratio_criterion& criterion)
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Aspect_ratio_criterion<T, V>& criterion)
   {
     if (   ratio_ < angle_ratio_
         && (do_spheres_intersect_ || 1 == wp_nb_) )
@@ -772,11 +782,12 @@ public:
       Base::increment_counter();
       return;
     }
-    
+
     Base::do_visit(criterion);
   }
-  
-  void visit(const Facet_size_criterion& criterion)
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Facet_size_criterion<T, V>& criterion)
   {
     if (   ratio_ < size_ratio_
         && (do_spheres_intersect_ || 1 == wp_nb_) )
@@ -784,10 +795,10 @@ public:
       Base::increment_counter();
       return;
     }
-    
+
     Base::do_visit(criterion);
   }
-  
+
 private:
   int wp_nb_;
   bool do_spheres_intersect_;
@@ -795,9 +806,77 @@ private:
   FT approx_ratio_;
   FT angle_ratio_;
   FT size_ratio_;
-  
+
 };  // end class Facet_criterion_visitor
-  
+
+
+template <typename Tr>
+class Facet_criterion_visitor_with_radius_lower_bound
+  : public Facet_criterion_visitor_with_features<Tr>
+{
+  typedef Facet_criterion_visitor_with_features<Tr> Base;
+  typedef Facet_criterion_visitor_with_radius_lower_bound<Tr> Self;
+
+  typedef typename Tr::Geom_traits  Gt;
+  typedef typename Gt::FT           FT;
+
+public:
+  typedef typename Base::Quality  Facet_quality;
+  typedef typename Base::Is_bad   Is_facet_bad;
+  typedef typename Base::Handle   Handle;
+  typedef Handle                  Facet;
+
+  // Constructor
+  Facet_criterion_visitor_with_radius_lower_bound(const Tr& tr, const Facet& fh)
+    : Base(tr, fh)
+    , dont_go_further_(false)
+  {}
+
+  Is_facet_bad is_bad() const
+  {
+    if (dont_go_further_)
+      return Is_facet_bad();
+    else
+      return Base::is_bad();
+  }
+
+  bool go_further() const
+  {
+    if (dont_go_further_)
+      return false;
+    else
+      return Base::go_further();
+  }
+
+  // visit functions
+  template<typename Criterion>
+  void visit(const Criterion& criterion)
+  {
+    Base::visit(criterion);
+  }
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Abstract_criterion<T, V>& criterion)
+  {
+    Base::visit(criterion);
+  }
+
+  template<typename T, typename V>
+  void visit(const Mesh_3::Uniform_size_criterion<T, V>& criterion)
+  {
+    Base::visit(criterion);
+
+    if (criterion.is_lower_bound() && Base::is_bad())
+      dont_go_further_ = true;
+  }
+
+private:
+  bool dont_go_further_;
+
+
+};// end class Facet_criterion_visitor_with_radius_lower_bound
+
+
 
 }  // end namespace Mesh_3
 
