@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Mesh_3/include/CGAL/Mesh_3/vertex_perturbation.h $
-// $Id: vertex_perturbation.h c28e05b 2018-02-23T12:50:06+01:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Mesh_3/include/CGAL/Mesh_3/vertex_perturbation.h $
+// $Id: vertex_perturbation.h 8f703b54cb6 2023-01-27T21:48:32+01:00 Mael
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stephane Tayeb
@@ -33,12 +24,13 @@
 
 #include <CGAL/Mesh_3/C3T3_helpers.h>
 #include <CGAL/Mesh_3/Triangulation_helpers.h>
+#include <CGAL/Time_stamper.h>
 
 #ifdef CGAL_MESH_3_PERTURBER_VERBOSE
   #include <CGAL/Timer.h>
   #ifdef CGAL_LINKED_WITH_TBB
     #include <tbb/enumerable_thread_specific.h>
-    #include <tbb/atomic.h>
+    #include <atomic>
   #endif
 #endif
 
@@ -57,7 +49,7 @@ namespace Mesh_3 {
 namespace details
 {
 /**
-   * @brief Returns the angle in radian of vectors \c u and \c v
+   * @brief Returns the angle in radian of vectors `u` and `v`
    */
 template <typename K>
 typename K::FT
@@ -106,7 +98,7 @@ angle_in_radian(const typename K::Vector_3& u,
 }
 
 /**
-   * @brief Returns the angle in radian of vectors \c u and \c v
+   * @brief Returns the angle in radian of vectors `u` and `v`
    */
 template <typename Vector_3>
 typename Kernel_traits<Vector_3>::Kernel::FT
@@ -116,7 +108,7 @@ angle_in_radian(const Vector_3& u, const Vector_3& v)
 }
 
 /**
-   * @brief Returns the squared length of edge \c e
+   * @brief Returns the squared length of edge `e`.
    */
 template <typename Tr>
 typename Tr::Geom_traits::FT
@@ -127,10 +119,13 @@ edge_sq_length(const typename Tr::Edge& e,
   typedef typename Tr::Bare_point      Bare_point;
   typedef typename Tr::Weighted_point  Weighted_point;
 
-  typename Gt::Construct_point_3 cp =
-    tr.geom_traits().construct_point_3_object();
+  // There is no need to use tr.min_squared_distance() here because we are computing
+  // distances between vertices within a common cell, which means that even
+  // if we are using a periodic triangulation, the distance is correctly computed.
   typename Gt::Compute_squared_distance_3 sq_distance =
     tr.geom_traits().compute_squared_distance_3_object();
+  typename Gt::Construct_point_3 cp =
+    tr.geom_traits().construct_point_3_object();
 
   const Weighted_point& wp = tr.point(e.first, e.second);
   const Weighted_point& wq = tr.point(e.first, e.third);
@@ -141,8 +136,8 @@ edge_sq_length(const typename Tr::Edge& e,
 }
 
 /**
-   * @brief Returns the minimal incident edge length of \c v
-   * in triangulation \c tr
+   * @brief Returns the minimal incident edge length of `v`
+   * in triangulation `tr`.
    */
 template <typename Tr>
 typename Tr::Geom_traits::FT
@@ -192,8 +187,8 @@ public:
    * @brief constructor
    */
   Abstract_perturbation()
-    : p_next_(NULL)
-    , p_previous_(NULL)
+    : p_next_(nullptr)
+    , p_previous_(nullptr)
     , order_(0)
 #ifdef CGAL_MESH_3_PERTURBER_VERBOSE
     , counter_(0)
@@ -201,7 +196,7 @@ public:
 #endif
   {
 #ifdef CGAL_MESH_3_PERTURBER_VERBOSE
-    // Initialized here in case it's some tbb::atomic
+    // Initialized here in case it's some std::atomic
     total_counter_ = 0;
     total_time_ = 0;
 #endif
@@ -218,7 +213,7 @@ public:
   /**
    * @brief This operator try to move vertex \v using the perturbation.
    * @param v the vertex to move
-   * @param slivers a vector which contains incident slivers of \c v
+   * @param slivers a vector which contains incident slivers of `v`
    * @param c3t3 the c3t3
    * @param domain the domain
    * @param criterion the criterion which is used to evaluate if a cell is
@@ -227,12 +222,12 @@ public:
    * @param modified_vertices an output vector which contains vertices of c3t3
    *   which may have been impacted by v relocation.
    * @return a pair containing:
-   *   - a bool which is \c true if a move has been done.
+   *   - a bool which is `true` if a move has been done.
    *   - a Vertex_handle which is always filled and may be the new vertex (if
-   *   the move is a success), or the vertex which lies at \c v's position in
+   *   the move is a success), or the vertex which lies at `v`'s position in
    *   the new c3t3.
    *
-   * Note that this function is hill_climbing only. The min \c criterion value
+   * Note that this function is hill_climbing only. The min `criterion` value
    * of c3t3 could not decrease.
    */
   std::pair<bool,Vertex_handle>
@@ -243,7 +238,7 @@ public:
              const SliverCriterion& criterion,
              const FT& sliver_bound,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const
+             bool *could_lock_zone = nullptr) const
   {
 #ifndef CGAL_MESH_3_PERTURBER_VERBOSE
     return do_perturb(v, slivers, c3t3, domain, criterion,
@@ -272,7 +267,7 @@ public:
   {
     p_next_ = next;
 
-    if ( NULL != next )
+    if ( nullptr != next )
       next->p_previous_ = this;
   }
 
@@ -320,7 +315,7 @@ protected:
              const SliverCriterion& criterion,
              const FT& sliver_bound,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const = 0;
+             bool *could_lock_zone = nullptr) const = 0;
 
   /**
    * @brief a helper function which returns the amplitude of perturbation
@@ -362,8 +357,8 @@ private:
   mutable int counter_;
 #ifdef CGAL_LINKED_WITH_TBB
   mutable tbb::enumerable_thread_specific<CGAL::Timer> timer_;
-  tbb::atomic<int> total_counter_;
-  tbb::atomic<std::size_t> total_time_;
+  std::atomic<int> total_counter_;
+  std::atomic<std::size_t> total_time_;
 #else
   mutable CGAL::Timer timer_;
   int total_counter_;
@@ -431,7 +426,7 @@ protected:
              const SliverCriterion& criterion,
              const FT& sliver_bound,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const = 0;
+             bool *could_lock_zone = nullptr) const = 0;
 
 protected:
   // -----------------------------------
@@ -440,7 +435,7 @@ protected:
 
   /**
    * Tries to apply a gradient perturbation using direction of
-   * \c gradient_vector
+   * `gradient_vector`
    */
   std::pair<bool, Vertex_handle>
   apply_perturbation(const Vertex_handle& v,
@@ -449,7 +444,7 @@ protected:
                      const MeshDomain& domain,
                      const SliverCriterion& criterion,
                      std::vector<Vertex_handle>& modified_vertices,
-                     bool *could_lock_zone = NULL) const
+                     bool *could_lock_zone = nullptr) const
   {
     typedef Triangulation_helpers<typename C3T3::Triangulation> Th;
 
@@ -595,7 +590,7 @@ protected:
              const SliverCriterion& criterion,
              const FT&,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const
+             bool *could_lock_zone = nullptr) const
   {
     CGAL_precondition(!slivers.empty());
 
@@ -771,7 +766,7 @@ protected:
              const SliverCriterion& criterion,
              const FT&,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const
+             bool *could_lock_zone = nullptr) const
   {
     CGAL_precondition(!slivers.empty());
 
@@ -922,7 +917,7 @@ protected:
              const SliverCriterion& criterion,
              const FT&,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const
+             bool *could_lock_zone = nullptr) const
   {
     CGAL_precondition(!slivers.empty());
 
@@ -987,10 +982,13 @@ private:
     CGAL_assertion(cell->has_vertex(v));
     const typename C3T3::Triangulation& tr = c3t3.triangulation();
 
-    typename Gt::Construct_point_3 cp =
-      tr.geom_traits().construct_point_3_object();
+    // There is no need to use tr.min_squared_distance() here because we are computing
+    // distances between vertices within a common cell, which means that even
+    // if we are using a periodic triangulation, the distance is correctly computed.
     typename Gt::Compute_squared_distance_3 sq_distance =
       tr.geom_traits().compute_squared_distance_3_object();
+    typename Gt::Construct_point_3 cp =
+      tr.geom_traits().construct_point_3_object();
 
     const int i = cell->index(v);
     const Weighted_point& wp0 = tr.point(cell, i);
@@ -1062,16 +1060,16 @@ private:
   }
 
   /**
-   * @brief returns the cotangent of \c value
+   * @brief returns the cotangent of `value`.
    */
   FT cotangent(const FT& value) const
   {
-    return FT(1/std::tan(CGAL::to_double(value)));
+    return FT(1./std::tan(CGAL::to_double(value)));
   }
 
   /**
-   * @brief returns the normal of facet (ch,i), oriented from inside to outside
-   * of \c ch
+   * @brief returns the normal of facet `(ch,i)`, oriented from inside to outside
+   * of `ch`.
    */
   Vector_3 normal_estimate(const C3T3& c3t3, const Cell_handle& ch, const int i) const
   {
@@ -1152,7 +1150,7 @@ protected:
              const SliverCriterion& criterion,
              const FT& sliver_bound,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const = 0;
+             bool *could_lock_zone = nullptr) const = 0;
 
 protected:
   // -----------------------------------
@@ -1165,7 +1163,7 @@ protected:
   FT sphere_sq_radius() const { return sphere_sq_radius_; }
 
   /**
-   * @brief returns a FT between \c min and \c max
+   * @brief returns a FT between `min` and `max`.
    */
   FT random_ft(const FT& min = FT(0.), const FT& max = FT(1.)) const
   {
@@ -1174,7 +1172,7 @@ protected:
   }
 
   /**
-   * @brief returns a random vector with size \c vector_size
+   * @brief returns a random vector with size `vector_size`.
    */
   Vector_3 random_vector_fixed_size(const C3T3& c3t3,
                                     const FT& vector_sq_size) const
@@ -1192,7 +1190,7 @@ protected:
   }
 
   /**
-   * @brief returns a random vector with size between 0 and \c vector_size
+   * @brief returns a random vector with size between 0 and `vector_size`.
    */
   Vector_3 random_vector_max_size(const C3T3& c3t3,
                                   const FT& vector_max_sq_size) const
@@ -1292,7 +1290,7 @@ protected:
              const SliverCriterion& criterion,
              const FT& sliver_bound,
              std::vector<Vertex_handle>& modified_vertices,
-             bool *could_lock_zone = NULL) const
+             bool *could_lock_zone = nullptr) const
   {
     CGAL_precondition(!slivers.empty());
 
@@ -1307,7 +1305,7 @@ private:
   // -----------------------------------
 
   /**
-   * @brief try to improve mesh using random moves of \c v
+   * @brief tries to improve mesh using random moves of `v`.
    */
   std::pair<bool,Vertex_handle>
   apply_perturbation(const Vertex_handle& v,
@@ -1317,7 +1315,7 @@ private:
                      const SliverCriterion& criterion,
                      const FT& sliver_bound,
                      std::vector<Vertex_handle>& modified_vertices,
-                     bool *could_lock_zone = NULL) const
+                     bool *could_lock_zone = nullptr) const
   {
     typedef Triangulation_helpers<typename C3T3::Triangulation> Th;
 
@@ -1418,7 +1416,7 @@ private:
   }
 
 private:
-  // If set to \c true, then random point will be generated on sphere surface.
+  // If set to `true`, then random points will be generated on sphere surface.
   bool on_sphere_;
 };
 
