@@ -1,21 +1,12 @@
-// Copyright (c) 1997-2001  
+// Copyright (c) 1997-2001
 // ETH Zurich (Switzerland).  All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Bounding_volumes/include/CGAL/Min_circle_2/Min_circle_2_adapterH2.h $
+// $Id: Min_circle_2_adapterH2.h 74e4d89cbc1 2022-09-27T10:42:05+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Bounding_volumes/include/CGAL/Min_circle_2/Min_circle_2_adapterH2.h $
-// $Id: Min_circle_2_adapterH2.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Sven Schoenherr <sven@inf.ethz.ch>, Bernd Gaertner
 
@@ -70,7 +61,7 @@ class Min_circle_2_adapterH2 {
     orientation( const Point& p, const Point& q, const Point& r) const
     {
         typedef  typename DA_::RT  RT;
-    
+
         RT  phx;
         RT  phy;
         RT  phw;
@@ -80,11 +71,11 @@ class Min_circle_2_adapterH2 {
         RT  rhx;
         RT  rhy;
         RT  rhw;
-    
+
         dao.get( p, phx, phy, phw);
         dao.get( q, qhx, qhy, qhw);
         dao.get( r, rhx, rhy, rhw);
-    
+
         return( static_cast< CGAL::Orientation>(
                  CGAL_NTS sign( ( phx*rhw - rhx*phw) * ( qhy*rhw - rhy*qhw)
                               - ( phy*rhw - rhy*phw) * ( qhx*rhw - rhx*qhw))));
@@ -316,7 +307,7 @@ std::ostream&
 operator << ( std::ostream& os,
               const CGAL::_Min_circle_2_adapterH2__Circle<PT_,DA_>& c)
 {
-    switch ( CGAL::get_mode( os)) {
+    switch ( CGAL::IO::get_mode( os)) {
 
       case CGAL::IO::PRETTY:
         os << "CGAL::Min_circle_2_adapterH2::Circle( "
@@ -341,8 +332,8 @@ operator << ( std::ostream& os,
         break;
 
       default:
-        CGAL_optimisation_assertion_msg( false,
-                                        "CGAL::get_mode( os) invalid!");
+        CGAL_assertion_msg( false,
+                                        "CGAL::IO::get_mode( os) invalid!");
         break; }
 
     return( os);
@@ -353,11 +344,11 @@ std::istream&
 operator >> ( std::istream& is,
               CGAL::_Min_circle_2_adapterH2__Circle<PT_,DA_>& c)
 {
-    switch ( CGAL::get_mode( is)) {
+    switch ( CGAL::IO::get_mode( is)) {
 
       case CGAL::IO::PRETTY:
-	std::cerr << std::endl;
-	std::cerr << "Stream must be in ascii or binary mode" << std::endl;
+        std::cerr << std::endl;
+        std::cerr << "Stream must be in ASCII or binary mode" << std::endl;
         break;
 
       case CGAL::IO::ASCII:
@@ -372,7 +363,7 @@ operator >> ( std::istream& is,
         break;
 
       default:
-        CGAL_optimisation_assertion_msg( false,
+        CGAL_assertion_msg( false,
                                          "CGAL::IO::mode invalid!");
         break; }
 
