@@ -1,21 +1,12 @@
-// Copyright (c) 1997-2001  
+// Copyright (c) 1997-2001
 // ETH Zurich (Switzerland).  All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Bounding_volumes/include/CGAL/Min_ellipse_2/Min_ellipse_2_impl.h $
+// $Id: Min_ellipse_2_impl.h 74e4d89cbc1 2022-09-27T10:42:05+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Bounding_volumes/include/CGAL/Min_ellipse_2/Min_ellipse_2_impl.h $
-// $Id: Min_ellipse_2_impl.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Sven Schoenherr <sven@inf.ethz.ch>, Bernd Gaertner
 
@@ -37,7 +28,7 @@ operator << ( std::ostream& os,
     typedef typename Min_ellipse_2<Traits_>::Point  Point;
     typedef  ostream_iterator<Point>        Os_it;
 
-    switch ( CGAL::get_mode( os)) {
+    switch ( CGAL::IO::get_mode( os)) {
 
       case CGAL::IO::PRETTY:
         os << endl;
@@ -69,8 +60,8 @@ operator << ( std::ostream& os,
         break;
 
       default:
-        CGAL_optimisation_assertion_msg( false,
-                                         "CGAL::get_mode( os) invalid!");
+        CGAL_assertion_msg( false,
+                                         "CGAL::IO::get_mode( os) invalid!");
         break; }
 
     return( os);
@@ -82,11 +73,11 @@ operator >> ( std::istream& is, CGAL::Min_ellipse_2<Traits_>& min_ellipse)
 {
     using namespace std;
 
-    switch ( CGAL::get_mode( is)) {
+    switch ( CGAL::IO::get_mode( is)) {
 
       case CGAL::IO::PRETTY:
         cerr << endl;
-        cerr << "Stream must be in ascii or binary mode" << endl;
+        cerr << "Stream must be in ASCII or binary mode" << endl;
         break;
 
       case CGAL::IO::ASCII:
@@ -98,7 +89,7 @@ operator >> ( std::istream& is, CGAL::Min_ellipse_2<Traits_>& min_ellipse)
         break;
 
       default:
-        CGAL_optimisation_assertion_msg( false, "CGAL::IO::mode invalid!");
+        CGAL_assertion_msg( false, "CGAL::IO::mode invalid!");
         break; }
 
     return( is);
