@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Minkowski_sum_2/include/CGAL/Minkowski_sum_2/Exact_offset_base_2.h $
-// $Id: Exact_offset_base_2.h 8cdfad0 2017-11-15T22:58:57+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Minkowski_sum_2/include/CGAL/Minkowski_sum_2/Exact_offset_base_2.h $
+// $Id: Exact_offset_base_2.h 488ba8c4e48 2022-08-10T23:32:42+03:00 Efi Fogel
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Ron Wein   <wein_r@yahoo.com>
 
@@ -37,11 +28,9 @@ namespace CGAL {
  * A base class for computing the offset of a given polygon by a given
  * radius in an exact manner.
  */
-template <class Traits_, class Container_>
-class Exact_offset_base_2
-{
+template <typename Traits_, typename Container_>
+class Exact_offset_base_2 {
 private:
-
   typedef Traits_                                        Traits_2;
 
   // Rational kernel types:
@@ -57,7 +46,6 @@ protected:
   typedef Rational                                       Basic_NT;
 
 private:
-
   // Algebraic kernel types:
   typedef typename Traits_2::Alg_kernel                  Alg_kernel;
   typedef typename Alg_kernel::FT                        Algebraic;
@@ -72,7 +60,6 @@ private:
   typedef CGAL::Gps_traits_2<Traits_2>                   Gps_traits_2;
 
 protected:
-
   typedef CGAL::Polygon_2<Rat_kernel, Container_>        Polygon_2;
   typedef CGAL::Polygon_with_holes_2<Rat_kernel,
                                      Container_>         Polygon_with_holes_2;
@@ -84,21 +71,15 @@ private:
   typedef typename Polygon_2::Vertex_circulator          Vertex_circulator;
 
 protected:
-
   typedef Arr_labeled_traits_2<Traits_2>                 Labeled_traits_2;
-
   typedef typename Labeled_traits_2::X_monotone_curve_2  Labeled_curve_2;
 
 public:
-
   /*! Default constructor. */
-  Exact_offset_base_2 ()
-  {}
+  Exact_offset_base_2() {}
 
 protected:
-
-  /*!
-   * Compute the curves that constitute the offset of a simple polygon by a
+  /*! Compute the curves that constitute the offset of a simple polygon by a
    * given radius.
    * \param pgn The polygon.
    * \param orient The orientation to traverse the vertices.
@@ -108,16 +89,16 @@ protected:
    * \pre The value type of the output iterator is Labeled_curve_2.
    * \return A past-the-end iterator for the holes container.
    */
-  template <class OutputIterator>
-  OutputIterator _offset_polygon (const Polygon_2& pgn,
-                                  CGAL::Orientation orient,
-                                  const Rational& r,
-                                  unsigned int cycle_id,
-                                  OutputIterator oi) const
+  template <typename OutputIterator>
+  OutputIterator _offset_polygon(const Polygon_2& pgn,
+                                 CGAL::Orientation orient,
+                                 const Rational& r,
+                                 unsigned int cycle_id,
+                                 OutputIterator oi) const
   {
     // Prepare circulators over the polygon vertices.
-    const bool            forward = (pgn.orientation() == orient);
-    Vertex_circulator     first, curr, next;
+    const bool forward = (pgn.orientation() == orient);
+    Vertex_circulator first, curr, next;
 
     first = pgn.vertices_circulator();
     curr = first;
@@ -125,38 +106,33 @@ protected:
 
     // Traverse the polygon vertices and edges and construct the arcs that
     // constitute the single convolution cycle.
-    Alg_kernel                    alg_ker;
-    typename Alg_kernel::Equal_2  f_equal = alg_ker.equal_2_object();
+    const Rational sqr_r = CGAL::square (r);
+    Rational x1, y1;                    // The source of the current edge.
+    Rational x2, y2;                    // The target of the current edge.
+    Rational delta_x, delta_y;          // (x2 - x1) and (y2 - y1), resp.
+    Algebraic len;                      // The length of the current edge.
+    Algebraic trans_x, trans_y;         // The translation vector.
+    Alg_point_2 op1, op2;               // The edge points of the offset edge.
+    Alg_point_2 first_op;               // The first offset point.
+    Algebraic a, b, c;
 
-    Nt_traits       nt_traits;
-    const Rational  sqr_r = CGAL::square (r);
-    const Algebraic alg_r = nt_traits.convert (r);
-    Rational        x1, y1;              // The source of the current edge.
-    Rational        x2, y2;              // The target of the current edge.
-    Rational        delta_x, delta_y;    // (x2 - x1) and (y2 - y1), resp.
-    Algebraic       len;                 // The length of the current edge.
-    Algebraic       trans_x, trans_y;    // The translation vector.
-    Alg_point_2     op1, op2;            // The edge points of the offset edge.
-    Alg_point_2     first_op;            // The first offset point.
-    Algebraic       a, b, c;
+    unsigned int curve_index(0);
+    std::list<Object> xobjs;
 
-    unsigned int                    curve_index = 0;
-    Traits_2                        traits;
-    std::list<Object>               xobjs;
-    std::list<Object>::iterator     xobj_it;
-    typename Traits_2::Make_x_monotone_2
-                       f_make_x_monotone = traits.make_x_monotone_2_object();
-    Curve_2                         arc;
-    X_monotone_curve_2              xarc;
-    bool                            assign_success;
+    Traits_2 traits;
+    auto nt_traits = traits.nt_traits();
+    const Algebraic alg_r = nt_traits->convert(r);
+    auto f_make_x_monotone = traits.make_x_monotone_2_object();
 
-    do
-    {
+    auto alg_ker = traits.alg_kernel();
+    auto f_equal = alg_ker->equal_2_object();
+
+    bool assign_success;
+
+    do {
       // Get a circulator for the next vertex (in the proper orientation).
-      if (forward)
-        ++next;
-      else
-        --next;
+      if (forward) ++next;
+      else --next;
 
       // Compute the vector v = (delta_x, delta_y) of the current edge,
       // and compute the edge length ||v||.
@@ -167,8 +143,8 @@ protected:
 
       delta_x = x2 - x1;
       delta_y = y2 - y1;
-      len = nt_traits.sqrt (nt_traits.convert (CGAL::square (delta_x) +
-                                               CGAL::square (delta_y)));
+      len = nt_traits->sqrt(nt_traits->convert(CGAL::square(delta_x) +
+                                               CGAL::square(delta_y)));
 
       // The angle theta between the vector v and the x-axis is given by:
       //
@@ -183,45 +159,39 @@ protected:
       //
       //   trans_x = r*cos(alpha - PI/2) = r*sin(alpha)
       //   trans_y = r*sin(alpha - PI/2) = -r*cos(alpha)
-      trans_x = nt_traits.convert (r * delta_y) / len;
-      trans_y = nt_traits.convert (-r * delta_x) / len;
+      trans_x = nt_traits->convert(r * delta_y) / len;
+      trans_y = nt_traits->convert(-r * delta_x) / len;
 
       // Construct the first offset vertex, which corresponds to the
       // source vertex of the current polygon edge.
-      op1 = Alg_point_2 (nt_traits.convert (x1) + trans_x,
-                         nt_traits.convert (y1) + trans_y);
+      op1 = Alg_point_2(nt_traits->convert(x1) + trans_x,
+                        nt_traits->convert(y1) + trans_y);
 
-      if (curr == first)
-      {
+      if (curr == first) {
         // This is the first edge we visit -- store op1 for future use.
         first_op = op1;
       }
-      else
-      {
-        if (! f_equal (op2, op1))
-        {
+      else {
+        if (! f_equal (op2, op1)) {
           // Connect op2 (from the previous iteration) and op1 with a circular
           // arc, whose supporting circle is (x1, x2) with radius r.
-          arc = Curve_2 (Rat_circle_2 (*curr, sqr_r),
-                         CGAL::COUNTERCLOCKWISE,
-                         op2, op1);
+          auto ctr_cv = traits.construct_curve_2_object();
+          Curve_2 arc = ctr_cv(Rat_circle_2 (*curr, sqr_r),
+                               CGAL::COUNTERCLOCKWISE, op2, op1);
 
           // Subdivide the arc into x-monotone subarcs and append them to the
           // convolution cycle.
           xobjs.clear();
-          f_make_x_monotone (arc, std::back_inserter(xobjs));
+          f_make_x_monotone(arc, std::back_inserter(xobjs));
 
-          for (xobj_it = xobjs.begin(); xobj_it != xobjs.end(); ++xobj_it)
-          {
-            assign_success = CGAL::assign (xarc, *xobj_it);
+          for (auto xobj_it = xobjs.begin(); xobj_it != xobjs.end(); ++xobj_it) {
+            X_monotone_curve_2 xarc;
+            assign_success = CGAL::assign(xarc, *xobj_it);
             CGAL_assertion (assign_success);
             CGAL_USE(assign_success);
 
-            *oi = Labeled_curve_2 (xarc,
-                                   X_curve_label (xarc.is_directed_right(),
-                                                  cycle_id,
-                                                  curve_index));
-            ++oi;
+            *oi++ = Labeled_curve_2(xarc, X_curve_label(xarc.is_directed_right(),
+                                                        cycle_id, curve_index));
             curve_index++;
           }
         }
@@ -229,25 +199,21 @@ protected:
 
       // Construct the second offset vertex, which corresponds to the
       // target vertex of the current polygon edge.
-      op2 = Alg_point_2 (nt_traits.convert (x2) + trans_x,
-                         nt_traits.convert (y2) + trans_y);
+      op2 = Alg_point_2(nt_traits->convert(x2) + trans_x,
+                        nt_traits->convert(y2) + trans_y);
 
       // The equation of the line connecting op1 and op2 is given by:
       //
       //   (y1 - y2)*x + (x2 - x1)*y + (r*len - y1*x2 - x1*y2) = 0
       //
-      a = nt_traits.convert (-delta_y);
-      b = nt_traits.convert (delta_x);
-      c = alg_r*len - nt_traits.convert (y1*x2 - x1*y2);
+      a = nt_traits->convert(-delta_y);
+      b = nt_traits->convert(delta_x);
+      c = alg_r*len - nt_traits->convert(y1*x2 - x1*y2);
 
-      xarc = X_monotone_curve_2 (a, b, c,
-                                 op1, op2);
-
-      *oi = Labeled_curve_2 (xarc,
-                             X_curve_label (xarc.is_directed_right(),
-                                            cycle_id,
-                                            curve_index));
-      ++oi;
+      auto ctr_xcv = traits.construct_x_monotone_curve_2_object();
+      X_monotone_curve_2 xarc = ctr_xcv(a, b, c, op1, op2);
+      *oi++ = Labeled_curve_2(xarc, X_curve_label(xarc.is_directed_right(),
+                                                  cycle_id, curve_index));
       curve_index++;
 
       // Proceed to the next polygon vertex.
@@ -255,42 +221,38 @@ protected:
 
     } while (curr != first);
 
-    if (! f_equal (op2, first_op))
-    {
+    if (! f_equal (op2, first_op)) {
       // Close the convolution cycle by creating the final circular arc,
       // centered at the first vertex.
-      arc = Curve_2 (Rat_circle_2 (*first, sqr_r),
-                     CGAL::COUNTERCLOCKWISE,
-                     op2, first_op);
+      auto ctr_cv = traits.construct_curve_2_object();
+      Curve_2 arc = ctr_cv(Rat_circle_2 (*first, sqr_r),
+                           CGAL::COUNTERCLOCKWISE, op2, first_op);
 
       // Subdivide the arc into x-monotone subarcs and append them to the
       // convolution cycle.
-      bool           is_last;
+      bool is_last;
 
       xobjs.clear();
-      f_make_x_monotone (arc, std::back_inserter(xobjs));
+      f_make_x_monotone(arc, std::back_inserter(xobjs));
 
-      xobj_it = xobjs.begin();
-      while (xobj_it != xobjs.end())
-      {
-        assign_success = CGAL::assign (xarc, *xobj_it);
+      auto xobj_it = xobjs.begin();
+      while (xobj_it != xobjs.end()) {
+        X_monotone_curve_2 xarc;
+        assign_success = CGAL::assign(xarc, *xobj_it);
         CGAL_assertion (assign_success);
         CGAL_USE(assign_success);
 
         ++xobj_it;
         is_last = (xobj_it == xobjs.end());
 
-        *oi = Labeled_curve_2 (xarc,
-                               X_curve_label (xarc.is_directed_right(),
-                                              cycle_id,
-                                              curve_index,
-                                              is_last));
-        ++oi;
+        *oi++ = Labeled_curve_2(xarc, X_curve_label(xarc.is_directed_right(),
+                                                    cycle_id, curve_index,
+                                                    is_last));
         curve_index++;
       }
     }
 
-    return (oi);
+    return oi;
   }
 
 };
