@@ -2,25 +2,21 @@
 // INRIA Saclay - Ile de France (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/Mpzf.h $
+// $Id: Mpzf.h f3d0d76f6b2 2022-10-06T15:35:41+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/Mpzf.h $
-// $Id: Mpzf.h d715ddd 2019-10-25T14:38:26+02:00 Marc Glisse
-// SPDX-License-Identifier: LGPL-3.0+
-//
-// Author(s)	:  Marc Glisse
+// Author(s)        :  Marc Glisse
 
 #ifndef CGAL_MPZF_H
 #define CGAL_MPZF_H
+
+#ifndef CGAL_NO_MPZF_DIVISION_OPERATOR
+#define CGAL_MPZF_DIVISION_OPERATOR 1
+#endif
+
 #include <cstdlib>
 #include <algorithm>
 #include <climits>
@@ -86,10 +82,11 @@
 
 #if defined(BOOST_MSVC)
 #  pragma warning(push)
-#  pragma warning(disable:4146 4244 4267 4800)
+#  pragma warning(disable:4146 4244 4267 4702 4800)
      // warning on - applied on unsigned number
      // conversion with loss of data
      // conversion with loss of data
+     // unreachable code
      // int to bool performance
 #endif
 
@@ -116,16 +113,9 @@
 #if !defined(CGAL_HAS_THREADS)
 #define CGAL_MPZF_THREAD_LOCAL
 #define CGAL_MPZF_TLS
-#elif defined(CGAL_CAN_USE_CXX11_THREAD_LOCAL)
+#else
 #define CGAL_MPZF_THREAD_LOCAL thread_local
 #define CGAL_MPZF_TLS thread_local
-#elif defined(_MSC_VER)
-#define CGAL_MPZF_THREAD_LOCAL __declspec(thread)
-#define CGAL_MPZF_TLS
-#else
-#define CGAL_MPZF_THREAD_LOCAL __thread
-#define CGAL_MPZF_TLS
-// Too bad for the others
 #endif
 namespace CGAL {
 namespace Mpzf_impl {
@@ -145,7 +135,7 @@ template <class T, class = void> struct pool1 {
 template <class T, class D> std::vector<T> pool1<T,D>::data;
 
 // Use an intrusive single-linked list instead (allocate one more limb and use
-// it to store the pointer to next), the difference isn't that noticable (still
+// it to store the pointer to next), the difference isn't that noticeable (still
 // the list wins).  Neither is thread-safe (both can be with threadlocal, and
 // the list can be with an atomic compare-exchange (never tried)).  With gcc,
 // TLS has a large effect on classes with constructor/destructor, but is free
@@ -166,7 +156,6 @@ template <class T, class = void> struct pool2 {
   static T& ptr(T t) { t -= extra+1; return *reinterpret_cast<T*>(t); }
 };
 
-#if defined(CGAL_CAN_USE_CXX11_THREAD_LOCAL)
 template <class T, class = void> struct pool3 {
   static T pop() { T ret = data(); data() = ptr(data()); return ret; }
   static void push(T t) { ptr(t) = data(); data() = t; }
@@ -180,7 +169,7 @@ template <class T, class = void> struct pool3 {
       // Deallocate everything. As an alternative, we could store it in a
       // global location, for re-use by a later thread.
       while (!empty())
-	delete[] (pop() - (extra + 1));
+        delete[] (pop() - (extra + 1));
     }
   };
   static T& data () {
@@ -189,7 +178,6 @@ template <class T, class = void> struct pool3 {
   }
   static T& ptr(T t) { t -= extra+1; return *reinterpret_cast<T*>(t); }
 };
-#endif
 
 // No caching
 template <class T, class = void> struct no_pool {
@@ -228,15 +216,7 @@ inline int clz (boost::uint64_t x) {
 // In C++11, std::fill_n returns a pointer to the end, but in C++03,
 // it returns void.
 inline mp_limb_t* fill_n_ptr(mp_limb_t* p, int n, int c) {
-#if CGAL_CXX11
   return std::fill_n (p, n, c);
-#else
-  mp_limb_t* q = p + n;
-  std::fill (p, q, c);
-  //std::fill_n (p, n, c);
-  //memset (p, sizeof(mp_limb_t)*n, c);
-  return q;
-#endif
 }
 } // namespace Mpzf_impl
 
@@ -297,7 +277,9 @@ struct Mpzf {
       if(data()[-1] >= mini) return; // TODO: when mini==2, no need to check
       delete[] (data() - (pool::extra+1)); // too small, useless
     }
+#ifndef CGAL_MPZF_USE_CACHE
     if(mini<2) mini=2;
+#endif
     data() = (new mp_limb_t[mini+(pool::extra+1)]) + (pool::extra+1);
     data()[-1] = mini;
   }
@@ -341,7 +323,7 @@ struct Mpzf {
 #ifdef CGAL_MPZF_USE_CACHE
       if (data() != cache)
 #endif
-	delete[] (data() - pool::extra);
+        delete[] (data() - pool::extra);
       init(asize);
     } else ++data();
     size=x.size;
@@ -356,19 +338,62 @@ struct Mpzf {
     exp=x.exp;
     if(size!=0) mpn_copyi(data(),x.data(),asize);
   }
-#if !defined(CGAL_CFG_NO_CPP0X_RVALUE_REFERENCE) \
-    && !defined(CGAL_MPZF_USE_CACHE)
+#if defined(CGAL_MPZF_USE_CACHE)
+  Mpzf(Mpzf&& x)noexcept:size(x.size),exp(x.exp){
+    auto xd = x.data();
+    while(*--xd==0);
+    if (xd != x.cache) {
+      data() = x.data();
+      x.init();
+    } else {
+      init();
+      if(size!=0) mpn_copyi(data(),x.data(),std::abs(size));
+    }
+    x.size = 0;
+  }
+  Mpzf& operator=(Mpzf&& x)noexcept{
+    if (this == &x) return *this; // is this needed?
+    size = x.size;
+    exp = x.exp;
+    auto xd = x.data();
+    auto td = data();
+    while(*--xd==0);
+    while(*--td==0);
+    if (xd != x.cache) {
+      data() = x.data();
+      if (td != cache) {
+        pool::push(td+1);
+        // should we instead give it to x in case x is reused?
+        // x.data() = td + 1;
+      }
+      x.init();
+    } else {
+      // In some cases data points in the middle of the buffer, reset it
+      data() = td + 1;
+      if(size!=0) mpn_copyi(data(),x.data(),std::abs(size));
+    }
+    x.size = 0;
+    return *this;
+  }
+#else
   Mpzf(Mpzf&& x):data_(x.data()),size(x.size),exp(x.exp){
     x.init(); // yes, that's a shame...
     x.size = 0;
     x.exp = 0;
   }
-  Mpzf& operator=(Mpzf&& x){
-    std::swap(size,x.size);
+  Mpzf& operator=(Mpzf&& x)noexcept{
+    size = x.size;
+    // In case something tries to read it, size needs to be smaller than data
+    x.size = 0;
     exp = x.exp;
     std::swap(data(),x.data());
     return *this;
   }
+  friend void swap(Mpzf&a, Mpzf&b)noexcept{
+    std::swap(a.size, b.size);
+    std::swap(a.exp, b.exp);
+    std::swap(a.data(), b.data());
+  }
   friend Mpzf operator-(Mpzf&& x){
     Mpzf ret = std::move(x);
     ret.size = -ret.size;
@@ -422,8 +447,8 @@ struct Mpzf {
     if (dexp == 0) {
       if (d == 0) { size=0; exp=0; return; }
       else { // denormal number
-	m = u.s.man;
-	++dexp;
+        m = u.s.man;
+        ++dexp;
       }
     } else {
       m = (1LL<<52) | u.s.man;
@@ -443,10 +468,10 @@ struct Mpzf {
     }else{
       data()[0] = m << e2;
       if(e2>11){ // Wrong test for denormals
-	data()[1] = m >> (64-e2);
-	size = 2;
+        data()[1] = m >> (64-e2);
+        size = 2;
       } else {
-	size = 1;
+        size = 1;
       }
     }
 #else
@@ -462,11 +487,11 @@ struct Mpzf {
     else {
       data()[0] = d0;
       if (d1 == 0) {
-	size = 1;
+        size = 1;
       }
       else {
-	data()[1] = d1;
-	size = 2;
+        data()[1] = d1;
+        size = 2;
       }
     }
 #endif
@@ -551,6 +576,12 @@ struct Mpzf {
   friend bool operator!=(Mpzf const&a, Mpzf const&b){
     return !(a==b);
   }
+  friend Mpzf const& min BOOST_PREVENT_MACRO_SUBSTITUTION (Mpzf const&a, Mpzf const&b){
+    return (b<a)?b:a;
+  }
+  friend Mpzf const& max BOOST_PREVENT_MACRO_SUBSTITUTION (Mpzf const&a, Mpzf const&b){
+    return (a<b)?b:a;
+  }
   private:
   static Mpzf aors(Mpzf const&a, Mpzf const&b, int bsize){
     Mpzf res=noalloc();
@@ -586,53 +617,53 @@ struct Mpzf {
       res.size=0;
       // TODO: if aexp>0, swap a and b so we don't repeat the code.
       if(0<bexp){
-	if(absasize<=bexp){ // no overlap
-	  mpn_copyi(rdata, adata, absasize);
-	  rdata+=absasize;
-	  rdata=Mpzf_impl::fill_n_ptr(rdata,bexp-absasize,0);
-	  mpn_copyi(rdata, bdata, absbsize);
-	  res.size=absbsize+bexp;
-	  if(bsize<0) res.size=-res.size;
-	  return res;
-	} else {
-	  mpn_copyi(rdata, adata, bexp);
-	  adata+=bexp;
-	  absasize-=bexp;
-	  rdata+=bexp;
-	  res.size=bexp;
-	}
+        if(absasize<=bexp){ // no overlap
+          mpn_copyi(rdata, adata, absasize);
+          rdata+=absasize;
+          rdata=Mpzf_impl::fill_n_ptr(rdata,bexp-absasize,0);
+          mpn_copyi(rdata, bdata, absbsize);
+          res.size=absbsize+bexp;
+          if(bsize<0) res.size=-res.size;
+          return res;
+        } else {
+          mpn_copyi(rdata, adata, bexp);
+          adata+=bexp;
+          absasize-=bexp;
+          rdata+=bexp;
+          res.size=bexp;
+        }
       }
       else if(0<aexp){
-	if(absbsize<=aexp){ // no overlap
-	  mpn_copyi(rdata, bdata, absbsize);
-	  rdata+=absbsize;
-	  rdata=Mpzf_impl::fill_n_ptr(rdata,aexp-absbsize,0);
-	  mpn_copyi(rdata, adata, absasize);
-	  res.size=absasize+aexp;
-	  if(asize<0) res.size=-res.size;
-	  return res;
-	} else {
-	  mpn_copyi(rdata, bdata, aexp);
-	  bdata+=aexp;
-	  absbsize-=aexp;
-	  rdata+=aexp;
-	  res.size=aexp;
-	}
+        if(absbsize<=aexp){ // no overlap
+          mpn_copyi(rdata, bdata, absbsize);
+          rdata+=absbsize;
+          rdata=Mpzf_impl::fill_n_ptr(rdata,aexp-absbsize,0);
+          mpn_copyi(rdata, adata, absasize);
+          res.size=absasize+aexp;
+          if(asize<0) res.size=-res.size;
+          return res;
+        } else {
+          mpn_copyi(rdata, bdata, aexp);
+          bdata+=aexp;
+          absbsize-=aexp;
+          rdata+=aexp;
+          res.size=aexp;
+        }
       }
       if(absasize>=absbsize){
-	mp_limb_t carry=mpn_add(rdata,adata,absasize,bdata,absbsize);
-	res.size+=absasize;
-	if(carry!=0){
-	  res.size++;
-	  rdata[absasize]=carry;
-	}
+        mp_limb_t carry=mpn_add(rdata,adata,absasize,bdata,absbsize);
+        res.size+=absasize;
+        if(carry!=0){
+          res.size++;
+          rdata[absasize]=carry;
+        }
       } else {
-	mp_limb_t carry=mpn_add(rdata,bdata,absbsize,adata,absasize);
-	res.size+=absbsize;
-	if(carry!=0){
-	  res.size++;
-	  rdata[absbsize]=carry;
-	}
+        mp_limb_t carry=mpn_add(rdata,bdata,absbsize,adata,absasize);
+        res.size+=absbsize;
+        if(carry!=0){
+          res.size++;
+          rdata[absbsize]=carry;
+        }
       }
       // unnecessary if a.exp != b.exp
       while(/*res.size>0&&*/res.data()[0]==0){--res.size;++res.data();++res.exp;}
@@ -659,36 +690,36 @@ struct Mpzf {
       res.size=0;
       bool carry1=false;
       if(0<yexp){ // must have overlap since x is larger
-	mpn_copyi(rdata, xdata, yexp);
-	xdata+=yexp;
-	absxsize-=yexp;
-	rdata+=yexp;
-	res.size=yexp;
+        mpn_copyi(rdata, xdata, yexp);
+        xdata+=yexp;
+        absxsize-=yexp;
+        rdata+=yexp;
+        res.size=yexp;
       }
       else if(0<xexp){
-	if(absysize<=xexp){ // no overlap
-	  mpn_neg(rdata, ydata, absysize); // assert that it returns 1
-	  rdata+=absysize;
-	  rdata=Mpzf_impl::fill_n_ptr(rdata,xexp-absysize,-1);
-	  mpn_sub_1(rdata, xdata, absxsize, 1);
-	  res.size=absxsize+xexp;
-	  while(/*res.size>0&&*/res.data()[res.size-1]==0) --res.size;
-	  if(xsize<0) res.size=-res.size;
-	  return res;
-	} else {
-	  mpn_neg(rdata, ydata, xexp); // assert that it returns 1
-	  ydata+=xexp;
-	  absysize-=xexp;
-	  rdata+=xexp;
-	  res.size=xexp;
-	  carry1=true; // assumes no trailing zeros
-	}
+        if(absysize<=xexp){ // no overlap
+          mpn_neg(rdata, ydata, absysize); // assert that it returns 1
+          rdata+=absysize;
+          rdata=Mpzf_impl::fill_n_ptr(rdata,xexp-absysize,-1);
+          mpn_sub_1(rdata, xdata, absxsize, 1);
+          res.size=absxsize+xexp;
+          while(/*res.size>0&&*/res.data()[res.size-1]==0) --res.size;
+          if(xsize<0) res.size=-res.size;
+          return res;
+        } else {
+          mpn_neg(rdata, ydata, xexp); // assert that it returns 1
+          ydata+=xexp;
+          absysize-=xexp;
+          rdata+=xexp;
+          res.size=xexp;
+          carry1=true; // assumes no trailing zeros
+        }
       }
       CGAL_assertion_code( mp_limb_t carry= )
-	mpn_sub(rdata, xdata, absxsize, ydata, absysize);
+        mpn_sub(rdata, xdata, absxsize, ydata, absysize);
       if(carry1)
-	CGAL_assertion_code( carry+= )
-	  mpn_sub_1(rdata, rdata, absxsize, 1);
+        CGAL_assertion_code( carry+= )
+          mpn_sub_1(rdata, rdata, absxsize, 1);
       CGAL_assertion(carry==0);
       res.size+=absxsize;
       while(/*res.size>0&&*/res.data()[res.size-1]==0) --res.size;
@@ -739,7 +770,11 @@ struct Mpzf {
     return res;
   }
 
+#ifndef CGAL_MPZF_DIVISION_OPERATOR
+  friend Mpzf division(Mpzf const&a, Mpzf const&b){
+#else // CGAL_MPZF_DIVISION_OPERATOR
   friend Mpzf operator/(Mpzf const&a, Mpzf const&b){
+#endif // CGAL_MPZF_DIVISION_OPERATOR
     // FIXME: Untested
     int asize=std::abs(a.size);
     int bsize=std::abs(b.size);
@@ -757,16 +792,16 @@ struct Mpzf {
       --res.size;
       mpn_tdiv_qr(qp, rp, 0, adata, asize, bdata, bsize);
       CGAL_assertion_code(
-	  for (int i=0; i<bsize; ++i)
-	    if (rp[i] != 0) throw std::logic_error("non exact Mpzf division");
+          for (int i=0; i<bsize; ++i)
+            if (rp[i] != 0) throw std::logic_error("non exact Mpzf division");
       )
     }
     else if(adata[-1]==0){ // We are lucky
       --adata; ++asize; --res.exp;
       mpn_tdiv_qr(qp, rp, 0, adata, asize, bdata, bsize);
       CGAL_assertion_code(
-	  for (int i=0; i<bsize; ++i)
-	    if (rp[i] != 0) throw std::logic_error("non exact Mpzf division");
+          for (int i=0; i<bsize; ++i)
+            if (rp[i] != 0) throw std::logic_error("non exact Mpzf division");
       )
     }
     else{
@@ -779,8 +814,8 @@ struct Mpzf {
       //a2.exp = a.exp-1;
       mpn_tdiv_qr(qp, rp, 0, a2.data(), asize+1, bdata, bsize);
       CGAL_assertion_code(
-	  for (int i=0; i<bsize; ++i)
-	    if (rp[i] != 0) throw std::logic_error("non exact Mpzf division");
+          for (int i=0; i<bsize; ++i)
+            if (rp[i] != 0) throw std::logic_error("non exact Mpzf division");
       )
     }
     while(/*res.size>0&&*/res.data()[res.size-1]==0) --res.size;
@@ -863,6 +898,9 @@ struct Mpzf {
     }
   }
 
+  friend Mpzf operator+(Mpzf const&x){
+    return x;
+  }
   friend Mpzf operator-(Mpzf const&x){
     Mpzf ret = x;
     ret.size = -ret.size;
@@ -871,7 +909,9 @@ struct Mpzf {
   Mpzf& operator+=(Mpzf const&x){ *this=*this+x; return *this; }
   Mpzf& operator-=(Mpzf const&x){ *this=*this-x; return *this; }
   Mpzf& operator*=(Mpzf const&x){ *this=*this*x; return *this; }
+#ifdef CGAL_MPZF_DIVISION_OPERATOR
   Mpzf& operator/=(Mpzf const&x){ *this=*this/x; return *this; }
+#endif // not CGAL_MPZF_DIVISION_OPERATOR
 
   bool is_canonical () const {
     if (size == 0) return true;
@@ -912,8 +952,8 @@ struct Mpzf {
     int lz = Mpzf_impl::clz(x);
     if (lz <= 11) {
       if (lz != 11) {
-	e += (11 - lz);
-	x >>= (11 - lz);
+        e += (11 - lz);
+        x >>= (11 - lz);
       }
       dl = double(x);
       dh = double(x + 1);
@@ -944,9 +984,7 @@ struct Mpzf {
   }
 
 #ifdef CGAL_USE_GMPXX
-#ifndef CGAL_CFG_NO_CPP0X_EXPLICIT_CONVERSION_OPERATORS
   explicit
-#endif
   operator mpq_class () const {
     mpq_class q;
     export_to_mpq_t(q.get_mpq_t());
@@ -954,9 +992,7 @@ struct Mpzf {
   }
 #endif
 
-#ifndef CGAL_CFG_NO_CPP0X_EXPLICIT_CONVERSION_OPERATORS
   explicit
-#endif
   operator Gmpq () const {
     Gmpq q;
     export_to_mpq_t(q.mpq());
@@ -967,25 +1003,23 @@ struct Mpzf {
     CGAL_precondition(mpq_cmp_ui(q,0,1)==0);
     if (size != 0) {
       mpz_import (mpq_numref (q),
-		  std::abs(size),
-		  -1, // data()[0] is the least significant part
-		  sizeof(mp_limb_t),
-		  0, // native endianness inside mp_limb_t
-		  GMP_NAIL_BITS, // should be 0
-		  data());
+                  std::abs(size),
+                  -1, // data()[0] is the least significant part
+                  sizeof(mp_limb_t),
+                  0, // native endianness inside mp_limb_t
+                  GMP_NAIL_BITS, // should be 0
+                  data());
       if (exp > 0)
-	mpq_mul_2exp(q, q, (sizeof(mp_limb_t) * CHAR_BIT *  exp));
+        mpq_mul_2exp(q, q, (sizeof(mp_limb_t) * CHAR_BIT *  exp));
       else if (exp < 0)
-	mpq_div_2exp(q, q, (sizeof(mp_limb_t) * CHAR_BIT * -exp));
+        mpq_div_2exp(q, q, (sizeof(mp_limb_t) * CHAR_BIT * -exp));
 
       if (size < 0)
-	mpq_neg(q,q);
+        mpq_neg(q,q);
     }
   }
 #if 0
-#ifndef CGAL_CFG_NO_CPP0X_EXPLICIT_CONVERSION_OPERATORS
   explicit
-#endif
 // This makes Mpzf==int ambiguous
   operator Gmpzf () const {
     mpz_t z;
@@ -1030,96 +1064,100 @@ std::istream& operator>> (std::istream& is, Mpzf& a)
       typedef Tag_false            Is_numerical_sensitive;
 
       struct Is_zero
-	: public CGAL::cpp98::unary_function< Type, bool > {
-	  bool operator()( const Type& x ) const {
-	    return x.is_zero();
-	  }
-	};
+        : public CGAL::cpp98::unary_function< Type, bool > {
+          bool operator()( const Type& x ) const {
+            return x.is_zero();
+          }
+        };
 
       struct Is_one
-	: public CGAL::cpp98::unary_function< Type, bool > {
-	  bool operator()( const Type& x ) const {
-	    return x.is_one();
-	  }
-	};
+        : public CGAL::cpp98::unary_function< Type, bool > {
+          bool operator()( const Type& x ) const {
+            return x.is_one();
+          }
+        };
 
       struct Gcd
-	: public CGAL::cpp98::binary_function< Type, Type, Type > {
-	  Type operator()(
-	      const Type& x,
-	      const Type& y ) const {
-	    return Mpzf_gcd(x, y);
-	  }
-	};
+        : public CGAL::cpp98::binary_function< Type, Type, Type > {
+          Type operator()(
+              const Type& x,
+              const Type& y ) const {
+            return Mpzf_gcd(x, y);
+          }
+        };
 
       struct Square
-	: public CGAL::cpp98::unary_function< Type, Type > {
-	  Type operator()( const Type& x ) const {
-	    return Mpzf_square(x);
-	  }
-	};
+        : public CGAL::cpp98::unary_function< Type, Type > {
+          Type operator()( const Type& x ) const {
+            return Mpzf_square(x);
+          }
+        };
 
       struct Integral_division
-	: public CGAL::cpp98::binary_function< Type, Type, Type > {
-	  Type operator()(
-	      const Type& x,
-	      const Type& y ) const {
-	    return x / y;
-	  }
-	};
+        : public CGAL::cpp98::binary_function< Type, Type, Type > {
+          Type operator()(
+              const Type& x,
+              const Type& y ) const {
+#ifdef CGAL_MPZF_DIVISION_OPERATOR
+            return x / y;
+#else // not CGAL_MPZF_DIVISION_OPERATOR
+            return division(x, y);
+#endif // not CGAL_MPZF_DIVISION_OPERATOR
+          }
+        };
 
       struct Sqrt
-	: public CGAL::cpp98::unary_function< Type, Type > {
-	  Type operator()( const Type& x) const {
-	    return Mpzf_sqrt(x);
-	  }
-	};
+        : public CGAL::cpp98::unary_function< Type, Type > {
+          Type operator()( const Type& x) const {
+            return Mpzf_sqrt(x);
+          }
+        };
 
       struct Is_square
-	: public CGAL::cpp98::binary_function< Type, Type&, bool > {
-	  bool operator()( const Type& x, Type& y ) const {
-	    // TODO: avoid doing 2 calls.
-	    if (!Mpzf_is_square(x)) return false;
-	    y = Mpzf_sqrt(x);
-	    return true;
-	  }
-	  bool operator()( const Type& x) const {
-	    return Mpzf_is_square(x);
-	  }
-	};
+        : public CGAL::cpp98::binary_function< Type, Type&, bool > {
+          bool operator()( const Type& x, Type& y ) const {
+            // TODO: avoid doing 2 calls.
+            if (!Mpzf_is_square(x)) return false;
+            y = Mpzf_sqrt(x);
+            return true;
+          }
+          bool operator()( const Type& x) const {
+            return Mpzf_is_square(x);
+          }
+        };
 
     };
   template <> struct Real_embeddable_traits< Mpzf >
     : public INTERN_RET::Real_embeddable_traits_base< Mpzf , CGAL::Tag_true > {
       struct Sgn
-	: public CGAL::cpp98::unary_function< Type, ::CGAL::Sign > {
-	  ::CGAL::Sign operator()( const Type& x ) const {
-	    return x.sign();
-	  }
-	};
+        : public CGAL::cpp98::unary_function< Type, ::CGAL::Sign > {
+          ::CGAL::Sign operator()( const Type& x ) const {
+            return x.sign();
+          }
+        };
 
       struct To_double
-	: public CGAL::cpp98::unary_function< Type, double > {
-	    double operator()( const Type& x ) const {
-	      return x.to_double();
-	    }
-	};
+        : public CGAL::cpp98::unary_function< Type, double > {
+            double operator()( const Type& x ) const {
+              return x.to_double();
+            }
+        };
 
       struct Compare
-	: public CGAL::cpp98::binary_function< Type, Type, Comparison_result > {
-	    Comparison_result operator()(
-		const Type& x,
-		const Type& y ) const {
-	      return CGAL::sign(Mpzf_cmp(x,y));
-	    }
-	};
+        : public CGAL::cpp98::binary_function< Type, Type, Comparison_result > {
+            Comparison_result operator()(
+                const Type& x,
+                const Type& y ) const {
+              return CGAL::sign(Mpzf_cmp(x,y));
+            }
+        };
 
       struct To_interval
-	: public CGAL::cpp98::unary_function< Type, std::pair< double, double > > {
-	    std::pair<double, double> operator()( const Type& x ) const {
-	      return x.to_interval();
-	    }
-	};
+        : public CGAL::cpp98::unary_function< Type, std::pair< double, double > > {
+            std::pair<double, double> operator()( const Type& x ) const {
+              return x.to_interval();
+            }
+        };
 
     };
 
