@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Nef_2/include/CGAL/Nef_2/PM_overlayer.h $
-// $Id: PM_overlayer.h 3674c93 2022-11-15T15:21:01+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Nef_2/include/CGAL/Nef_2/PM_overlayer.h $
+// $Id: PM_overlayer.h b3192c9f4d8 2023-08-24T13:30:44+01:00 Andreas Fabri
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -336,6 +336,8 @@ public:
   using Base::set_isolated_vertex;
   using Base::has_outdeg_two;
   using Base::merge_halfedge_pairs_at_target;
+  using Base::isolated_vertices_begin;
+  using Base::isolated_vertices_end;
 
   // C++ is really friendly:
   #define USECMARK(t) const Mark& mark(t h) const { return Base::mark(h); }
@@ -605,18 +607,18 @@ avoid the simplification for edge pairs referenced by |e|.}*/
     CGAL_For_all(hfc,hend) {
       set_face(hfc,f);
       if(target(hfc) == target(e_min)) {
-        Point p1 = point(source(hfc)),
-          p2 = point(target(hfc)),
-          p3 = point(target(next(hfc)));
+        const Point& p1 = point(source(hfc));
+        const Point&  p2 = point(target(hfc));
+        const Point&  p3 = point(target(next(hfc)));
         if (!K.left_turn(p1,p2,p3) )
           e_min = hfc;
       } else if ( K.compare_xy(point(target(hfc)), point(target(e_min))) < 0 )
         e_min = hfc;
       linked[hfc]=true;
     }
-    Point p1 = point(source(e_min)),
-          p2 = point(target(e_min)),
-          p3 = point(target(next(e_min)));
+    const Point& p1 = point(source(e_min));
+    const Point& p2 = point(target(e_min));
+    const Point& p3 = point(target(next(e_min)));
     if ( K.orientation(p1,p2,p3) > 0 ) set_halfedge(f,e_min); // outer
     else set_hole(f,e_min); // store as inner
   }
@@ -626,12 +628,15 @@ avoid the simplification for edge pairs referenced by |e|.}*/
   for(v = this->vertices_begin(); v != vend; v=vn) { CGAL_NEF_TRACEN("at vertex "<<PV(v));
     vn=v; ++vn;
     if ( is_isolated(v) ) {
-      if ( mark(v) == mark(face(v)) ) delete_vertex_only(v);
-      else set_isolated_vertex(face(v),v);
+      if (mark(v) == mark(face(v))) {
+        delete_vertex_only(v);
+      } else {
+        set_isolated_vertex(face(v), v);
+      }
     } else { // v not isolated
       Halfedge_handle e2 = first_out_edge(v), e1 = previous(e2);
-      Point p1 = point(source(e1)), p2 = point(v),
-            p3 = point(target(e2));
+      const Point& p1 = point(source(e1)), p2 = point(v);
+      const Point& p3 = point(target(e2));
       if ( has_outdeg_two(v) &&
            mark(v) == mark(e1) && mark(v) == mark(e2) &&
            (K.orientation(p1,p2,p3) == 0) )
@@ -643,7 +648,15 @@ avoid the simplification for edge pairs referenced by |e|.}*/
   for (f = this->faces_begin(); f != fend; f=fn) {
     fn=f; ++fn;
     Union_find_handle pit = Pitem[f];
-    if ( unify_faces.find(pit) != pit ) delete_face(f);
+      Union_find_handle root = unify_faces.find(pit);
+      if (root != pit) {
+
+      for(Isolated_vertex_iterator ivi = isolated_vertices_begin(f); ivi != isolated_vertices_end(f); ++ivi){
+        ivi->set_face(*root);
+        link_as_isolated_vertex(*root,ivi);
+      }
+      delete_face(f);
+    }
   }
 
 
@@ -828,9 +841,9 @@ void create_face_objects(const Below_info& D) const
     CGAL_For_all(hfc,hend) {
       FaceCycle[hfc]=i; // assign face cycle number
       if(target(hfc) == target(e_min)) {
-        Point p1 = point(source(hfc)),
-          p2 = point(target(hfc)),
-          p3 = point(target(next(hfc)));
+        const Point& p1 = point(source(hfc));
+        const Point&p2 = point(target(hfc));
+        const Point&p3 = point(target(next(hfc)));
         if (!K.left_turn(p1,p2,p3) )
           e_min = hfc;
       } else if ( K.compare_xy(point(target(hfc)), point(target(e_min))) < 0 )
@@ -844,10 +857,10 @@ void create_face_objects(const Below_info& D) const
   Face_handle f_outer = this->new_face();
   for (int j=0; j<i; ++j) {
     Halfedge_handle e = MinimalHalfedge[j];
-      CGAL_NEF_TRACEN("  face cycle "<<j);CGAL_NEF_TRACEN("  minimal halfedge "<<PE(e));
-    Point p1 = point(source(e)),
-          p2 = point(target(e)),
-          p3 = point(target(next(e)));
+    CGAL_NEF_TRACEN("  face cycle "<<j);CGAL_NEF_TRACEN("  minimal halfedge "<<PE(e));
+    const Point& p1 = point(source(e));
+    const Point& p2 = point(target(e));
+    const Point& p3 = point(target(next(e)));
     if ( K.left_turn(p1,p2,p3) ) { // left_turn => outer face cycle
       CGAL_NEF_TRACEN("  creating new face object");
       Face_handle f = this->new_face();
@@ -889,9 +902,9 @@ void create_face_objects_pl(const Below_info& D) const
     CGAL_For_all(hfc,hend) {
       FaceCycle[hfc]=i; // assign face cycle number
       if(target(hfc) == target(e_min)) {
-        Point p1 = point(source(hfc)),
-          p2 = point(target(hfc)),
-          p3 = point(target(next(hfc)));
+        const Point& p1 = point(source(hfc));
+        const Point& p2 = point(target(hfc));
+        const Point& p3 = point(target(next(hfc)));
         if (!K.left_turn(p1,p2,p3) )
           e_min = hfc;
       } else if ( K.compare_xy(point(target(hfc)), point(target(e_min))) < 0 )
@@ -905,10 +918,10 @@ void create_face_objects_pl(const Below_info& D) const
   (void)/* Face_handle f_outer = */ this->new_face();
   for (int j=0; j<i; ++j) {
     Halfedge_handle e = MinimalHalfedge[j];
-      CGAL_NEF_TRACEN("  face cycle "<<j);CGAL_NEF_TRACEN("  minimal halfedge "<<PE(e));
-    Point p1 = point(source(e)),
-          p2 = point(target(e)),
-          p3 = point(target(next(e)));
+    CGAL_NEF_TRACEN("  face cycle "<<j);CGAL_NEF_TRACEN("  minimal halfedge "<<PE(e));
+    const Point& p1 = point(source(e));
+    const Point& p2 = point(target(e));
+    const Point& p3 = point(target(next(e)));
     if ( K.left_turn(p1,p2,p3) ) { // left_turn => outer face cycle
       CGAL_NEF_TRACEN("  creating new face object");
       Face_handle f = this->new_face();
@@ -953,8 +966,8 @@ Segment segment(const Const_decorator& N,
 
 bool is_forward_edge(const Const_decorator& N,
                      Halfedge_const_iterator hit) const
-{ Point p1 = N.point(N.source(hit));
-  Point p2 = N.point(N.target(hit));
+{ const Point& p1 = N.point(N.source(hit));
+  const Point& p2 = N.point(N.target(hit));
   return (K.compare_xy(p1,p2) < 0); }
 
 void assert_type_precondition() const
