@@ -1,19 +1,12 @@
 // Copyright (c) 1997-2000  Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Nef_2/include/CGAL/Nef_2/gen_point_location.h $
+// $Id: gen_point_location.h f79d8bb542f 2022-11-30T10:31:13+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Nef_2/include/CGAL/Nef_2/gen_point_location.h $
-// $Id: gen_point_location.h 41627 2008-01-14 23:06:54Z spion $
-// 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
 
@@ -21,18 +14,22 @@
 #ifndef CGAL_NEF_2_GEN_POINT_LOCATION_H
 #define CGAL_NEF_2_GEN_POINT_LOCATION_H
 
+#include <CGAL/license/Nef_2.h>
+
+
 #include <CGAL/LEDA_basic.h>
-#if CGAL_LEDA_VERSION < 500
-#include <LEDA/pp_dictionary.h>
-#else
 #include <LEDA/core/pp_dictionary.h>
-#endif
 #include <sstream>
 #include <string>
 #include <list>
 #include <vector>
 #include <map>
+#ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
 #include <CGAL/Nef_2/geninfo.h>
+#else
+#include <boost/any.hpp>
+#endif
+
 
 #undef CGAL_NEF_DEBUG
 #define CGAL_NEF_DEBUG 17
@@ -42,7 +39,7 @@
 
 // for dictionary
 template <class Node>
-inline std::ostream& operator<<(std::ostream& o, const std::list<Node>& n) 
+inline std::ostream& operator<<(std::ostream& o, const std::list<Node>& n)
 { return o; }
 
 /*{\Manpage {GenericLocation}{Node, Edge}
@@ -51,18 +48,22 @@ inline std::ostream& operator<<(std::ostream& o, const std::list<Node>& n)
 template <class Node, class Edge>
 class GenericLocation {
 /*{\Mdefinition
-  An instance of the data type |\Mtype| is used as return value for planar 
+  An instance of the data type |\Mtype| is used as return value for planar
   point location. It can store a node or an edge of a graph or the special
   value |nil| which is used to signal that no node or edge could be found.
 }*/
-  typedef void* GenPtr;
+  #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
+  typedef void*  GenPtr;
+  #else
+  typedef boost::any GenPtr;
+  #endif
 public:
-/*{\Mtypes}*/ 
+/*{\Mtypes}*/
   enum Type { NIL, NODE, EDGE };
-  /*{\Menum This enumeration allows to specify the 3 basic types of the 
+  /*{\Menum This enumeration allows to specify the 3 basic types of the
      values that a |\Mtype| can represent.}*/
 
-  /*{\Mcreation}*/ 
+  /*{\Mcreation}*/
     GenericLocation()       { init(); }
     /*{\Mcreate creates a |\Mtype| and initializes with the value |nil|.}*/
     GenericLocation(Node n) { init(n); }
@@ -81,21 +82,31 @@ public:
     operator const Node&() const
     {
   #if !defined(CHECKING_OFF)
-      if (type != NODE) 
+      if (type != NODE)
         CGAL_LEDA_SCOPE::error_handler(1, "Location: not convertible to node");
   #endif
+      #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
       return geninfo<Node>::const_access(value);
+      #else
+      return
+        *boost::any_cast<Node>(&value);
+      #endif
     }
     /*{\Mconversion converts |\Mvar| into a node.\\
        \precond |\Mvar| represents a node.}*/
 
     operator const Edge&() const
-    { 
+    {
   #if !defined(CHECKING_OFF)
-      if (type != EDGE) 
+      if (type != EDGE)
         CGAL_LEDA_SCOPE::error_handler(1, "Location: not convertible to edge");
   #endif
+      #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
       return geninfo<Edge>::const_access(value);
+      #else
+      return
+        *boost::any_cast<Edge>(&value);
+      #endif
     }
     /*{\Mconversion converts |\Mvar| into an edge.\\
        \precond |\Mvar| represents an edge.}*/
@@ -122,35 +133,56 @@ public:
 
   private:
     void init() { type = NIL; }
-    void init(Node n) 
-    { type = NODE; 
-      geninfo<Node>::create(value); 
-      geninfo<Node>::access(value) = n; 
+    void init(Node n)
+    { type = NODE;
+      #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
+      geninfo<Node>::create(value);
+      geninfo<Node>::access(value) = n;
+      #else
+      value=n;
+      #endif
     }
-    void init(Edge e) 
-    { type = EDGE; 
-      geninfo<Edge>::create(value); 
-      geninfo<Edge>::access(value) = e; 
+    void init(Edge e)
+    { type = EDGE;
+      #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
+      geninfo<Edge>::create(value);
+      geninfo<Edge>::access(value) = e;
+      #else
+      value=e;
+      #endif
     }
 
     void clear()
-    { 
+    {
       switch(type) {
+      #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
        case NODE: geninfo<Node>::clear(value); break;
        case EDGE: geninfo<Edge>::clear(value); break;
+      #else
+       case NODE: value=boost::any(); break;
+       case EDGE: value=boost::any(); break;
+      #endif
        case NIL: break;
       }
     }
 
     void assign(const GenericLocation<Node, Edge>& L)
-    { 
+    {
       type = L.type;
       switch(type) {
-       case NODE: 
-         geninfo<Node>::access(value) = geninfo<Node>::const_access(L.value); 
+       case NODE:
+        #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
+         geninfo<Node>::access(value) = geninfo<Node>::const_access(L.value);
+        #else
+         *boost_any_cast<Node>(&value) = boost::any_cast<Node>(L.value);
+        #endif
          break;
-       case EDGE: 
+       case EDGE:
+        #ifdef CGAL_I_DO_WANT_TO_USE_GENINFO
          geninfo<Edge>::access(value) = geninfo<Edge>::const_access(L.value);
+        #else
+         *boost::any_cast<Edge>(&value) = boost::any_cast<Edge>(L.value);
+        #endif
          break;
        case NIL: break;
       }
@@ -166,15 +198,15 @@ private:
 };
 
 /*{\Mimplementation
-  The data type |\Mtype| is implemented as a union of the types |Node| and 
+  The data type |\Mtype| is implemented as a union of the types |Node| and
   |Edge|. There is only constant time and space overhead.
 }*/
 template <class Node, class Edge>
 inline
-bool 
-operator==(const GenericLocation<Node, Edge>& L1, 
+bool
+operator==(const GenericLocation<Node, Edge>& L1,
            const GenericLocation<Node, Edge>& L2)
-{ 
+{
   if (L1.get_type() != L2.get_type()) return false;
   switch (L1.get_type()) {
    case GenericLocation<Node, Edge>::NIL:  return true;
@@ -185,13 +217,13 @@ operator==(const GenericLocation<Node, Edge>& L1,
 
 template <class Node, class Edge>
 inline
-bool 
-operator!=(const GenericLocation<Node, Edge>& L1, 
+bool
+operator!=(const GenericLocation<Node, Edge>& L1,
            const GenericLocation<Node, Edge>& L2)
 { return ! (L1==L2); }
 
 template <class Node, class Edge>
-std::ostream& operator<<(std::ostream& o, 
+std::ostream& operator<<(std::ostream& o,
                          const GenericLocation<Node, Edge>& L)
 {
   switch (L.get_type()) {
@@ -224,7 +256,7 @@ public:
   ~GenericXStructure() { clear(); }
 
   void init(int n, const PredLessThanX& cmp)
-  { CGAL_NEF_TRACEN("XSinit "<<n); 
+  { CGAL_NEF_TRACEN("XSinit "<<n);
     LtX = cmp;
     Coordinates = Array_Coordinates(n);
     SweepLines =  Array_Sweeplines(2*n+1);
@@ -237,9 +269,9 @@ public:
     stops = 0;
   }
 
-  void insertLines(const XCoord& X, 
+  void insertLines(const XCoord& X,
                    const Sweepline& atX, const Sweepline& inXplus)
-  { CGAL_NEF_TRACEN("XSinsert "<<X); 
+  { CGAL_NEF_TRACEN("XSinsert "<<X);
     Coordinates[stops]    = X;
     SweepLines[2*stops+1]   = atX;
     SweepLines[2*stops+2] = inXplus;
@@ -255,16 +287,16 @@ public:
     }
     Coord_iterator stopit = std::lower_bound (
         Coordinates.begin(),Coordinates.end(),X,LtX);
-    /* determines stopit maximal such that 
+    /* determines stopit maximal such that
        \forall j \in [begin,stopit) : *j < X
        as a consequence now: *stopit >= X */
     bool found_exact = false;
     if ( LtX(X,*stopit) ) --stopit;  // X <  *stopit
     else found_exact = true;         // X >= *stopit
-      
+
     CGAL_NEF_TRACEN("stopit "<<*stopit);
     int offset = stopit-Coordinates.begin();
-    return found_exact ? 
+    return found_exact ?
       SweepLines.begin() + (2*offset+1) :
       SweepLines.begin() + (2*offset+2);
   }
@@ -280,18 +312,18 @@ class PointLocator {
 /*{\Mdefinition
    An instance |\Mvar| of the parameterized data type |\Mtype| can be used
    to perform point location queries in the two-dimensional plane.
-   Every non-empty instance |\Mvar| is associated with an embedded planar 
+   Every non-empty instance |\Mvar| is associated with an embedded planar
    graph |G|, which has to remain unchanged while it is referenced by |PL|.\\
    A location query for a point |p| returns the first object (node or edge)
    of |G| which is intersected by the straight ray starting in |p| and going
    vertically downwards/upwards.
-   If the ray does not intersect any node or edge of |G|, then |nil| is 
+   If the ray does not intersect any node or edge of |G|, then |nil| is
    returned.\\
-   The class |\Mtype| is generic, it is parameterized with a traits class 
+   The class |\Mtype| is generic, it is parameterized with a traits class
    |PLocTraits| which widely controls its behaviour.
    The traits may even change the return type of a query and its semantics.
    There are predined traits classes for the LEDA graph types, which are
-   described below in a seperate section.
+   described below in a separate section.
 }*/
 public:
   // copied types from PLocTraits
@@ -311,26 +343,26 @@ public:
   typedef typename PLocTraits::QueryResult       QueryResult;
 
 /*{\Mtypes}*/
-  // define additional types 
+  // define additional types
   typedef GenericLocation<Node, Edge> Location;
-  /*{\Mtypedef usual return value for the point loaction.}*/
+  /*{\Mtypedef usual return value for the point location.}*/
 
   enum Direction { downwards, upwards};
   /*{\Menum used to specify the direction for the point location.}*/
 
-  typedef CGAL_LEDA_SCOPE::pp_dictionary<Curve, Location, PredCompareCurves>   
+  typedef CGAL_LEDA_SCOPE::pp_dictionary<Curve, Location, PredCompareCurves>
                                                               Sweepline;
   typedef GenericXStructure<XCoord, PredLessThanX, Sweepline> XStructure;
   typedef typename Sweepline::item                            SL_item;
   typedef typename XStructure::Sweepline_iterator Sweepline_iterator;
-  /*{\Mcreation}*/ 
+  /*{\Mcreation}*/
   PointLocator() { clear(); }
   /*{\Mcreate creates an empty |\Mtype|.}*/
 
-  PointLocator(const Graph& G, const PLocTraits& PLT = PLocTraits()) : 
+  PointLocator(const Graph& G, const PLocTraits& PLT = PLocTraits()) :
    traits(PLT) { init(G); }
   /*{\Mcreate creates a |\Mtype| for the graph |G| and the traits |PLT|.}*/
-     
+
   /*{\Moperations}*/
   void clear() { X_Structure.clear(); traits.clear(); }
   /*{\Mop makes |\Mvar| empty.}*/
@@ -397,16 +429,16 @@ PointLocator<PLocTraits>::init(const Graph& G)
 
       // explore the nodes on SL
       typename std::list<Node>::iterator cur_node;
-      for(cur_node = NodesOnSL.begin(); 
+      for(cur_node = NodesOnSL.begin();
           cur_node != NodesOnSL.end(); ++cur_node) {
         IncEdgeIterator ei     = traits.IncEdges_begin(G, *cur_node);
         IncEdgeIterator beyond = traits.IncEdges_end(G, *cur_node);
           CGAL_NEF_TRACEN("NODE: "<<(*cur_node)->point());
-        for(; ei != beyond; ++ei) { 
+        for(; ei != beyond; ++ei) {
           switch (traits.ClassifyEdge(G, traits.toEdge(ei), *cur_node)) {
-            case PLocTraits::StartingNonVertical: 
+            case PLocTraits::StartingNonVertical:
               EmergingEdges.push_front(traits.toEdge(ei)); break;
-            case PLocTraits::StartingVertical:    
+            case PLocTraits::StartingVertical:
               VerticalEdges.push_front(traits.toEdge(ei)); break;
             case PLocTraits::EndingNonVertical:
               SL.del(traits.makeCurve(G, traits.toEdge(ei))); break;
@@ -418,8 +450,8 @@ PointLocator<PLocTraits>::init(const Graph& G)
       // compute SL_at_X
 
       typename std::list<Edge>::iterator cur_edge;
-      for(cur_edge=VerticalEdges.begin(); 
-          cur_edge!=VerticalEdges.end(); ++cur_edge) 
+      for(cur_edge=VerticalEdges.begin();
+          cur_edge!=VerticalEdges.end(); ++cur_edge)
         SL.insert(traits.makeCurve(G, *cur_edge), Location(*cur_edge));
       for(cur_node=NodesOnSL.begin();
           cur_node!=NodesOnSL.end(); ++cur_node)
@@ -428,7 +460,7 @@ PointLocator<PLocTraits>::init(const Graph& G)
 
       // compute SL_in_X_plus
 
-      for(cur_edge=VerticalEdges.begin(); 
+      for(cur_edge=VerticalEdges.begin();
           cur_edge!=VerticalEdges.end(); ++cur_edge)
         SL.del(traits.makeCurve(G, *cur_edge));
       for(cur_node=NodesOnSL.begin();
@@ -436,10 +468,10 @@ PointLocator<PLocTraits>::init(const Graph& G)
         SL.del(traits.makeCurve(G, *cur_node));
 
       for(cur_edge=EmergingEdges.begin();
-          cur_edge!=EmergingEdges.end(); ++cur_edge) 
+          cur_edge!=EmergingEdges.end(); ++cur_edge)
         SL.insert(traits.makeCurve(G, *cur_edge), Location(*cur_edge));
 
-    X_Structure.insertLines(traits.getXCoord(G, *NodesOnSL.begin()), 
+    X_Structure.insertLines(traits.getXCoord(G, *NodesOnSL.begin()),
                             SL_at_X, SL);
   }
 
@@ -472,7 +504,7 @@ template <class PLocTraits>
 typename PointLocator<PLocTraits>::QueryResult
 PointLocator<PLocTraits>::locate_up(const typename PLocTraits::Point& p) const
 {
-  Sweepline_iterator line_at_x = 
+  Sweepline_iterator line_at_x =
     X_Structure.getLineAt(traits.getXCoord(p)), line_plus;
   Curve p_curve = traits.makeCurve(p);
   PredCompareCurves cmp = traits.getCompareCurves();
@@ -489,24 +521,24 @@ PointLocator<PLocTraits>::locate_up(const typename PLocTraits::Point& p) const
 }
 
 /*{\Mimplementation
-  The implementation of the data type |\Mtype| is based on partially 
+  The implementation of the data type |\Mtype| is based on partially
   persistent binary search trees.
-  The expected space requirement is $O(k)$ where $k$ is the sum of the number 
+  The expected space requirement is $O(k)$ where $k$ is the sum of the number
   of nodes and the number of edges in the graph $G$.
-  The expected time needed for construction and the operation |init| is 
+  The expected time needed for construction and the operation |init| is
   $O(k \cdot \log k)$, for the |locate|-operations it is $O(\log k)$. The
   operation |clear| runs in $O(k)$.
 }*/
 /*{\Mtext
   \headerline{\arabic{manctr}. Predefined traits classes}
   \stepcounter{manctr}
-  All predefined traits classes have in common that the return type of a query 
+  All predefined traits classes have in common that the return type of a query
   is the type |Location|.
   The embedding of the given graph |G| is a straight-line embedding, so that
   it is totally determined by the position of the nodes of |G|.
   Such a position is specified by a |Point| which can be one of the LEDA point
-  types |point| or |rat_point|. The positions can be specified implicitly by 
-  the node attribute of a parameterized graph (e.g. |GRAPH<Point,...>|) or 
+  types |point| or |rat_point|. The positions can be specified implicitly by
+  the node attribute of a parameterized graph (e.g. |GRAPH<Point,...>|) or
   explicitly by a |node_array<Point>|. In case of explicit specification a
   |node_array| with the positions of the nodes can be passed to the constructor
   of the traits class.
@@ -518,21 +550,21 @@ PointLocator<PLocTraits>::locate_up(const typename PLocTraits::Point& p) const
   left of |e|.\\
   Here comes a list of the predefined traits classes:\\[-5.5ex]
   \begin{itemize}
-  \item |PLocTraits<Graph>|: standard traits for implicitly specified node 
+  \item |PLocTraits<Graph>|: standard traits for implicitly specified node
     positions\\
-    |Graph| can be |GRAPH<Point,...>| (standard graph) or 
+    |Graph| can be |GRAPH<Point,...>| (standard graph) or
     |PLANAR_MAP<Point,...,...>| (map).
-  \item |PLocTraits_NodeArray<Graph,Point>|: std. traits for explicitly 
+  \item |PLocTraits_NodeArray<Graph,Point>|: std. traits for explicitly
     specified node positions\\
     |Graph| can be |graph| (standard graph) or |planar_map| (map).
   \item |PLocTraits_Map<Graph>| and |PLocTraits_Map_NodeArray<Graph,Point>|:\\
     The parameter |Graph| can be |GRAPH<Point,...>| and |graph| respectively.
     These traits classes assume that the given graphs are maps.
-  \item |PLocTraits< GRAPH<Circle,Point> >|: traits class for closest-site 
+  \item |PLocTraits< GRAPH<Circle,Point> >|: traits class for closest-site
     voronoi diagrams
   \end{itemize}
-  Note that a traits class instantiated with |Graph| can also handle graph 
-  types which are derived from |Graph|. Thus |PLocTraits< graph<Point,T> >| 
+  Note that a traits class instantiated with |Graph| can also handle graph
+  types which are derived from |Graph|. Thus |PLocTraits< graph<Point,T> >|
   can be used for graphs of type |ugraph<Point,T>| for example.
 }*/
 /*{\Mexample
