@@ -1,23 +1,21 @@
+// Copyright (c) 1997-2002  Max-Planck-Institute Saarbruecken (Germany).
+// All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Nef_3/include/CGAL/Nef_3/Default_items.h $
+// $Id: Default_items.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Nef_3/include/CGAL/Nef_3/Default_items.h $
-// $Id: Default_items.h 56667 2010-06-09 07:37:13Z sloriot $
-// 
 //
 // Author(s)     : Andreas Fabri <andreas.fabri@geometryfactory.com>
 
 #ifndef CGAL_NEF_DEFAULT_ITEMS_H
 #define CGAL_NEF_DEFAULT_ITEMS_H
 
+#include <CGAL/license/Nef_3.h>
+
+
 #include <CGAL/Nef_3/SNC_items.h>
 #include <CGAL/Nef_3/SNC_indexed_items.h>
 #include <CGAL/Extended_homogeneous.h>
