@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Nef_3/include/CGAL/Nef_3/SM_visualizor.h $
+// $Id: SM_visualizor.h fb6f703b55f 2021-05-04T14:07:49+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Nef_3/include/CGAL/Nef_3/SM_visualizor.h $
-// $Id: SM_visualizor.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Michael Seel    <seel@mpi-sb.mpg.de>
 //                 Miguel Granados <granados@mpi-sb.mpg.de>
@@ -33,33 +24,33 @@
 #include <CGAL/Nef_S2/SM_decorator.h>
 #include <CGAL/Nef_S2/SM_triangulator.h>
 
-#define CGAL_NEF3_LGREY CGAL::Color(170,170,200)
-#define CGAL_NEF3_DGREY CGAL::Color(30,30,50)
+#define CGAL_NEF3_LGREY CGAL::IO::Color(170,170,200)
+#define CGAL_NEF3_DGREY CGAL::IO::Color(30,30,50)
 
 namespace CGAL {
 
 template <typename Refs_>
-class SNC_SM_BooleColor 
+class SNC_SM_BooleColor
 {
-  typedef typename Refs_::SVertex_const_handle   SVertex_const_handle;   
-  typedef typename Refs_::SHalfedge_const_handle SHalfedge_const_handle;   
-  typedef typename Refs_::SHalfloop_const_handle SHalfloop_const_handle;   
-  typedef typename Refs_::SFace_const_handle     SFace_const_handle;   
-  typedef typename Refs_::Mark Mark;   
+  typedef typename Refs_::SVertex_const_handle   SVertex_const_handle;
+  typedef typename Refs_::SHalfedge_const_handle SHalfedge_const_handle;
+  typedef typename Refs_::SHalfloop_const_handle SHalfloop_const_handle;
+  typedef typename Refs_::SFace_const_handle     SFace_const_handle;
+  typedef typename Refs_::Mark Mark;
 public:
   Color color(SVertex_const_handle, Mark m) const
-  { return ( m ? CGAL::BLACK : CGAL::WHITE ); }
+  { return ( m ? CGAL::black() : CGAL::white() ); }
   Color color(SHalfedge_const_handle, Mark m) const
-  { return ( m ? CGAL::BLACK : CGAL::WHITE ); }
+  { return ( m ? CGAL::black() : CGAL::white() ); }
   Color color(SHalfloop_const_handle, Mark m) const
-  { return ( m ? CGAL::BLACK : CGAL::WHITE ); }
+  { return ( m ? CGAL::black() : CGAL::white() ); }
   Color color(SFace_const_handle, Mark m) const
   { return ( m ? CGAL_NEF3_DGREY : CGAL_NEF3_LGREY ); }
 };
 
 
 template <typename SM_explorer>
-class SM_visualizor 
+class SM_visualizor
 {
 /*{\Mdefinition An instance |\Mvar| of the data type |\Mname| is a
 decorator to draw the structure of a sphere map into the surface of a
@@ -74,9 +65,9 @@ public:
   typedef SM_decorator<Sphere_map>                 SM_decorator;
   typedef SM_triangulator<SM_decorator>            SM_triangulator;
 
-  typedef typename Sphere_map::SVertex_const_handle     SVertex_const_handle;   
-  typedef typename Sphere_map::SHalfedge_const_handle   SHalfedge_const_handle; 
-  typedef typename Sphere_map::SFace_const_handle       SFace_const_handle;     
+  typedef typename Sphere_map::SVertex_const_handle     SVertex_const_handle;
+  typedef typename Sphere_map::SHalfedge_const_handle   SHalfedge_const_handle;
+  typedef typename Sphere_map::SFace_const_handle       SFace_const_handle;
   typedef typename Sphere_map::SVertex_const_iterator   SVertex_const_iterator;
   typedef typename Sphere_map::SHalfedge_const_iterator SHalfedge_const_iterator;
   typedef typename Sphere_map::SFace_const_iterator     SFace_const_iterator;
@@ -88,15 +79,15 @@ public:
     we stick to the Nef_3 world. All Nef_S2 handles obtain a SM_ prefix.
   */
 
-  typedef typename Sphere_map::SVertex_const_iterator   
+  typedef typename Sphere_map::SVertex_const_iterator
     SM_Vertex_const_iterator;
-  typedef typename Sphere_map::SHalfedge_const_iterator 
+  typedef typename Sphere_map::SHalfedge_const_iterator
     SM_Halfedge_const_iterator;
-  typedef typename Sphere_map::SHalfloop_const_iterator 
+  typedef typename Sphere_map::SHalfloop_const_iterator
     SM_Halfloop_const_iterator;
-  typedef typename Sphere_map::SFace_const_iterator     
+  typedef typename Sphere_map::SFace_const_iterator
     SM_Face_const_iterator;
-  
+
 
   typedef typename Sphere_kernel::Sphere_point    Sphere_point;
   typedef typename Sphere_kernel::Sphere_segment  Sphere_segment;
@@ -132,10 +123,10 @@ void draw_map() const
   bool top=false;
   bool bot=false;
   CGAL_forall_sedges(e,*E_) {
-    top = top || 
+    top = top ||
       E_->point(E_->source(e)).hz() > 0 ||
       E_->point(E_->target(e)).hz() > 0;
-    bot = bot || 
+    bot = bot ||
       E_->point(E_->source(e)).hz() < 0 ||
       E_->point(E_->target(e)).hz() < 0;
   }
@@ -144,24 +135,24 @@ void draw_map() const
 
   CGAL_forall_sedges(e,*E_) {
     if ( E_->source(e) == E_->target(e) ) {
-      S_.push_back(E_->circle(e), CO_.color(e,E_->mark(e))); 
-    } else 
+      S_.push_back(E_->circle(e), CO_.color(e,E_->mark(e)));
+    } else
       /*
       if(E_->point(E_->source(e)) == E_->point(E_->target(e)).antipode()) {
       CGAL_assertion(!top || !bot);
       if(!top)
-	S_.push_back(Sphere_segment(E_->point(E_->source(e)),
-				    E_->point(E_->target(e)),
-				    c),CO_.color(e,E_->mark(e)));
+        S_.push_back(Sphere_segment(E_->point(E_->source(e)),
+                                    E_->point(E_->target(e)),
+                                    c),CO_.color(e,E_->mark(e)));
       else
-     
-	c=Sphere_circle(E_->point(E_->source(e)),Sphere_point(0,0,1));
+
+        c=Sphere_circle(E_->point(E_->source(e)),Sphere_point(0,0,1));
     }
     else
-      */ 
+      */
       S_.push_back(Sphere_segment(E_->point(E_->source(e)),
-				  E_->point(E_->target(e)),
-				  E_->circle(e)),CO_.color(e,E_->mark(e)));
+                                  E_->point(E_->target(e)),
+                                  E_->circle(e)),CO_.color(e,E_->mark(e)));
   }
   // draw sphere circles underlying loops of E_:
 
@@ -193,22 +184,22 @@ void draw_map() const
 
   CGAL_forall_sedges(h,T_) // for all sphere edges
     S_.push_back_triangle_edge(Sphere_segment(T_.point(T_.source(h)),
-					      T_.point(T_.target(h)),
-					      T_.circle(h)));
+                                              T_.point(T_.target(h)),
+                                              T_.circle(h)));
 }
 
 /* |draw_triangulation| draws all object of the underlying triangulation:
    triangles, edges, loops, and vertices taken from MT_ */
 
 void draw_triangulation() const
-{ 
+{
   // draw sphere segments underlying edges of triangulation:
   SHalfedge_const_iterator ed;
   SVertex_const_iterator vd;
   SM_Halfedge_const_iterator e;
   CGAL_forall_sedges(e,T_) {
     S_.push_back(Sphere_segment(T_.point(T_.source(e)),T_.point(T_.target(e)),
-				T_.circle(e)),CO_.color(ed,T_.mark(e)));
+                                T_.circle(e)),CO_.color(ed,T_.mark(e)));
   }
 
   // draw points underlying vertices of triangulation:
@@ -221,7 +212,7 @@ void draw_triangulation() const
     if ( Done[e] ) continue;
     SM_Halfedge_const_iterator en(T_.next(e)),enn(T_.next(en));
     CGAL_assertion(T_.incident_mark(e)==T_.incident_mark(en)&&
-			T_.incident_mark(en)==T_.incident_mark(enn));
+                        T_.incident_mark(en)==T_.incident_mark(enn));
     Mark m = T_.incident_mark(e);
     Sphere_triangle t = T_.incident_triangle(e);
     S_.push_back(t, (m ? CGAL_NEF3_DGREY : CGAL_NEF3_LGREY) );
@@ -230,7 +221,7 @@ void draw_triangulation() const
 
 }
 
-}; // end of SM_Visualizor 
+}; // end of SM_Visualizor
 
 
 
