@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Nef_3/include/CGAL/Nef_3/SNC_const_decorator.h $
+// $Id: SNC_const_decorator.h 3674c937f76 2022-11-15T15:21:01+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Nef_3/include/CGAL/Nef_3/SNC_const_decorator.h $
-// $Id: SNC_const_decorator.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Michael Seel    <seel@mpi-sb.mpg.de>
 //                 Miguel Granados <granados@mpi-sb.mpg.de>
@@ -49,7 +40,7 @@ namespace CGAL {
 template<typename S> class SM_const_decorator;
 
 template <typename SNC_structure_>
-class SNC_const_decorator { 
+class SNC_const_decorator {
   typedef SNC_structure_                            Base;
  public:
   typedef SNC_structure_                            SNC_structure;
@@ -84,7 +75,7 @@ public:
 
   typedef typename SNC_structure::Vertex_const_iterator Vertex_const_iterator;
   typedef typename SNC_structure::Halfedge_const_iterator Halfedge_const_iterator;
-  typedef typename SNC_structure::Halffacet_const_iterator Halffacet_const_iterator; 
+  typedef typename SNC_structure::Halffacet_const_iterator Halffacet_const_iterator;
   typedef typename SNC_structure::Volume_const_iterator Volume_const_iterator;
   typedef typename SNC_structure::SVertex_const_iterator SVertex_const_iterator;
   typedef typename SNC_structure::SHalfedge_const_iterator SHalfedge_const_iterator;
@@ -118,9 +109,9 @@ public:
   typedef typename SNC_structure::Mark Mark;
   typedef typename SNC_structure::Infi_box Infi_box;
 
-  typedef typename SM_const_decorator::SHalfedge_around_svertex_const_circulator 
+  typedef typename SM_const_decorator::SHalfedge_around_svertex_const_circulator
                                        SHalfedge_around_svertex_const_circulator;
-  typedef typename SM_const_decorator::SHalfedge_around_sface_const_circulator 
+  typedef typename SM_const_decorator::SHalfedge_around_sface_const_circulator
                                        SHalfedge_around_sface_const_circulator;
 
  public:
@@ -136,59 +127,39 @@ public:
     sncp_ = S.sncp_;
   }
 
- protected:  
+ protected:
   void set_snc(const SNC_structure& W) {
     sncp_ = &W;
   }
 
  public:
   const SNC_structure* sncp() const { return sncp_; }
-  
-  SFace_const_handle adjacent_sface(Halffacet_const_handle f) const {
-    Halffacet_cycle_const_iterator fc(f->facet_cycles_begin());
-    CGAL_assertion( fc != f->facet_cycles_end());
-
-    if ( fc.is_shalfedge() ) { 
-      SHalfedge_const_handle se(fc);
-      CGAL_assertion( facet(se) == f);
-      CGAL_assertion( sface(se) != SFace_const_handle());
-      CGAL_assertion( volume(sface(se->twin())) == f->incident_volume());
-      return sface(se->twin());
-    } 
-    else 
-      CGAL_error_msg( "Facet outer cycle entry point"
-			     "is not an SHalfedge? ");
-    return SFace_const_handle(); // never reached
-  }
-
-  //  static const Point_3& point(Vertex_const_handle v)
-  //  { return v->point(); }
 
   static Vector_3 vector(Halfedge_const_handle e)
   { return Vector_3(e->point()-CGAL::ORIGIN); }
 
   static Segment_3 segment(Halfedge_const_handle e)
   { return Segment_3(e->source()->point(),
-		     e->twin()->source()->point()); }
+                     e->twin()->source()->point()); }
 
-  template <typename Visitor>
-  void visit_shell_objects(SFace_const_handle f, Visitor& V) const;
+  template <typename Visitor, typename Traits = Self::Decorator_traits>
+  void visit_shell_objects(typename Traits::SFace_handle f, Visitor& V) const;
 
-  Vertex_const_iterator   vertices_begin() const { 
+  Vertex_const_iterator   vertices_begin() const {
     return this->sncp()->vertices_begin(); }
-  Vertex_const_iterator   vertices_end()   const { 
+  Vertex_const_iterator   vertices_end()   const {
     return this->sncp()->vertices_end(); }
   Halfedge_const_iterator halfedges_begin()const {
     return this->sncp()->halfedges_begin(); }
-  Halfedge_const_iterator halfedges_end()  const { 
+  Halfedge_const_iterator halfedges_end()  const {
     return this->sncp()->halfedges_end(); }
-  Halffacet_const_iterator halffacets_begin() const { 
+  Halffacet_const_iterator halffacets_begin() const {
     return this->sncp()->halffacets_begin(); }
-  Halffacet_const_iterator halffacets_end() const { 
+  Halffacet_const_iterator halffacets_end() const {
     return this->sncp()->halffacets_end(); }
-  Volume_const_iterator   volumes_begin() const   { 
+  Volume_const_iterator   volumes_begin() const   {
     return this->sncp()->volumes_begin(); }
-  Volume_const_iterator   volumes_end()   const   { 
+  Volume_const_iterator   volumes_end()   const   {
     return this->sncp()->volumes_end(); }
   SHalfedge_const_iterator shalfedges_begin() const {
     return this->sncp()->shalfedges_begin(); }
@@ -210,17 +181,17 @@ public:
     return c->shells_end();
   }
 
-  Size_type number_of_vertices() const  
+  Size_type number_of_vertices() const
   { return this->sncp()->number_of_vertices(); }
-  Size_type number_of_halfedges() const 
+  Size_type number_of_halfedges() const
   { return this->sncp()->number_of_halfedges(); }
-  Size_type number_of_edges() const     
+  Size_type number_of_edges() const
   { return this->sncp()->number_of_edges(); }
-  Size_type number_of_halffacets() const    
+  Size_type number_of_halffacets() const
   { return this->sncp()->number_of_halffacets();}
-  Size_type number_of_facets() const    
+  Size_type number_of_facets() const
   { return this->sncp()->number_of_facets();}
-  Size_type number_of_volumes() const   
+  Size_type number_of_volumes() const
   { return this->sncp()->number_of_volumes();}
   Size_type number_of_shalfedges() const
   { return this->sncp()->number_of_shalfedges();}
@@ -236,9 +207,9 @@ public:
     Halffacet_const_handle hf;
     CGAL_forall_facets(hf, *sncp()) {
       if(!Infi_box::is_standard(hf->plane()))
-	++i;
+        ++i;
     }
-    CGAL_warning("altered code");
+    // CGAL_warning("altered code");
     //    CGAL_assertion(i>=6);
     return (i == 6);
   }
@@ -250,7 +221,7 @@ public:
     SHalfedge_around_facet_const_circulator fcc(sh), fend(fcc);
     CGAL_For_all(fcc,fend)
       if(!is_standard(fcc->source()->source()))
-	return false;
+        return false;
     return true;
   }
 
@@ -262,123 +233,127 @@ public:
   }
   static bool is_standard_kernel() { return Infi_box::standard_kernel(); }
   static bool is_extended_kernel() { return Infi_box::extended_kernel(); }
-  static void set_size_of_infimaximal_box(const typename Infi_box::NT& size) { 
-    Infi_box::set_size_of_infimaximal_box(size); 
+  static void set_size_of_infimaximal_box(const typename Infi_box::NT& size) {
+    Infi_box::set_size_of_infimaximal_box(size);
   }
 
-  typedef CGAL::SM_point_locator<SM_const_decorator>         SM_point_locator;
-
-  Halffacet_const_handle get_visible_facet( const Vertex_const_handle v, 
-				      const Ray_3& ray) const
+  template <typename Traits = Self::Decorator_traits>
+  typename Traits::Halffacet_handle get_visible_facet( const typename Traits::Vertex_handle v,
+                                                       const Ray_3& ray) const
     /*{\Mop when one shoot a ray |ray| in order to find the facet below to
       an object, and vertex |v| is hit, we need to choose one of the facets
       in the adjacency list of |v| such that it could be 'seen' from the
       piercing point of the |ray| on the sphere map on |v|.  We make it just
-      locating the sphere facet |sf| pierced by |ray| and taking the adjacent 
+      locating the sphere facet |sf| pierced by |ray| and taking the adjacent
       facet to one of the sphere segments on the boundary of |sf|.
       \precondition |ray| target is on |v| and the intersection between
-      |ray| and the 2-skeleton incident to v is empty. }*/ {
+      |ray| and the 2-skeleton incident to v is empty. }*/
+  {
 
-    Halffacet_const_handle f_visible;
+    typedef typename Traits::Halffacet_handle Halffacet_handle;
+    typedef typename Traits::SFace_handle SFace_handle;
+    typedef typename Traits::SHalfedge_handle SHalfedge_handle;
+    typedef typename Traits::SFace_cycle_iterator SFace_cycle_iterator;
+    typedef typename Traits::SHalfloop_handle SHalfloop_handle;
+    typedef CGAL::SM_point_locator<typename Traits::SM_decorator> SM_point_locator;
+
+    Halffacet_handle f_visible;
     CGAL_assertion( ray.source() != v->point());
     CGAL_assertion( ray.has_on(v->point()));
     Sphere_point sp(ray.source() - v->point());
     CGAL_NEF_TRACEN( "Locating "<<sp <<" in "<<v->point());
-    CGAL_assertion(Infi_box::degree(sp.hx()) < 2 && 
-		   Infi_box::degree(sp.hy()) < 2 && 
-		   Infi_box::degree(sp.hz()) < 2 && 
-		   Infi_box::degree(sp.hw()) == 0);
+    CGAL_assertion(Infi_box::degree(sp.hx()) < 2 &&
+                   Infi_box::degree(sp.hy()) < 2 &&
+                   Infi_box::degree(sp.hz()) < 2 &&
+                   Infi_box::degree(sp.hw()) == 0);
     sp = Infi_box::simplify(sp);
     CGAL_NEF_TRACEN( "Locating "<<sp <<" in "<<v->point());
     SM_point_locator L(&*v);
     Object_handle o = L.locate(sp);
 
-    SFace_const_handle sf;
+    SFace_handle sf;
     if(!CGAL::assign(sf,o)) {
-      SHalfedge_const_handle se;
-      if(CGAL::assign(se,o))
-	std::cerr << "on sedge " << PH(se) 
-		  << " on facet " << se->facet()->plane() << std::endl;
-      SVertex_const_handle sv;
-      if(CGAL::assign(sv,o))
-	std::cerr << "on svertex " << sv->point() << std::endl; 
       CGAL_error_msg( "it is not possible to decide which one is a visible facet (if any)");
-      return Halffacet_const_handle();
+      return Halffacet_handle();
     }
 
-    SFace_cycle_const_iterator fc = sf->sface_cycles_begin(),
+    SFace_cycle_iterator fc = sf->sface_cycles_begin(),
       fce = sf->sface_cycles_end();
     if( is_empty_range( fc, fce)) {
-	CGAL_NEF_TRACEN( "no adjacent facet found.");
-	f_visible =  Halffacet_const_handle();
+        CGAL_NEF_TRACEN( "no adjacent facet found.");
+        f_visible =  Halffacet_handle();
     }
     else {
       if (fc.is_shalfedge()) {
-	SHalfedge_const_handle se(fc);
-	CGAL_NEF_TRACEN( "adjacent facet found (SEdges cycle).");
-	CGAL_NEF_TRACEN("se"<<PH(se));
-	CGAL_NEF_TRACEN(se->facet()->plane() <<"/"<<
-	       se->snext()->facet()->plane()  <<"/"<< 
-	       se->snext()->snext()->facet()->plane());
-	f_visible = se->twin()->facet();
-	CGAL_NEF_TRACEN("f_visible"<< f_visible->plane());
+        SHalfedge_handle se(fc);
+        CGAL_NEF_TRACEN( "adjacent facet found (SEdges cycle).");
+        CGAL_NEF_TRACEN("se"<<PH(se));
+        CGAL_NEF_TRACEN(se->facet()->plane() <<"/"<<
+               se->snext()->facet()->plane()  <<"/"<<
+               se->snext()->snext()->facet()->plane());
+        f_visible = se->twin()->facet();
+        CGAL_NEF_TRACEN("f_visible"<< f_visible->plane());
       }
       else if (fc.is_shalfloop()) {
-	SHalfloop_const_handle sl(fc);
-	SM_const_decorator SD;
-	CGAL_NEF_TRACEN( "adjacent facet found (SHalfloop cycle)."<< sl->circle() 
-			 << " with facet "<< sl->facet()->plane());
-	f_visible = sl->twin()->facet();
-	CGAL_NEF_TRACEN("f_visible"<< f_visible->plane());
+        SHalfloop_handle sl(fc);
+        CGAL_NEF_TRACEN( "adjacent facet found (SHalfloop cycle)."<< sl->circle()
+                         << " with facet "<< sl->facet()->plane());
+        f_visible = sl->twin()->facet();
+        CGAL_NEF_TRACEN("f_visible"<< f_visible->plane());
       }
       else if(fc.is_svertex()) {
-#ifdef CGAL_NEF_DEBUG
-	// TODO: is there any warranty that the outter facet cycle enty point is always at first
-	// in the cycles list?
-	++fc; while( fc != fce)  { CGAL_assertion( fc.is_svertex()); ++fc; }
+#ifdef CGAL_USE_TRACE
+        // TODO: is there any warranty that the outer facet cycle entry point is always at first
+        // in the cycles list?
+        ++fc; while( fc != fce)  { CGAL_assertion( fc.is_svertex()); ++fc; }
+        CGAL_NEF_TRACEN( "no adjacent facets were found (but incident edge(s)).");
 #endif
-	CGAL_NEF_TRACEN( "no adjacent facets were found (but incident edge(s)).");
-	f_visible = Halffacet_const_handle();
+        f_visible = Halffacet_handle();
       }
       else
-	CGAL_error_msg("Damn wrong handle");
+        CGAL_error_msg("Damn wrong handle");
     }
     return f_visible;
   }
 
-  Halffacet_const_handle get_visible_facet( const Halfedge_const_handle e,
-                                      const Ray_3& ray) const {
+  template <typename Traits = Self::Decorator_traits>
+  typename Traits::Halffacet_handle get_visible_facet( const typename Traits::Halfedge_handle e,
+                                                       const Ray_3& ray) const
    //{\Mop when one shoot a ray |ray| in order to find the facet below to
-   //  an object, and an edge |e| is hit, we need to choose one of the two 
+   //  an object, and an edge |e| is hit, we need to choose one of the two
    //  facets in the adjacency list of |e| that could be 'seen'  from the
    //  piercing point of the |ray| on the local (virtual) view  of |e|
-   //  \precondition |ray| target belongs to |e|. } 
+   //  \precondition |ray| target belongs to |e|. }
+  {
+    typedef typename Traits::SM_decorator SM_decorator;
+    typedef typename Traits::Halffacet_handle Halffacet_handle;
+    typedef typename Traits::SHalfedge_around_svertex_circulator SHalfedge_around_svertex_circulator;
 
-    SM_const_decorator SD(&*e->source());
+    SM_decorator SD(&*e->source());
     if( SD.is_isolated(e))
-      return Halffacet_const_handle();
-    
+      return Halffacet_handle();
+
     // We search for the plane in the adjacency list of e, which is closest
     // to the ray. The cross product of the direction of e and the orthogonal
-    // vector of a plane gives us a vector vec0/vec1 on the plane of the facet 
+    // vector of a plane gives us a vector vec0/vec1 on the plane of the facet
     // and orthogonal to e, pointing inside of the facet.
 
     Vector_3 ev(segment(e).to_vector()), rv(ray.to_vector());
-    SHalfedge_around_svertex_const_circulator sh(SD.first_out_edge(e));
-    Halffacet_const_handle res = sh->facet(); 
+    SHalfedge_around_svertex_circulator sh(SD.first_out_edge(e));
+    Halffacet_handle res = sh->facet();
     Vector_3 vec0(cross_product(ev,res->plane().orthogonal_vector()));
     /* // probably incorrect assertion
     CGAL_assertion_code
-      (Sphere_segment _ess( SD.source(sh)->point(), 
-			    SD.source(next(sh))->point(),
-			    SD.circle(sh)));
+      (Sphere_segment _ess( SD.source(sh)->point(),
+                            SD.source(next(sh))->point(),
+                            SD.circle(sh)));
     CGAL_assertion( _ess.has_on(vec0));
     */
-    SHalfedge_around_svertex_const_circulator send(sh);
+    SHalfedge_around_svertex_circulator send(sh);
     CGAL_NEF_TRACEN("initial face candidate "<< res->plane()<<" with vector  "<<vec0);
 
-    // We compare the vectors vec0/vec1 of the facets. The one that is nearest 
-    // to pointing in the opposite direction of the ray, is chosen. The 
+    // We compare the vectors vec0/vec1 of the facets. The one that is nearest
+    // to pointing in the opposite direction of the ray, is chosen. The
     // respective facet is the nearest to the ray.
 
     sh++;
@@ -389,15 +364,15 @@ public:
       if(sk0<=FT(0) && sk1>=FT(0))
         continue;
       if(sk0>=FT(0) && sk1<=FT(0)) {
-        res = sh->facet(); 
-	vec0 = vec1;
-	continue;
+        res = sh->facet();
+        vec0 = vec1;
+        continue;
       }
 
-      // We have to comapare the two skalar products sk0 and sk1. Therefore 
+      // We have to comapare the two scalar products sk0 and sk1. Therefore
       // we have to normalize the input vectors vec0 and vec1, which means
-      // that we have to divide them by their lengths len0 and len1. 
-      // To cicumvent irrational numbers, we sqaure the whole inequality.
+      // that we have to divide them by their lengths len0 and len1.
+      // To cicumvent irrational numbers, we square the whole inequality.
 
       FT len0 = vec0.x()*vec0.x()+vec0.y()*vec0.y()+vec0.z()*vec0.z();
       FT len1 = vec1.x()*vec1.x()+vec1.y()*vec1.y()+vec1.z()*vec1.z();
@@ -410,12 +385,12 @@ public:
 
       if((sk0>FT(0) && diff<FT(0)) || (sk0<FT(0) && diff>FT(0))) {
         res = sh->facet();
-	vec0 = vec1;
+        vec0 = vec1;
       }
     }
- 
+
     // We have to check which of the two halffacet is visible from
-    // the ray. 
+    // the ray.
 
     if(rv*res->plane().orthogonal_vector() > FT(0))
       res = res->twin();
@@ -423,241 +398,170 @@ public:
     CGAL_NEF_TRACEN("return "<<res->plane());
     return res; // never reached
   }
-  
-  Halffacet_const_handle get_visible_facet(Halffacet_const_handle f,
-				      const Ray_3& ray) const 
+
+  template <typename Traits = Self::Decorator_traits>
+  typename Traits::Halffacet_handle get_visible_facet( const typename Traits::Halffacet_handle f,
+                                                       const Ray_3& ray) const
     /*{\Mop when one shoot a ray |ray| in order to find the facet below to
       an object, and a facet |f| is hit, we need to choose the right facet
       from the halffacet pair |f| that  could be 'seen'  from the
       piercing point of the |ray| on the local (virtual) view  of |f|.
       \precondition |ray| target belongs to |f| and the intersection between
-      |ray| and is not coplanar with |f|. }*/ {
+      |ray| and is not coplanar with |f|. }*/
+  {
+    typedef typename Traits::Halffacet_handle Halffacet_handle;
 
-    Halffacet_const_handle f_visible = f;
+    Halffacet_handle f_visible = f;
     if( f_visible->plane().has_on_negative_side(ray.source()))
       f_visible = f_visible->twin();
     CGAL_assertion( f_visible->plane().has_on_positive_side(ray.source()));
     return f_visible;
   }
 
-  Halffacet_const_handle get_visible_facet( const Vertex_const_handle v, 
-				      const Segment_3& ray) const 
-    /*{\Mop when one shoots a ray |ray| in order to find the facet below to
-      an object, and vertex |v| is hit, we need to choose one of the facets
-      in the adjacency list of |v| such that it could be 'seen' from the
-      piercing point of the |ray| on the sphere map on |v|.  We make it just
-      locating the sphere facet |sf| pierced by |ray| and taking the adjacent 
-      facet to one of the sphere segments on the boundary of |sf|.
-      \precondition |ray| target is on |v| and the intersection between
-      |ray| and the 2-skeleton incident to v is empty. }*/ {
-
-    Halffacet_const_handle f_visible;
-    CGAL_assertion( ray.source() != v->point());
-    CGAL_assertion( ray.has_on(v->point()));
-    Sphere_point sp(ray.source() - v->point());
-    CGAL_NEF_TRACEN( "Locating "<<sp <<" in "<<v->point());
-    CGAL_assertion(Infi_box::degree(sp.hx()) < 2 && 
-		   Infi_box::degree(sp.hy()) < 2 && 
-		   Infi_box::degree(sp.hz()) < 2 && 
-		   Infi_box::degree(sp.hw()) == 0);
-    sp = Infi_box::simplify(sp);
-    CGAL_NEF_TRACEN( "Locating "<<sp <<" in "<<v->point());
-    SM_point_locator L(v);
-    Object_handle o = L.locate(sp);
-
-    SFace_const_handle sf;
-    CGAL_assertion(CGAL::assign(sf,o));
-    CGAL::assign( sf, o);
-
-    SFace_cycle_const_iterator fc = sf->sface_cycles_begin(),
-      fce = sf->sface_cycles_end();
-    if( is_empty_range( fc, fce)) {
-	CGAL_NEF_TRACEN( "no adjacent facets were found.");
-	f_visible =  Halffacet_const_handle();
-    }
-    else {
-      if (fc.is_shalfedge()) {
-      SHalfedge_const_handle se(fc); 
-      CGAL_NEF_TRACEN( "adjacent facet found (SEdges cycle).");
-	CGAL_NEF_TRACEN("se"<<PH(se));
-	f_visible = se->twin()->facet();
-	CGAL_NEF_TRACEN("f_visible"<<&f_visible);
-      }
-      else if (fc.is_shalfloop()) {
-      SHalfloop_const_handle sl(fc);
-      CGAL_NEF_TRACEN( "adjacent facet found (SHalfloop cycle).");
-      f_visible = sl->twin()->facet();
-      }
-      else if(fc.is_svertex()) {
-	CGAL_NEF_TRACEN( "no adjacent facets were found (but incident edge(s)).");
-	f_visible = Halffacet_const_handle();
-      }
-      else
-	CGAL_error_msg("Damn wrong handle");
-    }
-    return f_visible;
-  }
-
-  /*
-  Halffacet_const_handle get_visible_facet( const Halfedge_const_handle e,
-                                      const Segment_3& ray) const {
-    //{\Mop when one shoot a ray |ray| in order to find the facet below to
-    //  an object, and an edge |e| is hit, we need to choose one of the two 
-   //   facets in the adjacency list of |e| that could be 'seen'  from the
-   //   piercing point of the |ray| on the local (virtual) view  of |e|
-   //   \precondition |ray| target belongs to |e|. } 
-
-    CGAL_error();
-
-    SM_const_decorator SD;
-    if( SD.is_isolated(e))
-      return Halffacet_const_handle();
-
-    Halffacet_const_handle res = facet(sh);    
-
-    Vector_3 ed(segment(e).to_vector());
-    Vector_3 ev(segment(e).to_vector()), rv(ray.to_vector());
-    SHalfedge_around_svertex_const_circulator sh(SD.first_out_edge(e)), send(sh);
-    Vector_3 vec0(cross_product(ev,res->plane().orthogonal_vector()));
-    CGAL_NEF_TRACEN("initial face candidate "<< res->plane());
-   
-    sh++;
-    CGAL_For_all(sh,send) {
-    Vector_3 vec1(cross_product(ev,sh->plane().orthogonal_vector()));
-      RT sk0(rv*vec0),  sk1(rv*vec1);
-      if(sk0<0 && sk1>0)
-        continue;
-      if(sk0>0 && sk1<0) {
-        res = facet(sh);
-	continue;
-      }
-
-      RT len0 = vec0.x()*vec0.x()+vec0.y()*vec0.y()+vec0.z()*vec0.z();
-      RT len1 = vec1.x()*vec1.x()+vec1.y()*vec1.y()+vec1.z()*vec1.z();
-      RT sq0 = sk0 * sk0;
-      RT sq1 = sk1 * sk1;     
-      RT diff = len0*sq1 - len1*sq0;
-
-      if((sk0 > 0 && diff<0) || (sk0 < 0 && diff>0))
-        res = facet(sh);
-    }
-
-    return Halffacet_const_handle(); // never reached
-  }
-  */
-
   Halffacet_const_handle get_visible_facet( const Halffacet_const_handle f,
-				      const Segment_3& ray) const 
+                                      const Segment_3& ray) const
     //{\Mop when one shoot a ray |ray| in order to find the facet below to
     //  an object, and a facet |f| is hit, we need to choose the right facet
     //  from the halffacet pair |f| that  could be 'seen'  from the
     //  piercing point of the |ray| on the local (virtual) view  of |f|.
     //  \precondition |ray| target belongs to |f| and the intersection between
-    //  |ray| and is not coplanar with |f|. } 
+    //  |ray| and is not coplanar with |f|. }
     {
       Halffacet_const_handle f_visible = f;
       CGAL_assertion( !f_visible->plane().has_on(ray.source()));
       if( f_visible->plane().has_on_negative_side(ray.source()))
-	f_visible = f->twin();
+        f_visible = f->twin();
       CGAL_assertion( f_visible->plane().has_on_positive_side(ray.source()));
       return f_visible;
     }
 };
 
+/* visiting shell objects:
+
+Objects are marked as done, when placed in the output list.  We have
+to maintain a stack of sface candidates (the spherical rubber sectors
+that provide connectivity at the local graphs of vertices) and facet
+candidates (the plane pieces in three space also providing
+connectivity). Note that we have to take care about the orientation of
+sobjects and facets. We have to take care that (1) the search along
+the shell extends along the whole shell structure (2) does not visit
+any object twice, and (3) all 3-space objects have to be reported and
+this also just once.
+
+The facets and sfaces are marked |done| when they are put into their
+corresponding queues thus each such object is visited exactly once
+when taken out of the queue.
+
+When an sface |sf| is taken out of the queue |SFaceCandiates| its
+boundary structure is examined and all 2-skeleton objects (vertices
+and edges of 3-space) that are incident to the volume represented by
+|sf| are reported. Facets are reported when they are taken out of
+|FacetCandiates|.
+
+*/
 template <typename EW>
-template <typename Visitor>
+template <typename Visitor, typename Traits>
 void SNC_const_decorator<EW>::
-visit_shell_objects(SFace_const_handle f, Visitor& V) const
-{ 
-  std::list<SFace_const_handle> SFaceCandidates;
-  std::list<Halffacet_const_handle> FacetCandidates;
-  CGAL::Unique_hash_map<SFace_const_handle,bool> DoneSF(false);
-  CGAL::Unique_hash_map<Vertex_const_handle,bool> DoneV(false);
-  CGAL::Unique_hash_map<SVertex_const_handle,bool> DoneSV(false);
-  CGAL::Unique_hash_map<Halffacet_const_handle,bool> DoneF(false);
-  SFaceCandidates.push_back(f);  DoneSF[f] = true;
+visit_shell_objects(typename Traits::SFace_handle f, Visitor& V) const
+{
+  typedef typename Traits::Halffacet_cycle_iterator Halffacet_cycle_iterator;
+  typedef typename Traits::Halffacet_handle Halffacet_handle;
+  typedef typename Traits::SFace_cycle_iterator SFace_cycle_iterator;
+  typedef typename Traits::SFace_handle SFace_handle;
+  typedef typename Traits::SHalfedge_around_facet_circulator SHalfedge_around_facet_circulator;
+  typedef typename Traits::SHalfedge_around_sface_circulator SHalfedge_around_sface_circulator;
+  typedef typename Traits::SHalfedge_handle SHalfedge_handle;
+  typedef typename Traits::SHalfloop_handle SHalfloop_handle;
+  typedef typename Traits::SM_decorator SM_decorator;
+  typedef typename Traits::SVertex_handle SVertex_handle;
+
+  std::list<SFace_handle> SFaceCandidates;
+  std::list<Halffacet_handle> FacetCandidates;
+  CGAL::Generic_handle_map<bool> Done(false);
+
+  SFaceCandidates.push_back(f);  Done[f] = true;
   while ( true ) {
     if ( SFaceCandidates.empty() && FacetCandidates.empty() ) break;
     if ( !FacetCandidates.empty() ) {
-      Halffacet_const_handle f = *FacetCandidates.begin();
+      Halffacet_handle f = *FacetCandidates.begin();
       FacetCandidates.pop_front();
       V.visit(f); // report facet
-      Halffacet_cycle_const_iterator fc;
+      Halffacet_cycle_iterator fc;
       CGAL_forall_facet_cycles_of(fc,f) {
         if (fc.is_shalfedge() ) {
-	  SHalfedge_const_handle e(fc);
-	  SHalfedge_const_handle she;
-          SHalfedge_around_facet_const_circulator ec(e),ee(e);
+          SHalfedge_handle e(fc);
+          SHalfedge_handle she;
+          SHalfedge_around_facet_circulator ec(e),ee(e);
           CGAL_For_all(ec,ee) { she = ec->twin();
-            if ( DoneSF[she->incident_sface()] ) continue;
+            if ( Done[she->incident_sface()] ) continue;
             SFaceCandidates.push_back(she->incident_sface());
-            DoneSF[she->incident_sface()] = true;
+            Done[she->incident_sface()] = true;
           }
-        } else if (fc.is_shalfloop() ) { 
-	  SHalfloop_const_handle l(fc);
-	  SHalfloop_const_handle ll = l->twin();
-          if ( DoneSF[ll->incident_sface()] ) continue;
+        } else if (fc.is_shalfloop() ) {
+          SHalfloop_handle l(fc);
+          SHalfloop_handle ll = l->twin();
+          if ( Done[ll->incident_sface()] ) continue;
           SFaceCandidates.push_back(ll->incident_sface());
-          DoneSF[ll->incident_sface()] = true;
+          Done[ll->incident_sface()] = true;
         } else CGAL_error_msg("Damn wrong handle.");
       }
     }
     if ( !SFaceCandidates.empty() ) {
-      SFace_const_handle sf = *SFaceCandidates.begin();
+      SFace_handle sf = *SFaceCandidates.begin();
       SFaceCandidates.pop_front();
       V.visit(sf);
-      if ( !DoneV[sf->center_vertex()] )
+      if ( !Done[sf->center_vertex()] )
         V.visit(sf->center_vertex()); // report vertex
-      DoneV[sf->center_vertex()] = true;
+      Done[sf->center_vertex()] = true;
       //      SVertex_const_handle sv;
-      SM_const_decorator SD(&*sf->center_vertex());
-      /*      
+      SM_decorator SD(&*sf->center_vertex());
+      /*
       CGAL_forall_svertices(sv,SD){
-	if(SD.is_isolated(sv) && !DoneSV[sv])
-	  V.visit(sv);
+        if(SD.is_isolated(sv) && !DoneSV[sv])
+          V.visit(sv);
       }
       */
-      SFace_cycle_const_iterator fc;
+      SFace_cycle_iterator fc;
       CGAL_forall_sface_cycles_of(fc,sf) {
         if (fc.is_shalfedge() ) {
-	  SHalfedge_const_handle e(fc);
-	  SHalfedge_around_sface_const_circulator ec(e),ee(e);
-          CGAL_For_all(ec,ee) { 
-	    V.visit(SHalfedge_const_handle(ec));
-            SVertex_const_handle vv = ec->twin()->source();
-            if ( !SD.is_isolated(vv) && !DoneSV[vv] ) {
+          SHalfedge_handle e(fc);
+          SHalfedge_around_sface_circulator ec(e),ee(e);
+          CGAL_For_all(ec,ee) {
+            V.visit(SHalfedge_handle(ec));
+            SVertex_handle vv = ec->twin()->source();
+            if ( !SD.is_isolated(vv) && !Done[vv] ) {
               V.visit(vv); // report edge
-              DoneSV[vv] = DoneSV[vv->twin()] = true;
+              Done[vv] = Done[vv->twin()] = true;
             }
-            Halffacet_const_handle f = ec->twin()->facet();
-            if ( DoneF[f] ) continue;
-            FacetCandidates.push_back(f); DoneF[f] = true;
+            Halffacet_handle f = ec->twin()->facet();
+            if ( Done[f] ) continue;
+            FacetCandidates.push_back(f); Done[f] = true;
           }
         } else if (fc.is_svertex() ) {
-	  SVertex_const_handle v(fc);
-          if ( DoneSV[v] ) continue; 
+          SVertex_handle v(fc);
+          if ( Done[v] ) continue;
           V.visit(v); // report edge
-	  V.visit(v->twin());
-          DoneSV[v] = DoneSV[v->twin()] = true;
-	  CGAL_assertion(SD.is_isolated(v));
-	  SFaceCandidates.push_back(v->twin()->incident_sface());
-	  DoneSF[v->twin()->incident_sface()]=true;
+          V.visit(v->twin());
+          Done[v] = Done[v->twin()] = true;
+          CGAL_assertion(SD.is_isolated(v));
+          SFaceCandidates.push_back(v->twin()->incident_sface());
+          Done[v->twin()->incident_sface()]=true;
           // note that v is isolated, thus twin(v) is isolated too
-	  //	  SM_const_decorator SD;
-	  //	  SFace_const_handle fo;
-	  //	  fo = v->twin()->incident_sface();
-	  /*
-	  if(SD.is_isolated(v)) 
-	    fo = v->source()->sfaces_begin();
-	  else
-	    fo = v->twin()->incident_sface();
-	  */
+          //          SM_const_decorator SD;
+          //          SFace_const_handle fo;
+          //          fo = v->twin()->incident_sface();
+          /*
+          if(SD.is_isolated(v))
+            fo = v->source()->sfaces_begin();
+          else
+            fo = v->twin()->incident_sface();
+          */
         } else if (fc.is_shalfloop() ) {
-	  SHalfloop_const_handle l(fc);
-	  V.visit(l);
-          Halffacet_const_handle f = l->twin()->facet();
-          if ( DoneF[f] ) continue;
-          FacetCandidates.push_back(f);  DoneF[f] = true;
+          SHalfloop_handle l(fc);
+          V.visit(l);
+          Halffacet_handle f = l->twin()->facet();
+          if ( Done[f] ) continue;
+          FacetCandidates.push_back(f);  Done[f] = true;
         } else CGAL_error_msg("Damn wrong handle.");
       }
     }
