@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Nef_3/include/CGAL/Nef_nary_union_3.h $
+// $Id: Nef_nary_union_3.h 7b09c8e5ead 2022-08-02T17:37:38+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Nef_3/include/CGAL/Nef_nary_union_3.h $
-// $Id: Nef_nary_union_3.h fa92aa4 2018-01-18T10:43:57+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     :     Peter Hachenberger  <hachenberger@mpi-sb.mpg.de>
 
@@ -40,7 +31,7 @@ class Nef_nary_union_3 {
 
  public:
   Nef_nary_union_3() : inserted(0) {}
-  
+
   void unite() {
     pit i1(queue.begin()), i2(i1);
     ++i2;
@@ -61,10 +52,11 @@ class Nef_nary_union_3 {
   }
 
   Polyhedron get_union() {
-
+    if (queue.empty())
+      return empty;
     while(queue.size() > 1)
       unite();
-    inserted = 0;
+    inserted = 1;
     return queue.front();
   }
 };
