@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Surface_sweep_2/include/CGAL/No_intersection_surface_sweep_2.h $
-// $Id: No_intersection_surface_sweep_2.h 33d3aba 2018-04-17T16:42:59+02:00 Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Surface_sweep_2/include/CGAL/No_intersection_surface_sweep_2.h $
+// $Id: No_intersection_surface_sweep_2.h c32b1f41275 2022-11-16T13:22:39+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Baruch Zukerman <baruchzu@post.tau.ac.il>
 //             Efi Fogel <efifogel@gmail.com>
@@ -23,14 +14,18 @@
 #ifndef CGAL_NO_INTERSECTION_SURFACE_SWEEP_2_H
 #define CGAL_NO_INTERSECTION_SURFACE_SWEEP_2_H
 
+#include <CGAL/license/Surface_sweep_2.h>
+
 /*! \file
  *
  * Definition of the No_intersection_surface_sweep_2 class.
  */
 
+#include <vector>
+#include <algorithm>
+#include <iterator>
 #include <boost/mpl/assert.hpp>
 
-#include <CGAL/license/Surface_sweep_2.h>
 #include <CGAL/assertions.h>
 #include <CGAL/memory.h>
 #include <CGAL/Surface_sweep_2/Event_comparer.h>
@@ -38,9 +33,6 @@
 #include <CGAL/Multiset.h>
 #include <CGAL/Arrangement_2/Arr_traits_adaptor_2.h>
 #include <CGAL/Arr_tags.h>
-#include <vector>
-#include <algorithm>
-#include <iterator>
 
 #ifndef CGAL_SS_VERBOSE
 
@@ -137,22 +129,31 @@ public:
   typedef typename Traits_adaptor_2::Top_side_category    Top_side_category;
   typedef typename Traits_adaptor_2::Right_side_category  Right_side_category;
 
-  BOOST_MPL_ASSERT(
-      (typename
-       Arr_sane_identified_tagging< Left_side_category, Bottom_side_category,
-       Top_side_category, Right_side_category >::result)
-  );
+  CGAL_static_assertion((Arr_sane_identified_tagging< Left_side_category, Bottom_side_category,
+                          Top_side_category, Right_side_category >::value));
 
 protected:
-  typedef typename Arr_are_all_sides_oblivious_tag<
-    Left_side_category, Bottom_side_category,
-    Top_side_category, Right_side_category >::result
-    Are_all_sides_oblivious_category;
+  /*!
+   */
+  typedef typename Arr_all_sides_oblivious_category<Left_side_category,
+                                                    Bottom_side_category,
+                                                    Top_side_category,
+                                                    Right_side_category>::result
+    All_sides_oblivious_category;
+
+  /*!
+   */
+  typedef typename Arr_sides_category<Left_side_category,
+                                      Bottom_side_category,
+                                      Top_side_category,
+                                      Right_side_category>::result
+    Sides_category;
 
 public:
   typedef CGAL::Surface_sweep_2::Event_comparer<Traits_adaptor_2, Event>
                                                         Event_comparer;
-  typedef Multiset<Event*, Event_comparer, Allocator>   Event_queue;
+  typedef Multiset<Event*, Event_comparer, Allocator, Tag_true>
+                                                        Event_queue;
   typedef typename Event_queue::iterator                Event_queue_iterator;
 
   typedef typename Event::Subcurve_iterator
@@ -167,28 +168,12 @@ public:
                                                         Status_line;
   typedef typename Status_line::iterator                Status_line_iterator;
 
-#ifdef CGAL_CXX11
   typedef std::allocator_traits<Allocator> Allocator_traits;
-  typedef typename Allocator_traits::template rebind_alloc<Event> Event_alloc;
   typedef typename Allocator_traits::template rebind_alloc<Subcurve> Subcurve_alloc;
-#else // not CGAL_CXX11
-  typedef typename Allocator::template rebind<Event>    Event_alloc_rebind;
-  typedef typename Event_alloc_rebind::other            Event_alloc;
 
-  typedef typename Allocator::template rebind<Subcurve> Subcurve_alloc_rebind;
-  typedef typename Subcurve_alloc_rebind::other         Subcurve_alloc;
-#endif // not CGAL_CXX11
-  
 protected:
-  /*! \struct
-   * An auxiliary functor for comparing event pointers.
-   */
-  struct CompEventPtr {
-    Comparison_result operator()(Event* e1, Event* e2) const
-    { return (e1 < e2) ? SMALLER : ((e1 > e2) ? LARGER : EQUAL); }
-  };
 
-  typedef Multiset<Event*, CompEventPtr>           Allocated_events_set;
+  typedef Compact_container<Event>                 Allocated_events_set;
   typedef typename Allocated_events_set::iterator  Allocated_events_iterator;
 
   // Data members:
@@ -221,7 +206,6 @@ protected:
                                     // may happen only with events that are
                                     // associated with isolated query points.
 
-  Event_alloc m_eventAlloc;         // An allocator for the events objects.
   Subcurve_alloc m_subCurveAlloc;   // An allocator for the subcurve objects.
 
   Event m_masterEvent;              // A master Event (created once by the
@@ -273,8 +257,8 @@ public:
    * \param curves_begin  An iterator for the first x-monotone curve in the
    *                      range.
    * \param curves_end A past-the-end iterator for this range.
-   * \param points_begin An iterator for the first point in the range.
-   * \param points_end A past-the-end iterator for this range.
+   * \param action_points_begin An iterator for the first point in the range.
+   * \param action_points_end A past-the-end iterator for this range.
    * \pre The value-type of XCurveInputIterator is the traits-class
    *      X_monotone_curve_2, and the value-type of PointInputIterator is the
    *      traits-class Point_2.
@@ -294,27 +278,29 @@ public:
     m_visitor->after_sweep();
   }
 
-  /*! Run the sweep-line alogrithm on a range of x-monotone curves, a range
+  /*! Run the sweep-line algorithm on a range of x-monotone curves, a range
    * of action event points (if a curve passed through an action point, it will
    * be split) and a range of query points (if a curve passed through a
-   * query point,it will not be splitted).
+   * query point,it will not be split).
    * \param curves_begin An iterator for the first x-monotone curve in the
    *                     range.
    * \param curves_end A past-the-end iterator for this range.
-   * \param points_begin An iterator for the first point in the range.
-   * \param points_end A past-the-end iterator for this range.
+   * \param action_points_begin An iterator for the first point in the range.
+   * \param action_points_end A past-the-end iterator for this range.
+   * \param query_points_begin An iterator for the first point in the range.
+   * \param query_points_end A past-the-end iterator for this range.
    * \pre The value-type of XCurveInputIterator is the traits-class
-   *      X_monotone_curve_2, and the value-type of PointInputIterator is the
-   *      traits-class Point_2.
+   *      X_monotone_curve_2, and the value-type of ActionPointIterator
+   *      and QueryPointIterator is the traits-class Point_2.
    */
-  template <typename CurveInputIterator, typename ActionPointItr,
-            typename QueryPointItr>
+  template <typename CurveInputIterator, typename ActionPointIterator,
+            typename QueryPointIterator>
   void sweep(CurveInputIterator curves_begin,
              CurveInputIterator curves_end,
-             ActionPointItr action_points_begin,
-             ActionPointItr action_points_end,
-             QueryPointItr query_points_begin,
-             QueryPointItr query_points_end)
+             ActionPointIterator action_points_begin,
+             ActionPointIterator action_points_end,
+             QueryPointIterator query_points_begin,
+             QueryPointIterator query_points_end)
   {
     m_visitor->before_sweep();
     _init_sweep(curves_begin, curves_end);
@@ -326,6 +312,77 @@ public:
     m_visitor->after_sweep();
   }
 
+  /*!
+    runs the indexed sweep-line algorithm on a given range of
+    x-monotone curves and accessor. The main difference from the
+    original `sweep()` function is that the accessor allows to get
+    indices of end-points and avoid checking several times in the
+    event queue when the same vertex has several incident edges.
+
+    \param edges A range of edges
+    \param accessor An object providing, for a value_type `e` of
+           range `edges`, the following methods:
+     - size_t             min_end_index(e) -> the index of the min end of curve c
+     - size_t             max_end_index(e) -> the index of the max end of curve c
+     - X_monotone_curve_2 curve(e)         -> the x-monotone curve associated to e
+     - size_t             nb_vertices()    -> the total number of points/events
+     - void               before_init()    -> called before initialization
+     - void               after_init()     -> called after initialization
+   */
+  template <typename EdgeRange, typename Accessor>
+  void indexed_sweep (const EdgeRange& edges,
+                      const Accessor& accessor)
+  {
+    m_visitor->before_sweep();
+    accessor.before_init();
+    _init_indexed_sweep(edges, accessor);
+    accessor.after_init();
+    _sweep();
+    _complete_sweep();
+    m_visitor->after_sweep();
+  }
+
+  /*!
+    runs the indexed sweep-line algorithm on a given range of
+    x-monotone curves and accessor. The main difference from the
+    original `sweep()` function is that the accessor allows to get
+    indices of end-points and avoid checking several times in the
+    event queue when the same vertex has several incident edges.
+
+    Variant with action event points (if a curve passed through an
+    action point, it will be split).
+
+    \param edges A range of edges
+    \param accessor An object providing, for a value_type `e` of
+           range `edges`, the following methods:
+     - size_t             min_end_index(e) -> the index of the min end of curve c
+     - size_t             max_end_index(e) -> the index of the max end of curve c
+     - X_monotone_curve_2 curve(e)         -> the x-monotone curve associated to e
+     - size_t             nb_vertices()    -> the total number of points/events
+     - void               before_init()    -> called before initialization
+     - void               after_init()     -> called after initialization
+    \param points_begin An iterator for the first point in the range.
+    \param points_end A past-the-end iterator for this range.
+    \pre The value-type of PointInputIterator is the
+         traits-class Point_2.
+  */
+  template <typename EdgeRange, typename Accessor,
+            typename PointInputIterator>
+  void indexed_sweep (const EdgeRange& edges,
+                      const Accessor& accessor,
+                      PointInputIterator action_points_begin,
+                      PointInputIterator action_points_end)
+  {
+    m_visitor->before_sweep();
+    accessor.before_init();
+    _init_indexed_sweep(edges, accessor);
+    accessor.after_init();
+    _init_points(action_points_begin, action_points_end, Event::ACTION);
+    _sweep();
+    _complete_sweep();
+    m_visitor->after_sweep();
+  }
+
   /*! Get an iterator for the first subcurve in the status line. */
   Status_line_iterator status_line_begin() { return m_statusLine.begin(); }
 
@@ -393,7 +450,33 @@ protected:
       _init_curve(*cit, index);
   }
 
-  /*! Initiliaze the sweep algorithm. */
+  /*! Create a Subcurve object and two Event objects for each curve. */
+  template <typename EdgeRange, typename Accessor>
+  void _init_indexed_curves(const EdgeRange& edges,
+                            const Accessor& accessor)
+  {
+    std::vector<Event_queue_iterator> events (accessor.nb_vertices());
+
+    unsigned int index = 0;
+    for (const auto& e : edges)
+    {
+      std::size_t max_end = accessor.max_end_index(e);
+      std::size_t min_end = accessor.min_end_index(e);
+      const X_monotone_curve_2& curve = accessor.curve (e);
+
+      // Construct and initialize a subcurve object.
+      std::allocator_traits<Subcurve_alloc>::construct(m_subCurveAlloc, m_subCurves + index, m_masterSubcurve );
+      (m_subCurves + index)->set_hint(this->m_statusLine.end());
+      (m_subCurves + index)->init (curve);
+
+      _init_curve_end(curve, ARR_MAX_END, m_subCurves + index, events, max_end);
+      _init_curve_end(curve, ARR_MIN_END, m_subCurves + index, events, min_end);
+
+      ++ index;
+    }
+  }
+
+  /*! Initialize the sweep algorithm. */
   template <typename CurveInputIterator>
   void _init_sweep(CurveInputIterator curves_begin,
                    CurveInputIterator curves_end)
@@ -404,6 +487,17 @@ protected:
     _init_curves(curves_begin, curves_end);     // initialize the curves
   }
 
+  /*! Initialize the sweep algorithm. */
+  template <typename EdgeRange, typename Accessor>
+  void _init_indexed_sweep(const EdgeRange& edges,
+                           const Accessor& accessor)
+  {
+    m_num_of_subCurves =
+      static_cast<unsigned int>(std::distance(edges.begin(), edges.end()));
+    _init_structures();
+    _init_indexed_curves(edges, accessor);     // initialize the curves
+  }
+
   /*! Initialize the data structures for the sweep-line algorithm. */
   virtual void _init_structures();
 
@@ -428,7 +522,14 @@ protected:
    * \param sc The subcurve corresponding to cv.
    */
   void _init_curve_end(const X_monotone_curve_2& cv, Arr_curve_end ind,
-                       Subcurve* sc);
+                       Subcurve* sc, Arr_all_sides_oblivious_tag);
+  void _init_curve_end(const X_monotone_curve_2& cv, Arr_curve_end ind,
+                       Subcurve* sc, Arr_not_all_sides_oblivious_tag);
+
+  // Variant keeping track of indexed events
+  void _init_curve_end(const X_monotone_curve_2& cv, Arr_curve_end ind,
+                       Subcurve* sc,
+                       std::vector<Event_queue_iterator>& events, std::size_t index);
 
   /*! Handle the subcurves that are to the left of the event point (i.e.,
    * subcurves that we are done with).
@@ -439,7 +540,9 @@ protected:
    * Such an event is usually the left endpoint of its incident right
    * subcurves, and we locate their position in the status line.
    */
-  void _handle_event_without_left_curves();
+  void _handle_event_without_left_curves(Arr_all_sides_oblivious_tag);
+  void _handle_event_without_left_curves(Arr_all_sides_not_finite_tag);
+  void _handle_event_without_left_curves(Arr_not_all_sides_not_finite_tag);
 
   /*! Sort the left subcurves of an event point according to their order in
    * their status line (no geometric comparisons are needed).
@@ -452,7 +555,7 @@ protected:
   /*! Add a subcurve to the right of an event point.
    * \param event The event point.
    * \param curve The subcurve to add.
-   * \return (true) if an overlap occured; (false) otherwise.
+   * \return (true) if an overlap occurred; (false) otherwise.
    */
   virtual bool _add_curve_to_right(Event* event, Subcurve* curve);
 
@@ -500,7 +603,15 @@ protected:
   std::pair<Event*, bool> _push_event(const Point_2& pt, Attribute type,
                                       Arr_parameter_space ps_x,
                                       Arr_parameter_space ps_y,
-                                      Subcurve* sc = NULL);
+                                      Subcurve* sc = nullptr);
+
+  // Variant keeping track of indexed events
+  std::pair<Event*, bool> _push_event(const Point_2& pt, Attribute type,
+                                      Arr_parameter_space ps_x,
+                                      Arr_parameter_space ps_y,
+                                      Subcurve* sc,
+                                      std::vector<Event_queue_iterator>& events,
+                                      std::size_t index);
 
   /*! Push an event point associated with a curve end into the event queue.
    * \param cv The x-monotone curve.
@@ -518,7 +629,18 @@ protected:
                                       Attribute type,
                                       Arr_parameter_space ps_x,
                                       Arr_parameter_space ps_y,
-                                      Subcurve* sc = NULL);
+                                      Subcurve* sc = nullptr);
+
+  // Variant keeping track of indexed events
+  std::pair<Event*, bool> _push_event(const X_monotone_curve_2& cv,
+                                      Arr_curve_end ind,
+                                      Attribute type,
+                                      Arr_parameter_space ps_x,
+                                      Arr_parameter_space ps_y,
+                                      Subcurve* sc,
+                                      const Point_2& pt,
+                                      std::vector<Event_queue_iterator>& events,
+                                      std::size_t index);
 
   void _update_event_at_open_boundary(Event* e,
                                       const X_monotone_curve_2& cv,
@@ -526,7 +648,7 @@ protected:
                                       bool is_new)
   {
     _update_event_at_open_boundary(e, cv, ind, is_new,
-                                   Are_all_sides_oblivious_category());
+                                   All_sides_oblivious_category());
   }
 
   void _update_event_at_open_boundary(Event* e,
