@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Optimal_transportation_reconstruction_2/include/CGAL/OTR_2/Reconstruction_triangulation_2.h $
-// $Id: Reconstruction_triangulation_2.h a231468 2019-02-08T09:53:20+01:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Optimal_transportation_reconstruction_2/include/CGAL/OTR_2/Reconstruction_triangulation_2.h $
+// $Id: Reconstruction_triangulation_2.h d6ec19226dc 2022-12-22T14:22:40Z Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando de Goes, Pierre Alliez, Ivo Vigan, Clément Jamin
 
@@ -79,7 +70,7 @@ template<
   Reconstruction_vertex_base_2<Traits_>,
   Reconstruction_face_base_2<Traits_> > >
 class Reconstruction_triangulation_2
-  : public Delaunay_triangulation_2<Traits_, Tds_> 
+  : public Delaunay_triangulation_2<Traits_, Tds_>
 {
 public:
 
@@ -108,10 +99,10 @@ public:
 
   typedef std::map<Vertex_handle, Vertex_handle,
       less_Vertex_handle<Vertex_handle> > Vertex_handle_map;
-  typedef std::map<Face_handle, Face_handle, 
+  typedef std::map<Face_handle, Face_handle,
                    less_Face_handle<Face_handle> > Face_handle_map;
 
-  typedef std::set<Vertex_handle, 
+  typedef std::set<Vertex_handle,
                    less_Vertex_handle<Vertex_handle> > Vertex_handle_set;
   typedef std::set<Edge, less_Edge<Edge> > Edge_set;
 
@@ -119,14 +110,14 @@ public:
 
   typedef OTR_2::Cost<FT> Cost_;
   typedef OTR_2::Sample<Traits_> Sample_;
-  typedef std::vector<Sample_*> Sample_vector;
+  typedef std::vector<int> Sample_vector;
   typedef typename Sample_vector::const_iterator Sample_vector_const_iterator;
 
   typedef OTR_2::Sample_with_priority<Sample_> PSample;
   typedef std::priority_queue<PSample, boost::container::deque<PSample>,
       OTR_2::greater_priority<PSample> > SQueue;
 
-  typedef Reconstruction_edge_2<FT, Edge, 
+  typedef Reconstruction_edge_2<FT, Edge,
                                 Vertex_handle, Face_handle> Rec_edge_2;
 
   using Base::geom_traits;
@@ -144,12 +135,13 @@ public:
   >
   > MultiIndex;
 
+  std::vector<Sample_>& m_samples;
   FT m_factor; // ghost vs solid
   mutable Random rng;
 
 public:
-  Reconstruction_triangulation_2(Traits_ traits = Traits_())
-  : Base(traits), m_factor(1.)
+  Reconstruction_triangulation_2(std::vector<Sample_>& samples, Traits_ traits = Traits_())
+  : Base(traits), m_samples(samples), m_factor(1.)
   {
   }
 
@@ -341,14 +333,14 @@ public:
   }
 
   void collect_samples_from_edge(
-    const Edge& edge, Sample_vector& samples) const 
+    const Edge& edge, Sample_vector& samples) const
   {
     const Sample_vector& edge_samples = edge.first->samples(edge.second);
     samples.insert(samples.end(), edge_samples.begin(), edge_samples.end());
   }
 
   void collect_samples_from_vertex(
-    Vertex_handle vertex, Sample_vector& samples, bool cleanup) const 
+    Vertex_handle vertex, Sample_vector& samples, bool cleanup) const
   {
     Face_circulator fcirc = Base::incident_faces(vertex);
     Face_circulator fend = fcirc;
@@ -369,11 +361,11 @@ public:
       if (cleanup)
         face->clean_all_samples();
     }
-    Sample_* sample = vertex->sample();
-    if (sample)
+    int sample = vertex->sample();
+    if (sample != -1)
       samples.push_back(sample);
     if (cleanup)
-      vertex->set_sample(NULL);
+      vertex->set_sample(-1);
   }
 
   void collect_all_samples(Sample_vector& samples) const {
@@ -400,7 +392,7 @@ public:
     }
     for (Finite_vertices_iterator vi = Base::finite_vertices_begin();
         vi != Base::finite_vertices_end(); ++vi) {
-      vi->set_sample(NULL);
+      vi->set_sample(-1);
     }
   }
 
@@ -474,15 +466,15 @@ public:
     typename Sample_vector::const_iterator it;
     const Sample_vector& samples0 = edge.first->samples(edge.second);
     for (it = samples0.begin(); it != samples0.end(); ++it) {
-      Sample_* sample = *it;
-      mass += sample->mass();
+      const Sample_ & sample = m_samples[* it];
+      mass += sample.mass();
     }
 
     Edge twin = twin_edge(edge);
     const Sample_vector& samples1 = twin.first->samples(twin.second);
     for (it = samples1.begin(); it != samples1.end(); ++it) {
-      Sample_* sample = *it;
-      mass += sample->mass();
+      const Sample_& sample = m_samples[* it];
+      mass += sample.mass();
     }
 
     set_mass(edge, mass);
@@ -520,15 +512,15 @@ public:
     typename Sample_vector::const_iterator it;
     const Sample_vector& samples0 = edge.first->samples(edge.second);
     for (it = samples0.begin(); it != samples0.end(); ++it) {
-      Sample_* sample = *it;
-      squeue.push(PSample(sample, sample->coordinate()));
+      const Sample_& sample = m_samples[* it];
+      squeue.push(PSample(*it, sample.coordinate()));
     }
 
     Edge twin = twin_edge(edge);
     const Sample_vector& samples1 = twin.first->samples(twin.second);
     for (it = samples1.begin(); it != samples1.end(); ++it) {
-      Sample_* sample = *it;
-      squeue.push(PSample(sample, 1.0 - sample->coordinate()));
+      const Sample_& sample = m_samples[* it];
+      squeue.push(PSample(*it, 1.0 - sample.coordinate()));
     }
   }
 
@@ -546,13 +538,13 @@ public:
       PSample psample = squeue.top();
       squeue.pop();
 
-      FT mass = psample.sample()->mass();
+      FT mass = m_samples[psample.sample()].mass();
       FT coord = psample.priority() * L;
       FT bin = mass * coef;
       FT center = start + FT(0.5) * bin;
       FT pos = coord - center;
 
-      FT norm2 = psample.sample()->distance2();
+      FT norm2 = m_samples[psample.sample()].distance2();
       FT tang2 = bin * bin / 12 + pos * pos;
 
       sum.add(Cost_(norm2, tang2), mass);
@@ -575,15 +567,15 @@ public:
     Cost_ sum;
     for (Sample_vector_const_iterator it = samples.begin();
         it != samples.end(); ++it) {
-      Sample_* sample = *it;
-      FT mass = sample->mass();
-      const Point& query = sample->point();
+      const Sample_& sample =  m_samples[* it];
+      FT mass = sample.mass();
+      const Point& query = sample.point();
 
       FT Ds = geom_traits().compute_squared_distance_2_object()(query, ps);
       FT Dt = geom_traits().compute_squared_distance_2_object()(query, pt);
       FT dist2 = ((std::min))(Ds, Dt);
 
-      FT norm2 = sample->distance2();
+      FT norm2 = sample.distance2();
       FT tang2 = dist2 - norm2;
 
       sum.add(Cost_(norm2, tang2), mass);
@@ -598,7 +590,7 @@ public:
   template<class Iterator> // value_type = Sample_*
   void assign_samples(Iterator begin, Iterator end) {
     for (Iterator it = begin; it != end; ++it) {
-      Sample_* sample = *it;
+      int sample = *it;
       assign_sample(sample);
     }
   }
@@ -606,13 +598,13 @@ public:
   template<class Iterator> // value_type = Sample_*
   void assign_samples_brute_force(Iterator begin, Iterator end) {
     for (Iterator it = begin; it != end; ++it) {
-      Sample_* sample = *it;
+      int sample = *it;
       assign_sample_brute_force(sample);
     }
   }
 
-  bool assign_sample(Sample_* sample) {
-    const Point& point = sample->point();
+  bool assign_sample(int sample) {
+    const Point& point = m_samples[sample].point();
     Face_handle face = Base::locate(point);
 
     if (face == Face_handle() || Base::is_infinite(face)) {
@@ -631,8 +623,9 @@ public:
     return true;
   }
 
-  bool assign_sample_brute_force(Sample_* sample) {
-    const Point& point = sample->point();
+  bool assign_sample_brute_force(int sample_index) {
+    const Sample_& sample = m_samples[sample_index];
+    const Point& point = sample.point();
     Face_handle nearest_face = Face_handle();
     for (Finite_faces_iterator fi = Base::finite_faces_begin();
         fi != Base::finite_faces_end(); ++fi) {
@@ -650,12 +643,12 @@ public:
 
     Vertex_handle vertex = find_nearest_vertex(point, nearest_face);
     if (vertex != Vertex_handle()) {
-      assign_sample_to_vertex(sample, vertex);
+      assign_sample_to_vertex(sample_index, vertex);
       return true;
     }
 
     Edge edge = find_nearest_edge(point, nearest_face);
-    assign_sample_to_edge(sample, edge);
+    assign_sample_to_edge(sample_index, edge);
     return true;
   }
 
@@ -697,23 +690,24 @@ public:
     return nearest;
   }
 
-  void assign_sample_to_vertex(Sample_* sample, Vertex_handle vertex) const {
+  void assign_sample_to_vertex(int sample_index, Vertex_handle vertex) const {
     /*if (vertex->sample()) {
       std::cout << "assign to vertex: vertex already has sample"
           << std::endl;
     }*/
-
-    sample->distance2() = FT(0);
-    sample->coordinate() = FT(0);
-    vertex->set_sample(sample);
+    Sample_& sample = m_samples[sample_index];
+    sample.distance2() = FT(0);
+    sample.coordinate() = FT(0);
+    vertex->set_sample(sample_index);
   }
 
-  void assign_sample_to_edge(Sample_* sample, const Edge& edge) const {
+  void assign_sample_to_edge(int sample_index, const Edge& edge) const {
+    Sample_& sample = m_samples[sample_index];
     Segment segment = get_segment(edge);
-    const Point& query = sample->point();
-    sample->distance2() = compute_distance2(query, segment);
-    sample->coordinate() = compute_coordinate(query, segment);
-    edge.first->add_sample(edge.second, sample);
+    const Point& query = sample.point();
+    sample.distance2() = compute_distance2(query, segment);
+    sample.coordinate() = compute_coordinate(query, segment);
+    edge.first->add_sample(edge.second, sample_index);
   }
 
   FT compute_distance2(const Point& query, const Segment& segment) const {
@@ -730,7 +724,7 @@ public:
     const Point& p1 = segment.target();
     Vector p0p1 = geom_traits().construct_vector_2_object()(p0, p1);
     Vector p0q  = geom_traits().construct_vector_2_object()(p0, q);
-    
+
     FT t = geom_traits().compute_scalar_product_2_object()(p0q, p0p1)
          / geom_traits().compute_scalar_product_2_object()(p0p1, p0p1);
     return t; // [0,1]
@@ -796,8 +790,7 @@ public:
       pt, geom_traits().construct_vector_2_object()(pt, ps));
 
     boost::optional<FT> Dqt;
-    typename CGAL::cpp11::result_of<typename Traits_::Intersect_2(Line, Line)>::type
-      result = intersection(lab, lts);
+    const auto result = intersection(lab, lts);
     if (result)
     {
       const Point* iq = boost::get<Point>(&(*result));
@@ -934,7 +927,7 @@ public:
         return false;
     }
 
-    return true;  
+    return true;
   }
 
   // COLLAPSE //
@@ -1075,7 +1068,7 @@ public:
         return false;
       }
 
-      FT value = Dbc <= 0 ? 1 : 2*Dbc; // value used if Dbd or Dac are +infinity
+      FT value = Dbc <= 0 ? FT(1) : 2*Dbc; // value used if Dbd or Dac are +infinity
       if ( !is_infinity(Dac) )
       {
         if ( !is_infinity(Dbd))
@@ -1092,7 +1085,7 @@ public:
       // if ( max(Dac,Dbd)+CGAL_EPS < Dbc )
       if (value + CGAL_EPS < Dbc)
       {
-			/*
+                        /*
         std::cerr.precision(10);
         std::cerr << "--- Flip makes kernel worse ---" << std::endl;
         std::cerr << Dac << " or " << Dbd << " vs " << Dbc << std::endl;
@@ -1102,7 +1095,7 @@ public:
         std::cerr << "d: " << d->point() << std::endl;
         std::cerr << "t: " << target->point() << std::endl;
         std::cerr << "diff = " << Dbc - (std::max)(Dac, Dbd) << std::endl;
-				*/
+                                */
         return false;
       }
 
