@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Principal_component_analysis/include/CGAL/PCA_util_Eigen.h $
-// $Id: PCA_util_Eigen.h d3e42be 2019-07-17T15:36:30+02:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Principal_component_analysis/include/CGAL/PCA_util_Eigen.h $
+// $Id: PCA_util_Eigen.h be85b37b374 2023-04-04T10:42:43+01:00 Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Pierre Alliez and Sylvain Pion and Ankit Gupta and Simon Giraudot
 
@@ -26,12 +17,19 @@
 #include <CGAL/Eigen_diagonalize_traits.h>
 #include <CGAL/Default_diagonalize_traits.h>
 #include <CGAL/Dimension.h>
+#include <CGAL/Subiterator.h>
 
 namespace CGAL {
 
 namespace internal {
 
-// assemble covariance matrix from a triangle set 
+template <typename FT>
+FT approximate_cbrt (const FT& x)
+{
+  return static_cast<FT>(std::cbrt (CGAL::to_double(x)));
+}
+
+// assemble covariance matrix from a triangle set
 template < typename InputIterator,
            typename K >
 void
@@ -48,19 +46,19 @@ assemble_covariance_matrix_3(InputIterator first,
   typedef typename K::Triangle_3  Triangle;
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all triangles and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   Matrix moment;
-  moment << 1.0/12.0, 1.0/24.0, 1.0/24.0,
-            1.0/24.0, 1.0/12.0, 1.0/24.0,
-            1.0/24.0, 1.0/24.0, 1.0/12.0;
+  moment << FT(1.0/12.0), FT(1.0/24.0), FT(1.0/24.0),
+            FT(1.0/24.0), FT(1.0/12.0), FT(1.0/24.0),
+            FT(1.0/24.0), FT(1.0/24.0), FT(1.0/12.0);
 
   for(InputIterator it = first;
       it != beyond;
@@ -72,21 +70,21 @@ assemble_covariance_matrix_3(InputIterator first,
 
     // defined for convenience.
     Matrix transformation;
-    transformation << t[0].x(), t[1].x(), t[2].x(), 
+    transformation << t[0].x(), t[1].x(), t[2].x(),
                       t[0].y(), t[1].y(), t[2].y(),
                       t[0].z(), t[1].z(), t[2].z();
 
-    FT area = std::sqrt(t.squared_area());
+    FT area = CGAL::approximate_sqrt(t.squared_area());
 
     // skip zero measure primitives
     if(area == (FT)0.0)
       continue;
 
     // Find the 2nd order moment for the triangle wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = 2 * area * transformation * moment * transformation.transpose();
-    
+
     // and add to covariance matrix
     covariance[0] += transformation(0,0);
     covariance[1] += transformation(1,0);
@@ -98,18 +96,20 @@ assemble_covariance_matrix_3(InputIterator first,
     mass += area;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.z() * c.x());
-  covariance[3] += mass * (-1.0 * c.y() * c.y());
-  covariance[4] += mass * (-1.0 * c.z() * c.y());
-  covariance[5] += mass * (-1.0 * c.z() * c.z());
+  covariance[0] += -mass * (c.x() * c.x());
+  covariance[1] += -mass * (c.x() * c.y());
+  covariance[2] += -mass * (c.z() * c.x());
+  covariance[3] += -mass * (c.y() * c.y());
+  covariance[4] += -mass * (c.z() * c.y());
+  covariance[5] += -mass * (c.z() * c.z());
 
 }
 
-// assemble covariance matrix from a cuboid set 
+// assemble covariance matrix from a cuboid set
 template < typename InputIterator,
            typename K >
 void
@@ -126,15 +126,15 @@ assemble_covariance_matrix_3(InputIterator first,
   typedef typename K::Iso_cuboid_3    Iso_cuboid;
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   // final combined covariance matrix for all cuboids and their combined mass
   FT mass = (FT)0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   Matrix moment;
   moment << (FT)(1.0/3.0), (FT)(1.0/4.0), (FT)(1.0/4.0),
             (FT)(1.0/4.0), (FT)(1.0/3.0), (FT)(1.0/4.0),
@@ -150,28 +150,35 @@ assemble_covariance_matrix_3(InputIterator first,
 
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
-    FT x0 = t[0].x();
-    FT y0 = t[0].y();
-    FT z0 = t[0].z();
-    FT delta[9] = {t[0].x(), t[1].x(), t[2].x(), 
-                   t[0].y(), t[1].y(), t[2].y(),
-                   t[0].z(), t[1].z(), t[2].z()};
-    Matrix transformation (delta);
-    FT volume = t.volume();
+    FT x0 = t.xmin();
+    FT y0 = t.ymin();
+    FT z0 = t.zmin();
+
+    FT x1 = t.xmax();
+    FT y1 = t.ymax();
+    FT z1 = t.zmax();
+
+    Matrix transformation;
+    transformation << x1 - x0, 0      , 0      ,
+                      0      , y1 - y0, 0      ,
+                      0      , 0      , z1 - z0;
+
+    FT volume = (x1-x0) * (y1-y0) * (z1-z0);
 
     // skip zero measure primitives
     if(volume == (FT)0.0)
       continue;
+    CGAL_assertion(volume > 0.0);
 
     // Find the 2nd order moment for the cuboid wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = volume * transformation * moment * transformation.transpose();
-    
+
     // Translate the 2nd order moment to the minimum corner (x0,y0,z0) of the cuboid.
-    FT xav0 = (delta[0] + delta[1] + delta[2])/4.0;
-    FT yav0 = (delta[3] + delta[4] + delta[5])/4.0;
-    FT zav0 = (delta[6] + delta[7] + delta[8])/4.0;
+    FT xav0 = (x1 - x0) / FT(2.0);
+    FT yav0 = (y1 - y0) / FT(2.0);
+    FT zav0 = (z1 - z0) / FT(2.0);
 
     // and add to covariance matrix
     covariance[0] += transformation(0,0) + volume * (2*x0*xav0 + x0*x0);
@@ -184,6 +191,8 @@ assemble_covariance_matrix_3(InputIterator first,
     mass += volume;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
   covariance[0] += mass * (- c.x() * c.x());
@@ -194,12 +203,12 @@ assemble_covariance_matrix_3(InputIterator first,
   covariance[5] += mass * (- c.z() * c.z());
 }
 
-// assemble covariance matrix from a cuboid set 
+// assemble covariance matrix from a cuboid set
 template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Eigen_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
@@ -207,19 +216,45 @@ assemble_covariance_matrix_3(InputIterator first,
                              const CGAL::Dimension_tag<2>&,
                              const Eigen_diagonalize_traits<typename K::FT, 3>&)
 {
+#if 1
+  typedef typename K::FT              FT;
+  typedef typename K::Iso_cuboid_3    Iso_cuboid;
+  typedef typename K::Triangle_3      Triangle;
+  auto converter = [](const Iso_cuboid& c, int idx) -> Triangle
+    {
+      // Decomposition of 6 faces of the cuboid into 12 triangles
+      static constexpr std::array<std::array<int, 3>, 12 > indices
+      = {{ { 0, 1, 2 }, { 0, 2, 3 }, { 2, 3, 4 }, { 2, 4, 7 },
+           { 3, 4, 5 }, { 3, 5, 0 }, { 4, 5, 6 }, { 4, 6, 7 },
+           { 5, 6, 1 }, { 5, 1, 0 }, { 6, 7, 2 }, { 6, 2, 1 } }};
+      return Triangle (c[indices[idx][0]], c[indices[idx][1]], c[indices[idx][2]]);
+    };
+
+  assemble_covariance_matrix_3
+    (make_subiterator<Triangle, 12> (first, converter),
+     make_subiterator<Triangle, 12> (beyond),
+     covariance, c, K(), (Triangle*)nullptr, CGAL::Dimension_tag<2>(),
+     Eigen_diagonalize_traits<FT, 3>());
+
+#else
+  // This variant uses the standard formulas but seems to be broken
+  // (line/plane estimated appear to be wrong). In the absence of a
+  // reliable fix so far, the above workaround applying PCA to a
+  // decomposition of the cuboid into triangles is used.
+
   typedef typename K::FT FT;
   typedef typename K::Iso_cuboid_3 Iso_cuboid;
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all cuboids and their combined mass
   FT mass = (FT)0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   Matrix moment;
   moment << (FT)(7.0/3.0), (FT)1.5,       (FT)1.5,
             (FT)1.5,       (FT)(7.0/3.0), (FT)1.5,
@@ -234,36 +269,35 @@ assemble_covariance_matrix_3(InputIterator first,
     const Iso_cuboid& t = *it;
 
     // defined for convenience.
-    FT x0 = t[0].x();
-    FT y0 = t[0].y();
-    FT z0 = t[0].z();
-    FT delta[9] = {t[1].x()-x0, t[3].x()-x0, t[5].x()-x0, 
-                   t[1].y()-y0, t[3].y()-y0, t[5].y()-y0,
-                   t[1].z()-z0, t[3].z()-z0, t[5].z()-z0};
-    Matrix transformation (delta);
-    FT area = std::pow(delta[0]*delta[0] + delta[3]*delta[3] +
-                  delta[6]*delta[6],1/3.0)*std::pow(delta[1]*delta[1] +
-                  delta[4]*delta[4] + delta[7]*delta[7],1/3.0)*2 +
-                  std::pow(delta[0]*delta[0] + delta[3]*delta[3] +
-                  delta[6]*delta[6],1/3.0)*std::pow(delta[2]*delta[2] +
-                  delta[5]*delta[5] + delta[8]*delta[8],1/3.0)*2 +
-                  std::pow(delta[1]*delta[1] + delta[4]*delta[4] +
-                  delta[7]*delta[7],1/3.0)*std::pow(delta[2]*delta[2] +
-                  delta[5]*delta[5] + delta[8]*delta[8],1/3.0)*2;
+    FT x0 = t.xmin();
+    FT y0 = t.ymin();
+    FT z0 = t.zmin();
+
+    FT x1 = t.xmax();
+    FT y1 = t.ymax();
+    FT z1 = t.zmax();
+
+    Matrix transformation;
+    transformation << x1 - x0, 0      , 0      ,
+                      0      , y1 - y0, 0      ,
+                      0      , 0      , z1 - z0;
+
+    FT area = FT(2) * ((x1-x0)*(y1-y0) + (x1-x0)*(z1-z0) + (y1-y0)*(z1-z0));
 
     // skip zero measure primitives
     if(area == (FT)0.0)
       continue;
+    CGAL_assertion(area > 0.0);
 
     // Find the 2nd order moment for the cuboid wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = area * transformation * moment * transformation.transpose();
-    
+
     // Translate the 2nd order moment to the minimum corner (x0,y0,z0) of the cuboid.
-    FT xav0 = (delta[0] + delta[1] + delta[2])/4.0;
-    FT yav0 = (delta[3] + delta[4] + delta[5])/4.0;
-    FT zav0 = (delta[6] + delta[7] + delta[8])/4.0;
+    FT xav0 = (x1 - x0) / (2.0);
+    FT yav0 = (y1 - y0) / (2.0);
+    FT zav0 = (z1 - z0) / (2.0);
 
     // and add to covariance matrix
     covariance[0] += transformation(0,0) + area * (2*x0*xav0 + x0*x0);
@@ -276,23 +310,25 @@ assemble_covariance_matrix_3(InputIterator first,
     mass += area;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.z() * c.x());
-  covariance[3] += mass * (-1.0 * c.y() * c.y());
-  covariance[4] += mass * (-1.0 * c.z() * c.y());
-  covariance[5] += mass * (-1.0 * c.z() * c.z());
-
+  covariance[0] += -mass * (c.x() * c.x());
+  covariance[1] += -mass * (c.x() * c.y());
+  covariance[2] += -mass * (c.z() * c.x());
+  covariance[3] += -mass * (c.y() * c.y());
+  covariance[4] += -mass * (c.z() * c.y());
+  covariance[5] += -mass * (c.z() * c.z());
+#endif
 }
 
-// assemble covariance matrix from a sphere set 
+// assemble covariance matrix from a sphere set
 template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Eigen_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K&,                     // kernel
@@ -304,19 +340,19 @@ assemble_covariance_matrix_3(InputIterator first,
   typedef typename K::Sphere_3  Sphere;
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all spheres and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   Matrix moment;
-  moment << 4.0/15.0, 0.0,      0.0,
-            0.0,      4.0/15.0, 0.0,
-            0.0,      0.0,      4.0/15.0;
+  moment << FT(4.0/15.0), FT(0.0),      FT(0.0),
+            FT(0.0),      FT(4.0/15.0), FT(0.0),
+            FT(0.0),      FT(0.0),      FT(4.0/15.0);
 
   for(InputIterator it = first;
       it != beyond;
@@ -327,22 +363,23 @@ assemble_covariance_matrix_3(InputIterator first,
     const Sphere& t = *it;
 
     // defined for convenience.
-    FT radius = std::sqrt(t.squared_radius());
+    FT radius = CGAL::approximate_sqrt(t.squared_radius());
     Matrix transformation;
-    transformation << radius, 0.0, 0.0, 
+    transformation << radius, 0.0, 0.0,
                       0.0, radius, 0.0,
                       0.0, 0.0, radius;
-    FT volume = (FT)(4.0/3.0) * radius * t.squared_radius();
+    FT volume =  radius * t.squared_radius();
 
     // skip zero measure primitives
     if(volume == (FT)0.0)
       continue;
 
     // Find the 2nd order moment for the sphere wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
-    transformation = (3.0/4.0) * volume * transformation * moment * transformation.transpose();
-    
+    transformation = volume * transformation * moment * transformation.transpose();
+
+    volume *= FT(4.0 / 3.0);
     // Translate the 2nd order moment to the center of the sphere.
     FT x0 = t.center().x();
     FT y0 = t.center().y();
@@ -359,22 +396,24 @@ assemble_covariance_matrix_3(InputIterator first,
     mass += volume;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.z() * c.x());
-  covariance[3] += mass * (-1.0 * c.y() * c.y());
-  covariance[4] += mass * (-1.0 * c.z() * c.y());
-  covariance[5] += mass * (-1.0 * c.z() * c.z());
+  covariance[0] += -mass * (c.x() * c.x());
+  covariance[1] += -mass * (c.x() * c.y());
+  covariance[2] += -mass * (c.z() * c.x());
+  covariance[3] += -mass * (c.y() * c.y());
+  covariance[4] += -mass * (c.z() * c.y());
+  covariance[5] += -mass * (c.z() * c.z());
 
 }
-// assemble covariance matrix from a sphere set 
+// assemble covariance matrix from a sphere set
 template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Eigen_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K&,                     // kernel
@@ -386,19 +425,19 @@ assemble_covariance_matrix_3(InputIterator first,
   typedef typename K::Sphere_3  Sphere;
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all spheres and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   Matrix moment;
-  moment << 4.0/3.0, 0.0,     0.0,
-            0.0,     4.0/3.0, 0.0,
-            0.0,     0.0,     4.0/3.0;
+  moment << FT(4.0/3.0), FT(0.0),     FT(0.0),
+            FT(0.0),     FT(4.0/3.0), FT(0.0),
+            FT(0.0),     FT(0.0),     FT(4.0/3.0);
 
   for(InputIterator it = first;
       it != beyond;
@@ -410,22 +449,23 @@ assemble_covariance_matrix_3(InputIterator first,
 
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
-    FT radius = std::sqrt(t.squared_radius());
+    FT radius = CGAL::approximate_sqrt(t.squared_radius());
     Matrix transformation;
-    transformation << radius, 0.0,    0.0, 
+    transformation << radius, 0.0,    0.0,
                       0.0,    radius, 0.0,
                       0.0,    0.0,    radius;
-    FT area = (FT)4.0 * t.squared_radius();
+    FT area = t.squared_radius();
 
     // skip zero measure primitives
     if(area == (FT)0.0)
       continue;
 
     // Find the 2nd order moment for the sphere wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
-    transformation = (1.0/4.0) * area * transformation * moment * transformation.transpose();
-    
+    transformation = area * transformation * moment * transformation.transpose();
+
+    area *= FT(4.0);
     // Translate the 2nd order moment to the center of the sphere.
     FT x0 = t.center().x();
     FT y0 = t.center().y();
@@ -442,23 +482,25 @@ assemble_covariance_matrix_3(InputIterator first,
     mass += area;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.z() * c.x());
-  covariance[3] += mass * (-1.0 * c.y() * c.y());
-  covariance[4] += mass * (-1.0 * c.z() * c.y());
-  covariance[5] += mass * (-1.0 * c.z() * c.z());
+  covariance[0] += -mass * (c.x() * c.x());
+  covariance[1] += -mass * (c.x() * c.y());
+  covariance[2] += -mass * (c.z() * c.x());
+  covariance[3] += -mass * (c.y() * c.y());
+  covariance[4] += -mass * (c.z() * c.y());
+  covariance[5] += -mass * (c.z() * c.z());
 
 }
 
-// assemble covariance matrix from a tetrahedron set 
+// assemble covariance matrix from a tetrahedron set
 template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Eigen_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
@@ -473,16 +515,16 @@ assemble_covariance_matrix_3(InputIterator first,
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
   typedef typename Eigen::Matrix<FT, 3, 1> Vector;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
-  // assemble 2nd order moment about the origin.  
+  //     5
+  // assemble 2nd order moment about the origin.
   Matrix moment;
-  moment << 1.0/60.0,  1.0/120.0, 1.0/120.0,
-            1.0/120.0, 1.0/60.0,  1.0/120.0,
-            1.0/120.0, 1.0/120.0, 1.0/60.0;
+  moment << FT(1.0/60.0),  FT(1.0/120.0), FT(1.0/120.0),
+            FT(1.0/120.0), FT(1.0/60.0),  FT(1.0/120.0),
+            FT(1.0/120.0), FT(1.0/120.0), FT(1.0/60.0);
 
   Matrix accum; // zero by default
   accum << 0, 0, 0, 0, 0, 0, 0, 0, 0;
@@ -496,7 +538,7 @@ assemble_covariance_matrix_3(InputIterator first,
     FT z0 = t[0].z();
 
     Matrix transformation;
-    transformation << t[1].x()-x0, t[2].x()-x0, t[3].x()-x0, 
+    transformation << t[1].x()-x0, t[2].x()-x0, t[3].x()-x0,
                       t[1].y()-y0, t[2].y()-y0, t[3].y()-y0,
                       t[1].z()-z0, t[2].z()-z0, t[3].z()-z0;
     FT volume = CGAL::abs(t.volume());
@@ -511,31 +553,31 @@ assemble_covariance_matrix_3(InputIterator first,
     Vector_3 d = t[0] - c; // delta
     Vector vec_d;
     vec_d << d.x(), d.y(), d.z();
-      
+
     Point_3 C = CGAL::centroid(t) - (t[0] - CGAL::ORIGIN); // careful, local centroid
     Vector vec_c;
     vec_c << C.x(), C.y(), C.z();
-    
+
     Matrix M = vec_c * vec_d.transpose() + vec_d * vec_c.transpose() + vec_d * vec_d.transpose();
 
     accum += transformation + volume * M;
   }
-  
+
   covariance[0] = accum(0,0);
   covariance[1] = accum(1,0);
   covariance[2] = accum(2,0);
   covariance[3] = accum(1,1);
   covariance[4] = accum(2,1);
   covariance[5] = accum(2,2);
-  
+
 }
 
-// assemble covariance matrix from a segment set 
+// assemble covariance matrix from a segment set
 template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Eigen_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& ,                    // kernel
@@ -547,19 +589,19 @@ assemble_covariance_matrix_3(InputIterator first,
   typedef typename K::Segment_3  Segment;
   typedef typename Eigen::Matrix<FT, 3, 3> Matrix;
 
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0 1 2
   //   3 4
-  //     5          
+  //     5
   //Final combined covariance matrix for all segments and their combined mass
   FT mass = 0.0;
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   Matrix moment;
-  moment << 1.0, 0.5, 0.0,
-            0.5, 1.0, 0.0,
-            0.0, 0.0, 0.0;
+  moment << FT(1.0/3.0), FT(0.5/3.0), FT(0.0),
+            FT(0.5/3.0), FT(1.0/3.0), FT(0.0),
+            FT(0.0),     FT(0.0),     FT(0.0);
 
   for(InputIterator it = first;
       it != beyond;
@@ -572,17 +614,17 @@ assemble_covariance_matrix_3(InputIterator first,
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
     Matrix transformation;
-    transformation << t[0].x(), t[1].x(), 0.0, 
+    transformation << t[0].x(), t[1].x(), 0.0,
                       t[0].y(), t[1].y(), 0.0,
                       t[0].z(), t[1].z(), 1.0;
-    FT length = std::sqrt(t.squared_length());
+    FT length = CGAL::approximate_sqrt(t.squared_length());
 
     // skip zero measure primitives
     if(length == (FT)0.0)
       continue;
 
     // Find the 2nd order moment for the segment wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = length * transformation * moment * transformation.transpose();
 
@@ -597,14 +639,16 @@ assemble_covariance_matrix_3(InputIterator first,
     mass += length;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.z() * c.x());
-  covariance[3] += mass * (-1.0 * c.y() * c.y());
-  covariance[4] += mass * (-1.0 * c.z() * c.y());
-  covariance[5] += mass * (-1.0 * c.z() * c.z());
+  covariance[0] += -mass * (c.x() * c.x());
+  covariance[1] += -mass * (c.x() * c.y());
+  covariance[2] += -mass * (c.z() * c.x());
+  covariance[3] += -mass * (c.y() * c.y());
+  covariance[4] += -mass * (c.z() * c.y());
+  covariance[5] += -mass * (c.z() * c.z());
 
 }
 
@@ -645,7 +689,7 @@ template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Default_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& k,                    // kernel
@@ -661,7 +705,7 @@ template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Default_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& k,                     // kernel
@@ -673,12 +717,12 @@ assemble_covariance_matrix_3(InputIterator first,
                                 Eigen_diagonalize_traits<typename K::FT, 3>());
 }
 
-  
+
 template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Default_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& k,                     // kernel
@@ -694,7 +738,7 @@ template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Default_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& k,                    // kernel
@@ -710,7 +754,7 @@ template < typename InputIterator,
            typename K >
 void
 assemble_covariance_matrix_3(InputIterator first,
-                             InputIterator beyond, 
+                             InputIterator beyond,
                              typename Default_diagonalize_traits<typename K::FT, 3>::Covariance_matrix& covariance, // covariance matrix
                              const typename K::Point_3& c, // centroid
                              const K& k,                    // kernel
@@ -722,7 +766,7 @@ assemble_covariance_matrix_3(InputIterator first,
                                 Eigen_diagonalize_traits<typename K::FT, 3>());
 }
 
-  
+
 
 
 } // end namespace internal
