@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Shape_detection/include/CGAL/Polygon_mesh_processing/region_growing.h $
-// $Id: region_growing.h 7f2ca4c 2023-04-27T15:52:52+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Shape_detection/include/CGAL/Polygon_mesh_processing/region_growing.h $
+// $Id: region_growing.h 3bfc61af588 2024-03-12T10:39:28+01:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -21,6 +21,7 @@
 #include <CGAL/Shape_detection/Region_growing/Region_growing.h>
 #include <CGAL/Shape_detection/Region_growing/Polygon_mesh.h>
 #include <CGAL/Shape_detection/Region_growing/Segment_set.h>
+#include <CGAL/property_map.h>
 
 namespace CGAL {
 namespace Polygon_mesh_processing {
@@ -51,6 +52,46 @@ namespace internal
   {
     fill_plane_or_vector_map<GT>(normals, region_map, typename boost::property_traits<RegionMap>::value_type());
   }
+
+template<typename PolygonMesh, typename ECM>
+class One_ring_neighbor_query_with_constraints
+{
+  using face_descriptor = typename boost::graph_traits<PolygonMesh>::face_descriptor;
+  using halfedge_descriptor = typename boost::graph_traits<PolygonMesh>::halfedge_descriptor;
+  using Face_graph = PolygonMesh;
+public:
+
+  using Item = typename boost::graph_traits<PolygonMesh>::face_descriptor;
+  using Region = std::vector<Item>;
+
+  One_ring_neighbor_query_with_constraints(const PolygonMesh& pmesh, ECM ecm)
+    : m_face_graph(pmesh)
+    , m_ecm(ecm)
+  {}
+
+  void operator()(
+    const Item query,
+    std::vector<Item>& neighbors) const {
+
+    neighbors.clear();
+    const auto query_hedge = halfedge(query, m_face_graph);
+
+    for (halfedge_descriptor h : halfedges_around_face(query_hedge, m_face_graph))
+    {
+      if (get(m_ecm, edge(h, m_face_graph))) continue;
+      face_descriptor f=face(opposite(h,m_face_graph), m_face_graph);
+      if (f != boost::graph_traits<PolygonMesh>::null_face())
+      {
+        neighbors.push_back(f);
+      }
+    }
+  }
+
+private:
+  const Face_graph& m_face_graph;
+  ECM m_ecm;
+};
+
 }
 
 /*!
@@ -65,7 +106,8 @@ namespace internal
 
   @param mesh the polygon mesh whose faces are used for region growing
   @param region_map a property map storing the region index of each face. Values start at `0` up to the value returned minus `1`.
-         `std::size_t(-1)` is put for faces with no region assigned (can only happen if `minimum_region_size > 1`).
+         `std::size_t(-1)` is put for faces with no region assigned (it can happen if `minimum_region_size > 1` or for a non-triangular
+          face having a fitting plane not satisfying the maximum distance criterium).
   @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
   @return the number of regions detected
@@ -140,13 +182,21 @@ region_growing_of_planes_on_faces(const PolygonMesh& mesh,
   using parameters::choose_parameter;
   using parameters::get_parameter;
 
+  typedef typename boost::graph_traits<PolygonMesh>::edge_descriptor edge_descriptor;
+  typedef typename internal_np::Lookup_named_param_def <
+      internal_np::edge_is_constrained_t,
+      NamedParameters,
+      Static_boolean_property_map<edge_descriptor, false> // default (no constraint pmap)
+    > ::type ECM;
+  ECM ecm = choose_parameter(get_parameter(np, internal_np::edge_is_constrained),
+                             Static_boolean_property_map<edge_descriptor, false>());
 
-  using Neighbor_query = RG_PM::One_ring_neighbor_query<PolygonMesh>;
+  using Neighbor_query = internal::One_ring_neighbor_query_with_constraints<PolygonMesh, ECM>;
   using Region_type = RG_PM::Least_squares_plane_fit_region<Traits, PolygonMesh, VPM>;
   using Sorting = RG_PM::Least_squares_plane_fit_sorting<Traits, PolygonMesh, Neighbor_query, VPM>;
   using Region_growing = CGAL::Shape_detection::Region_growing<Neighbor_query, Region_type, RegionMap>;
 
-  Neighbor_query neighbor_query(mesh);
+  Neighbor_query neighbor_query(mesh, ecm);
   Region_type region_type(mesh, np);
   Sorting sorting(mesh, neighbor_query, np);
   sorting.sort();
@@ -304,6 +354,7 @@ detect_corners_of_regions(
   using parameters::get_parameter;
   using parameters::is_default_parameter;
 
+  using VPM = typename GetVertexPointMap < PolygonMesh, NamedParameters>::const_type;
   using Traits = typename GetGeomTraits<PolygonMesh, NamedParameters>::type;
   using Graph_traits = boost::graph_traits<PolygonMesh>;
   using halfedge_descriptor = typename Graph_traits::halfedge_descriptor;
@@ -327,7 +378,7 @@ detect_corners_of_regions(
   }
   Ecm ecm = choose_parameter(get_parameter(np, internal_np::edge_is_constrained), dynamic_ecm);
 
-  using Polyline_graph     = CGAL::Shape_detection::Polygon_mesh::Polyline_graph<PolygonMesh>;
+  using Polyline_graph     = CGAL::Shape_detection::Polygon_mesh::Polyline_graph<PolygonMesh, VPM>;
   using Segment_map        = typename Polyline_graph::Segment_map;
   using Item               = typename Polyline_graph::Item;
 
@@ -346,6 +397,12 @@ detect_corners_of_regions(
       put(ecm, e, true);
   }
 
+  //init to -1 by default
+  for(vertex_descriptor v : vertices(mesh))
+  {
+    put(corner_id_map, v, std::size_t(-1));
+  }
+
   // filter trivial edges: incident to a plane with only one face
   // such an edge cannot be removed and its vertices are corners
   std::vector<int> nb_faces_per_patch(nb_regions,0);
@@ -368,20 +425,23 @@ detect_corners_of_regions(
       filtered_edges.push_back(e);
   }
 
-  Polyline_graph pgraph(mesh, filtered_edges, region_map);
+  Polyline_graph pgraph(mesh, filtered_edges, region_map, np);
   const auto& segment_range = pgraph.segment_range();
 
   Line_region line_region(np.segment_map(pgraph.segment_map()));
 
-  Line_sorting line_sorting(
-    segment_range, pgraph, CGAL::parameters::segment_map(pgraph.segment_map()));
-  line_sorting.sort();
-
-  RG_lines rg_lines(
-    segment_range, pgraph, line_region);
-
   std::vector< std::pair<typename Line_region::Primitive, std::vector<edge_descriptor> > > subregions; // TODO dump into pmap lines
-  rg_lines.detect(std::back_inserter(subregions));
+  if (!segment_range.empty())
+  {
+    Line_sorting line_sorting(
+      segment_range, pgraph, CGAL::parameters::segment_map(pgraph.segment_map()));
+    line_sorting.sort();
+
+    RG_lines rg_lines(
+      segment_range, pgraph, line_region);
+
+    rg_lines.detect(std::back_inserter(subregions));
+  }
 
 #ifdef CGAL_DEBUG_DETECT_CORNERS_OF_REGIONS
   std::ofstream debug_corners("corners.xyz");
@@ -416,11 +476,13 @@ detect_corners_of_regions(
     for (vertex_descriptor v : line_vertices)
       if (vertex_count[v]==1)
       {
-#ifdef CGAL_DEBUG_DETECT_CORNERS_OF_REGIONS
-        debug_corners << mesh.point(v) << "\n";
-#endif
         if (get(corner_id_map, v) == std::size_t(-1))
+        {
+#ifdef CGAL_DEBUG_DETECT_CORNERS_OF_REGIONS
+          debug_corners << mesh.point(v) << "\n";
+#endif
           put(corner_id_map, v, cid++);
+        }
       }
   }
 
@@ -432,9 +494,19 @@ detect_corners_of_regions(
 #endif
     put(ecm, e, true);
     if (get(corner_id_map, source(e, mesh))==std::size_t(-1))
+    {
+#ifdef CGAL_DEBUG_DETECT_CORNERS_OF_REGIONS
+      debug_corners << mesh.point(source(e, mesh)) << "\n";
+#endif
       put(corner_id_map, source(e, mesh), cid++);
+    }
     if (get(corner_id_map, target(e, mesh))==std::size_t(-1))
+    {
+#ifdef CGAL_DEBUG_DETECT_CORNERS_OF_REGIONS
+      debug_corners << mesh.point(target(e, mesh)) << "\n";
+#endif
       put(corner_id_map, target(e, mesh), cid++);
+    }
   }
 
   return cid;
