@@ -2,19 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/GraphicsView/include/CGAL/Qt/GraphicsViewLineInput.h $
+// $Id: GraphicsViewLineInput.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL$
-// $Id$
-// 
 //
 // Author(s)     : Andreas Fabri <Andreas.Fabri@geometryfactory.com>
 //                 Laurent Rineau <Laurent.Rineau@geometryfactory.com>
@@ -22,15 +14,19 @@
 #ifndef CGAL_QT_GRAPHICS_VIEW_LINE_INPUT_H
 #define CGAL_QT_GRAPHICS_VIEW_LINE_INPUT_H
 
+#include <CGAL/license/GraphicsView.h>
+
+
 #include <QGraphicsView>
 #include <QRectF>
 #include <QPointF>
 #include <QGraphicsItem>
-#include <QGraphicsLineItem> 
+#include <QGraphicsLineItem>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 #include <QStyleOption>
+#include <QKeyEvent>
 
 #include <CGAL/Qt/Converter.h>
 #include <CGAL/Qt/GraphicsViewInput.h>
@@ -46,15 +42,15 @@ public:
   GraphicsViewLineInput(QObject *parent, QGraphicsScene* s);
 
 protected:
-    
+
   virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
   virtual void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
   virtual void keyPressEvent(QKeyEvent *event);
-  
-  bool eventFilter(QObject *obj, QEvent *event);
-  
 
-  
+  bool eventFilter(QObject *obj, QEvent *event);
+
+
+
 
 private:
 
@@ -66,7 +62,7 @@ private:
   QPointF qsp, qtp;
   typename K::Point_2 sp, tp;
   typename K::Line_2 l;
-  QGraphicsScene *scene_;  
+  QGraphicsScene *scene_;
   Converter<K> convert;
 };
 
@@ -103,9 +99,9 @@ GraphicsViewLineInput<K>::qlinef()
 }
 
 template <typename K>
-void 
+void
 GraphicsViewLineInput<K>::mousePressEvent(QGraphicsSceneMouseEvent *event)
-{  
+{
   if(event->modifiers()  & ::Qt::ShiftModifier){
     return;
   }
@@ -114,7 +110,7 @@ GraphicsViewLineInput<K>::mousePressEvent(QGraphicsSceneMouseEvent *event)
       sp = convert(qsp);
       tp = convert(qtp);
       scene_->removeItem(&line);
-      emit generate(CGAL::make_object(typename K::Line_2(sp,tp)));
+      Q_EMIT generate(CGAL::make_object(typename K::Line_2(sp,tp)));
   } else {
     qsp = event->scenePos();
     qtp = QPointF(qsp.x()+1, qsp.y());
@@ -128,20 +124,20 @@ GraphicsViewLineInput<K>::mousePressEvent(QGraphicsSceneMouseEvent *event)
 
 
 template <typename K>
-void 
+void
 GraphicsViewLineInput<K>::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
   qtp = event->scenePos();
   if(qtp == qsp){
     qtp = QPointF(qsp.x()+1, qsp.y());
-  } 
+  }
   line.setLine(qlinef());
 }
 
 
 template <typename K>
-void 
-GraphicsViewLineInput<K>::keyPressEvent ( QKeyEvent * event ) 
+void
+GraphicsViewLineInput<K>::keyPressEvent ( QKeyEvent * event )
 {
   if(event->key() != ::Qt::Key_Delete){ // need an anchored namespace to get away from CGAL::Qt
     return;
@@ -155,7 +151,7 @@ GraphicsViewLineInput<K>::keyPressEvent ( QKeyEvent * event )
 
 
 template <typename K>
-bool 
+bool
 GraphicsViewLineInput<K>::eventFilter(QObject *obj, QEvent *event)
 {
   if (event->type() == QEvent::GraphicsSceneMousePress) {
@@ -174,7 +170,7 @@ GraphicsViewLineInput<K>::eventFilter(QObject *obj, QEvent *event)
     // standard event processing
     return QObject::eventFilter(obj, event);
   }
-} 
+}
 
 } // namespace Qt
 } // namespace CGAL
