@@ -4,29 +4,22 @@
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
  This file is part of a fork of the QGLViewer library version 2.7.0.
- http://www.libqglviewer.com - contact@libqglviewer.com
-
- This file may be used under the terms of the GNU General Public License 
- version 3.0 as published by the Free Software Foundation and
- appearing in the LICENSE file included in the packaging of this file.
-
- This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/GraphicsView/include/CGAL/Qt/camera.h $
-// $Id: camera.h 93d9e8e 2018-06-29T14:39:19+01:00 Jane
-// SPDX-License-Identifier: GPL-3.0
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/GraphicsView/include/CGAL/Qt/camera.h $
+// $Id: camera.h c7fb2f56ae1 2022-12-07T09:47:41Z Andreas Fabri
+// SPDX-License-Identifier: GPL-3.0-only
 
 
 #ifndef QGLVIEWER_CAMERA_H
 #define QGLVIEWER_CAMERA_H
+#include <array>
 #include <QMap>
-#include <QDomElement>
 #include <CGAL/Qt/vec.h>
 #include <CGAL/Qt/quaternion.h>
 #include <CGAL/export/Qt.h>
 #include <QOpenGLFunctions_2_1>
+#include <QOpenGLFunctions>
 
 namespace CGAL{
 class QGLViewer;
@@ -208,6 +201,7 @@ public:
   CGAL::QGLViewer's window dimensions when the Camera is attached to a CGAL::QGLViewer. See
   also QOpenGLWidget::height() */
   int screenHeight() const { return screenHeight_; }
+  qreal devicePixelRatio() const { return devicePixelRatio_; }
   void getViewport(GLint viewport[4]) const;
   qreal pixelGLRatio(const Vec &position) const;
 
@@ -230,7 +224,7 @@ public:
 
   The near (resp. far) clipping plane is positioned at a distance equal to
   zClippingCoefficient() * sceneRadius() in front of (resp. behind) the
-  sceneCenter(). This garantees an optimal use of the z-buffer range and
+  sceneCenter(). This guarantees an optimal use of the z-buffer range and
   minimizes aliasing. See the zNear() and zFar() documentations.
 
   Default value is square root of 3.0 (so that a cube of size sceneRadius() is
@@ -288,7 +282,7 @@ public Q_SLOTS:
     setScreenWidthAndHeight(int(100.0 * aspect), 100);
   }
 
-  void setScreenWidthAndHeight(int width, int height);
+  void setScreenWidthAndHeight(int width, int height, qreal devicePixelRatio = 1.0);
   /*! Sets the zNearCoefficient() value. */
   void setZNearCoefficient(qreal coef) {
     zNearCoef_ = coef;
@@ -299,6 +293,16 @@ public Q_SLOTS:
     zClippingCoef_ = coef;
     projectionMatrixIsUpToDate_ = false;
   }
+  /*! Sets the zNear value in orthographic mode. */
+  void setOrthoZNear(qreal z)
+  {
+    m_zMin = z;
+  }
+  /*! Returns the zNear value in orthographic mode*/
+  qreal orthoZNear()
+  {
+    return m_zMin;
+  }
   //@}
 
   /*! @name Scene radius and center */
@@ -386,11 +390,11 @@ public:
   void computeProjectionMatrix() const;
   void computeModelViewMatrix() const;
   //!Sets the frustum according to the current type of the camera
-  //! (PERSPECTIVE or ORTHOGRAPHIC) in this order : 
+  //! (PERSPECTIVE or ORTHOGRAPHIC) in this order :
   //! left, right, top, bottom, near, far
   void setFrustum(double frustum[6]);
-  //!Fills `frustum` from the current frustum of the camera according 
-  //! to the current type (PERSPECTIVE or ORTHOGRAPHIC) in this order : 
+  //!Fills `frustum` from the current frustum of the camera according
+  //! to the current type (PERSPECTIVE or ORTHOGRAPHIC) in this order :
   //! left, right, top, bottom, near, far
   void getFrustum(double frustum[6]);
   void getProjectionMatrix(GLfloat m[16]) const;
@@ -415,12 +419,12 @@ public:
   /*! @name 2D screen to 3D world coordinate systems conversions */
   //@{
 public:
-  Vec projectedCoordinatesOf(const Vec &src, const Frame *frame = NULL) const;
-  Vec unprojectedCoordinatesOf(const Vec &src, const Frame *frame = NULL) const;
+  Vec projectedCoordinatesOf(const Vec &src, const Frame *frame = nullptr) const;
+  Vec unprojectedCoordinatesOf(const Vec &src, const Frame *frame = nullptr) const;
   void getProjectedCoordinatesOf(const qreal src[3], qreal res[3],
-                                 const Frame *frame = NULL) const;
+                                 const Frame *frame = nullptr) const;
   void getUnprojectedCoordinatesOf(const qreal src[3], qreal res[3],
-                                   const Frame *frame = NULL) const;
+                                   const Frame *frame = nullptr) const;
   void convertClickToLine(const QPoint &pixel, Vec &orig, Vec &dir) const;
   Vec pointUnderPixel(const QPoint &pixel, bool &found) const;
   //@}
@@ -433,15 +437,6 @@ public Q_SLOTS:
   void setFlySpeed(qreal speed);
   //@}
 
-  /*! @name XML representation */
-  //@{
-public:
-  virtual QDomElement domElement(const QString &name,
-                                 QDomDocument &document) const;
-public Q_SLOTS:
-  virtual void initFromDOMElement(const QDomElement &element);
-  //@}
-
 private Q_SLOTS:
   void onFrameModified();
 
@@ -452,6 +447,7 @@ private:
 
   // C a m e r a   p a r a m e t e r s
   int screenWidth_, screenHeight_; // size of the window, in pixels
+  qreal devicePixelRatio_;
   qreal fieldOfView_;              // in radians
   Vec sceneCenter_;
   qreal sceneRadius_; // OpenGL units
@@ -463,6 +459,7 @@ private:
   mutable bool modelViewMatrixIsUpToDate_;
   mutable GLdouble projectionMatrix_[16]; // Buffered projection matrix.
   mutable bool projectionMatrixIsUpToDate_;
+  qreal m_zMin; //USed for near plane in orthographic projection.
 
   // S t e r e o   p a r a m e t e r s
   qreal IODistance_;          // inter-ocular distance, in meters
@@ -474,6 +471,36 @@ private:
   KeyFrameInterpolator *interpolationKfi_;
 };
 
+inline void read_pixel(const QPoint &pixel, QOpenGLFunctions *p,
+                        const Camera *camera, GLenum format, GLenum type,
+                        GLvoid *pixel_data) {
+  const auto pixel_ratio = camera->devicePixelRatio();
+  p->glReadPixels(pixel.x() * pixel_ratio,
+                  (camera->screenHeight() - pixel.y()) * pixel_ratio - 1, 1, 1,
+                  format, type, pixel_data);
+}
+
+inline auto read_pixel_as_float_rgb(const QPoint &pixel, QOpenGLFunctions *p,
+                                    const Camera *camera) {
+  std::array<float, 3> res;
+  read_pixel(pixel, p, camera, GL_RGB, GL_FLOAT, res.data());
+  return res;
+}
+
+inline auto read_pixel_as_ubyte_rgba(const QPoint &pixel, QOpenGLFunctions *p,
+                                    const Camera *camera) {
+  std::array<GLubyte, 4> res;
+  read_pixel(pixel, p, camera, GL_RGBA, GL_UNSIGNED_BYTE, res.data());
+  return res;
+}
+
+inline float read_depth_under_pixel(const QPoint &pixel, QOpenGLFunctions *p,
+                                    const Camera *camera) {
+  float depth = 2.0f;
+  read_pixel(pixel, p, camera, GL_DEPTH_COMPONENT, GL_FLOAT, &depth);
+  return depth;
+}
+
 } // namespace qglviewer
 } //CGAL
 #endif // QGLVIEWER_CAMERA_H
