@@ -4,19 +4,11 @@
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
  This file is part of a fork of the QGLViewer library version 2.7.0.
- http://www.libqglviewer.com - contact@libqglviewer.com
-
- This file may be used under the terms of the GNU General Public License 
- version 3.0 as published by the Free Software Foundation and
- appearing in the LICENSE file included in the packaging of this file.
-
- This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/GraphicsView/include/CGAL/Qt/keyFrameInterpolator_impl.h $
-// $Id: keyFrameInterpolator_impl.h c4b28fd 2018-06-06T16:15:55+02:00 Maxime Gimeno
-// SPDX-License-Identifier: GPL-3.0
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/GraphicsView/include/CGAL/Qt/keyFrameInterpolator_impl.h $
+// $Id: keyFrameInterpolator_impl.h 45478184de2 2022-11-15T13:39:40+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-only
 #ifdef CGAL_HEADER_ONLY
 #define CGAL_INLINE_FUNCTION inline
 
@@ -27,7 +19,6 @@
 #endif
 
 #include <CGAL/Qt/keyFrameInterpolator.h>
-#include <CGAL/Qt/domUtils.h>
 
 namespace CGAL{
 namespace qglviewer{
@@ -41,11 +32,10 @@ namespace qglviewer{
   their default values. */
 CGAL_INLINE_FUNCTION
 KeyFrameInterpolator::KeyFrameInterpolator(Frame *frame)
-    : frame_(NULL), period_(40), interpolationTime_(0.0),
+    : frame_(nullptr), period_(40), interpolationTime_(0.0),
       interpolationSpeed_(1.0), interpolationStarted_(false),
       closedPath_(false), loopInterpolation_(false), pathIsValid_(false),
       valuesAreValid_(true), currentFrameValid_(false)
-// #CONNECTION# Values cut pasted initFromDOMElement()
 {
   setFrame(frame);
   for (int i = 0; i < 4; ++i)
@@ -181,7 +171,7 @@ void KeyFrameInterpolator::resetInterpolation() {
   edited, even during the interpolation. See the <a
   href="../examples/keyFrames.html">keyFrames example</a> for an illustration.
 
-  \c NULL \p frame pointers are silently ignored. The keyFrameTime() has to be
+  \c nullptr \p frame pointers are silently ignored. The keyFrameTime() has to be
   monotonously increasing over keyFrames.
 
   Use addKeyFrame(const Frame&, qreal) to add keyFrame by values. */
@@ -290,7 +280,7 @@ void KeyFrameInterpolator::updateModifiedFrameValues() {
   kf = keyFrame_.first();
   int index = 1;
   while (kf) {
-    KeyFrame *next = (index < keyFrame_.size()) ? keyFrame_.at(index) : NULL;
+    KeyFrame *next = (index < keyFrame_.size()) ? keyFrame_.at(index) : nullptr;
     index++;
     if (next)
       kf->computeTangent(prev, next);
@@ -328,7 +318,7 @@ qreal KeyFrameInterpolator::keyFrameTime(int index) const {
 /*! Returns the duration of the KeyFrameInterpolator path, expressed in seconds.
 
  Simply corresponds to lastTime() - firstTime(). Returns 0.0 if the path has
- less than 2 keyFrames. See also keyFrameTime(). */
+ fewer than 2 keyFrames. See also keyFrameTime(). */
 CGAL_INLINE_FUNCTION
 qreal KeyFrameInterpolator::duration() const {
   return lastTime() - firstTime();
@@ -365,7 +355,7 @@ void KeyFrameInterpolator::updateCurrentKeyFrameForTime(qreal time) {
 
   // TODO: Special case for loops when closed path is implemented !!
   if (!currentFrameValid_)
-    // Recompute everything from scrach
+    // Recompute everything from scratch
     currentFrame_[1]->toFront();
 
   while (currentFrame_[1]->peekNext()->time() > time) {
@@ -466,92 +456,13 @@ void KeyFrameInterpolator::interpolateAtTime(qreal time) {
   Q_EMIT interpolated();
 }
 
-/*! Returns an XML \c QDomElement that represents the KeyFrameInterpolator.
-
- The resulting QDomElement holds the KeyFrameInterpolator parameters as well as
- the path keyFrames (if the keyFrame is defined by a pointer to a Frame, use its
- current value).
-
- \p name is the name of the QDomElement tag. \p doc is the \c QDomDocument
- factory used to create QDomElement.
-
- Use initFromDOMElement() to restore the ManipulatedFrame state from the
- resulting QDomElement.
-
-
- See Vec::domElement() for a complete example. See also
- Quaternion::domElement(), Camera::domElement()...
-
- Note that the Camera::keyFrameInterpolator() are automatically saved by
- CGAL::QGLViewer::saveStateToFile() when a CGAL::QGLViewer is closed. */
-CGAL_INLINE_FUNCTION
-QDomElement KeyFrameInterpolator::domElement(const QString &name,
-                                             QDomDocument &document) const {
-  QDomElement de = document.createElement(name);
-  int count = 0;
-  Q_FOREACH (KeyFrame *kf, keyFrame_) {
-    Frame fr(kf->position(), kf->orientation());
-    QDomElement kfNode = fr.domElement("KeyFrame", document);
-    kfNode.setAttribute("index", QString::number(count));
-    kfNode.setAttribute("time", QString::number(kf->time()));
-    de.appendChild(kfNode);
-    ++count;
-  }
-  de.setAttribute("nbKF", QString::number(keyFrame_.count()));
-  de.setAttribute("time", QString::number(interpolationTime()));
-  de.setAttribute("speed", QString::number(interpolationSpeed()));
-  de.setAttribute("period", QString::number(interpolationPeriod()));
-  DomUtils::setBoolAttribute(de, "closedPath", closedPath());
-  DomUtils::setBoolAttribute(de, "loop", loopInterpolation());
-  return de;
-}
-
-/*! Restores the KeyFrameInterpolator state from a \c QDomElement created by
- domElement().
-
- Note that the frame() pointer is not included in the domElement(): you need to
- setFrame() after this method to attach a Frame to the KeyFrameInterpolator.
-
- See Vec::initFromDOMElement() for a complete code example.
-
- See also Camera::initFromDOMElement() and Frame::initFromDOMElement(). */
-CGAL_INLINE_FUNCTION
-void KeyFrameInterpolator::initFromDOMElement(const QDomElement &element) {
-  qDeleteAll(keyFrame_);
-  keyFrame_.clear();
-  QDomElement child = element.firstChild().toElement();
-  while (!child.isNull()) {
-    if (child.tagName() == "KeyFrame") {
-      Frame fr;
-      fr.initFromDOMElement(child);
-      qreal time = DomUtils::qrealFromDom(child, "time", 0.0);
-      addKeyFrame(fr, time);
-    }
-
-    child = child.nextSibling().toElement();
-  }
-
-  // #CONNECTION# Values cut pasted from constructor
-  setInterpolationTime(DomUtils::qrealFromDom(element, "time", 0.0));
-  setInterpolationSpeed(DomUtils::qrealFromDom(element, "speed", 1.0));
-  setInterpolationPeriod(DomUtils::intFromDom(element, "period", 40));
-  setClosedPath(DomUtils::boolFromDom(element, "closedPath", false));
-  setLoopInterpolation(DomUtils::boolFromDom(element, "loop", false));
-
-  // setFrame(NULL);
-  pathIsValid_ = false;
-  valuesAreValid_ = false;
-  currentFrameValid_ = false;
-
-  stopInterpolation();
-}
 
 #ifndef DOXYGEN
 
 //////////// KeyFrame private class implementation /////////
 CGAL_INLINE_FUNCTION
 KeyFrameInterpolator::KeyFrame::KeyFrame(const Frame &fr, qreal t)
-    : time_(t), frame_(NULL) {
+    : time_(t), frame_(nullptr) {
   p_ = fr.position();
   q_ = fr.orientation();
 }
