@@ -4,19 +4,11 @@
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
  This file is part of a fork of the QGLViewer library version 2.7.0.
- http://www.libqglviewer.com - contact@libqglviewer.com
-
- This file may be used under the terms of the GNU General Public License 
- version 3.0 as published by the Free Software Foundation and
- appearing in the LICENSE file included in the packaging of this file.
-
- This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 *****************************************************************************/
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/GraphicsView/include/CGAL/Qt/manipulatedFrame_impl.h $
-// $Id: manipulatedFrame_impl.h c4b28fd 2018-06-06T16:15:55+02:00 Maxime Gimeno
-// SPDX-License-Identifier: GPL-3.0
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/GraphicsView/include/CGAL/Qt/manipulatedFrame_impl.h $
+// $Id: manipulatedFrame_impl.h c9a020bb1a5 2021-02-09T12:12:56+01:00 Maxime Gimeno
+// SPDX-License-Identifier: GPL-3.0-only
 
 #ifdef CGAL_HEADER_ONLY
 #define CGAL_INLINE_FUNCTION inline
@@ -29,7 +21,6 @@
 
 #include <CGAL/Qt/manipulatedFrame.h>
 #include <CGAL/Qt/camera.h>
-#include <CGAL/Qt/domUtils.h>
 #include <CGAL/Qt/qglviewer.h>
 
 #include <cstdlib>
@@ -51,7 +42,6 @@ namespace qglviewer{
 CGAL_INLINE_FUNCTION
 ManipulatedFrame::ManipulatedFrame()
     : action_(NO_MOUSE_ACTION), keepsGrabbingMouse_(false) {
-  // #CONNECTION# initFromDOMElement and accessor docs
   setRotationSensitivity(1.0);
   setTranslationSensitivity(1.0);
   setSpinningSensitivity(0.3);
@@ -59,7 +49,7 @@ ManipulatedFrame::ManipulatedFrame()
   setZoomSensitivity(1.0);
 
   isSpinning_ = false;
-  previousConstraint_ = NULL;
+  previousConstraint_ = nullptr;
 
   connect(&spinningTimer_, SIGNAL(timeout()), SLOT(spinUpdate()));
 }
@@ -109,71 +99,7 @@ void ManipulatedFrame::checkIfGrabsMouse(int x, int y,
                                         (fabs(y - proj.y) < thresold)));
 }
 
-////////////////////////////////////////////////////////////////////////////////
-//          S t a t e   s a v i n g   a n d   r e s t o r i n g               //
-////////////////////////////////////////////////////////////////////////////////
 
-/*! Returns an XML \c QDomElement that represents the ManipulatedFrame.
-
- Adds to the Frame::domElement() the ManipulatedFrame specific informations in a
- \c ManipulatedParameters child QDomElement.
-
- \p name is the name of the QDomElement tag. \p doc is the \c QDomDocument
- factory used to create QDomElement.
-
- Use initFromDOMElement() to restore the ManipulatedFrame state from the
- resulting \c QDomElement.
-
- See Vec::domElement() for a complete example. See also
- Quaternion::domElement(), Camera::domElement()... */
-CGAL_INLINE_FUNCTION
-QDomElement ManipulatedFrame::domElement(const QString &name,
-                                         QDomDocument &document) const {
-  QDomElement e = Frame::domElement(name, document);
-  QDomElement mp = document.createElement("ManipulatedParameters");
-  mp.setAttribute("rotSens", QString::number(rotationSensitivity()));
-  mp.setAttribute("transSens", QString::number(translationSensitivity()));
-  mp.setAttribute("spinSens", QString::number(spinningSensitivity()));
-  mp.setAttribute("wheelSens", QString::number(wheelSensitivity()));
-  mp.setAttribute("zoomSens", QString::number(zoomSensitivity()));
-  e.appendChild(mp);
-  return e;
-}
-
-/*! Restores the ManipulatedFrame state from a \c QDomElement created by
-domElement().
-
-Fields that are not described in \p element are set to their default values (see
-ManipulatedFrame()).
-
-First calls Frame::initFromDOMElement() and then initializes ManipulatedFrame
-specific parameters. Note that constraint() and referenceFrame() are not
-restored and are left unchanged.
-
-
-See Vec::initFromDOMElement() for a complete code example. */
-CGAL_INLINE_FUNCTION
-void ManipulatedFrame::initFromDOMElement(const QDomElement &element) {
-  // Not called since it would set constraint() and referenceFrame() to NULL.
-  // *this = ManipulatedFrame();
-  Frame::initFromDOMElement(element);
-
-  stopSpinning();
-
-  QDomElement child = element.firstChild().toElement();
-  while (!child.isNull()) {
-    if (child.tagName() == "ManipulatedParameters") {
-      // #CONNECTION# constructor default values and accessor docs
-      setRotationSensitivity(DomUtils::qrealFromDom(child, "rotSens", 1.0));
-      setTranslationSensitivity(
-          DomUtils::qrealFromDom(child, "transSens", 1.0));
-      setSpinningSensitivity(DomUtils::qrealFromDom(child, "spinSens", 0.3));
-      setWheelSensitivity(DomUtils::qrealFromDom(child, "wheelSens", 1.0));
-      setZoomSensitivity(DomUtils::qrealFromDom(child, "zoomSens", 1.0));
-    }
-    child = child.nextSibling().toElement();
-  }
-}
 
 ////////////////////////////////////////////////////////////////////////////////
 //                 M o u s e    h a n d l i n g                               //
@@ -230,10 +156,10 @@ void ManipulatedFrame::startAction(int ma, bool withConstraint) {
   // manipulatedCameraFrame::wheelEvent and mouseReleaseEvent() restore previous
   // constraint
   if (withConstraint)
-    previousConstraint_ = NULL;
+    previousConstraint_ = nullptr;
   else {
     previousConstraint_ = constraint();
-    setConstraint(NULL);
+    setConstraint(nullptr);
   }
 
   switch (action_) {
@@ -259,7 +185,7 @@ CGAL_INLINE_FUNCTION
 void ManipulatedFrame::computeMouseSpeed(const QMouseEvent *const e) {
   const QPoint delta = (e->pos() - prevPos_);
   const qreal dist = sqrt(qreal(delta.x() * delta.x() + delta.y() * delta.y()));
-  delay_ = last_move_time.restart();
+  delay_ = static_cast<int>(last_move_time.restart());
   if (delay_ == 0)
     // Less than a millisecond: assume delay = 1ms
     mouseSpeed_ = dist;
@@ -303,7 +229,7 @@ qreal ManipulatedFrame::deltaWithPrevPos(QMouseEvent *const event,
 CGAL_INLINE_FUNCTION
 qreal ManipulatedFrame::wheelDelta(const QWheelEvent *event) const {
   static const qreal WHEEL_SENSITIVITY_COEF = 8E-4;
-  return event->delta() * wheelSensitivity() * WHEEL_SENSITIVITY_COEF;
+  return event->angleDelta().y() * wheelSensitivity() * WHEEL_SENSITIVITY_COEF;
 }
 
 CGAL_INLINE_FUNCTION
@@ -466,7 +392,7 @@ void ManipulatedFrame::mouseMoveEvent(QMouseEvent *const event,
     // These MouseAction values make no sense for a manipulatedFrame
     break;
 
-  case NO_MOUSE_ACTION:
+  default:
     // Possible when the ManipulatedFrame is a MouseGrabber. This method is then
     // called without startAction because of mouseTracking.
     break;
