@@ -1,21 +1,10 @@
 // Copyright (c) 2006-2013 INRIA Nancy-Grand Est (France). All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
-
-// See the file LICENSE.LGPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Algebraic_kernel_d/include/CGAL/RS/functors_z_1.h $
-// $Id: functors_z_1.h 26c857a 2018-06-13T15:11:45+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Algebraic_kernel_d/include/CGAL/RS/functors_z_1.h $
+// $Id: functors_z_1.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author: Luis Peñaranda <luis.penaranda@gmx.com>
 
@@ -182,7 +171,7 @@ struct Solve_z_1{
 
         template <class OutputIterator>
         OutputIterator operator()(const Polynomial_1 &p,
-                                  bool known_to_be_square_free,
+                                  bool,
                                   OutputIterator res)const{
                 ZPolynomial_1 zp=PolConverter()(p);
                 Isolator isol(zp);
@@ -419,7 +408,7 @@ public CGAL::cpp98::binary_function<Polynomial_,Algebraic_,bool>{
                 typedef typename Ptraits::Substitute                    Subst;
                 std::vector<CGAL::Gmpfi> substitutions;
                 substitutions.push_back(CGAL::Gmpfi(l,r));
-                CGAL::Gmpfi eval=Subst()(p,     
+                CGAL::Gmpfi eval=Subst()(p,
                                          substitutions.begin(),
                                          substitutions.end());
                 return eval.sign();
