@@ -2,20 +2,11 @@
 // Copyright (c) 1999-2007  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/Root_of_traits_specializations.h $
-// $Id: Root_of_traits_specializations.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/Root_of_traits_specializations.h $
+// $Id: Root_of_traits_specializations.h cdbd4c7fd20 2021-02-17T23:25:52+01:00 Marc Glisse
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Michael Hemmer
@@ -61,21 +52,26 @@ struct Lazy_exact_ro2
 
     void update_exact() const
     {
+        typedef typename Base::Indirect I;
+        I* pet;
         if (old_rep)
-          this->et = new RO2(make_root_of_2(op1.exact(), op2.exact(),
-                                            op3.exact(), smaller));
+          pet = new I(make_root_of_2(op1.exact(), op2.exact(),
+                                     op3.exact(), smaller));
         else
-          this->et = new RO2(make_root_of_2(op1.exact(), op2.exact(),
-                                            op3.exact()));
+          pet = new I(make_root_of_2(op1.exact(), op2.exact(),
+                                     op3.exact()));
         if (!this->approx().is_point())
-            this->at = to_interval(*(this->et));
+            this->set_at(pet);
+        this->set_ptr(pet);
         this->prune_dag();
 
     }
 
     void prune_dag() const
     {
-        op1 = op2 = op3 = Lazy_exact_nt<ET>();
+        op1.reset();
+        op2.reset();
+        op3.reset();
     }
 };
 
@@ -102,11 +98,11 @@ public:
           return new Lazy_exact_ro2<NT>(a, b, c, smaller);
         };
     };
-  
+
 private:
   typedef CGAL::Algebraic_structure_traits<Root_of_2> AST;
 public:
-  typedef typename AST::Square  Square; 
+  typedef typename AST::Square  Square;
   typedef typename AST::Inverse Inverse;
 
   struct Make_sqrt{
