@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Visibility_2/include/CGAL/Simple_polygon_visibility_2.h $
-// $Id: Simple_polygon_visibility_2.h 8cdfad0 2017-11-15T22:58:57+01:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Visibility_2/include/CGAL/Simple_polygon_visibility_2.h $
+// $Id: Simple_polygon_visibility_2.h c32b1f41275 2022-11-16T13:22:39+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s):  Francisc Bungiu <fbungiu@gmail.com>
@@ -36,12 +27,12 @@
 #include <CGAL/assertions.h>
 #include <stack>
 
-// TODO:  
-// * fix handle needles = O(nlogn)  
+// TODO:
+// * fix handle needles = O(nlogn)
 
 namespace CGAL {
 
-  template<class Arrangement_2_, class RegularizationCategory = CGAL::Tag_true> 
+  template<class Arrangement_2_, class RegularizationCategory = CGAL::Tag_true>
     class Simple_polygon_visibility_2 {
 
   public:
@@ -53,7 +44,7 @@ namespace CGAL {
   typedef typename K::Intersect_2                       Intersect_2;
 
   typedef typename Arrangement_2::Vertex_const_handle   Vertex_const_handle;
-  typedef typename Arrangement_2::Halfedge_const_handle       
+  typedef typename Arrangement_2::Halfedge_const_handle
   Halfedge_const_handle;
   typedef typename Arrangement_2::Halfedge_handle       Halfedge_handle;
   typedef typename Arrangement_2::Ccb_halfedge_const_circulator
@@ -73,10 +64,10 @@ namespace CGAL {
   typedef CGAL::Tag_false                     Supports_general_polygon_category;
   typedef CGAL::Tag_true                      Supports_simple_polygon_category;
 
-  Simple_polygon_visibility_2() : p_arr(NULL), traits(NULL) {}
+  Simple_polygon_visibility_2() : p_arr(nullptr), traits(nullptr) {}
 
   /*! Constructor given an arrangement and the Regularization tag. */
-  Simple_polygon_visibility_2(const Arrangement_2& arr): 
+  Simple_polygon_visibility_2(const Arrangement_2& arr):
   p_arr(&arr) {
     traits = p_arr->geometry_traits();
     point_location.attach(arr);
@@ -85,13 +76,13 @@ namespace CGAL {
     inserted_artificial_starting_vertex = false;
   }
 
-  
+
   std::string name() const { return std::string("S_visibility_2"); }
 
   /*! Method to check if the visibility object is attached or not to
     an arrangement*/
   bool is_attached() const {
-    return (p_arr != NULL);
+    return (p_arr != nullptr);
   }
 
   /*! Attaches the visibility object to the 'arr' arrangement */
@@ -108,8 +99,8 @@ namespace CGAL {
     attached to*/
   void detach() {
     point_location.detach();
-    p_arr = NULL;
-    traits = NULL;
+    p_arr = nullptr;
+    traits = nullptr;
     vertices.clear();
     query_pt_is_vertex = false;
     query_pt_is_on_halfedge = false;
@@ -123,8 +114,8 @@ namespace CGAL {
 
   /*! Computes the visibility object from the query point 'q' in the face
     'face' and constructs the output in 'out_arr'*/
-  template <typename VARR> 
-  typename VARR::Face_handle 
+  template <typename VARR>
+  typename VARR::Face_handle
   compute_visibility(const Point_2& q,
                      const Face_const_handle face,
                      VARR& out_arr) const
@@ -133,7 +124,7 @@ namespace CGAL {
     CGAL_precondition(!face->is_unbounded());
 
     out_arr.clear();
-    
+
     query_pt_is_vertex = false;
     query_pt_is_on_halfedge = false;
     inserted_artificial_starting_vertex = false;
@@ -155,12 +146,12 @@ namespace CGAL {
 
   /*! Computes the visibility region of the query point 'q' located on the
     halfedge 'he' and constructs the output in 'out_arr'*/
-  template <typename VARR> 
-  typename VARR::Face_handle 
+  template <typename VARR>
+  typename VARR::Face_handle
   compute_visibility(
-		     const Point_2& q, 
-		     const Halfedge_const_handle he,
-		     VARR& out_arr ) const
+                     const Point_2& q,
+                     const Halfedge_const_handle he,
+                     VARR& out_arr ) const
   {
 
     out_arr.clear();
@@ -214,8 +205,8 @@ namespace CGAL {
 
   mutable Arr_point_location point_location;
 
-  /*! Stack of visibile points; manipulated when going through the sequence
-    of input vertices; contains the vertices of the visibility region after 
+  /*! Stack of visible points; manipulated when going through the sequence
+    of input vertices; contains the vertices of the visibility region after
     the run of the algorithm*/
   mutable std::stack<Point_2> stack;
   /*! Sequence of input vertices*/
@@ -238,7 +229,7 @@ namespace CGAL {
     while(!stack.empty()) {
       const Point_2& top = stack.top();
       if (top != q || query_pt_is_vertex) {
-	points.push_back(top);
+        points.push_back(top);
       }
       stack.pop();
     }
@@ -250,45 +241,45 @@ namespace CGAL {
 
 
     // Quick fix for now. Can be done faster
-    bool is_degenerate = false; 
+    bool is_degenerate = false;
 
     for(typename std::vector<Point_2>::size_type i = 0; i < points.size()-2;i++){
       if(CGAL::orientation(points[i],points[i+1],points[i+2]) == CGAL::COLLINEAR){
-	is_degenerate = true;
-	break; 
+        is_degenerate = true;
+        break;
       }
     }
     if(is_degenerate){
       //std::cout << is_degenerate << std::endl;
       std::vector<Segment_2> segments;
-	
+
       for(typename std::vector<Point_2>::size_type i = 0;i < points.size() - 1; ++i)
-	{
-	  segments.push_back(Segment_2(points[i], points[i+1]));
-	}
+        {
+          segments.push_back(Segment_2(points[i], points[i+1]));
+        }
       CGAL::insert(out_arr, segments.begin(), segments.end());
     }else{
       points.pop_back();
-      //std::cout << " ordanary " << std::endl; 	
+      //std::cout << " ordanary " << std::endl;
       typename VARR::Vertex_handle v_last, v_first;
-      v_last = v_first = 
+      v_last = v_first =
         out_arr.insert_in_face_interior(points[0],out_arr.unbounded_face());
-	
+
       for(unsigned int i = 0; i < points.size()-1; i++){
-	if(points[i] < points[(i+1)]){
-	  v_last = out_arr.insert_from_left_vertex (
-						    Segment_2(points[i], points[i+1]), v_last
-						    )->target();
-	} else {
-	  v_last = out_arr.insert_from_right_vertex(
-						    Segment_2(points[i], points[i+1]), v_last
-						    )->target();
-	}        
+        if(points[i] < points[(i+1)]){
+          v_last = out_arr.insert_from_left_vertex (
+                                                    Segment_2(points[i], points[i+1]), v_last
+                                                    )->target();
+        } else {
+          v_last = out_arr.insert_from_right_vertex(
+                                                    Segment_2(points[i], points[i+1]), v_last
+                                                    )->target();
+        }
       }
       out_arr.insert_at_vertices(
-				 Segment_2(points.front(), points.back()),
-				 v_last, v_first
-				 );
+                                 Segment_2(points.front(), points.back()),
+                                 v_last, v_first
+                                 );
 
     }
 
@@ -307,7 +298,7 @@ namespace CGAL {
   }
 
 
-  /*! Finds a visible vertex from the query point 'q' in 'face' 
+  /*! Finds a visible vertex from the query point 'q' in 'face'
     to start the algorithm from*/
   Ccb_halfedge_const_circulator find_visible_start(Face_const_handle face,
                                                    const Point_2 &q) const
@@ -317,39 +308,39 @@ namespace CGAL {
     if(const Halfedge_const_handle* e =
        boost::get<Halfedge_const_handle>(&(result)))
       {
-	CGAL_assertion((*e)->face() == face);
-	Point_2 p(q.x(),
-		  traits->compute_y_at_x_2_object()(
-						    Line_2((*e)->source()->point(),
-							   (*e)->target()->point()) ,
-						    q.x()));
+        CGAL_assertion((*e)->face() == face);
+        Point_2 p(q.x(),
+                  traits->compute_y_at_x_2_object()(
+                                                    Line_2((*e)->source()->point(),
+                                                           (*e)->target()->point()) ,
+                                                    q.x()));
 
-	vertices.push_back(p);
-	inserted_artificial_starting_vertex = true;
+        vertices.push_back(p);
+        inserted_artificial_starting_vertex = true;
 
-	return (*e)->next()->ccb();
+        return (*e)->next()->ccb();
       }
     else if (const Vertex_const_handle* v =
-	     boost::get<Vertex_const_handle>(&(result)))
+             boost::get<Vertex_const_handle>(&(result)))
       {
-	Halfedge_around_vertex_const_circulator cir =
-	(*v)->incident_halfedges();
+        Halfedge_around_vertex_const_circulator cir =
+        (*v)->incident_halfedges();
 
-	while(face != cir->face()) {
-	  ++cir;
-	}
-	return cir->next()->ccb();
+        while(face != cir->face()) {
+          ++cir;
+        }
+        return cir->next()->ccb();
       }
     else
       {
-	CGAL_assertion_msg(false, "Should not be reachable.");
-	return Ccb_halfedge_const_circulator();
+        CGAL_assertion_msg(false, "Should not be reachable.");
+        return Ccb_halfedge_const_circulator();
       }
   }
 
 
   /*! Main method of the algorithm - initializes the stack and variables
-    and calles the corresponding methods acc. to the algorithm's state;
+    and calls the corresponding methods acc. to the algorithm's state;
     'q' - query point;
     'i' - current vertex' index
     'w' - endpoint of ray shot from query point */
@@ -375,45 +366,45 @@ namespace CGAL {
     Ray_2 ray_origin( q, vertices[0] );
     do {
       switch(upcase) {
-      case LEFT: 
-	left(i, w, q);
-	break;
+      case LEFT:
+        left(i, w, q);
+        break;
       case RIGHT:
-	right(i, w, q);
-	break;
+        right(i, w, q);
+        break;
       case SCANA:
-	scana(i, w, q);
-	break;
+        scana(i, w, q);
+        break;
       case SCANB:
-	scanb(i, w);
-	break;
+        scanb(i, w);
+        break;
       case SCANC:
-	scanc(i, w);
-	break;
+        scanc(i, w);
+        break;
       case SCAND:
-	scand(i, w);
-	break;
+        scand(i, w);
+        break;
       case FINISH:
-	break;
+        break;
       }
       if ( upcase == LEFT ) {
         Point_2 s_t = stack.top();
         stack.pop();
         if (traits->orientation_2_object()(q, vertices[0], stack.top() )
-	    == RIGHT_TURN
-	    &&
-	    traits->orientation_2_object()(q, vertices[0], s_t)
-	    == LEFT_TURN )
-	  {
-	    Segment_2 seg( stack.top(), s_t );
-	    if (Object_2 result = Intersect_2()(seg, ray_origin) )
-	      {
-		const Point_2 * ipoint = object_cast<Point_2>(&result);
-		CGAL_assertion( ipoint != NULL );
-		s_t = *ipoint;
-		upcase = SCANB;
-	      }
-	  }
+            == RIGHT_TURN
+            &&
+            traits->orientation_2_object()(q, vertices[0], s_t)
+            == LEFT_TURN )
+          {
+            Segment_2 seg( stack.top(), s_t );
+            if (Object_2 result = Intersect_2()(seg, ray_origin) )
+              {
+                const Point_2 * ipoint = object_cast<Point_2>(&result);
+                CGAL_assertion( ipoint != nullptr );
+                s_t = *ipoint;
+                upcase = SCANB;
+              }
+          }
         stack.push( s_t );
       }
     } while(upcase != FINISH);
@@ -430,38 +421,38 @@ namespace CGAL {
       Point_2 s_t_prev = stack.top();
       stack.push( s_t );
       Orientation orient1 = traits->orientation_2_object()(
-							   q,
-							   vertices[i],
-							   vertices[i+1] );
+                                                           q,
+                                                           vertices[i],
+                                                           vertices[i+1] );
 
       if ( orient1 != RIGHT_TURN ) {
-	// Case L2
-	upcase = LEFT;
-	stack.push( vertices[i+1] );
-	w = vertices[i+1];
-	i++;
+        // Case L2
+        upcase = LEFT;
+        stack.push( vertices[i+1] );
+        w = vertices[i+1];
+        i++;
       } else {
-	Orientation orient2 = traits->orientation_2_object()(
-							     s_t_prev,
-							     vertices[i],
-							     vertices[i+1] );
+        Orientation orient2 = traits->orientation_2_object()(
+                                                             s_t_prev,
+                                                             vertices[i],
+                                                             vertices[i+1] );
 
-	if ( orient2 == RIGHT_TURN ) {
-	  // Case L3
-	  upcase = SCANA;
-	  w = vertices[i+1];
-	  i++;
-	} else {
-	  // Case L4
-	  upcase = RIGHT;
-	  w = vertices[i];
-	  i++;
-	}
-      } 
+        if ( orient2 == RIGHT_TURN ) {
+          // Case L3
+          upcase = SCANA;
+          w = vertices[i+1];
+          i++;
+        } else {
+          // Case L4
+          upcase = RIGHT;
+          w = vertices[i];
+          i++;
+        }
+      }
     }
   }
 
-  /*! Scans the stack such that all vertices that were pushed before to the 
+  /*! Scans the stack such that all vertices that were pushed before to the
     stack and are now not visible anymore. */
   void right(Size_type& i, Point_2& w, const Point_2& q) const {
     Point_2 s_j;
@@ -481,23 +472,23 @@ namespace CGAL {
 
       orient2 = traits->orientation_2_object()( q, s_j_prev, vertices[i]);
       if ( orient1 != LEFT_TURN && orient2 != RIGHT_TURN ) {
-	mode = 1;
-	break;
+        mode = 1;
+        break;
       }
 
       Segment_2 seg2( vertices[i-1], vertices[i] );
       Segment_2 seg( s_j_prev, s_j );
       if ( vertices[i-1] != s_j )
-	{
-	  Object_2 result = Intersect_2()( seg, seg2 );
-	  if(result) {
-	    const Point_2 * ipoint = object_cast<Point_2>(&result);
-	    CGAL_assertion( ipoint != NULL );
-	    u = *ipoint;
-	    mode = 2;
-	    break;
-	  }
-	}
+        {
+          Object_2 result = Intersect_2()( seg, seg2 );
+          if(result) {
+            const Point_2 * ipoint = object_cast<Point_2>(&result);
+            CGAL_assertion( ipoint != nullptr );
+            u = *ipoint;
+            mode = 2;
+            break;
+          }
+        }
     }
 
     CGAL_assertion( mode != 0 );
@@ -505,54 +496,54 @@ namespace CGAL {
       orient1 = traits->orientation_2_object()(q, vertices[i], vertices[i+1] );
 
       orient2 = traits->orientation_2_object()(vertices[i-1],
-					       vertices[i],
-					       vertices[i+1] );
+                                               vertices[i],
+                                               vertices[i+1] );
 
       if ( orient1 == RIGHT_TURN ) {
-	// Case R1
-	// Since the next action is RIGHT, we do not compute the intersection
-	// of (s_j,s_j_prev) and the ray (query_pt, vertices[i]),
-	// thus, (s_j,s_j_prev) is not shortcutted, but it is harmless
-	upcase = RIGHT;
-	stack.push( s_j );
-	w = vertices[i];
-	i++;
+        // Case R1
+        // Since the next action is RIGHT, we do not compute the intersection
+        // of (s_j,s_j_prev) and the ray (query_pt, vertices[i]),
+        // thus, (s_j,s_j_prev) is not shortcutted, but it is harmless
+        upcase = RIGHT;
+        stack.push( s_j );
+        w = vertices[i];
+        i++;
       } else if ( orient2 == RIGHT_TURN ) {
-	// Case R2
-	Ray_2 ray( q, vertices[i] );
-	Segment_2 seg( s_j_prev, s_j );
+        // Case R2
+        Ray_2 ray( q, vertices[i] );
+        Segment_2 seg( s_j_prev, s_j );
 
-	Object_2 result = Intersect_2()( seg, ray );
-	const Point_2 * ipoint = object_cast<Point_2>(&result);
+        Object_2 result = Intersect_2()( seg, ray );
+        const Point_2 * ipoint = object_cast<Point_2>(&result);
 
-	CGAL_assertion( ipoint != NULL );
+        CGAL_assertion( ipoint != nullptr );
 
-	u = *ipoint;
-	if ( stack.top() != u ) {
-	  stack.push( u );
-	}
-	upcase = LEFT;
-	stack.push( vertices[i] );
-	stack.push( vertices[i+1] );
-	w = vertices[i+1];
-	i++;
+        u = *ipoint;
+        if ( stack.top() != u ) {
+          stack.push( u );
+        }
+        upcase = LEFT;
+        stack.push( vertices[i] );
+        stack.push( vertices[i+1] );
+        w = vertices[i+1];
+        i++;
       } else {
-	// Case R3
-	Ray_2 ray( q, vertices[i] );
-	Segment_2 seg( s_j_prev, s_j );
+        // Case R3
+        Ray_2 ray( q, vertices[i] );
+        Segment_2 seg( s_j_prev, s_j );
 
-	Object_2 result = Intersect_2()( seg, ray );
-	const Point_2 * ipoint = object_cast<Point_2>(&result);
+        Object_2 result = Intersect_2()( seg, ray );
+        const Point_2 * ipoint = object_cast<Point_2>(&result);
 
-	CGAL_assertion( ipoint != NULL );
+        CGAL_assertion( ipoint != nullptr );
 
-	u = *ipoint;
-	if ( stack.top() != u ) {
-	  stack.push( u );
-	}
-	upcase = SCANC;
-	w = vertices[i];
-	i++;
+        u = *ipoint;
+        if ( stack.top() != u ) {
+          stack.push( u );
+        }
+        upcase = SCANC;
+        w = vertices[i];
+        i++;
       }
     } else if ( mode == 2 ) {
       // Case R4
@@ -573,7 +564,7 @@ namespace CGAL {
 
     if ( orient1 == RIGHT_TURN ) {
       bool fwd = traits->
-	collinear_are_ordered_along_line_2_object()(q, stack.top(), u );
+        collinear_are_ordered_along_line_2_object()(q, stack.top(), u );
 
       if ( !fwd ) {
         // Case A1
@@ -598,7 +589,7 @@ namespace CGAL {
     }
   }
 
-  /*! Find the first edge interecting the segment (v_0, s_t) */
+  /*! Find the first edge intersecting the segment (v_0, s_t) */
   void scanb(Size_type& i, Point_2& w) const {
     if ( i == vertices.size() - 1 ) {
       upcase = FINISH;
@@ -640,15 +631,15 @@ namespace CGAL {
     }
     w = vertices[k+1];
   }
-  
+
   /*! Scan edges v_i,v_{i+1},...,v_n, until find an edge intersecting given ray
     or given segment. is_ray = true -> ray, false -> segment.
     The intersection point is returned by u */
   Size_type scan_edges( Size_type i,
-			const Point_2& ray_begin,
-			const Point_2& ray_end,
-			Point_2& u,
-			bool is_ray ) const
+                        const Point_2& ray_begin,
+                        const Point_2& ray_end,
+                        Point_2& u,
+                        bool is_ray ) const
   {
     Orientation old_orient = RIGHT_TURN;
     Ray_2 ray( ray_begin, ray_end );
@@ -657,20 +648,20 @@ namespace CGAL {
     Object_2 result;
     for ( k = i; k+1 < vertices.size(); k++ ) {
       Orientation curr_orient = traits->orientation_2_object()(
-							       ray_begin,
-							       ray_end,
-							       vertices[k+1] );
+                                                               ray_begin,
+                                                               ray_end,
+                                                               vertices[k+1] );
       if ( curr_orient != old_orient ) {
         // Orientation switch, an intersection may occur
         Segment_2 seg( vertices[k], vertices[k+1] );
         if ( is_ray ) {
-	  result = Intersect_2()( seg, ray );
-	  if(result)
-	    break;
+          result = Intersect_2()( seg, ray );
+          if(result)
+            break;
         } else {
-	  result = Intersect_2()( seg, s2 );
-	  if(result)
-	    break;
+          result = Intersect_2()( seg, s2 );
+          if(result)
+            break;
         }
       }
       old_orient = curr_orient;
