@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Snap_rounding_2/include/CGAL/Snap_rounding_2.h $
-// $Id: Snap_rounding_2.h e5118d1 2018-02-23T15:34:15+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Snap_rounding_2/include/CGAL/Snap_rounding_2.h $
+// $Id: Snap_rounding_2.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // author(s)     : Eli Packer <elip@post.tau.ac.il>
@@ -395,9 +386,9 @@ bool Hot_pixel<Traits_>::intersect_right(const Segment_2 & seg,
     Comparison_result c_source = compare_x(p_right, src);
 
     return (((seg_dir == SEG_LEFT || seg_dir == SEG_DOWN_LEFT ||
-	      seg_dir == SEG_UP_LEFT) && c_target != EQUAL) ||
+              seg_dir == SEG_UP_LEFT) && c_target != EQUAL) ||
             ((seg_dir == SEG_RIGHT || seg_dir == SEG_DOWN_RIGHT ||
-	      seg_dir == SEG_UP_RIGHT) && c_source != EQUAL));
+              seg_dir == SEG_UP_RIGHT) && c_source != EQUAL));
   }
   return false;
 }
@@ -425,7 +416,7 @@ bool Hot_pixel<Traits_>::intersect_bot(const Segment_2 & seg,
     Comparison_result c_source = compare_x(construct_vertex(seg, 0), p_right);
 
     return(c_p != EQUAL || (seg_dir == SEG_UP_LEFT && c_target != EQUAL) ||
-	   (seg_dir == SEG_DOWN_RIGHT && c_source != EQUAL));
+           (seg_dir == SEG_DOWN_RIGHT && c_source != EQUAL));
   } else if (assign(s,result))
     return(true);
   else
@@ -463,9 +454,9 @@ bool Hot_pixel<Traits_>::intersect_top(const Segment_2 & seg,
       return(false);// were checked
     else
       return(((seg_dir == SEG_DOWN || seg_dir == SEG_DOWN_LEFT ||
-	       seg_dir == SEG_DOWN_RIGHT) && c3 != EQUAL) ||
+               seg_dir == SEG_DOWN_RIGHT) && c3 != EQUAL) ||
              ((seg_dir == SEG_UP || seg_dir == SEG_UP_LEFT ||
-	       seg_dir == SEG_UP_RIGHT) && c4 != EQUAL));
+               seg_dir == SEG_UP_RIGHT) && c4 != EQUAL));
   }
   return(false);
 }
@@ -516,17 +507,17 @@ bool Hot_pixel_dir_cmp<Traits_>::operator ()(const Hot_pixel * h1,
 
   // Point segment intersects only one pixel, thus ignored
   return((seg_dir == SEG_UP_RIGHT &&  (cx == SMALLER || (cx == EQUAL &&
-							 cy == SMALLER))) ||
-	 (seg_dir == SEG_UP_LEFT && (cx == LARGER || (cx == EQUAL &&
-						      cy == SMALLER))) ||
-	 (seg_dir == SEG_DOWN_RIGHT && (cx == SMALLER || (cx == EQUAL &&
-							  cy == LARGER))) ||
+                                                         cy == SMALLER))) ||
+         (seg_dir == SEG_UP_LEFT && (cx == LARGER || (cx == EQUAL &&
+                                                      cy == SMALLER))) ||
+         (seg_dir == SEG_DOWN_RIGHT && (cx == SMALLER || (cx == EQUAL &&
+                                                          cy == LARGER))) ||
          (seg_dir == SEG_DOWN_LEFT && (cx == LARGER || (cx == EQUAL &&
-							cy == LARGER))) ||
-	 (seg_dir == SEG_UP && cy == SMALLER) ||
+                                                        cy == LARGER))) ||
+         (seg_dir == SEG_UP && cy == SMALLER) ||
          (seg_dir == SEG_DOWN && cy == LARGER) ||
-	 (seg_dir == SEG_LEFT && cx == LARGER) ||
-	 (seg_dir == SEG_RIGHT && cx == SMALLER));
+         (seg_dir == SEG_LEFT && cx == LARGER) ||
+         (seg_dir == SEG_RIGHT && cx == SMALLER));
 }
 
 /*! */
@@ -766,7 +757,7 @@ void snap_rounding_2(InputIterator begin,
   typedef std::list<Segment_data>                     Segment_data_list;
 
   Segment_data_list seg_list;
-  Multiple_kd_tree * mul_kd_tree = NULL;
+  Multiple_kd_tree * mul_kd_tree = nullptr;
 
   output_container.clear();
   // copy segments list
