@@ -1,24 +1,15 @@
-// Copyright (c) 1999  
+// Copyright (c) 1999
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Kernel_23/include/CGAL/Sphere_3.h $
-// $Id: Sphere_3.h 01af331 2018-03-14T15:59:38+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Kernel_23/include/CGAL/Sphere_3.h $
+// $Id: Sphere_3.h 3fa436459d4 2022-06-10T08:41:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Stefan Schirra
@@ -27,12 +18,13 @@
 #define CGAL_SPHERE_3_H
 
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/Bbox_3.h>
 #include <CGAL/representation_tags.h>
 #include <CGAL/Dimension.h>
 
+#include <type_traits>
+
 namespace CGAL {
 
 template <class R_>
@@ -45,7 +37,7 @@ class Sphere_3 : public R_::Kernel_base::Sphere_3
   typedef typename R_::Aff_transformation_3  Aff_transformation_3;
 
   typedef Sphere_3                           Self;
-  CGAL_static_assertion((boost::is_same<Self, typename R_::Sphere_3>::value));
+  CGAL_static_assertion((std::is_same<Self, typename R_::Sphere_3>::value));
 
 public:
 
@@ -71,6 +63,9 @@ public:
   Sphere_3(const Rep& s)
    : Rep(s) {}
 
+  Sphere_3(Rep&& s)
+   : Rep(std::move(s)) {}
+
   Sphere_3(const Point_3_& p, const FT& sq_rad,
            const Orientation& o = COUNTERCLOCKWISE)
    : Rep(typename R::Construct_sphere_3()(Return_base_tag(), p, sq_rad, o)) {}
@@ -95,7 +90,7 @@ public:
 
   Sphere_3 orthogonal_transform(const Aff_transformation_3 &t) const;
 
-  typename cpp11::result_of<typename R::Construct_center_3( Sphere_3)>::type
+  decltype(auto)
   center() const
   {
     return R().construct_center_3_object()(*this);
@@ -134,14 +129,14 @@ public:
   has_on(const Point_3_ &p) const
   {
     return R().has_on_3_object()(*this, p);
-  }  
+  }
 
   typename R::Boolean
   has_on(const Circle_3 &c) const
   {
     return R().has_on_3_object()(*this, c);
   }
-  
+
   typename R::Boolean
   has_on_boundary(const Point_3_ &p) const
   {
@@ -217,7 +212,7 @@ template <class R >
 std::ostream&
 insert(std::ostream& os, const Sphere_3<R>& c,const Cartesian_tag&)
 {
-    switch(get_mode(os)) {
+    switch(IO::get_mode(os)) {
     case IO::ASCII :
         os << c.center() << ' ' << c.squared_radius() << ' '
            << static_cast<int>(c.orientation());
@@ -249,7 +244,7 @@ template <class R >
 std::ostream&
 insert(std::ostream& os, const Sphere_3<R>& c, const Homogeneous_tag&)
 {
-    switch(get_mode(os)) {
+    switch(IO::get_mode(os)) {
     case IO::ASCII :
         os << c.center() << ' ' << c.squared_radius() << ' '
            << static_cast<int>(c.orientation());
@@ -292,7 +287,7 @@ extract(std::istream& is, Sphere_3<R>& c, const Cartesian_tag&)
     typename R::Point_3 center;
     typename R::FT squared_radius(0);
     int o=0;
-    switch(get_mode(is)) {
+    switch(IO::get_mode(is)) {
     case IO::ASCII :
         is >> center >> squared_radius >> o;
         break;
@@ -304,7 +299,7 @@ extract(std::istream& is, Sphere_3<R>& c, const Cartesian_tag&)
     default:
         is.setstate(std::ios::failbit);
         std::cerr << "" << std::endl;
-        std::cerr << "Stream must be in ascii or binary mode" << std::endl;
+        std::cerr << "Stream must be in ASCII or binary mode" << std::endl;
         break;
     }
     if (is)
@@ -320,7 +315,7 @@ extract(std::istream& is, Sphere_3<R>& c, const Homogeneous_tag&)
     typename R::Point_3 center;
     typename R::FT squared_radius;
     int o=0;
-    switch(get_mode(is)) {
+    switch(IO::get_mode(is)) {
     case IO::ASCII :
         is >> center >> squared_radius >> o;
         break;
@@ -332,7 +327,7 @@ extract(std::istream& is, Sphere_3<R>& c, const Homogeneous_tag&)
     default:
         is.setstate(std::ios::failbit);
         std::cerr << "" << std::endl;
-        std::cerr << "Stream must be in ascii or binary mode" << std::endl;
+        std::cerr << "Stream must be in ASCII or binary mode" << std::endl;
         break;
     }
     if (is)
