@@ -1,24 +1,13 @@
-//=============================================================================
 // Copyright (C) 2001-2005 by Computer Graphics Group, RWTH Aachen
 // Copyright (C) 2011 by Graphics & Geometry Group, Bielefeld University
 // Copyright (C) 2014 GeometryFactory
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Surface_mesh/include/CGAL/Surface_mesh/Properties.h $
+// $Id: Properties.h 2c7f7751a82 2023-01-30T20:47:18Z Giles Bathgate
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Surface_mesh/include/CGAL/Surface_mesh/Properties.h $
-// $Id: Properties.h ea25094 2018-08-14T14:18:24+02:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
-//
-
 
 #ifndef CGAL_SURFACE_MESH_PROPERTY_H
 #define CGAL_SURFACE_MESH_PROPERTY_H
@@ -27,13 +16,13 @@
 
 #ifndef DOXYGEN_RUNNING
 
-#include <vector>
-#include <string>
-#include <algorithm>
-#include <typeinfo>
-
-#include <CGAL/property_map.h>
 #include <CGAL/assertions.h>
+#include <CGAL/property_map.h>
+
+#include <algorithm>
+#include <string>
+#include <typeinfo>
+#include <vector>
 
 namespace CGAL {
 
@@ -143,17 +132,17 @@ public: // virtual interface of Base_property_array
     bool transfer(const Base_property_array& other)
     {
       const Property_array<T>* pa = dynamic_cast<const Property_array*>(&other);
-      if(pa != NULL){
+      if(pa != nullptr){
         std::copy((*pa).data_.begin(), (*pa).data_.end(), data_.end()-(*pa).data_.size());
         return true;
-      } 
+      }
       return false;
     }
 
     bool transfer(const Base_property_array& other, std::size_t from, std::size_t to)
     {
       const Property_array<T>* pa = dynamic_cast<const Property_array*>(&other);
-      if (pa != NULL)
+      if (pa != nullptr)
       {
         data_[to] = (*pa)[from];
         return true;
@@ -231,7 +220,7 @@ private:
 
 template<typename, typename>
 class Property_container;
-/// @endcond 
+/// @endcond
 
 
 
@@ -245,7 +234,7 @@ class Property_container
 public:
 
     // default constructor
-    Property_container() : size_(0) {}
+    Property_container() = default;
 
     // destructor (deletes all property arrays)
     virtual ~Property_container() { clear(); }
@@ -253,6 +242,11 @@ public:
     // copy constructor: performs deep copy of property arrays
     Property_container(const Property_container& _rhs) { operator=(_rhs); }
 
+    Property_container(Property_container&& c) noexcept
+    {
+      c.swap(*this);
+    }
+
     // assignment: performs deep copy of property arrays
     Property_container& operator=(const Property_container& _rhs)
     {
@@ -261,12 +255,21 @@ public:
             clear();
             parrays_.resize(_rhs.n_properties());
             size_ = _rhs.size();
+            capacity_ = _rhs.capacity();
             for (std::size_t i=0; i<parrays_.size(); ++i)
                 parrays_[i] = _rhs.parrays_[i]->clone();
         }
         return *this;
     }
 
+    Property_container& operator=(Property_container&& c) noexcept
+    {
+      Property_container tmp(std::move(c));
+      tmp.swap(*this);
+      return *this;
+    }
+
+
     void transfer(const Property_container& _rhs)
     {
       for(std::size_t i=0; i<parrays_.size(); ++i){
@@ -296,10 +299,11 @@ public:
           continue;
 
         parrays_.push_back (_rhs.parrays_[i]->empty_clone());
+        parrays_.back()->reserve(capacity_);
         parrays_.back()->resize(size_);
       }
     }
-  
+
     // Transfer one element with all properties
     // WARNING: properties must be the same in the two containers
     bool transfer(const Property_container& _rhs, std::size_t from, std::size_t to)
@@ -314,6 +318,9 @@ public:
     // returns the current size of the property arrays
     size_t size() const { return size_; }
 
+    // returns the current capacity of the property arrays
+    size_t capacity() const { return capacity_; }
+
     // returns the number of property arrays
     size_t n_properties() const { return parrays_.size(); }
 
@@ -331,7 +338,7 @@ public:
       typedef typename Ref_class::template Get_property_map<Key, T>::type type;
     };
 
-    template <class T> 
+    template <class T>
     std::pair<typename Get_pmap_type<T>::type, bool>
     get(const std::string& name, std::size_t i) const
     {
@@ -362,6 +369,7 @@ public:
 
         // otherwise add the property
         Property_array<T>* p = new Property_array<T>(name, t);
+        p->reserve(capacity_);
         p->resize(size_);
         parrays_.push_back(p);
         return std::make_pair(Pmap(p), true);
@@ -369,7 +377,7 @@ public:
 
 
     // get a property by its name. returns invalid property if it does not exist.
-    template <class T> 
+    template <class T>
     std::pair<typename Get_pmap_type<T>::type, bool>
     get(const std::string& name) const
     {
@@ -398,7 +406,7 @@ public:
 
 
     // get the type of property by its name. returns typeid(void) if it does not exist.
-    const std::type_info& 
+    const std::type_info&
     get_type(const std::string& name) const
     {
         for (std::size_t i=0; i<parrays_.size(); ++i)
@@ -409,7 +417,7 @@ public:
 
 
     // delete a property
-    template <class T> 
+    template <class T>
     bool
     remove(typename Get_pmap_type<T>::type& h)
     {
@@ -439,10 +447,11 @@ public:
 
 
     // reserve memory for n entries in all arrays
-    void reserve(size_t n) const
+    void reserve(size_t n)
     {
         for (std::size_t i=0; i<parrays_.size(); ++i)
             parrays_[i]->reserve(n);
+        capacity_ = (std::max)(n, capacity_);
     }
 
     // resize all arrays to size n
@@ -453,11 +462,22 @@ public:
         size_ = n;
     }
 
+    // resize the vector of properties to n, deleting all other properties
+    void resize_property_array(size_t n)
+    {
+        if (parrays_.size()<=n)
+          return;
+        for (std::size_t i=n; i<parrays_.size(); ++i)
+            delete parrays_[i];
+        parrays_.resize(n);
+    }
+
     // free unused space in all arrays
-    void shrink_to_fit() const
+    void shrink_to_fit()
     {
         for (std::size_t i=0; i<parrays_.size(); ++i)
             parrays_[i]->shrink_to_fit();
+        capacity_ = size_;
     }
 
     // add a new element to each vector
@@ -466,6 +486,7 @@ public:
         for (std::size_t i=0; i<parrays_.size(); ++i)
             parrays_[i]->push_back();
         ++size_;
+        capacity_ = ((std::max)(size_, capacity_));
     }
 
     // reset element to its default property values
@@ -486,21 +507,24 @@ public:
     void swap (Property_container& other)
     {
       this->parrays_.swap (other.parrays_);
+      std::swap(this->size_, other.size_);
+      std::swap(this->capacity_, other.capacity_);
     }
-  
+
 private:
     std::vector<Base_property_array*>  parrays_;
-    size_t  size_;
+    size_t  size_ = 0;
+    size_t  capacity_ = 0;
 };
 
   /// @endcond
 
 #ifndef DOXYGEN_RUNNING
-/// 
 ///
-/// `Property_map` enables to attach properties to the simplices of a 
+///
+/// `Property_map` enables to attach properties to the simplices of a
 ///  surface mesh.
-/// 
+///
 /// @tparam Key The key type of the property map. It must be a model of `Index`.
 /// @tparam Value The value type of the property.
 ///
@@ -509,13 +533,11 @@ private:
 template <class I, class T, class CRTP_derived_class>
 class Property_map_base
 /// @cond CGAL_DOCUMENT_INTERNALS
-  : public boost::put_get_helper< 
+  : public boost::put_get_helper<
            typename Property_array<T>::reference,
            CRTP_derived_class>
 /// @endcond
 {
-    typedef void (Property_map_base::*bool_type)() const;
-    void this_type_does_not_support_comparisons() const {}
 public:
     typedef I key_type;
     typedef T value_type;
@@ -527,7 +549,7 @@ public:
     typedef typename Property_array<T>::const_reference const_reference;
     typedef typename Property_array<T>::iterator iterator;
     typedef typename Property_array<T>::const_iterator const_iterator;
-#else 
+#else
     /// A reference to the value type of the property.
   typedef unspecified_type reference;
 
@@ -542,38 +564,60 @@ public:
 
 public:
 /// @cond CGAL_DOCUMENT_INTERNALS
-    Property_map_base(Property_array<T>* p=NULL) : parray_(p) {}
+    Property_map_base(Property_array<T>* p=nullptr) : parray_(p) {}
+
+    Property_map_base(Property_map_base&& pm) noexcept
+      : parray_(std::exchange(pm.parray_, nullptr))
+    {}
+
+    Property_map_base(const Property_map_base& pm)
+      : parray_(pm.parray_)
+    {}
+
+    Property_map_base& operator=(const Property_map_base& pm)
+    {
+      parray_ = pm.parray_;
+      return *this;
+    }
 
     void reset()
     {
-        parray_ = NULL;
+        parray_ = nullptr;
     }
-  /// @endcond 
+  /// @endcond
 
 public:
     /// \name Accessing Properties
     //@{
 #ifdef DOXYGEN_RUNNING
     /// Conversion to a Boolean. It is \c true when the property map
-    /// can be used, and \c false otherwise.  
+    /// can be used, and \c false otherwise.
   operator bool () const;
 #else
-    operator bool_type() const {
-        return parray_ != NULL ?
-            &Property_map_base::this_type_does_not_support_comparisons : 0;
+    explicit operator bool() const {
+        return parray_ != nullptr;
     }
 #endif
+
+    bool operator==(const Property_map_base& pm) const {
+      return parray_ == pm.parray_;
+    }
+
+    bool operator!=(const Property_map_base& pm) const {
+      return parray_ != pm.parray_;
+    }
+
     /// Access the property associated with the key \c i.
     reference operator[](const I& i)
     {
-      CGAL_assertion(parray_ != NULL);
+      CGAL_assertion(parray_ != nullptr);
       return (*parray_)[i];
     }
 
     /// Access the property associated with the key \c i.
     reference operator[](const I& i) const
     {
-      CGAL_assertion(parray_ != NULL);
+      CGAL_assertion(parray_ != nullptr);
       return (*parray_)[i];
     }
 
@@ -600,22 +644,24 @@ public:
     /// \returns a pointer to the underlying storage of the property.
     const T* data() const
     {
-      CGAL_assertion(parray_ != NULL);
+      CGAL_assertion(parray_ != nullptr);
       return parray_->data();
     }
 
     //@}
+#ifndef CGAL_TEST_SURFACE_MESH
 private:
+#endif
 
     Property_array<T>& array()
     {
-        CGAL_assertion(parray_ != NULL);
+        CGAL_assertion(parray_ != nullptr);
         return *parray_;
     }
 
     const Property_array<T>& array() const
     {
-        CGAL_assertion(parray_ != NULL);
+        CGAL_assertion(parray_ != nullptr);
         return *parray_;
     }
 
