@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Three/include/CGAL/Three/Scene_item.h $
-// $Id: Scene_item.h 2a49dfc 2019-01-11T09:47:34+01:00 Maxime Gimeno
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Three/include/CGAL/Three/Scene_item.h $
+// $Id: Scene_item.h c32b1f41275 2022-11-16T13:22:39+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Laurent RINEAU, Maxime Gimeno
@@ -73,23 +64,25 @@ public:
    */
   enum OpenGL_program_IDs
   {
-   PROGRAM_WITH_LIGHT = 0,      //! Used to render a surface or an edge affected by the light. It uses a per fragment lighting model, and renders the selected item brighter.
-   PROGRAM_WITHOUT_LIGHT,       //! Used to render a polyhedron edge or points. It renders in a uniform color and is not affected by light. \attention It renders the selected item in black.
-   PROGRAM_NO_SELECTION,        //! Used to render a polyline or a surface that is not affected by light, like a cutting plane. It renders in a uniform color that does not change with selection.
-   PROGRAM_WITH_TEXTURE,        //! Used to render a textured polyhedron. Affected by light.
-   PROGRAM_PLANE_TWO_FACES,     //! Used to render a two-faced plane. The two faces have a different color. Not affected by light.
-   PROGRAM_WITH_TEXTURED_EDGES, //! Used to render the edges of a textured polyhedron. Not affected by light.
-   PROGRAM_INSTANCED,           //! Used to display instanced rendered spheres.Affected by light.
-   PROGRAM_INSTANCED_WIRE,      //! Used to display instanced rendered wired spheres. Not affected by light.
-   PROGRAM_C3T3,                //! Used to render a c3t3_item. It discards any fragment on a side of a plane, meaning that nothing is displayed on this side of the plane. Affected by light.
-   PROGRAM_C3T3_EDGES,          //! Used to render the edges of a c3t3_item. It discards any fragment on a side of a plane, meaning that nothing is displayed on this side of the plane. Not affected by light.
-   PROGRAM_CUTPLANE_SPHERES,    //! Used to render the spheres of an item with a cut plane.
-   PROGRAM_SPHERES,             //! Used to render one or several spheres.
-   PROGRAM_FLAT,                /** Used to render flat shading without pre computing normals*/
-   PROGRAM_OLD_FLAT,            /** Used to render flat shading without pre computing normals without geometry shader*/
-   PROGRAM_SOLID_WIREFRAME,     //! Used to render edges with width superior to 1.
-   PROGRAM_HEAT_INTENSITY,      //! Used to render special item in Display_property_plugin
-   NB_OF_PROGRAMS               //! Holds the number of different programs in this enum.
+    ROGRAM_WITH_LIGHT = 0,      //! Used to render a surface or an edge affected by the light. It uses a per fragment lighting model, and renders the selected item brighter.
+    PROGRAM_WITHOUT_LIGHT,       //! Used to render a polyhedron edge or points. It renders in a uniform color and is not affected by light. \attention It renders the selected item in black.
+    PROGRAM_NO_SELECTION,        //! Used to render a polyline or a surface that is not affected by light, like a cutting plane. It renders in a uniform color that does not change with selection.
+    PROGRAM_WITH_TEXTURE,        //! Used to render a textured polyhedron. Affected by light.
+    PROGRAM_PLANE_TWO_FACES,     //! Used to render a two-faced plane. The two faces have a different color. Not affected by light.
+    PROGRAM_WITH_TEXTURED_EDGES, //! Used to render the edges of a textured polyhedron. Not affected by light.
+    PROGRAM_INSTANCED,           //! Used to display instanced rendered spheres.Affected by light.
+    PROGRAM_INSTANCED_WIRE,      //! Used to display instanced rendered wired spheres. Not affected by light.
+    PROGRAM_C3T3,                //! Used to render a c3t3_item. It discards any fragment on a side of a plane, meaning that nothing is displayed on this side of the plane. Affected by light.
+    PROGRAM_C3T3_EDGES,          //! Used to render the edges of a c3t3_item. It discards any fragment on a side of a plane, meaning that nothing is displayed on this side of the plane. Not affected by light.
+    PROGRAM_CUTPLANE_SPHERES,    //! Used to render the spheres of an item with a cut plane.
+    PROGRAM_SPHERES,             //! Used to render one or several spheres.
+    PROGRAM_DARK_SPHERES,        //! Used to render one or several spheres without light (for picking for example).
+    PROGRAM_FLAT,                /** Used to render flat shading without pre computing normals*/
+    PROGRAM_OLD_FLAT,            /** Used to render flat shading without pre computing normals without geometry shader*/
+    PROGRAM_SOLID_WIREFRAME,     //! Used to render edges with width superior to 1.
+    PROGRAM_NO_INTERPOLATION,   //! Used to render faces without interpolating their color.
+    PROGRAM_HEAT_INTENSITY,      //! Used to render special item in Display_property_plugin
+    NB_OF_PROGRAMS               //! Holds the number of different programs in this enum.
   };
   typedef CGAL::Bbox_3 Bbox;
   typedef CGAL::qglviewer::ManipulatedFrame ManipulatedFrame;
@@ -103,7 +96,7 @@ public:
   //! This is where the vectors of VBOs and VAOs are initialized.
   Scene_item(int buffers_size = 20, int vaos_size = 10);
 
-  //! \brief Sets the number of isolated vertices.
+  //! \brief sets the number of isolated vertices.
   //!
   //! This number will be displayed in a warning box at loading.
   //! @see getNbIsolatedvertices
@@ -112,12 +105,12 @@ public:
   //! @see setNbIsolatedvertices
   std::size_t getNbIsolatedvertices() const {return nb_isolated_vertices;}
   virtual ~Scene_item();
-  //! \brief Duplicates the item.
+  //! \brief duplicates the item.
   //!
   //! Creates a new item as a copy of this one.
   virtual Scene_item* clone() const = 0;
 
-  //! \brief Indicates if `m` is supported
+  //! \brief indicates if `m` is supported
   //!
   //! If it is, it will be displayed in the context menu of the item.
   virtual bool supportsRenderingMode(RenderingMode m) const = 0;
@@ -170,7 +163,7 @@ public:
   virtual QFont font() const { return QFont(); }
 
   // Functions that help the Scene to compute its bbox
-  //! \brief Determines if the item is finite or not.
+  //! \brief determines if the item is finite or not.
   //!
   //! For example, a plane is not finite.
   //! If false, the BBox is not computed.
@@ -207,10 +200,10 @@ public:
   virtual bool manipulatable() const { return false; }
   //!\brief The manipulatedFrame of the item.
   //!
-  //! A manipulated frame is an independant system that can be
+  //! A manipulated frame is an independent system that can be
   //! translated or rotated using the Ctrl key and the mouse.
   //!@returns the manipulatedFrame of the item.
-  virtual ManipulatedFrame* manipulatedFrame() { return 0; }
+  virtual ManipulatedFrame* manipulatedFrame() { return nullptr; }
 
   // Getters for the four basic properties
   //!Getter for the item's color.
@@ -247,7 +240,7 @@ public:
   //!
   int getId()const;
 
-  //! invalidates the context menu. Call it when supportsRenderingMode() changes, 
+  //! invalidates the context menu. Call it when supportsRenderingMode() changes,
   //! for example.
   void resetMenu();
   //!Handles key press events.
@@ -288,7 +281,7 @@ public:
   virtual Header_data header()const;
   //!Returns true if the item has statistics.
   virtual bool has_stats()const{return false;}
-  //!Returns a QString containing the requested value for the the table in the statistics dialog
+  //!Returns a QString containing the requested value for the table in the statistics dialog
   /*! \verbatim
    * Example :
    *  ____________________________
@@ -296,7 +289,7 @@ public:
    * |             |_______|_____|
    * |General Info | #Edges|12   |
    * |_____________|_______|_____|
-   * compute stats(0) should return "Cube" and computeStats(1) should return QString::number(12);
+   * ComputeStats(0) should return "Cube" and computeStats(1) should return QString::number(12);
    * The numbers must be coherent with the order of declaration of the titles in the header.
    * \endverbatim
    *
@@ -305,6 +298,18 @@ public:
 
   //!Contains the number of group and subgroups containing this item.
   int has_group;
+  //!
+  //! \brief newViewer adds Vaos for `viewer`.
+  //!
+  //! Must be overridden;
+  //!
+  virtual void newViewer(CGAL::Three::Viewer_interface* viewer) = 0;
+  //!
+  //! \brief removeViewer removes the Vaos of `viewer`.
+  //!
+  //! Must be overridden;
+  //!
+  virtual void removeViewer(CGAL::Three::Viewer_interface* viewer) = 0;
 
 public Q_SLOTS:
 
@@ -326,12 +331,12 @@ public Q_SLOTS:
   //!This function is called by `Scene::changeGroup` and should not be
   //!called manually.
   virtual void moveToGroup(Scene_group_item* group);
-  void setRenderingMode(int m) { setRenderingMode((RenderingMode)m);}
+  void setRenderingMode(int m) { setRenderingMode(static_cast<RenderingMode>(m));}
   //!Sets the rendering mode of the item.
   //!@see RenderingMode
-  virtual void setRenderingMode(RenderingMode m) { 
+  virtual void setRenderingMode(RenderingMode m) {
     if (supportsRenderingMode(m))
-      rendering_mode = m; 
+      rendering_mode = m;
     Q_EMIT redraw();
   }
   //!Sets the RenderingMode to Points.
@@ -363,19 +368,23 @@ public Q_SLOTS:
   void setPointsPlusNormalsMode(){
     setRenderingMode(PointsPlusNormals);
   }
-  
+  //!Sets the RenderingMode to GouraudPlusEdges.
+  void setGouraudPlusEdgesMode(){
+    setRenderingMode(GouraudPlusEdges);
+  }
+
   //!Emits an aboutToBeDestroyed() signal.
   //!Override this function to delete what needs to be deleted on destruction.
-  //!This might be needed as items are not always deleted right away by Qt and this behaviour may cause a simily
+  //!This might be needed as items are not always deleted right away by Qt and this behaviour may cause simply a
   //!memory leak, for example when multiple items are created at the same time.
   virtual void itemAboutToBeDestroyed(Scene_item*);
   //!Returns the alpha value for the item.
     //! Must be called within a valid openGl context.
     virtual float alpha() const;
-  
-    //! Sets the value of the aplha Slider for this item.
+
+    //! Sets the value of the alpha Slider for this item.
     //!
-    //! Must be overriden;
+    //! Must be overridden;
     //! \param alpha must be between 0 and 255
     virtual void setAlpha(int alpha);
   //!Selects a point through raycasting.
@@ -473,11 +482,11 @@ protected:
   void attribBuffers(CGAL::Three::Viewer_interface*, int program_name) const;
 
   /*! Compatibility function. Calls `viewer->getShaderProgram()`. */
-  virtual QOpenGLShaderProgram* getShaderProgram(int name , CGAL::Three::Viewer_interface *viewer = 0) const;
+  virtual QOpenGLShaderProgram* getShaderProgram(int name , CGAL::Three::Viewer_interface *viewer = nullptr) const;
 public:
   //! \brief defaultSaveName returns the name to be used as default
   //! when saving this item.
-  //! 
+  //!
   //! Default is `name()`.
   //! \return A new name for the default value in the "save as" dialog.
   virtual QString defaultSaveName() const { return name(); }
