@@ -2,20 +2,11 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Triangulation_2/include/CGAL/Triangulation_hierarchy_2.h $
+// $Id: Triangulation_hierarchy_2.h eed54a0ae5e 2022-11-15T18:45:39+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Triangulation_2/include/CGAL/Triangulation_hierarchy_2.h $
-// $Id: Triangulation_hierarchy_2.h 6c791f1 2018-01-17T16:12:12+00:00 Andreas Fabri
-// SPDX-License-Identifier: GPL-3.0+
-// 
 //
 // Author(s)     : Olivier Devillers <Olivivier.Devillers@sophia.inria.fr>
 //                 Mariette Yvinec  <Mariette.Yvinec@sophia.inria.fr>
@@ -28,16 +19,15 @@
 #include <CGAL/disable_warnings.h>
 
 #include <CGAL/basic.h>
-#include <CGAL/internal/Has_nested_type_Bare_point.h>
+#include <CGAL/STL_Extension/internal/Has_nested_type_Bare_point.h>
 #include <CGAL/Triangulation_hierarchy_vertex_base_2.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/spatial_sort.h>
 #include <CGAL/Spatial_sort_traits_adapter_2.h>
 
-#include <CGAL/internal/boost/function_property_map.hpp>
-
 #include <boost/mpl/identity.hpp>
 #include <boost/mpl/if.hpp>
+#include <boost/property_map/function_property_map.hpp>
 #include <boost/random/linear_congruential.hpp>
 #include <boost/random/geometric_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -46,6 +36,8 @@
 #include <iostream>
 #include <map>
 #include <vector>
+#include <array>
+#include <CGAL/array.h>
 
 namespace CGAL {
 
@@ -56,11 +48,11 @@ const int   Triangulation_hierarchy_2__minsize  = 20;
 const int   Triangulation_hierarchy_2__maxlevel = 5;
 // maximal number of points is 30^5 = 24 millions !
 
-template < class Tr_>
+template <class Tr_>
 class Triangulation_hierarchy_2
   : public Tr_
 {
- public:
+public:
   typedef Tr_                                  Tr_Base;
   typedef typename Tr_Base::Geom_traits        Geom_traits;
   typedef typename Tr_Base::size_type          size_type;
@@ -86,31 +78,55 @@ class Triangulation_hierarchy_2
 
 #ifndef CGAL_CFG_USING_BASE_MEMBER_BUG_2
   using Tr_Base::geom_traits;
+  using Tr_Base::number_of_vertices;
+  using Tr_Base::is_infinite;
 #endif
 
  private:
-  // here is the stack of triangulations which form the hierarchy
-  Tr_Base*   hierarchy[Triangulation_hierarchy_2__maxlevel];
+  void init_hierarchy() {
+    hierarchy[0] = this;
+    for(int i=1; i<Triangulation_hierarchy_2__maxlevel; ++i)
+      hierarchy[i] = &hierarchy_triangulations[i-1];
+  }
+
+ // here is the stack of triangulations which form the hierarchy
+  std::array<Tr_Base,Triangulation_hierarchy_2__maxlevel-1> hierarchy_triangulations;
+  std::array<Tr_Base*,Triangulation_hierarchy_2__maxlevel> hierarchy;
   boost::rand48  random;
 
 public:
   Triangulation_hierarchy_2(const Geom_traits& traits = Geom_traits());
   Triangulation_hierarchy_2(const Triangulation_hierarchy_2& tr);
 
+  Triangulation_hierarchy_2(Triangulation_hierarchy_2&& other)
+    noexcept( noexcept(Tr_Base(std::move(other))) )
+    : Tr_Base(std::move(other))
+    , hierarchy_triangulations(std::move(other.hierarchy_triangulations))
+    , random(std::move(other.random))
+  {
+    init_hierarchy();
+  }
+
   template<class InputIterator>
   Triangulation_hierarchy_2(InputIterator first, InputIterator beyond,
-			    const Geom_traits& traits = Geom_traits())
+                            const Geom_traits& traits = Geom_traits())
     : Tr_Base(traits)
-  { 
-    hierarchy[0] = this; 
-    for(int i=1;i<Triangulation_hierarchy_2__maxlevel;++i)
-      hierarchy[i] = new Tr_Base(traits);
-
+  {
+    init_hierarchy();
     insert (first, beyond);
   }
 
   Triangulation_hierarchy_2 &operator=(const  Triangulation_hierarchy_2& tr);
-  ~Triangulation_hierarchy_2();
+
+  Triangulation_hierarchy_2 & operator=(Triangulation_hierarchy_2&& other)
+    noexcept( noexcept(Triangulation_hierarchy_2(std::move(other))) )
+  {
+    static_cast<Tr_Base&>(*this) = std::move(other);
+    hierarchy_triangulations = std::move(other.hierarchy_triangulations);
+    return *this;
+  }
+
+  ~Triangulation_hierarchy_2() = default;
 
   //Helping
   void copy_triangulation(const Triangulation_hierarchy_2 &tr);
@@ -123,26 +139,26 @@ public:
   // INSERT REMOVE MOVE
   Vertex_handle insert(const Point &p, Face_handle start = Face_handle() );
   Vertex_handle insert(const Point& p,
-		       Locate_type lt,
-		       Face_handle loc, int li );
+                       Locate_type lt,
+                       Face_handle loc, int li );
   Vertex_handle push_back(const Point &p);
- 
+
   template < class InputIterator >
   std::ptrdiff_t insert(InputIterator first, InputIterator last)
   {
-    std::ptrdiff_t n = this->number_of_vertices();
+    std::ptrdiff_t n = number_of_vertices();
 
       std::vector<Point> points (first, last);
 
       // Spatial sort can only be used with Gt::Point_2: we need an adapter
       typedef typename Geom_traits::Construct_point_2 Construct_point_2;
       typedef typename boost::result_of<const Construct_point_2(const Point&)>::type Ret;
-      typedef CGAL::internal::boost_::function_property_map<Construct_point_2, Point, Ret> fpmap;
+      typedef boost::function_property_map<Construct_point_2, Point, Ret> fpmap;
       typedef CGAL::Spatial_sort_traits_adapter_2<Geom_traits, fpmap> Search_traits_2;
 
       spatial_sort(points.begin(), points.end(),
                    Search_traits_2(
-                     CGAL::internal::boost_::make_function_property_map<Point, Ret, Construct_point_2>(
+                     boost::make_function_property_map<Point, Ret, Construct_point_2>(
                        geom_traits().construct_point_2_object()), geom_traits()));
 
       // hints[i] is the face of the previously inserted point in level i.
@@ -168,7 +184,7 @@ public:
               prev = v;
           }
       }
-      std::ptrdiff_t m = this->number_of_vertices();
+      std::ptrdiff_t m = number_of_vertices();
       return m - n;
   }
 
@@ -186,26 +202,26 @@ protected: // some internal methods
   // GIVING NEW FACES
 
   template <class OutputItFaces>
-  Vertex_handle insert_and_give_new_faces(const Point  &p, 
+  Vertex_handle insert_and_give_new_faces(const Point  &p,
                                           OutputItFaces fit,
                                           Face_handle start = Face_handle() );
 
   template <class OutputItFaces>
   Vertex_handle insert_and_give_new_faces(const Point& p,
                                           Locate_type lt,
-                                          Face_handle loc, int li, 
+                                          Face_handle loc, int li,
                                           OutputItFaces fit);
 
   template <class OutputItFaces>
-  void remove_and_give_new_faces(Vertex_handle v, 
+  void remove_and_give_new_faces(Vertex_handle v,
                                  OutputItFaces fit);
-	
+
   template <class OutputItFaces>
-  Vertex_handle move_if_no_collision_and_give_new_faces(Vertex_handle v, 
-                                                        const Point &p, OutputItFaces fit);	
+  Vertex_handle move_if_no_collision_and_give_new_faces(Vertex_handle v,
+                                                        const Point &p, OutputItFaces fit);
 
 public:
-	
+
   //LOCATE
   Face_handle
   locate(const Point& p,
@@ -236,7 +252,7 @@ private:
   Vertex_handle
   nearest_vertex_dispatch(const Point&, Face_handle, Tag_true) const
   {
-    CGAL_triangulation_assertion(false);
+    CGAL_assertion(false);
     return Vertex_handle();
   }
 
@@ -251,79 +267,76 @@ private:
 
   // helping function to copy_triangulation
   // the version to be used with Tag_true is templated to avoid
-  // systematique instanciation
+  // systematic instantiation
   template <class Tag>
   void add_hidden_vertices_into_map(Tag,
-				    std::map<Vertex_handle,Vertex_handle >& V)
+                                    std::map<Vertex_handle,Vertex_handle >& V)
   {
-    for (typename Tr_Base::Hidden_vertices_iterator 
-	   it=hierarchy[0]->hidden_vertices_begin(); 
-	 it != hierarchy[0]->hidden_vertices_end(); ++it) {
+    for (typename Tr_Base::Hidden_vertices_iterator
+           it=hierarchy[0]->hidden_vertices_begin();
+         it != hierarchy[0]->hidden_vertices_end(); ++it) {
       if (it->up() != Vertex_handle()) V[ it->up()->down() ] = it;
     }
   }
-  
-  
+
+
   void add_hidden_vertices_into_map(Tag_false ,
-				    std::map<Vertex_handle,Vertex_handle >& )
+                                    std::map<Vertex_handle,Vertex_handle >& )
   {return;}
 };
 
 
 
-template <class Tr >
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+Triangulation_hierarchy_2<Tr_>::
 Triangulation_hierarchy_2(const Geom_traits& traits)
   : Tr_Base(traits)
-{ 
-  hierarchy[0] = this; 
-  for(int i=1;i<Triangulation_hierarchy_2__maxlevel;++i)
-    hierarchy[i] = new Tr_Base(traits);
+  , hierarchy_triangulations(
+           make_filled_array<Triangulation_hierarchy_2__maxlevel-1,
+                             Tr_Base>(traits))
+{
+  init_hierarchy();
 }
 
 
 // copy constructor duplicates vertices and faces
-template <class Tr>
-Triangulation_hierarchy_2<Tr>::
-Triangulation_hierarchy_2(const Triangulation_hierarchy_2<Tr> &tr)
-    : Tr_Base()
-{ 
-  // create an empty triangulation to be able to delete it !
-  hierarchy[0] = this; 
-  for(int i=1;i<Triangulation_hierarchy_2__maxlevel;++i)
-    hierarchy[i] = new Tr_Base(tr.geom_traits());
+template <class Tr_>
+Triangulation_hierarchy_2<Tr_>::
+Triangulation_hierarchy_2(const Triangulation_hierarchy_2<Tr_> &tr)
+  : Triangulation_hierarchy_2(tr.geom_traits())
+{
   copy_triangulation(tr);
-} 
- 
+}
 
-//Assignement
-template <class Tr>
-Triangulation_hierarchy_2<Tr> &
-Triangulation_hierarchy_2<Tr>::
-operator=(const Triangulation_hierarchy_2<Tr> &tr)
+
+//Assignment
+template <class Tr_>
+Triangulation_hierarchy_2<Tr_> &
+Triangulation_hierarchy_2<Tr_>::
+operator=(const Triangulation_hierarchy_2<Tr_> &tr)
 {
   copy_triangulation(tr);
   return *this;
 }
 
 
-template <class Tr>
+template <class Tr_>
 void
-Triangulation_hierarchy_2<Tr>::   
-copy_triangulation(const Triangulation_hierarchy_2<Tr> &tr)
+Triangulation_hierarchy_2<Tr_>::
+copy_triangulation(const Triangulation_hierarchy_2<Tr_> &tr)
 {
   {
     for(int i=0;i<Triangulation_hierarchy_2__maxlevel;++i)
     hierarchy[i]->copy_triangulation(*tr.hierarchy[i]);
   }
-   
+
 
   //up and down have been copied in straightforward way
   // compute a map at lower level
   std::map<Vertex_handle, Vertex_handle > V;
   {
-    for( Finite_vertices_iterator it=hierarchy[0]->finite_vertices_begin(); 
-	 it != hierarchy[0]->finite_vertices_end(); ++it) {
+    for( Finite_vertices_iterator it=hierarchy[0]->finite_vertices_begin();
+         it != hierarchy[0]->finite_vertices_end(); ++it) {
       if (it->up() != Vertex_handle()) V[ it->up()->down() ] = it;
     }
   }
@@ -332,80 +345,66 @@ copy_triangulation(const Triangulation_hierarchy_2<Tr> &tr)
 
   {
     for(int i=1;i<Triangulation_hierarchy_2__maxlevel;++i) {
-      for( Finite_vertices_iterator it=hierarchy[i]->finite_vertices_begin(); 
-	   it != hierarchy[i]->finite_vertices_end(); ++it) {
-	// down pointer goes in original instead in copied triangulation
-	it->set_down(V[it->down()]);
-	// make reverse link
-	it->down()->set_up(it);
-	// I think the next line is unnecessary (my)
-	// make map for next level
-	if (it->up()!=  Vertex_handle() ) V[ it->up()->down() ] = it;
+      for( Finite_vertices_iterator it=hierarchy[i]->finite_vertices_begin();
+           it != hierarchy[i]->finite_vertices_end(); ++it) {
+        // down pointer goes in original instead in copied triangulation
+        it->set_down(V[it->down()]);
+        // make reverse link
+        it->down()->set_up(it);
+        // I think the next line is unnecessary (my)
+        // make map for next level
+        if (it->up()!=  Vertex_handle() ) V[ it->up()->down() ] = it;
       }
     }
   }
 }
 
-/* template <class Tr> */
+/* template <class Tr_> */
 /* void */
-/* Triangulation_hierarchy_2<Tr>::  */
+/* Triangulation_hierarchy_2<Tr_>::  */
 /* add_hidden_vertices_into_map(Tag_false, */
-/* 			     std::map<Vertex_handle,Vertex_handle >& V) { */
+/*                              std::map<Vertex_handle,Vertex_handle >& V) { */
 /*   return; */
 /* } */
 
 
-/* template <class Tr> */
+/* template <class Tr_> */
 /* void */
-/* Triangulation_hierarchy_2<Tr>::  */
+/* Triangulation_hierarchy_2<Tr_>::  */
 /* add_hidden_vertices_into_map(Tag_true, */
-/* 			     std::map<Vertex_handle,Vertex_handle >& V)  */
+/*                              std::map<Vertex_handle,Vertex_handle >& V)  */
 /* { */
 /*   for (typename Tr_Base::Hidden_vertices_iterator  */
-/* 	 it=hierarchy[0]->hidden_vertices_begin();  */
+/*          it=hierarchy[0]->hidden_vertices_begin();  */
 /*        it != hierarchy[0]->hidden_vertices_end(); ++it) { */
 /*     if (it->up() != Vertex_handle()) V[ it->up()->down() ] = it; */
 /*   } */
 /* } */
 
 
-template <class Tr>
+template <class Tr_>
 void
-Triangulation_hierarchy_2<Tr>:: 
-swap(Triangulation_hierarchy_2<Tr> &tr)
+Triangulation_hierarchy_2<Tr_>::
+swap(Triangulation_hierarchy_2<Tr_> &tr)
 {
-  Tr_Base* temp;
   Tr_Base::swap(tr);
-  for(int i= 1; i<Triangulation_hierarchy_2__maxlevel; ++i){
-    temp = hierarchy[i];
-    hierarchy[i] = tr.hierarchy[i];
-    tr.hierarchy[i]= temp;
-  }
+  using std::swap;
+  swap(hierarchy_triangulations, tr.hierarchy_triangulations);
 }
 
-template <class Tr>
-Triangulation_hierarchy_2<Tr>:: 
-~Triangulation_hierarchy_2()
-{
-  clear();
-  for(int i= 1; i<Triangulation_hierarchy_2__maxlevel; ++i){ 
-    delete hierarchy[i];
-  }
-}
-
-template <class Tr>
+template <class Tr_>
 void
-Triangulation_hierarchy_2<Tr>:: 
+Triangulation_hierarchy_2<Tr_>::
 clear()
 {
-        for(int i=0;i<Triangulation_hierarchy_2__maxlevel;++i)
-	hierarchy[i]->clear();
+  for(int i=0;i<Triangulation_hierarchy_2__maxlevel;++i)
+    if(hierarchy[i]) hierarchy[i]->clear();
 }
 
 
-template <class Tr>
+template <class Tr_>
 bool
-Triangulation_hierarchy_2<Tr>:: 
+Triangulation_hierarchy_2<Tr_>::
 is_valid(bool verbose, int level) const
 {
   bool result = true;
@@ -414,33 +413,33 @@ is_valid(bool verbose, int level) const
   //verify correctness of triangulation at all levels
   for(i=0;i<Triangulation_hierarchy_2__maxlevel;++i) {
     if(verbose) // pirnt  number of vertices at each level
-      std::cout << "number_of_vertices " 
-		<<  hierarchy[i]->number_of_vertices() << std::endl;
+      std::cout << "number_of_vertices "
+                <<  hierarchy[i]->number_of_vertices() << std::endl;
     result = result && hierarchy[i]->is_valid(verbose,level);
   }
     //verify that lower level has no down pointers
-  for( it = hierarchy[0]->finite_vertices_begin(); 
-       it != hierarchy[0]->finite_vertices_end(); ++it) 
+  for( it = hierarchy[0]->finite_vertices_begin();
+       it != hierarchy[0]->finite_vertices_end(); ++it)
     result = result && ( it->down() ==   Vertex_handle());
   //verify that other levels have down pointer and reciprocal link is fine
   for(i=1;i<Triangulation_hierarchy_2__maxlevel;++i)
-    for( it = hierarchy[i]->finite_vertices_begin(); 
-	 it != hierarchy[i]->finite_vertices_end(); ++it) 
-      result = result && 
-	       ( &*(it->down()->up())  ==  &*(it) );
+    for( it = hierarchy[i]->finite_vertices_begin();
+         it != hierarchy[i]->finite_vertices_end(); ++it)
+      result = result &&
+               ( &*(it->down()->up())  ==  &*(it) );
   //verify that levels have up pointer and reciprocal link is fine
   for(i=0;i<Triangulation_hierarchy_2__maxlevel-1;++i)
-    for( it = hierarchy[i]->finite_vertices_begin(); 
-	 it != hierarchy[i]->finite_vertices_end(); ++it) 
+    for( it = hierarchy[i]->finite_vertices_begin();
+         it != hierarchy[i]->finite_vertices_end(); ++it)
       result = result && ( it->up() ==  Vertex_handle() ||
-	        &*it == &*(it->up())->down() );
+                &*it == &*(it->up())->down() );
   return result;
 }
 
-  
-template <class Tr>
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle
-Triangulation_hierarchy_2<Tr>::
+
+template <class Tr_>
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
 insert(const Point &p, Face_handle loc)
 {
   int vertex_level = random_level();
@@ -452,7 +451,7 @@ insert(const Point &p, Face_handle loc)
   Vertex_handle vertex=hierarchy[0]->Tr_Base::insert(p,lt,positions[0],i);
   Vertex_handle previous=vertex;
   Vertex_handle first = vertex;
-      
+
   int level  = 1;
   while (level <= vertex_level ){
     vertex=hierarchy[level]->Tr_Base::insert(p,positions[level]);
@@ -464,12 +463,12 @@ insert(const Point &p, Face_handle loc)
   return first;
 }
 
-template <class Tr>
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
 insert(const Point& p,
        Locate_type lt,
-       Face_handle loc, 
+       Face_handle loc,
        int li )
 {
   int vertex_level = random_level();
@@ -497,34 +496,34 @@ insert(const Point& p,
   return first;
 }
 
-template <class Tr>
+template <class Tr_>
 inline
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle
-Triangulation_hierarchy_2<Tr>::
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
 push_back(const Point &p)
 {
   return insert(p);
 }
 
-template <class Tr>
-void 
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+void
+Triangulation_hierarchy_2<Tr_>::
 remove(Vertex_handle v )
 {
   Vertex_handle u=v->up();
   int l = 0 ;
   while(1){
     hierarchy[l++]->remove(v);
-    if (u == Vertex_handle()) break; 
+    if (u == Vertex_handle()) break;
     if (l >= Triangulation_hierarchy_2__maxlevel) break;
     v=u; u=v->up();
   }
 }
 
-template <class Tr>
+template <class Tr_>
 template <class OutputItFaces>
 void
-Triangulation_hierarchy_2<Tr>::
+Triangulation_hierarchy_2<Tr_>::
 remove_and_give_new_faces(Vertex_handle v, OutputItFaces fit)
 {
   Vertex_handle u=v->up();
@@ -532,58 +531,58 @@ remove_and_give_new_faces(Vertex_handle v, OutputItFaces fit)
   while(1){
     if(l==0) hierarchy[l++]->remove_and_give_new_faces(v, fit);
     else hierarchy[l++]->remove(v);
-    if (u == Vertex_handle()) break; 
+    if (u == Vertex_handle()) break;
     if (l >= Triangulation_hierarchy_2__maxlevel) break;
     v=u; u=v->up();
-  }	
+  }
 }
 
 
-template <class Tr>
-inline void 
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+inline void
+Triangulation_hierarchy_2<Tr_>::
 remove_degree_3(Vertex_handle v )
 {
   remove(v);
 }
 
-template <class Tr>
-inline void 
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+inline void
+Triangulation_hierarchy_2<Tr_>::
 remove_first(Vertex_handle v )
 {
   remove(v);
 }
 
-template <class Tr>
-inline void 
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+inline void
+Triangulation_hierarchy_2<Tr_>::
 remove_second(Vertex_handle v )
 {
   remove(v);
 }
 
-template <class Tr>
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
 move_if_no_collision(Vertex_handle v, const Point &p) {
   Vertex_handle u=v->up(), norm = v;
   int l = 0 ;
   while(1) {
     Vertex_handle w = hierarchy[l++]->move_if_no_collision(v, p);
     if(w != v) return w;
-    if (u == Vertex_handle()) break; 
+    if (u == Vertex_handle()) break;
     if (l >= Triangulation_hierarchy_2__maxlevel) break;
     v=u; u=v->up();
   }
   return norm;
 }
 
-template <class Tr>
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
 move(Vertex_handle v, const Point &p) {
-  CGAL_triangulation_precondition(!this->is_infinite(v));
+  CGAL_precondition(!is_infinite(v));
   Vertex_handle w = move_if_no_collision(v,p);
   if(w != v) {
     remove(v);
@@ -592,36 +591,36 @@ move(Vertex_handle v, const Point &p) {
   return v;
 }
 
-template <class Tr>
+template <class Tr_>
 template <class OutputItFaces>
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle 
-Triangulation_hierarchy_2<Tr>::
-move_if_no_collision_and_give_new_faces(Vertex_handle v, const Point &p, 
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
+move_if_no_collision_and_give_new_faces(Vertex_handle v, const Point &p,
                                         OutputItFaces oif)
 {
   Vertex_handle u=v->up(), norm = v;
   int l = 0 ;
   while(1){
     Vertex_handle w;
-    if(l == 0) 
-      w = 
+    if(l == 0)
+      w =
         hierarchy[l++]->move_if_no_collision_and_give_new_faces(v, p, oif);
     else w = hierarchy[l++]->move_if_no_collision(v, p);
 
     if(w != v) return w;
 
-    if (u == Vertex_handle()) break; 
+    if (u == Vertex_handle()) break;
     if (l >= Triangulation_hierarchy_2__maxlevel) break;
     v=u; u=v->up();
   }
   return norm;
 }
 
-template < class Tr >
+template <class Tr_>
 template < class OutputItFaces >
 inline
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle 
-Triangulation_hierarchy_2<Tr>::insert_and_give_new_faces(const Point  &p, 
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::insert_and_give_new_faces(const Point  &p,
                                                          OutputItFaces oif,
                                                          Face_handle loc)
 {
@@ -635,7 +634,7 @@ Triangulation_hierarchy_2<Tr>::insert_and_give_new_faces(const Point  &p,
     hierarchy[0]->Tr_Base::insert_and_give_new_faces(p,lt,positions[0],i,oif);
   Vertex_handle previous=vertex;
   Vertex_handle first = vertex;
-      
+
   int level  = 1;
   while (level <= vertex_level ){
     vertex=hierarchy[level]->Tr_Base::insert(p,positions[level]);
@@ -646,16 +645,16 @@ Triangulation_hierarchy_2<Tr>::insert_and_give_new_faces(const Point  &p,
   }
   return first;
 }
-		
-template < class Tr >
+
+template <class Tr_>
 template < class OutputItFaces >
 inline
-typename Triangulation_hierarchy_2<Tr>::Vertex_handle 
-Triangulation_hierarchy_2<Tr>::
+typename Triangulation_hierarchy_2<Tr_>::Vertex_handle
+Triangulation_hierarchy_2<Tr_>::
 insert_and_give_new_faces(const Point  &p,
                           Locate_type lt,
                           Face_handle loc,
-                          int li, 
+                          int li,
                           OutputItFaces oif)
 {
   int vertex_level = random_level();
@@ -683,9 +682,9 @@ insert_and_give_new_faces(const Point  &p,
   return first;
 }
 
-template <class Tr>
-typename Triangulation_hierarchy_2<Tr>::Face_handle 
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+typename Triangulation_hierarchy_2<Tr_>::Face_handle
+Triangulation_hierarchy_2<Tr_>::
 locate(const Point& p, Locate_type& lt, int& li, Face_handle loc) const
 {
   Face_handle positions[Triangulation_hierarchy_2__maxlevel];
@@ -693,9 +692,9 @@ locate(const Point& p, Locate_type& lt, int& li, Face_handle loc) const
   return positions[0];
 }
 
-template <class Tr>
-typename Triangulation_hierarchy_2<Tr>::Face_handle 
-Triangulation_hierarchy_2<Tr>::
+template <class Tr_>
+typename Triangulation_hierarchy_2<Tr_>::Face_handle
+Triangulation_hierarchy_2<Tr_>::
 locate(const Point& p, Face_handle loc ) const
 {
   Locate_type lt;
@@ -703,9 +702,9 @@ locate(const Point& p, Face_handle loc ) const
   return locate(p, lt, li, loc);
 }
 
-template <class Tr>
+template <class Tr_>
 void
-Triangulation_hierarchy_2<Tr>::
+Triangulation_hierarchy_2<Tr_>::
 locate_in_all(const Point& p,
               Locate_type& lt,
               int& li,
@@ -716,22 +715,22 @@ locate_in_all(const Point& p,
   Vertex_handle nearest;
   int level  = Triangulation_hierarchy_2__maxlevel;
   typename Geom_traits::Compare_distance_2
-    closer = this->geom_traits().compare_distance_2_object();
+    closer = geom_traits().compare_distance_2_object();
 
   typename Geom_traits::Construct_point_2
-    construct_point = this->geom_traits().construct_point_2_object();
-  
+    construct_point = geom_traits().construct_point_2_object();
+
   // find the highest level with enough vertices that is at the same time 2D
-  while ( (hierarchy[--level]->number_of_vertices() 
-	   < static_cast<size_type> (Triangulation_hierarchy_2__minsize ))
-	  || (hierarchy[level]->dimension()<2) ){
+  while ( (hierarchy[--level]->number_of_vertices()
+           < static_cast<size_type> (Triangulation_hierarchy_2__minsize ))
+          || (hierarchy[level]->dimension()<2) ){
     if ( ! level) break;  // do not go below 0
   }
-  if((level>0) && (hierarchy[level]->dimension()<2)){ 
+  if((level>0) && (hierarchy[level]->dimension()<2)){
     level--;
   }
 
-  for (int i=level+1; i<Triangulation_hierarchy_2__maxlevel;++i) pos[i]=0;
+  for (int i=level+1; i<Triangulation_hierarchy_2__maxlevel;++i) pos[i]=nullptr;
   while(level > 0) {
     pos[level]=position=hierarchy[level]->locate(p, position);
     // locate at that level from "position"
@@ -751,12 +750,12 @@ locate_in_all(const Point& p,
     else{
       nearest = position->vertex(1);
 }
-    // compare to vertex 2, but only if the triangulation is 2D, because otherwise vertex(2) is  NULL
+    // compare to vertex 2, but only if the triangulation is 2D, because otherwise vertex(2) is  nullptr
     if ( (hierarchy[level]->dimension()==2) && (!  hierarchy[level]->is_infinite(position->vertex(2)))){
-      if ( closer( construct_point(p), 
-		   construct_point(position->vertex(2)->point()),
-		   construct_point(nearest->point())) == SMALLER ){
-	nearest = position->vertex(2);
+      if ( closer( construct_point(p),
+                   construct_point(position->vertex(2)->point()),
+                   construct_point(nearest->point())) == SMALLER ){
+        nearest = position->vertex(2);
       }
     }
     // go at the same vertex on level below
@@ -764,12 +763,12 @@ locate_in_all(const Point& p,
     position = nearest->face();                // incident face
     --level;
   }
-  pos[0]=hierarchy[0]->locate(p,lt,li,loc == Face_handle() ? position : loc);  // at level 0 
+  pos[0]=hierarchy[0]->locate(p,lt,li,loc == Face_handle() ? position : loc);  // at level 0
 }
 
-template <class Tr>
+template <class Tr_>
 int
-Triangulation_hierarchy_2<Tr>::
+Triangulation_hierarchy_2<Tr_>::
 random_level()
 {
   boost::geometric_distribution<> proba(1.0/Triangulation_hierarchy_2__ratio);
