@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Surface_mesh_approximation/include/CGAL/Variational_shape_approximation.h $
-// $Id: Variational_shape_approximation.h aa47744 2019-07-28T22:30:17+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Surface_mesh_approximation/include/CGAL/Variational_shape_approximation.h $
+// $Id: Variational_shape_approximation.h 6e6598cd5ed 2023-10-10T19:32:59+02:00 Jane Tournois
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Pierre Alliez and Lingjie Zhu
@@ -42,10 +33,9 @@
 #include <boost/graph/adjacency_list.hpp>
 #include <boost/graph/dijkstra_shortest_paths.hpp>
 #include <boost/graph/subgraph.hpp>
-#include <boost/foreach.hpp>
 #include <boost/optional.hpp>
 
-#include <CGAL/boost/graph/Named_function_parameters.h>
+#include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 
 #include <vector>
@@ -64,7 +54,7 @@
 #include <iostream>
 #endif
 
-#define CGAL_VSA_INVALID_TAG std::numeric_limits<std::size_t>::max()
+#define CGAL_VSA_INVALID_TAG (std::numeric_limits<std::size_t>::max)()
 
 namespace CGAL {
 
@@ -124,7 +114,7 @@ public:
   typedef typename Error_metric::Proxy Proxy;
 
   /// Indexed triangle type
-  typedef CGAL::cpp11::array<std::size_t, 3> Indexed_triangle;
+  typedef std::array<std::size_t, 3> Indexed_triangle;
   /// @}
 
 // private typedefs and data member
@@ -305,20 +295,36 @@ public:
    * @brief initializes the seeds with both maximum number of proxies and minimum error drop stop criteria.
    * The first criterion met stops the seeding.
    * Parameters out of range are ignored.
-   * @tparam NamedParameters a sequence of \ref vsa_namedparameters
+   * @tparam NamedParameters a sequence of \ref bgl_namedparameters
 
-   * @param np optional sequence of \ref vsa_namedparameters among the ones listed below
+   * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
    * @return number of proxies initialized
 
    * \cgalNamedParamsBegin{Seeding Named Parameters}
-   *  \cgalParamBegin{seeding_method} selection of seeding method.
-   *  \cgalParamEnd
-   *  \cgalParamBegin{max_number_of_proxies} maximum number of proxies to approximate the input mesh.
-   *  \cgalParamEnd
-   *  \cgalParamBegin{min_error_drop} minimum error drop of the approximation, expressed in ratio between two iterations of proxy addition.
-   *  \cgalParamEnd
-   *  \cgalParamBegin{number_of_relaxations} number of relaxation iterations interleaved within seeding.
-   *  \cgalParamEnd
+   *   \cgalParamNBegin{seeding_method}
+   *     \cgalParamDescription{the selection of seeding method}
+   *     \cgalParamType{`CGAL::Surface_mesh_approximation::Seeding_method`}
+   *     \cgalParamDefault{`CGAL::Surface_mesh_approximation::HIERARCHICAL`}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{max_number_of_proxies}
+   *     \cgalParamDescription{the maximum number of proxies used to approximate the input mesh}
+   *     \cgalParamType{`std::size_t`}
+   *     \cgalParamDefault{`num_faces(tm) / 3`, used when `min_error_drop` is also not provided}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{min_error_drop}
+   *     \cgalParamDescription{the minimum error drop of the approximation, expressed as
+   *                           the ratio between two iterations of proxy addition}
+   *     \cgalParamType{`geom_traits::FT`}
+   *     \cgalParamDefault{`0.1`, used when `max_number_of_proxies` is also not provided}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{number_of_relaxations}
+   *     \cgalParamDescription{the number of relaxation iterations interleaved within seeding}
+   *     \cgalParamType{`std::size_t`}
+   *     \cgalParamDefault{`5`}
+   *   \cgalParamNEnd
    * \cgalNamedParamsEnd
    */
   template <typename NamedParameters>
@@ -370,7 +376,7 @@ public:
   FT run(std::size_t nb_iterations = 1) {
     for (std::size_t i = 0; i < nb_iterations; ++i) {
       // tag the whole surface
-      BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+      for(face_descriptor f : faces(*m_ptm))
         put(m_fproxy_map, f, CGAL_VSA_INVALID_TAG);
 
       partition(m_proxies.begin(), m_proxies.end());
@@ -424,7 +430,7 @@ public:
    */
   FT compute_total_error() {
     FT sum_error(0.0);
-    BOOST_FOREACH(const Proxy_wrapper &pxw, m_proxies)
+    for(const Proxy_wrapper& pxw : m_proxies)
       sum_error += pxw.err;
 
 #ifdef CGAL_SURFACE_MESH_APPROXIMATION_DEBUG
@@ -478,7 +484,7 @@ public:
       const double avg_face =
         static_cast<double>(m_nb_of_faces) / static_cast<double>(nb_proxies);
       std::vector<double> px_size(m_proxies.size(), 0.0);
-      BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+      for(face_descriptor f : faces(*m_ptm))
         px_size[get(m_fproxy_map, f)] += 1.0;
       double residual = 0.0;
       for (std::size_t i = 0; i < m_proxies.size(); ++i) {
@@ -515,7 +521,7 @@ public:
     }
 
     std::size_t num_added = 0;
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+    for(face_descriptor f : faces(*m_ptm)) {
       const std::size_t px_id = get(m_fproxy_map, f);
       if (m_proxies[px_id].seed == f)
         continue;
@@ -563,7 +569,7 @@ public:
       }
       bool found = false;
       face_descriptor tele_to;
-      BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+      for(face_descriptor f : faces(*m_ptm)) {
         if (get(m_fproxy_map, f) == px_worst && f != m_proxies[px_worst].seed) {
           // teleport to anywhere but the seed
           tele_to = f;
@@ -585,7 +591,7 @@ public:
       // teleport to a face of the worst region
       // update merged proxies
       std::list<face_descriptor> merged_patch;
-      BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+      for(face_descriptor f : faces(*m_ptm)) {
         std::size_t px_idx = get(m_fproxy_map, f);
         if (px_idx == best_proxies->first || px_idx == best_proxies->second) {
           put(m_fproxy_map, f, best_proxies->first);
@@ -625,7 +631,7 @@ public:
     const FT pre_err = m_proxies[px0].err + m_proxies[px1].err;
     // merge px1 to px0
     std::list<face_descriptor> merged_patch;
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+    for(face_descriptor f : faces(*m_ptm)) {
       std::size_t px_idx = get(m_fproxy_map, f);
       if (px_idx == px1 || px_idx == px0) {
         put(m_fproxy_map, f, px0);
@@ -639,7 +645,7 @@ public:
     for (std::size_t i = 0; i < m_proxies.size(); ++i)
       m_proxies[i].idx = i;
     // keep face proxy map valid
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+    for(face_descriptor f : faces(*m_ptm)) {
       if (get(m_fproxy_map, f) > px1)
         put(m_fproxy_map, f, get(m_fproxy_map, f) - 1);
     }
@@ -663,14 +669,14 @@ public:
 
     std::size_t px0 = 0, px1 = 0;
     std::vector<std::list<face_descriptor> > px_faces(m_proxies.size());
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       px_faces[get(m_fproxy_map, f)].push_back(f);
 
     // find best merge
     Pair_set merged_set;
     FT min_error_change = FT(0.0);
     bool first_merge = true;
-    BOOST_FOREACH(edge_descriptor e, edges(*m_ptm)) {
+    for(edge_descriptor e : edges(*m_ptm)) {
       if (CGAL::is_border(e, *m_ptm))
         continue;
       std::size_t pxi = get(m_fproxy_map, face(halfedge(e, *m_ptm), *m_ptm));
@@ -685,7 +691,7 @@ public:
       merged_set.insert(Proxy_pair(pxi, pxj));
       // simulated merge
       std::list<face_descriptor> merged_patch(px_faces[pxi]);
-      BOOST_FOREACH(face_descriptor f, px_faces[pxj])
+      for(face_descriptor f : px_faces[pxj])
         merged_patch.push_back(f);
       const Proxy_wrapper pxw_tmp = fit_proxy_from_patch(merged_patch, CGAL_VSA_INVALID_TAG);
 
@@ -731,7 +737,7 @@ public:
 
     // collect confined proxy area
     std::list<face_descriptor> confined_area;
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       if (get(m_fproxy_map, f) == px_idx)
         confined_area.push_back(f);
     // not enough faces to split
@@ -744,7 +750,7 @@ public:
 
     // select seed faces in the confined area
     std::size_t count = 1;
-    BOOST_FOREACH(face_descriptor f, confined_area) {
+    for(face_descriptor f : confined_area) {
       if (count >= n)
         break;
 
@@ -758,7 +764,7 @@ public:
 
     // relaxation on confined area and proxies
     for (std::size_t i = 0; i < nb_relaxations; ++i) {
-      BOOST_FOREACH(face_descriptor f, confined_area)
+      for(face_descriptor f : confined_area)
         put(m_fproxy_map, f, CGAL_VSA_INVALID_TAG);
 
       partition(confined_proxies.begin(), confined_proxies.end());
@@ -766,7 +772,7 @@ public:
     }
 
     // copy back
-    BOOST_FOREACH(const Proxy_wrapper &pxw, confined_proxies)
+    for(const Proxy_wrapper& pxw : confined_proxies)
       m_proxies[pxw.idx] = pxw;
 
     return true;
@@ -777,23 +783,42 @@ public:
   /// @{
   /*!
    * @brief extracts the output mesh in the form of an indexed triangle set.
-   * @tparam NamedParameters a sequence of \ref vsa_namedparameters
+   * @tparam NamedParameters a sequence of \ref bgl_namedparameters
    *
-   * @param np optional sequence of \ref vsa_namedparameters among the ones listed below
+   * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
    * @return `true` if the extracted surface mesh is manifold, and `false` otherwise.
    *
    * \cgalNamedParamsBegin{Meshing Named Parameters}
-   *   \cgalParamBegin{subdivision_ratio} chord subdivision ratio threshold to the chord length or average edge length.
-   *   \cgalParamEnd
-   *   \cgalParamBegin{relative_to_chord} set `true` if the subdivision_ratio is the ratio of the
-   *     furthest vertex distance to the chord length, or to the average edge length otherwise.
-   *   \cgalParamEnd
-   *   \cgalParamBegin{with_dihedral_angle}  set `true` if subdivision_ratio is weighted by dihedral angle.
-   *   \cgalParamEnd
-   *   \cgalParamBegin{optimize_anchor_location}  if set to `true`, optimize the anchor locations.
-   *   \cgalParamEnd
-   *   \cgalParamBegin{pca_plane}  set `true` if use PCA plane fitting, otherwise use the default area averaged plane parameters.
-   *   \cgalParamEnd
+   *   \cgalParamNBegin{subdivision_ratio}
+   *     \cgalParamDescription{the chord subdivision ratio threshold to the chord length or average edge length}
+   *     \cgalParamType{`geom_traits::FT`}
+   *     \cgalParamDefault{`5.0`}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{relative_to_chord}
+   *     \cgalParamDescription{If `true`, the `subdivision_ratio` is the ratio of the furthest vertex distance
+   *                           to the chord length, otherwise is the average edge length}
+   *     \cgalParamType{`Boolean`}
+   *     \cgalParamDefault{`false`}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{with_dihedral_angle}
+   *     \cgalParamDescription{If `true`, the `subdivision_ratio` is weighted by dihedral angle}
+   *     \cgalParamType{`Boolean`}
+   *     \cgalParamDefault{`false`}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{optimize_anchor_location}
+   *     \cgalParamDescription{If `true`, optimize the anchor locations}
+   *     \cgalParamType{`Boolean`}
+   *     \cgalParamDefault{`true`}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{pca_plane}
+   *     \cgalParamDescription{If `true`, use PCA plane fitting, otherwise use the default area averaged plane parameters}
+   *     \cgalParamType{`Boolean`}
+   *     \cgalParamDefault{`false`}
+   *   \cgalParamNEnd
    * \cgalNamedParamsEnd
    */
   template <typename NamedParameters>
@@ -811,7 +836,7 @@ public:
     m_average_edge_length = compute_averaged_edge_length(*m_ptm, m_vpoint_map);
 
     // initialize all vertex anchor status
-    BOOST_FOREACH(vertex_descriptor v, vertices(*m_ptm))
+    for(vertex_descriptor v : vertices(*m_ptm))
       put(m_vanchor_map, v, CGAL_VSA_INVALID_TAG);
     m_anchors.clear();
     m_bcycles.clear();
@@ -841,22 +866,38 @@ public:
   /// @{
   /*!
    * @brief outputs approximation results.
-   * @tparam NamedParameters a sequence of \ref vsa_namedparameters
+   * @tparam NamedParameters a sequence of \ref bgl_namedparameters
 
-   * @param np optional sequence of \ref vsa_namedparameters among the ones listed below
+   * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
    * \cgalNamedParamsBegin{Output Named Parameters}
-   *  \cgalParamBegin{face_proxy_map} a `WritePropertyMap` with
-   * `boost::graph_traits<TriangleMesh>::%face_descriptor` as key and `std::size_t` as value type.
-   * A proxy is a set of connected faces which are placed under the same proxy patch (see \cgalFigureRef{iterations}).
-   * The proxy-ids are contiguous in range `[0, number_of_proxies() - 1]`.
-   *  \cgalParamEnd
-   *  \cgalParamBegin{proxies} output iterator over proxies.
-   *  \cgalParamEnd
-   *  \cgalParamBegin{anchors} output iterator over anchor points.
-   *  \cgalParamEnd
-   *  \cgalParamBegin{triangles} output iterator over indexed triangles.
-   *  \cgalParamEnd
+   *   \cgalParamNBegin{face_proxy_map}
+   *     \cgalParamDescription{a property map to output the proxy index of each face of the input polygon mesh}
+   *     \cgalParamType{a model of `WritablePropertyMap` with `boost::graph_traits<TriangleMesh>::%face_descriptor`
+   *                    as key and `std::size_t` as value type}
+   *     \cgalParamDefault{no output operation is performed}
+   *     \cgalParamExtra{A proxy is a set of connected faces which are placed under the same proxy patch (see \cgalFigureRef{iterations})}
+   *     \cgalParamExtra{The proxy-ids are contiguous in range `[0, number_of_proxies - 1]`}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{proxies}
+   *     \cgalParamDescription{an `OutputIterator` to put proxies in}
+   *     \cgalParamType{a class model of `OutputIterator` with
+   *                    `CGAL::Surface_mesh_approximation::L21_metric_vector_proxy_no_area_weighting::Proxy` value type}
+   *     \cgalParamDefault{no output operation is performed}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{anchors}
+   *     \cgalParamDescription{an `OutputIterator` to put anchor points in}
+   *     \cgalParamType{a class model of `OutputIterator` with `geom_traits::%Point_3` value type}
+   *     \cgalParamDefault{no output operation is performed}
+   *   \cgalParamNEnd
+   *
+   *   \cgalParamNBegin{triangles}
+   *     \cgalParamDescription{an `OutputIterator` to put indexed triangles in}
+   *     \cgalParamType{a class model of `OutputIterator` with `std::array<std::size_t, 3>` value type}
+   *     \cgalParamDefault{no output operation is performed}
+   *   \cgalParamNEnd
    * \cgalNamedParamsEnd
    */
   template <typename NamedParameters>
@@ -890,7 +931,7 @@ public:
    */
   template <typename FaceProxyMap>
   void proxy_map(FaceProxyMap face_proxy_map) const {
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       put(face_proxy_map, f, get(m_fproxy_map, f));
   }
 
@@ -910,7 +951,7 @@ public:
     if (px_idx >= m_proxies.size())
       return;
 
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       if (get(m_fproxy_map, f) == px_idx)
         *out++ = f;
   }
@@ -922,7 +963,7 @@ public:
    */
   template <typename OutputIterator>
   void proxies(OutputIterator out) const {
-    BOOST_FOREACH(const Proxy_wrapper &pxw, m_proxies)
+    for(const Proxy_wrapper& pxw : m_proxies)
       *out++ = pxw.px;
   }
 
@@ -938,7 +979,7 @@ public:
    */
   template <typename OutputIterator>
   void wrapped_proxies(OutputIterator out) const {
-    BOOST_FOREACH(const Proxy_wrapper &pxw, m_proxies)
+    for(const Proxy_wrapper& pxw : m_proxies)
       *out++ = pxw;
   }
 
@@ -949,7 +990,7 @@ public:
    */
   template <typename OutputIterator>
   void anchor_points(OutputIterator out) const {
-    BOOST_FOREACH(const Anchor &a, m_anchors)
+    for(const Anchor& a : m_anchors)
       *out++ = a.pos;
   }
 
@@ -965,7 +1006,7 @@ public:
    */
   template <typename OutputIterator>
   void anchor_vertices(OutputIterator out) const {
-    BOOST_FOREACH(const Anchor &a, m_anchors)
+    for(const Anchor& a : m_anchors)
       *out++ = a.vtx;
   }
 
@@ -977,7 +1018,7 @@ public:
    */
   template <typename OutputIterator>
   void indexed_triangles(OutputIterator out) const {
-    BOOST_FOREACH(const Indexed_triangle &t, m_tris)
+    for(const Indexed_triangle& t : m_tris)
       *out++ = t;
   }
 
@@ -993,7 +1034,7 @@ public:
    */
   template <typename OutputIterator>
   void indexed_boundary_polygons(OutputIterator out) const {
-    BOOST_FOREACH(const Boundary_cycle &bcycle, m_bcycles) {
+    for(const Boundary_cycle& bcycle : m_bcycles) {
       std::vector<std::size_t> plg;
       halfedge_descriptor he = bcycle.he_head;
       do {
@@ -1028,7 +1069,7 @@ private:
       // pick from current non seed faces randomly
       std::vector<face_descriptor> picked_seeds;
       if (random_pick_non_seed_faces(max_nb_proxies - m_proxies.size(), picked_seeds)) {
-        BOOST_FOREACH(face_descriptor f, picked_seeds)
+        for(face_descriptor f : picked_seeds)
           add_one_proxy_at(f);
         run(nb_relaxations);
       }
@@ -1048,7 +1089,7 @@ private:
       if (!random_pick_non_seed_faces(nb_to_add, picked_seeds))
         return m_proxies.size();
 
-      BOOST_FOREACH(face_descriptor f, picked_seeds)
+      for(face_descriptor f : picked_seeds)
         add_one_proxy_at(f);
       const FT err = run(nb_relaxations);
       error_drop = err / initial_err;
@@ -1111,7 +1152,9 @@ private:
         target_px = max_nb_proxies;
       else
         target_px *= 2;
-      add_proxies_error_diffusion(target_px - m_proxies.size());
+      // if no proxies could be added, stop
+      if( add_proxies_error_diffusion(target_px - m_proxies.size()) == 0)
+        break;
       const FT err = run(nb_relaxations);
       error_drop = err / initial_err;
     }
@@ -1133,7 +1176,7 @@ private:
       face_descriptor f = pxw_itr->seed;
       put(m_fproxy_map, f, pxw_itr->idx);
 
-      BOOST_FOREACH(face_descriptor fadj, faces_around_face(halfedge(f, *m_ptm), *m_ptm)) {
+      for(face_descriptor fadj : faces_around_face(halfedge(f, *m_ptm), *m_ptm)) {
         if (fadj != boost::graph_traits<TriangleMesh>::null_face()
             && get(m_fproxy_map, fadj) == CGAL_VSA_INVALID_TAG) {
           face_pqueue.push(Face_to_integrate(
@@ -1147,7 +1190,7 @@ private:
       face_pqueue.pop();
       if (get(m_fproxy_map, c.f) == CGAL_VSA_INVALID_TAG) {
         put(m_fproxy_map, c.f, c.px);
-        BOOST_FOREACH(face_descriptor fadj, faces_around_face(halfedge(c.f, *m_ptm), *m_ptm)) {
+        for(face_descriptor fadj : faces_around_face(halfedge(c.f, *m_ptm), *m_ptm)) {
           if (fadj != boost::graph_traits<TriangleMesh>::null_face()
             && get(m_fproxy_map, fadj) == CGAL_VSA_INVALID_TAG) {
             face_pqueue.push(Face_to_integrate(
@@ -1166,9 +1209,10 @@ private:
    * @param t concurrency tag
    */
   template<typename ProxyWrapperIterator>
-  void fit(const ProxyWrapperIterator beg, const ProxyWrapperIterator end, const CGAL::Sequential_tag &) {
+  void fit(const ProxyWrapperIterator beg, const ProxyWrapperIterator end, const CGAL::Sequential_tag & t) {
+    CGAL_USE(t);
     std::vector<std::list<face_descriptor> > px_faces(m_proxies.size());
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       px_faces[get(m_fproxy_map, f)].push_back(f);
 
     // update proxy parameters and seed
@@ -1187,9 +1231,10 @@ private:
    * @param t concurrency tag
    */
   template<typename ProxyWrapperIterator>
-  void fit(const ProxyWrapperIterator beg, const ProxyWrapperIterator end, const CGAL::Parallel_tag &) {
+  void fit(const ProxyWrapperIterator beg, const ProxyWrapperIterator end, const CGAL::Parallel_tag & t) {
+    CGAL_USE(t);
     std::vector<std::list<face_descriptor> > px_faces(m_proxies.size());
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       px_faces[get(m_fproxy_map, f)].push_back(f);
 
     // update proxy parameters and seed
@@ -1222,7 +1267,7 @@ private:
 
     face_descriptor fworst;
     bool first = true;
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+    for(face_descriptor f : faces(*m_ptm)) {
       std::size_t px_idx = get(m_fproxy_map, f);
       if (px_idx != px_worst || f == m_proxies[px_idx].seed)
         continue;
@@ -1264,7 +1309,7 @@ private:
     face_descriptor seed = *px_patch.begin();
     FT err_min = m_metric->compute_error(seed, *m_ptm, px);
     FT sum_error(0.0);
-    BOOST_FOREACH(face_descriptor f, px_patch) {
+    for(face_descriptor f : px_patch) {
       const FT err = m_metric->compute_error(f, *m_ptm, px);
       sum_error += err;
       if (err < err_min) {
@@ -1291,7 +1336,7 @@ private:
    * 3. Update the proxy error.
    * 4. Update proxy map.
    * @pre current face proxy map is valid
-   * @param face_descriptor face
+   * @param f face
    * @param px_idx proxy index
    * @return fitted wrapped proxy
    */
@@ -1323,13 +1368,13 @@ private:
       return false;
 
     std::set<face_descriptor> seed_faces_set;
-    BOOST_FOREACH(const Proxy_wrapper &pxw, m_proxies)
+    for(const Proxy_wrapper& pxw : m_proxies)
       seed_faces_set.insert(pxw.seed);
 
     const std::size_t nb_nsf = m_nb_of_faces - m_proxies.size();
     std::vector<face_descriptor> non_seed_faces;
     non_seed_faces.reserve(nb_nsf);
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+    for(face_descriptor f : faces(*m_ptm)) {
       if (seed_faces_set.find(f) != seed_faces_set.end())
         continue;
       non_seed_faces.push_back(f);
@@ -1359,7 +1404,7 @@ private:
    */
   void bootstrap_from_connected_components() {
     // set all faces invalid to mark as unvisited / untagged
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       put(m_fproxy_map, f, CGAL_VSA_INVALID_TAG);
 
     // prepare for connected components visiting
@@ -1377,7 +1422,7 @@ private:
       while (!fstack.empty()) {
         face_descriptor active_face = fstack.top();
         fstack.pop();
-        BOOST_FOREACH(face_descriptor fadj,
+        for(face_descriptor fadj :
           faces_around_face(halfedge(active_face, *m_ptm), *m_ptm)) {
           if (fadj != boost::graph_traits<TriangleMesh>::null_face()
             && get(m_fproxy_map, fadj) == CGAL_VSA_INVALID_TAG) {
@@ -1390,7 +1435,7 @@ private:
       cc_patches.push_back(cc_patch);
       // check if all visited
       if_all_visited = true;
-      BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+      for(face_descriptor f : faces(*m_ptm)) {
         if (get(m_fproxy_map, f) == CGAL_VSA_INVALID_TAG) {
           if_all_visited = false;
           ++cc_idx;
@@ -1401,7 +1446,7 @@ private:
     }
 
     m_proxies.clear();
-    BOOST_FOREACH(const std::list<face_descriptor> &cc_patch, cc_patches)
+    for(const std::list<face_descriptor>& cc_patch : cc_patches)
       m_proxies.push_back(fit_proxy_from_patch(cc_patch, m_proxies.size()));
 #ifdef CGAL_SURFACE_MESH_APPROXIMATION_DEBUG
     std::cerr << "#cc " << m_proxies.size() << std::endl;
@@ -1417,17 +1462,17 @@ private:
   void compute_proxy_planes(const bool if_pca_plane) {
     // fit proxy planes, areas, normals
     std::vector<std::list<face_descriptor> > px_faces(m_proxies.size());
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm))
+    for(face_descriptor f : faces(*m_ptm))
       px_faces[get(m_fproxy_map, f)].push_back(f);
 
-    BOOST_FOREACH(const std::list<face_descriptor> &px_patch, px_faces) {
+    for(const std::list<face_descriptor>& px_patch : px_faces) {
       Plane_3 fit_plane = if_pca_plane ?
         fit_plane_pca(px_patch.begin(), px_patch.end()) :
           fit_plane_area_averaged(px_patch.begin(), px_patch.end());
 
       Vector_3 norm = CGAL::NULL_VECTOR;
       FT area(0.0);
-      BOOST_FOREACH(face_descriptor f, px_patch) {
+      for(face_descriptor f : px_patch) {
         halfedge_descriptor he = halfedge(f, *m_ptm);
         const Point_3 &p0 = m_vpoint_map[source(he, *m_ptm)];
         const Point_3 &p1 = m_vpoint_map[target(he, *m_ptm)];
@@ -1452,10 +1497,10 @@ private:
    * @brief finds the anchors.
    */
   void find_anchors() {
-    BOOST_FOREACH(vertex_descriptor vtx, vertices(*m_ptm)) {
+    for(vertex_descriptor vtx : vertices(*m_ptm)) {
       std::size_t border_count = 0;
 
-      BOOST_FOREACH(halfedge_descriptor h, halfedges_around_target(vtx, *m_ptm)) {
+      for(halfedge_descriptor h : halfedges_around_target(vtx, *m_ptm)) {
         if (CGAL::is_border_edge(h, *m_ptm))
           ++border_count;
         else if (get(m_fproxy_map, face(h, *m_ptm)) != get(m_fproxy_map, face(opposite(h, *m_ptm), *m_ptm)))
@@ -1478,7 +1523,7 @@ private:
     const bool with_dihedral_angle) {
     // collect candidate halfedges in a set
     std::set<halfedge_descriptor> he_candidates;
-    BOOST_FOREACH(halfedge_descriptor h, halfedges(*m_ptm)) {
+    for(halfedge_descriptor h : halfedges(*m_ptm)) {
       if (!CGAL::is_border(h, *m_ptm)
         && (CGAL::is_border(opposite(h, *m_ptm), *m_ptm)
           || get(m_fproxy_map, face(h, *m_ptm)) != get(m_fproxy_map, face(opposite(h, *m_ptm), *m_ptm))))
@@ -1511,7 +1556,7 @@ private:
         std::cerr << "#chord_anchor " << m_bcycles.back().num_anchors << std::endl;
 #endif
 
-        BOOST_FOREACH(const halfedge_descriptor he, chord)
+        for(const halfedge_descriptor& he : chord)
           he_candidates.erase(he);
       } while (he_start != he_mark);
     }
@@ -1521,7 +1566,7 @@ private:
    * @brief adds anchors to the boundary cycles with only 2 anchors.
    */
   void add_anchors() {
-    BOOST_FOREACH(const Boundary_cycle &bcycle, m_bcycles) {
+    for(const Boundary_cycle& bcycle : m_bcycles) {
       if (bcycle.num_anchors > 2)
         continue;
 
@@ -1559,7 +1604,7 @@ private:
         FT dist_max(0.0);
         chord_vec = scale_functor(chord_vec,
           FT(1.0) / CGAL::approximate_sqrt(chord_vec.squared_length()));
-        BOOST_FOREACH(const halfedge_descriptor he, chord) {
+        for(const halfedge_descriptor& he : chord) {
           Vector_3 vec = vector_functor(pt_begin, m_vpoint_map[target(he, *m_ptm)]);
           vec = cross_product_functor(chord_vec, vec);
           const FT dist = CGAL::approximate_sqrt(vec.squared_length());
@@ -1571,7 +1616,7 @@ private:
       }
       else {
         FT dist_max(0.0);
-        BOOST_FOREACH(const halfedge_descriptor he, chord) {
+        for(const halfedge_descriptor& he : chord) {
           const FT dist = CGAL::approximate_sqrt(CGAL::squared_distance(
             pt_begin, m_vpoint_map[target(he, *m_ptm)]));
           if (dist > dist_max) {
@@ -1589,7 +1634,7 @@ private:
 
   /*!
    * @brief runs the pseudo Constrained Delaunay Triangulation at each proxy region,
-   * and stores the extracted indexed triangles in @a tris.
+   * and stores the extracted indexed triangles in `tris`.
    * @pre all anchors are found, i.e. all boundary cycles have been visited
    * and attached with at least 3 anchors.
    */
@@ -1609,7 +1654,7 @@ private:
     typedef typename SubGraph::vertex_descriptor sg_vertex_descriptor;
     typedef std::vector<sg_vertex_descriptor> VertexVector;
 
-    typedef boost::unordered_map<vertex_descriptor, sg_vertex_descriptor> VertexMap;
+    typedef std::unordered_map<vertex_descriptor, sg_vertex_descriptor> VertexMap;
     typedef boost::associative_property_map<VertexMap> ToSGVertexMap;
     VertexMap vmap;
     ToSGVertexMap to_sgv_map(vmap);
@@ -1619,13 +1664,13 @@ private:
     VertexIndex1Map global_vanchor_map = get(boost::vertex_index1, gmain);
     VertexIndex2Map global_vtag_map = get(boost::vertex_index2, gmain);
     EdgeWeightMap global_eweight_map = get(boost::edge_weight, gmain);
-    BOOST_FOREACH(vertex_descriptor v, vertices(*m_ptm)) {
+    for(vertex_descriptor v : vertices(*m_ptm)) {
       sg_vertex_descriptor sgv = add_vertex(gmain);
       global_vanchor_map[sgv] = get(m_vanchor_map, v);
       global_vtag_map[sgv] = get(m_vanchor_map, v);
       vmap.insert(std::pair<vertex_descriptor, sg_vertex_descriptor>(v, sgv));
     }
-    BOOST_FOREACH(edge_descriptor e, edges(*m_ptm)) {
+    for(edge_descriptor e : edges(*m_ptm)) {
       const vertex_descriptor vs = source(e, *m_ptm);
       const vertex_descriptor vt = target(e, *m_ptm);
       const FT len = CGAL::approximate_sqrt(CGAL::squared_distance(
@@ -1634,22 +1679,22 @@ private:
     }
 
     std::vector<VertexVector> vertex_patches(m_proxies.size());
-    BOOST_FOREACH(vertex_descriptor v, vertices(*m_ptm)) {
+    for(vertex_descriptor v : vertices(*m_ptm)) {
       std::set<std::size_t> px_set;
-      BOOST_FOREACH(face_descriptor f, faces_around_target(halfedge(v, *m_ptm), *m_ptm)) {
+      for(face_descriptor f : faces_around_target(halfedge(v, *m_ptm), *m_ptm)) {
         if (f != boost::graph_traits<TriangleMesh>::null_face())
           px_set.insert(get(m_fproxy_map, f));
       }
-      BOOST_FOREACH(std::size_t p, px_set)
+      for(std::size_t p : px_set)
         vertex_patches[p].push_back(to_sgv_map[v]);
     }
-    BOOST_FOREACH(VertexVector &vpatch, vertex_patches) {
+    for(VertexVector& vpatch : vertex_patches) {
       // add a super vertex connecting to its boundary anchors in each patch
       const sg_vertex_descriptor superv = add_vertex(gmain);
       global_vanchor_map[superv] = CGAL_VSA_INVALID_TAG;
       global_vtag_map[superv] = CGAL_VSA_INVALID_TAG;
       int anchor_count = 0;
-      BOOST_FOREACH(sg_vertex_descriptor v, vpatch) {
+      for(sg_vertex_descriptor v : vpatch) {
         if (is_anchor_attached(v, global_vanchor_map)) {
           add_edge(superv, v, FT(0.0), gmain);
           anchor_count++;
@@ -1665,14 +1710,14 @@ private:
     }
 
     // multi-source Dijkstra's shortest path algorithm applied to each proxy patch
-    BOOST_FOREACH(VertexVector &vpatch, vertex_patches) {
+    for(VertexVector& vpatch : vertex_patches) {
       // ignore ball patch
       if (vpatch.back() == boost::graph_traits<SubGraph>::null_vertex())
         continue;
 
       // construct subgraph
       SubGraph &glocal = gmain.create_subgraph();
-      BOOST_FOREACH(sg_vertex_descriptor v, vpatch)
+      for(sg_vertex_descriptor v : vpatch)
         add_vertex(v, glocal);
 
       // most subgraph functions work with local descriptors
@@ -1687,7 +1732,7 @@ private:
         boost::predecessor_map(&pred[0]).weight_map(local_eweight_map));
 
       // backtrack to the anchor and tag each vertex in the local patch graph
-      BOOST_FOREACH(sg_vertex_descriptor v, vertices(glocal)) {
+      for(sg_vertex_descriptor v : make_range(vertices(glocal))) {
         // skip the added super source vertex in the patch
         if (v == source)
           continue;
@@ -1699,7 +1744,7 @@ private:
     }
 
     // tag all boundary chords
-    BOOST_FOREACH(const Boundary_cycle &bcycle, m_bcycles) {
+    for(const Boundary_cycle& bcycle : m_bcycles) {
       halfedge_descriptor he = bcycle.he_head;
       do {
         Boundary_chord chord;
@@ -1707,7 +1752,7 @@ private:
 
         std::vector<FT> vdist;
         vdist.push_back(FT(0.0));
-        BOOST_FOREACH(halfedge_descriptor h, chord) {
+        for(halfedge_descriptor h : chord) {
           FT elen = global_eweight_map[edge(
             to_sgv_map[source(h, *m_ptm)],
             to_sgv_map[target(h, *m_ptm)],
@@ -1729,13 +1774,13 @@ private:
     }
 
     // collect triangles
-    BOOST_FOREACH(face_descriptor f, faces(*m_ptm)) {
+    for(face_descriptor f : faces(*m_ptm)) {
       halfedge_descriptor he = halfedge(f, *m_ptm);
       std::size_t i = global_vtag_map[to_sgv_map[source(he, *m_ptm)]];
       std::size_t j = global_vtag_map[to_sgv_map[target(he, *m_ptm)]];
       std::size_t k = global_vtag_map[to_sgv_map[target(next(he, *m_ptm), *m_ptm)]];
       if (i != j && i != k && j != k) {
-        CGAL::cpp11::array<std::size_t, 3> t;
+        std::array<std::size_t, 3> t;
         t[0] = i;
         t[1] = j;
         t[2] = k;
@@ -1747,7 +1792,7 @@ private:
   /*!
    * @brief walks along the region boundary cycle to the first halfedge
    * pointing to a vertex associated with an anchor.
-   * @param[in/out] he_start region boundary halfedge
+   * @param[in,out] he_start region boundary halfedge
    */
   void walk_to_first_anchor(halfedge_descriptor &he_start) {
     const halfedge_descriptor start_mark = he_start;
@@ -1762,7 +1807,7 @@ private:
   /*!
    * @brief walks along the region boundary cycle to the next anchor
    * and records the path as a `Boundary_chord`.
-   * @param[in/out] he_start starting region boundary halfedge
+   * @param[in,out] he_start starting region boundary halfedge
    * pointing to a vertex associated with an anchor
    * @param[out] chord recorded path chord
    */
@@ -1775,11 +1820,11 @@ private:
 
   /*!
    * @brief walks to the next boundary cycle halfedge.
-   * @param[in/out] he_start region boundary halfedge
+   * @param[in,out] he_start region boundary halfedge
    */
   void walk_to_next_border_halfedge(halfedge_descriptor &he_start) const {
     const std::size_t px_idx = get(m_fproxy_map, face(he_start, *m_ptm));
-    BOOST_FOREACH(halfedge_descriptor h, halfedges_around_target(he_start, *m_ptm)) {
+    for(halfedge_descriptor h : halfedges_around_target(he_start, *m_ptm)) {
       if (CGAL::is_border(h, *m_ptm) || get(m_fproxy_map, face(h, *m_ptm)) != px_idx) {
         he_start = opposite(h, *m_ptm);
         return;
@@ -1788,11 +1833,11 @@ private:
   }
 
   /*!
-   * @brief subdivides a chord recursively in range `[@a chord_begin, @a chord_end).`
+   * @brief subdivides a chord recursively in range `[chord_begin, chord_end)`.
    * @param chord_begin begin iterator of the chord
    * @param chord_end end iterator of the chord
    * @param subdivision_ratio the chord recursive split error threshold
-   * @param relative_to_chord set `true` if the subdivision_ratio is relative to the the chord length (relative sense),
+   * @param relative_to_chord set `true` if the subdivision_ratio is relative to the chord length (relative sense),
    * otherwise it's relative to the average edge length (absolute sense).
    * @param with_dihedral_angle if set to `true` add dihedral angle weight to the distance.
    * @return the number of anchors of the chord apart from the first one
@@ -1948,11 +1993,11 @@ private:
    * the anchor vertex to the incident proxy plane.
    */
   void optimize_anchor_location() {
-    BOOST_FOREACH(Anchor &a, m_anchors) {
+    for(Anchor& a : m_anchors) {
       const vertex_descriptor v = a.vtx;
       // incident proxy set
       std::set<std::size_t> px_set;
-      BOOST_FOREACH(halfedge_descriptor h, halfedges_around_target(v, *m_ptm)) {
+      for(halfedge_descriptor h : halfedges_around_target(v, *m_ptm)) {
         if (!CGAL::is_border(h, *m_ptm))
           px_set.insert(get(m_fproxy_map, face(h, *m_ptm)));
       }
@@ -1961,7 +2006,7 @@ private:
       FT sum_area(0.0);
       Vector_3 vec = CGAL::NULL_VECTOR;
       const Point_3 vtx_pt = m_vpoint_map[v];
-      BOOST_FOREACH(const std::size_t px_idx, px_set) {
+      for(const std::size_t px_idx : px_set) {
         const Vector_3 proj = vector_functor(
           CGAL::ORIGIN, m_px_planes[px_idx].plane.projection(vtx_pt));
         const FT area = m_px_planes[px_idx].area;
@@ -1986,7 +2031,7 @@ private:
   FT compute_averaged_edge_length(const TriangleMesh &tm, const VertexPointMap &vpoint_map) const {
     // compute average edge length
     FT sum(0.0);
-    BOOST_FOREACH(edge_descriptor e, edges(tm)) {
+    for(edge_descriptor e : edges(tm)) {
       const vertex_descriptor vs = source(e, tm);
       const vertex_descriptor vt = target(e, tm);
       sum += CGAL::approximate_sqrt(CGAL::squared_distance(
