@@ -1,19 +1,10 @@
 // Copyright (c) 2016  GeometryFactory (France).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/BGL/include/CGAL/boost/graph/Seam_mesh.h $
-// $Id: Seam_mesh.h 0d5009e 2019-03-26T16:43:41+01:00 Laurent Rineau
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/BGL/include/CGAL/boost/graph/Seam_mesh.h $
+// $Id: Seam_mesh.h 62a31babbd1 2022-11-14T17:44:33+01:00 albert-github
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri, Mael Rouxel-Labbé
@@ -28,12 +19,13 @@
 
 #include <CGAL/circulator.h>
 #include <CGAL/Unique_hash_map.h>
+#include <CGAL/assertions.h>
 
-#include <boost/foreach.hpp>
 #include <boost/iterator/iterator_facade.hpp>
-#include <boost/unordered_set.hpp>
 
+#include <unordered_set>
 #include <fstream>
+#include <functional>
 #include <iostream>
 #include <iterator>
 #include <utility>
@@ -42,6 +34,7 @@
 namespace CGAL {
 
 #ifndef DOXYGEN_RUNNING
+
 template <typename HD>
 class Seam_mesh_halfedge_descriptor
 {
@@ -96,11 +89,95 @@ public:
     return 2 * hash_value(hd.tmhd) + static_cast<std::size_t>(hd.seam);
   }
 };
+
+template <typename HD>
+class Seam_mesh_vertex_descriptor
+{
+public:
+  Seam_mesh_halfedge_descriptor<HD> hd;
+
+  Seam_mesh_vertex_descriptor() { }
+
+  Seam_mesh_vertex_descriptor(const Seam_mesh_halfedge_descriptor<HD>& h)
+    : hd(h)
+  { }
+
+  bool operator==(const Seam_mesh_vertex_descriptor& other) const
+  {
+    return (hd == other.hd);
+  }
+
+  bool operator!=(const Seam_mesh_vertex_descriptor& other) const
+  {
+    return (hd != other.hd);
+  }
+
+  bool operator<(const Seam_mesh_vertex_descriptor& other) const
+  {
+    return hd < other.hd;
+  }
+
+  operator HD() const
+  {
+    return hd;
+  }
+
+#ifdef CGAL_SEAM_MESH_INSERT_OPERATOR
+  friend std::ostream& operator<<(std::ostream& os, const Seam_mesh_vertex_descriptor vd)
+  {
+    os << "seam mesh vertex: " << vd.hd;
+    return os;
+  }
 #endif
 
+  friend std::size_t hash_value(const Seam_mesh_vertex_descriptor& vd)
+  {
+    return hash_value(vd.hd.tmhd);
+  }
+};
+
+template <typename HD, typename SM>
+class Seam_mesh_edge_descriptor
+{
+public:
+  Seam_mesh_halfedge_descriptor<HD> hd;
+  const SM* mesh_;
+
+  Seam_mesh_edge_descriptor() : mesh_(nullptr) { }
+
+  Seam_mesh_edge_descriptor(const Seam_mesh_halfedge_descriptor<HD>& hd, const SM* m)
+    : hd(hd), mesh_(m)
+  {}
+
+  friend bool operator==(Seam_mesh_edge_descriptor e1, Seam_mesh_edge_descriptor e2)
+  {
+    return (e1.hd == e2.hd) || (e1.hd == e2.mesh_->opposite(e2.hd));
+  }
+
+  friend bool operator!=(Seam_mesh_edge_descriptor e1, Seam_mesh_edge_descriptor e2)
+  {
+    return ! (e1 == e2);
+  }
+
+#ifdef CGAL_SEAM_MESH_INSERT_OPERATOR
+  friend std::ostream& operator<<(std::ostream& os, const Seam_mesh_edge_descriptor& ed)
+  {
+    os << ed.hd;
+    return os;
+  }
+#endif
+
+  friend std::size_t hash_value(const Seam_mesh_edge_descriptor& ed)
+  {
+    return hash_value((std::min)(ed.hd, ed.mesh_->opposite(ed.hd)));
+  }
+};
+
+#endif // DOXYGEN_RUNNING
+
 /// \ingroup PkgBGLAdaptors
 ///
-/// This class is a data structure that takes a triangle mesh, further refered
+/// This class is a data structure that takes a triangle mesh, further referred
 /// to as `underlying mesh` and turns some marked edges of that mesh into
 /// virtual boundary edges.
 ///
@@ -122,6 +199,10 @@ class Seam_mesh
   typedef Seam_mesh<TM, SEM, SVM>                                 Self;
 
 public:
+  /// The underlying mesh type
+  typedef TM                                                      Triangle_mesh;
+
+  // backward compatibility
   typedef TM                                                      TriangleMesh;
 
 public:
@@ -134,8 +215,8 @@ public:
   /// The type for the objects used to identify halfedges in the underlying mesh.
   typedef typename boost::graph_traits<TM>::halfedge_descriptor   TM_halfedge_descriptor;
 
- /// The type for the iterators that traverse through the complete halfedge set of the underlying mesh.
- typedef typename boost::graph_traits<TM>::halfedge_iterator     TM_halfedge_iterator;
+  /// The type for the iterators that traverse through the complete halfedge set of the underlying mesh.
+  typedef typename boost::graph_traits<TM>::halfedge_iterator     TM_halfedge_iterator;
 
   /// The type for the objects used to identify edges in the underlying mesh.
   typedef typename boost::graph_traits<TM>::edge_descriptor       TM_edge_descriptor;
@@ -178,7 +259,7 @@ private:
   mutable vertices_size_type number_of_vertices;
 
 public:
-  /// Returns the underlying mesh.
+  /// returns the underlying mesh.
   const TM& mesh() const
   {
     return tm;
@@ -197,23 +278,15 @@ public:
   class halfedge_descriptor
   {
 public:
-    TM_halfedge_descriptor tmhd;
-    bool seam;
-
     /// %Default constructor
-    halfedge_descriptor() : tmhd(), seam(false) { }
+    halfedge_descriptor();
 
-    halfedge_descriptor(TM_halfedge_descriptor tmhd, bool seam = false)
-      : tmhd(tmhd), seam(seam)
-    { }
+    /// Constructor from a halfedge of the underlying mesh
+    halfedge_descriptor(TM_halfedge_descriptor tmhd, bool seam = false);
 
 #ifdef CGAL_SEAM_MESH_INSERT_OPERATOR
     /// Print the halfedge and if it is on a seam.
-    friend std::ostream& operator<<(std::ostream& os, const halfedge_descriptor& hd)
-    {
-      os << hd.tmhd << ((hd.seam)?" on seam":"");
-      return os;
-    }
+    friend std::ostream& operator<<(std::ostream& os, const halfedge_descriptor& hd);
 #endif
   };
 #else
@@ -237,7 +310,7 @@ public:
     bool seam;
     const Self* mesh_;
 
-    halfedge_iterator() : hd(), end(), seam(false), mesh_(NULL) { }
+    halfedge_iterator() : hd(), end(), seam(false), mesh_(nullptr) { }
 
     halfedge_iterator(const Iterator_range<TM_halfedge_iterator>& ir, const Self* m)
       : hd(ir.first), end(ir.second), seam(false), mesh_(m)
@@ -275,13 +348,13 @@ public:
       return halfedge_descriptor(*hd, seam);
     }
   };
-#endif
+#endif // DOXYGEN_RUNNING
 
+#ifdef DOXYGEN_RUNNING
   /// This class represents a vertex of the seam mesh.
   ///
   /// Implementation note: to properly duplicate vertices that are on seams,
-  /// a vertex_descriptor is in fact represented as a halfedge of the underlying
-  /// mesh.
+  /// a vertex_descriptor is in fact represented as a halfedge of the seam mesh.
   ///
   /// \cgalModels `Descriptor`
   /// \cgalModels `LessThanComparable`
@@ -290,48 +363,20 @@ public:
   class vertex_descriptor
   {
   public:
-    halfedge_descriptor hd;
-
     /// %Default constructor
-    vertex_descriptor() { }
+    vertex_descriptor();
 
-    vertex_descriptor(const halfedge_descriptor& h)
-      : hd(h)
-    { }
-
-    bool operator==(const vertex_descriptor& other) const
-    {
-      return (hd == other.hd);
-    }
-
-    bool operator!=(const vertex_descriptor& other) const
-    {
-      return (hd != other.hd);
-    }
-
-    bool operator<(const vertex_descriptor& other) const
-    {
-      return hd < other.hd;
-    }
-
-    operator TM_halfedge_descriptor() const
-    {
-      return hd;
-    }
+    /// Constructor from a seam mesh halfedge
+    vertex_descriptor(const halfedge_descriptor& h);
 
 #ifdef CGAL_SEAM_MESH_INSERT_OPERATOR
-    friend std::ostream& operator<<(std::ostream& os, const vertex_descriptor vd)
-    {
-      os << "seam mesh vertex: " << vd.hd;
-      return os;
-    }
+    /// Print the seam mesh vertex.
+    friend std::ostream& operator<<(std::ostream& os, const vertex_descriptor vd);
 #endif
-
-    friend std::size_t hash_value(const vertex_descriptor& vd)
-    {
-      return hash_value(vd.hd.tmhd);
-    }
   };
+#else
+  typedef Seam_mesh_vertex_descriptor<TM_halfedge_descriptor>         vertex_descriptor;
+#endif
 
    // iterator
 #ifndef DOXYGEN_RUNNING
@@ -350,7 +395,7 @@ public:
 
   public:
     /// Constructors
-    vertex_iterator() : hd(), end(), mesh_(NULL) { }
+    vertex_iterator() : hd(), end(), mesh_(nullptr) { }
 
     vertex_iterator(const Iterator_range<TM_halfedge_iterator>& ir, const Self* m)
       : hd(ir.first), end(ir.second), mesh_(m)
@@ -413,43 +458,24 @@ public:
   };
 #endif
 
+#ifdef DOXYGEN_RUNNING
   /// This class represents an edge of the seam mesh.
   ///
   /// \cgalModels `Descriptor`
+  /// \cgalModels `Hashable`
   ///
   class edge_descriptor
   {
-  public:
-    halfedge_descriptor hd;
-    const Self* mesh_;
+    /// %Default constructor
+    edge_descriptor();
 
 #ifdef CGAL_SEAM_MESH_INSERT_OPERATOR
-    friend
-    std::ostream& operator<<(std::ostream& os, const edge_descriptor& ed)
-    {
-      os << ed.hd;
-      return os;
-    }
+    friend std::ostream& operator<<(std::ostream& os, const edge_descriptor& ed);
 #endif
-
-    edge_descriptor()
-      : mesh_(NULL)
-    {}
-
-    edge_descriptor(const halfedge_descriptor& hd, const Self* m)
-      : hd(hd), mesh_(m)
-    {}
-
-    friend bool operator==(edge_descriptor e1, edge_descriptor e2)
-    {
-      return (e1.hd == e2.hd) || (e1.hd == e2.mesh_->opposite(e2.hd)); 
-    }
-
-    friend bool operator!=(edge_descriptor e1, edge_descriptor e2)
-    {
-      return ! (e1 == e2);
-    }
   };
+#else
+  typedef Seam_mesh_edge_descriptor<TM_halfedge_descriptor, Self> edge_descriptor;
+#endif
 
 #ifndef DOXYGEN_RUNNING
    // iterator
@@ -470,7 +496,7 @@ public:
     const Self* mesh_;
 
   public:
-    edge_iterator() : hd(), end(), seam(false), mesh_(NULL) { }
+    edge_iterator() : hd(), end(), seam(false), mesh_(nullptr) { }
 
     edge_iterator(const Iterator_range<TM_halfedge_iterator>& ir, const Self* m)
       : hd(ir.first), end(ir.second), seam(false), mesh_(m)
@@ -548,31 +574,31 @@ public:
   /// \name Seam query functions
   /// @{
 
-  /// Returns `true` if the vertex is on the seam.
+  /// returns `true` if the vertex is on the seam.
   bool has_on_seam(TM_vertex_descriptor vd) const
   {
     return get(svm, vd);
   }
 
-  /// Returns `true` if the edge is on the seam.
+  /// returns `true` if the edge is on the seam.
   bool has_on_seam(TM_edge_descriptor ed) const
   {
     return get(sem, ed);
   }
 
-  /// Returns `true` if the halfedge is on the seam.
+  /// returns `true` if the halfedge is on the seam.
   bool has_on_seam(TM_halfedge_descriptor tmhd) const
   {
     return get(sem, CGAL::edge(tmhd, tm));
   }
 
-  /// Returns `true` if the halfedge is on the seam.
+  /// returns `true` if the halfedge is on the seam.
   bool has_on_seam(const halfedge_descriptor& hd) const
   {
     return has_on_seam(CGAL::edge(hd, tm));
   }
 
-  /// Return the number of seam edges in the seam mesh.
+  /// returns the number of seam edges in the seam mesh.
   edges_size_type number_of_seam_edges() const
   {
     return number_of_seams;
@@ -606,7 +632,7 @@ public:
   }
   /// @endcond
 
-  /// Returns the iterator range of the vertices of the mesh.
+  /// returns the iterator range of the vertices of the mesh.
   Iterator_range<vertex_iterator> vertices() const
   {
     Iterator_range<TM_halfedge_iterator> ir = CGAL::halfedges(tm);
@@ -632,7 +658,7 @@ public:
   }
   /// @endcond
 
-  /// Returns the iterator range of the halfedges of the mesh.
+  /// returns the iterator range of the halfedges of the mesh.
   Iterator_range<halfedge_iterator> halfedges() const
   {
     Iterator_range<TM_halfedge_iterator> ir = CGAL::halfedges(tm);
@@ -657,7 +683,7 @@ public:
   }
   /// @endcond
 
-  /// Returns the iterator range of the edges of the mesh.
+  /// returns the iterator range of the edges of the mesh.
   Iterator_range<edge_iterator> edges() const
   {
     Iterator_range<TM_halfedge_iterator> ir = CGAL::halfedges(tm);
@@ -680,7 +706,7 @@ public:
   }
   /// @endcond
 
-  /// Returns the iterator range of the faces of the mesh.
+  /// returns the iterator range of the faces of the mesh.
   Iterator_range<face_iterator> faces() const
   {
     return CGAL::faces(tm);
@@ -691,7 +717,7 @@ public:
   /// \name Memory Management
   /// @{
 
-  /// Returns the number of vertices in the seam mesh.
+  /// returns the number of vertices in the seam mesh.
   vertices_size_type num_vertices() const
   {
     if(number_of_vertices == static_cast<vertices_size_type>(-1)) {
@@ -701,19 +727,19 @@ public:
     return number_of_vertices;
   }
 
-  /// Returns the number of halfedges in the seam mesh.
+  /// returns the number of halfedges in the seam mesh.
   halfedges_size_type num_halfedges() const
   {
     return CGAL::num_halfedges(tm) + 2 * number_of_seams;
   }
 
-  /// Returns the number of edges in the seam mesh.
+  /// returns the number of edges in the seam mesh.
   halfedges_size_type num_edges() const
   {
     return CGAL::num_edges(tm) + number_of_seams;
   }
 
-  /// Returns the number of faces in the seam mesh.
+  /// returns the number of faces in the seam mesh.
   faces_size_type num_faces() const
   {
     return CGAL::num_faces(tm);
@@ -724,7 +750,7 @@ public:
   /// \name Degree Functions
   /// @{
 
-  /// Returns the number of incident halfedges of vertex `v`.
+  /// returns the number of incident halfedges of vertex `v`.
   degree_size_type degree(vertex_descriptor v) const
   {
     degree_size_type count(0);
@@ -748,13 +774,13 @@ public:
 #ifndef DOXYGEN_RUNNING
   ///@{
 
-  /// Returns the edge that contains halfedge `h` as one of its two halfedges.
+  /// returns the edge that contains halfedge `h` as one of its two halfedges.
   edge_descriptor edge(halfedge_descriptor h) const
   {
     return edge_descriptor(h,this);
   }
 
-  /// Returns the halfedge corresponding to the edge `e`.
+  /// returns the halfedge corresponding to the edge `e`.
   halfedge_descriptor halfedge(edge_descriptor e) const
   {
     return e.hd;
@@ -763,7 +789,7 @@ public:
 
   ///@{
 
-  /// Returns an incoming halfedge of vertex `v`.
+  /// returns an incoming halfedge of vertex `v`.
   /// If `v` is a seam vertex, this will be the halfedge whose target is `v` and
   /// whose opposite is a virtual border halfedge.
   /// Otherwise, the rules of the underlying mesh are followed.
@@ -774,7 +800,7 @@ public:
     return halfedge_descriptor(h, false /*not on seam*/);
   }
 
-  /// Finds a halfedge between two vertices. Returns a default constructed
+  /// finds a halfedge between two vertices. Returns a default constructed
   /// `halfedge_descriptor`, if  `source` and  `target` are not connected.
   std::pair<halfedge_descriptor, bool> halfedge(vertex_descriptor u,
                                                 vertex_descriptor v) const
@@ -805,7 +831,7 @@ public:
     return std::make_pair(halfedge_descriptor(), false/*invalid*/);
   }
 
-  /// Finds an edge between two vertices. Returns a default constructed
+  /// finds an edge between two vertices. Returns a default constructed
   /// `edge`, if  `source` and  `target` are not connected.
   std::pair<edge_descriptor, bool> edge(vertex_descriptor u, vertex_descriptor v) const
   {
@@ -820,7 +846,7 @@ public:
     return halfedge_descriptor(hd, false/*not on seam*/);
   }
 
-  /// Returns the face incident to halfedge `h`.
+  /// returns the face incident to halfedge `h`.
   face_descriptor face(halfedge_descriptor h) const
   {
     if(h.seam)
@@ -830,7 +856,7 @@ public:
   }
 
 public:
-  /// Returns the next halfedge within the incident face.
+  /// returns the next halfedge within the incident face.
   halfedge_descriptor next(const halfedge_descriptor& hd) const
   {
     if((!hd.seam) && (!is_border(hd.tmhd, tm)))
@@ -845,7 +871,7 @@ public:
                                !is_border(CGAL::opposite(*hatc, tm), tm));
   }
 
-  /// Returns the previous halfedge within the incident face.
+  /// returns the previous halfedge within the incident face.
   halfedge_descriptor prev(const halfedge_descriptor& hd) const
   {
     if((!hd.seam) && (!is_border(hd.tmhd, tm)))
@@ -860,7 +886,7 @@ public:
                                !is_border(CGAL::opposite(*hatc, tm), tm));
   }
 
-  /// Returns the opposite halfedge of `hd`.
+  /// returns the opposite halfedge of `hd`.
   halfedge_descriptor opposite(const halfedge_descriptor& hd) const
   {
     if(!hd.seam)
@@ -869,7 +895,7 @@ public:
     return halfedge_descriptor(CGAL::opposite(hd.tmhd, tm), false /*not on seam*/);
   }
 
-  /// Returns the vertex the halfedge `h` emanates from.
+  /// returns the vertex the halfedge `h` emanates from.
   vertex_descriptor target(halfedge_descriptor hd) const
   {
     TM_halfedge_descriptor tmhd(hd);
@@ -889,7 +915,7 @@ public:
     return vertex_descriptor(halfedge_descriptor(tmhd));
   }
 
-  /// Returns the vertex the halfedge `h` emanates from.
+  /// returns the vertex the halfedge `h` emanates from.
   vertex_descriptor source(const halfedge_descriptor& hd) const
   {
     return target(opposite(hd));
@@ -909,7 +935,7 @@ public:
 
   void build_TM_vertices_vector(std::vector<TM_vertex_descriptor>& tm_vds) const
   {
-    assert(tm_vds.empty());
+    CGAL_precondition(tm_vds.empty());
 
     // If the input is a list of integers, we need to build a correspondence
     // between vertices and integers.
@@ -927,7 +953,7 @@ public:
   /// \name Seam selection
   /// @{
 
-  /// Mark the edge of the underlying mesh that has extremities the vertices
+  /// marks the edge of the underlying mesh that has extremities the vertices
   /// `tm_vd_s` and `tm_vd_s` as a seam edge.
   ///
   /// \return whether the edge was successfully marked or not.
@@ -968,7 +994,7 @@ public:
     return true;
   }
 
-  /// Create new seams.
+  /// creates new seams.
   ///
   /// The edges to be marked as seams are described by the range [first, last) of
   /// vertices of the underlying mesh. Each edge to be marked is described
@@ -983,7 +1009,7 @@ public:
   TM_halfedge_descriptor add_seams(InputIterator first, InputIterator last)
   {
     // must have an even number of input vertices
-    assert(std::distance(first, last) % 2 == 0);
+    CGAL_precondition(std::distance(first, last) % 2 == 0);
 
     TM_halfedge_descriptor tmhd = boost::graph_traits<TM>::null_halfedge();
     InputIterator it = first;
@@ -1003,7 +1029,7 @@ public:
     return tmhd;
   }
 
-  /// Create new seams.
+  /// creates new seams.
   ///
   /// A seam edge is described by a pair of integers. The integer index
   /// of a vertex of the underlying mesh is given by its position
@@ -1029,7 +1055,7 @@ public:
     return add_seams(seam_vertices.begin(), seam_vertices.end());
   }
 
-  /// Create new seams.
+  /// creates new seams.
   ///
   /// A seam edge is described by a pair of integers. The integer
   /// index of a vertex of the underlying mesh is defined as its position when
@@ -1046,7 +1072,7 @@ public:
     return add_seams(in, tm_vds);
   }
 
-  /// Create new seams.
+  /// creates new seams.
   ///
   /// A seam edge is described by a pair of integers. The integer index
   /// of a vertex of the underlying mesh is given by its position
@@ -1090,7 +1116,7 @@ public:
     return add_seams(in, tm_vds);
   }
 
-  /// Create new seams.
+  /// creates new seams.
   ///
   /// A seam edge is described by a pair of integers. The integer
   /// index of a vertex of the underlying mesh is defined as its position when
@@ -1109,7 +1135,7 @@ public:
 
   /// @}
 
-  /// Constructs a seam mesh for a triangle mesh and an edge and vertex property map
+  /// constructs a seam mesh for a triangle mesh and an edge and vertex property map
   ///
   /// \param tm the underlying mesh
   /// \param sem the edge property map with value `true` for seam edges
@@ -1125,6 +1151,46 @@ public:
 
 } // namespace CGAL
 
+#ifndef CGAL_CFG_NO_STD_HASH
+
+namespace std {
+
+template <typename HD>
+struct hash<CGAL::Seam_mesh_vertex_descriptor<HD> >
+  : public CGAL::cpp98::unary_function<CGAL::Seam_mesh_vertex_descriptor<HD>, std::size_t>
+{
+  std::size_t operator()(const CGAL::Seam_mesh_vertex_descriptor<HD>& v) const
+  {
+    return hash_value(v);
+  }
+};
+
+template <typename HD>
+struct hash<CGAL::Seam_mesh_halfedge_descriptor<HD> >
+  : public CGAL::cpp98::unary_function<CGAL::Seam_mesh_halfedge_descriptor<HD>, std::size_t>
+{
+  std::size_t operator()(const CGAL::Seam_mesh_halfedge_descriptor<HD>& h) const
+  {
+    return hash_value(h);
+  }
+};
+
+template <typename HD, typename SM>
+struct hash<CGAL::Seam_mesh_edge_descriptor<HD, SM> >
+  : public CGAL::cpp98::unary_function<CGAL::Seam_mesh_edge_descriptor<HD, SM>, std::size_t>
+{
+  std::size_t operator()(const CGAL::Seam_mesh_edge_descriptor<HD, SM>& e) const
+  {
+    return hash_value(e);
+  }
+};
+
+// Seam_mesh::face_descriptor is equal to TM_face_descriptor so nothing to do
+
+} // namespace std
+
+#endif // CGAL_CFG_NO_STD_HASH
+
 #include <CGAL/enable_warnings.h>
 
 #endif //CGAL_SEAM_MESH_H
