@@ -1,19 +1,11 @@
 // Copyright (c) 2014  GeometryFactory (France).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/BGL/include/CGAL/boost/graph/iterator.h $
+// $Id: iterator.h f93cb3c5523 2024-07-23T17:15:05+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL$
-// $Id$
-// 
 //
 // Author(s)     : Andreas Fabri
 
@@ -38,10 +30,10 @@ namespace internal {
 
 template <typename G>
 struct Edge {
-  const G* g; 
+  const G* g;
 
   Edge()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Edge(const G& g)
@@ -59,10 +51,10 @@ struct Edge {
 
 template <typename G>
 struct Opposite_edge {
-  const G* g; 
+  const G* g;
 
   Opposite_edge()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Opposite_edge(const G& g)
@@ -80,10 +72,10 @@ struct Opposite_edge {
 
 template <typename G>
 struct Opposite_halfedge {
-  const G* g; 
+  const G* g;
 
   Opposite_halfedge()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Opposite_halfedge(const G& g)
@@ -101,10 +93,10 @@ struct Opposite_halfedge {
 
 template <typename G>
 struct Target {
-  const G* g; 
+  const G* g;
 
   Target()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Target(const G& g)
@@ -122,10 +114,10 @@ struct Target {
 
 template <typename G>
 struct Source {
-  const G* g; 
+  const G* g;
 
   Source()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Source(const G& g)
@@ -143,10 +135,10 @@ struct Source {
 
 template <typename G>
 struct Face {
-  const G* g; 
+  const G* g;
 
   Face()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Face(const G& g)
@@ -163,10 +155,10 @@ struct Face {
 };
 template <typename G>
 struct Opposite_face {
-  const G* g; 
+  const G* g;
 
   Opposite_face()
-    : g(NULL)
+    : g(nullptr)
   {}
 
   Opposite_face(const G& g)
@@ -187,8 +179,8 @@ struct Opposite_face {
 /**
  * \ingroup PkgBGLIterators
  * A bidirectional iterator with value type `boost::graph_traits<Graph>::%halfedge_descriptor` over all halfedges having the same vertex as source.
- * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_source_iterator` `havi` with `h = *havi;` 
- * the following holds: Either `++havi` is the past the end iterator, or `next(opposite(h,g),g) == *++havi`. 
+ * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_source_iterator` `havi` with `h = *havi;`
+ * the following holds: Either `++havi` is the past the end iterator, or `next(opposite(h,g),g) == *++havi`.
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalIterator`
  */
@@ -205,15 +197,15 @@ public:
   typedef const value_type&                   reference;
   typedef std::ptrdiff_t                      difference_type;
 
-private:  
+private:
   halfedge_descriptor anchor, pos;
   const Graph* g;
   int      winding;
-#endif 
-  
+#endif
+
 public:
   Halfedge_around_source_iterator()
-    : anchor(), pos(), g(0)
+    : anchor(), pos(), g(nullptr), winding(0)
   {}
 
   Halfedge_around_source_iterator(halfedge_descriptor hd, const Graph& g, int n=0)
@@ -221,30 +213,19 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_source_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
-  {
-    return (! (this->base() == NULL)) ?
-      &Halfedge_around_source_iterator::this_type_does_not_support_comparisons : 0;
-  }
 
   bool operator==( const Self& i) const {
     CGAL_assertion( anchor == anchor);
     return  ( g == i.g) && ( pos == i.pos) && ( winding == i.winding);
   }
-  
+
   bool operator!=( const Self& i) const {
     return !(*this == i);
   }
 
   bool operator== (void* ) const
   {
-    return g == NULL;
+    return g == nullptr;
   }
 
   reference operator*() const
@@ -285,8 +266,8 @@ public:
 /**
  * \ingroup PkgBGLIterators
  * A bidirectional iterator with value type `boost::graph_traits<Graph>::%halfedge_descriptor` over all halfedges having the same vertex as target.
- * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_target_iterator` `havi` with `h = *havi;` 
- * the following holds: Either `++havi` is the past the end iterator, or `opposite(next(h,g),g) == *++havi`. 
+ * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_target_iterator` `havi` with `h = *havi;`
+ * the following holds: Either `++havi` is the past the end iterator, or `opposite(next(h,g),g) == *++havi`.
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalIterator`
  */
@@ -305,15 +286,15 @@ public:
   typedef const value_type&                   reference;
   typedef std::ptrdiff_t                      difference_type;
 
-private:  
+private:
   halfedge_descriptor anchor, pos;
   const Graph* g;
   int      winding;
-#endif 
-  
+#endif
+
 public:
   Halfedge_around_target_iterator()
-    : anchor(), pos(), g(0)
+    : anchor(), pos(), g(nullptr), winding(0)
   {}
 
   Halfedge_around_target_iterator(halfedge_descriptor hd, const Graph& g, int n=0)
@@ -321,30 +302,19 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_target_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
-  {
-    return (! (this->base() == NULL)) ?
-      &Halfedge_around_target_iterator::this_type_does_not_support_comparisons : 0;
-  }
 
   bool operator==( const Self& i) const {
     CGAL_assertion( anchor == anchor);
     return  ( g == i.g) && ( pos == i.pos) && ( winding == i.winding);
   }
-  
+
   bool operator!=( const Self& i) const {
     return !(*this == i);
   }
 
   bool operator== (void* ) const
   {
-    return g == NULL;
+    return g == nullptr;
   }
 
   reference operator*() const
@@ -386,7 +356,7 @@ public:
 /**
  * \ingroup PkgBGLIterators
  * A bidirectional iterator  with value type `boost::graph_traits<Graph>::%halfedge_descriptor` over all halfedges incident to the same face or border.
- * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_face_iterator` `hafi` with  `h = *hafi` 
+ * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_face_iterator` `hafi` with  `h = *hafi`
  * the following holds: Either `++hafi` is the past the end iterator, or `next(h,g) == *++hafi`.
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalIterator`
@@ -394,7 +364,7 @@ public:
 
 template <typename Graph>
 class Halfedge_around_face_iterator {
-#ifndef DOXYGEN_RUNNING 
+#ifndef DOXYGEN_RUNNING
   typedef Halfedge_around_face_iterator Self;
 
 public:
@@ -404,9 +374,9 @@ public:
   typedef value_type*                         pointer;
   typedef value_type&                         reference;
   typedef std::ptrdiff_t                      difference_type;
-  
+
 #endif
-  
+
   Halfedge_around_face_iterator()
     : pos(), g(0)
   {}
@@ -420,18 +390,6 @@ public:
   pointer           operator -> ( )       { return &pos; }
   const value_type* operator -> ( ) const { return &pos; }
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_face_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
-  {
-    return (! (this->base() == NULL)) ?
-      &Halfedge_around_face_iterator::this_type_does_not_support_comparisons : 0;
-  }
-
   bool operator==( const Self& i) const {
     CGAL_assertion( anchor == anchor);
     return  ( g == i.g) && ( pos == i.pos) && ( winding == i.winding);
@@ -441,36 +399,36 @@ public:
     return !(*this == i);
   }
 
-  Self& operator++() 
+  Self& operator++()
   {
-    CGAL_assertion(g != NULL);
-    pos = next(pos,*g); 
+    CGAL_assertion(g != nullptr);
+    pos = next(pos,*g);
     if ( pos == anchor)
       ++winding;
     return *this;
   }
 
-  Self operator++(int) 
+  Self operator++(int)
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     Self tmp = *this;
     ++*this;
     return tmp;
   }
 
-  Self& operator--() 
+  Self& operator--()
   {
-    CGAL_assertion(g != NULL); 
+    CGAL_assertion(g != nullptr);
     if ( pos == anchor)
       --winding;
-  
+
     pos = prev(pos,*g);
     return *this;
   }
 
-  Self operator--(int) 
+  Self operator--(int)
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     Self tmp = *this;
     --*this;
     return tmp;
@@ -489,8 +447,8 @@ class Halfedge_around_target_circulator;
 /**
  * \ingroup PkgBGLIterators
  * A bidirectional circulator  with value type `boost::graph_traits<Graph>::%halfedge_descriptor` over all halfedges having the same vertex as source.
- * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_source_circulator` `havc` with `h = *havc;` 
- * the following holds: `next(opposite(h,g),g) == *++havc`. 
+ * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_source_circulator` `havc` with `h = *havc;`
+ * the following holds: `next(opposite(h,g),g) == *++havc`.
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalCirculator`
  */
@@ -508,6 +466,7 @@ class Halfedge_around_source_circulator
 {
 private:
   internal::Opposite_halfedge<Graph> opp;
+
 #ifndef DOXYGEN_RUNNING
   typedef typename boost::graph_traits<Graph>::halfedge_descriptor halfedge_descriptor;
   typedef typename boost::graph_traits<Graph>::vertex_descriptor vertex_descriptor;
@@ -523,33 +482,32 @@ public:
   {}
 
   Halfedge_around_source_circulator(halfedge_descriptor hd, const Graph& g)
-    : Halfedge_around_source_circulator::iterator_adaptor_(Halfedge_around_target_circulator<Graph>(hd,g)), opp(g)
+    : Halfedge_around_source_circulator::iterator_adaptor_(Halfedge_around_target_circulator<Graph>(opposite(hd,g),g)), opp(g)
   {}
 
   Halfedge_around_source_circulator(vertex_descriptor vd, const Graph& g)
     : Halfedge_around_source_circulator::iterator_adaptor_(Halfedge_around_target_circulator<Graph>(halfedge(vd,g),g)), opp(g)
   {}
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_source_circulator::*bool_type)() const;
-  
-  void this_type_does_not_support_comparisons() const {}
-  
-  operator bool_type() const
+
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Halfedge_around_source_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
-  
+
   bool operator== (void*) const
   {
-    return this->base_reference() == NULL;
+    return this->base_reference() == nullptr;
   }
-  
+
+  bool operator!= (void*) const
+  {
+    return this->base_reference() != nullptr;
+  }
+
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::halfedge_descriptor dereference() const { return opp(*this->base_reference()); }
-}; 
+};
 
 
 /**
@@ -587,21 +545,19 @@ public:
 #ifndef DOXYGEN_RUNNING
   typedef std::size_t size_type;
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Face_around_target_circulator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Face_around_target_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
   {
-    return this->base_reference() == NULL;
+    return this->base_reference() == nullptr;
+  }
+
+  bool operator!= (void*) const
+  {
+    return this->base_reference() != nullptr;
   }
 
 
@@ -610,14 +566,14 @@ private:
   typename  boost::graph_traits<Graph>::face_descriptor dereference() const { return fct(*this->base_reference()); }
 #endif
 
-}; 
+};
 
 
 /**
  * \ingroup PkgBGLIterators
  * A bidirectional circulator  with value type `boost::graph_traits<Graph>::%halfedge_descriptor` over all halfedges having the same vertex as target.
- * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_target_circulator` `havc` with `h = *havc;` 
- * the following holds: `opposite(next(h,g),g) == *++havc`. 
+ * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_target_circulator` `havc` with `h = *havc;`
+ * the following holds: `opposite(next(h,g),g) == *++havc`.
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalCirculator`
  */
@@ -638,7 +594,7 @@ public:
   typedef value_type&                         reference;
   typedef std::ptrdiff_t                      difference_type;
   typedef std::size_t                         size_type;
-#endif 
+#endif
 
   Halfedge_around_target_circulator()
     : g(0)
@@ -661,51 +617,48 @@ public:
   bool       operator == ( const Self& other) const { return  g == other.g && pos == other.pos; }
   bool       operator != ( const Self& other) const { return  g != other.g || pos != other.pos; }
 
-
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_target_circulator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (g == NULL)) ?
-      &Halfedge_around_target_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (g == nullptr));
   }
 
 
   bool operator== (void* ) const
   {
-    return g == NULL;
+    return g == nullptr;
   }
 
- 
-  Self& operator++() 
+  bool operator!= (void* ) const
   {
-    CGAL_assertion(g != NULL);
+    return g != nullptr;
+  }
+
+
+  Self& operator++()
+  {
+    CGAL_assertion(g != nullptr);
     pos = opposite(next(pos,*g),*g);
     return *this;
   }
 
-  Self operator++(int) 
+  Self operator++(int)
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     Self tmp = *this;
     ++*this;
     return tmp;
   }
 
-  Self& operator--() 
+  Self& operator--()
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     pos = prev(opposite(pos,*g),*g);
     return *this;
   }
 
-  Self operator--(int) 
+  Self operator--(int)
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     Self tmp = *this;
     --*this;
     return tmp;
@@ -721,7 +674,7 @@ private:
 /**
  * \ingroup PkgBGLIterators
  * A bidirectional circulator  with value type `boost::graph_traits<Graph>::%halfedge_descriptor` over all halfedges incident to the same face or border.
- * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_face_circulator` `hafc` with  `h = *hafc` 
+ * Let `h` be a halfedge of graph `g`. For a `Halfedge_around_face_circulator` `hafc` with  `h = *hafc`
  * the following holds:  `next(h,g) == *++hafc`.
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalCirculator`
@@ -740,8 +693,8 @@ public:
   typedef value_type&                         reference;
   typedef std::ptrdiff_t                      difference_type;
   typedef std::size_t                         size_type;
-#endif 
-  
+#endif
+
   Halfedge_around_face_circulator()
     : pos(), g(0)
   {}
@@ -757,50 +710,47 @@ public:
 
   bool       operator == ( const Self& other) const { return  g == other.g && pos == other.pos; }
   bool       operator != ( const Self& other) const { return  g != other.g || pos != other.pos; }
- 
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Halfedge_around_face_circulator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (g == NULL)) ?
-      &Halfedge_around_face_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (g == nullptr));
   }
 
   bool operator== (void* ) const
   {
-    return g == NULL;
+    return g == nullptr;
   }
 
-  Self& operator++() 
+  bool operator!= (void* ) const
   {
-    CGAL_assertion(g != NULL);
+    return g != nullptr;
+  }
+
+  Self& operator++()
+  {
+    CGAL_assertion(g != nullptr);
     pos = next(pos,*g);
     return *this;
   }
 
-  Self operator++(int) 
+  Self operator++(int)
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     Self tmp = *this;
     ++*this;
     return tmp;
   }
 
-  Self& operator--() 
+  Self& operator--()
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     pos = prev(pos,*g);
     return *this;
   }
 
-  Self operator--(int) 
+  Self operator--(int)
   {
-    CGAL_assertion(g != NULL);
+    CGAL_assertion(g != nullptr);
     Self tmp = *this;
     --*this;
     return tmp;
@@ -813,32 +763,32 @@ private:
 };
 
 
-/**  
+/**
  * \ingroup PkgBGLIterators
  * returns an iterator range over all halfedges with vertex `source(h,g)` as source.
  */
 template<typename Graph>
 Iterator_range<Halfedge_around_source_iterator<Graph> >
-halfedges_around_source(typename boost::graph_traits<Graph>::halfedge_descriptor h, Graph& g)
+halfedges_around_source(typename boost::graph_traits<Graph>::halfedge_descriptor h, const Graph& g)
 {
   typedef Halfedge_around_source_iterator<Graph> I;
   return make_range(I(h,g), I(h,g,1));
 }
 
-/**  
+/**
  * \ingroup PkgBGLIterators
  * returns an iterator range over all halfedges with vertex `v` as source.
  */
 template<typename Graph>
 Iterator_range<Halfedge_around_source_iterator<Graph> >
-halfedges_around_source(typename boost::graph_traits<Graph>::vertex_descriptor v, Graph& g)
+halfedges_around_source(typename boost::graph_traits<Graph>::vertex_descriptor v, const Graph& g)
 {
   return halfedges_around_source(opposite(halfedge(v,g),g),g);
 }
 
-/**  
+/**
  * \ingroup PkgBGLIterators
- * returns an iterator range over all halfedges with vertex `target(h,g)` as target. 
+ * returns an iterator range over all halfedges with vertex `target(h,g)` as target.
  */
 template<typename Graph>
 Iterator_range<Halfedge_around_target_iterator<Graph> >
@@ -848,20 +798,20 @@ halfedges_around_target(typename boost::graph_traits<Graph>::halfedge_descriptor
   return make_range(I(h,g), I(h,g,1));
 }
 
-/**  
+/**
  * \ingroup PkgBGLIterators
- * returns an iterator range over all halfedges with vertex `v` as target. 
+ * returns an iterator range over all halfedges with vertex `v` as target.
  */
 template<typename Graph>
 Iterator_range<Halfedge_around_target_iterator<Graph> >
-halfedges_around_target(typename boost::graph_traits<Graph>::vertex_descriptor v, Graph& g)
+halfedges_around_target(typename boost::graph_traits<Graph>::vertex_descriptor v, const Graph& g)
 {
   return halfedges_around_target(halfedge(v,g),g);
 }
 
-/**  
+/**
  * \ingroup PkgBGLIterators
- * returns an iterator range over all halfedges incident to the same face or border as `h`. 
+ * returns an iterator range over all halfedges incident to the same face or border as `h`.
  */
 template<typename Graph>
 Iterator_range<Halfedge_around_face_iterator<Graph> >
@@ -871,7 +821,16 @@ halfedges_around_face(typename boost::graph_traits<Graph>::halfedge_descriptor h
   return make_range(I(h,g), I(h,g,1));
 }
 
-
+/**
+ * \ingroup PkgBGLIterators
+ * A bidirectional iterator with value type `boost::graph_traits<Graph>::%face_descriptor`.
+ * It iterates over the same halfedges as the `Halfedge_around_face_iterator`,
+ * and provides the face descriptor associated to the opposite halfedge.  The face descriptor
+ * may be the null face, and it may be several times the same face descriptor.
+ *
+ * \tparam Graph must be a model of the concept `HalfedgeGraph`
+ * \cgalModels `BidirectionalCirculator`
+ */
 template <typename Graph>
 class Face_around_face_iterator
 #ifndef DOXYGEN_RUNNING
@@ -897,7 +856,7 @@ public:
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::face_descriptor dereference() const { return fct(*this->base_reference()); }
-}; 
+};
 
 
 /**
@@ -910,17 +869,23 @@ private:
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalCirculator`
  */
-
-
-
 template <typename Graph>
 class Face_around_face_circulator
 {};
 
-
+/**
+ * \ingroup PkgBGLIterators
+ * A bidirectional iterator with value type `boost::graph_traits<Graph>::%face_descriptor`.
+ * It iterates over the same halfedges as the `Halfedge_around_face_iterator`,
+ * and provides the face descriptor associated to the opposite halfedge.  The face descriptor
+ * may be the null face, and it may be several times the same face descriptor.
+ *
+ * \tparam Graph must be a model of the concept `HalfedgeGraph`
+ * \cgalModels `BidirectionalIterator`
+ */
 template <typename Graph>
 class Face_around_target_iterator
-#ifndef DOXYGEN_RUNNING  
+#ifndef DOXYGEN_RUNNING
   : public boost::iterator_adaptor<
             Face_around_target_iterator<Graph>                       // Derived
              , Halfedge_around_target_iterator<Graph>                // Base
@@ -946,11 +911,11 @@ public:
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::face_descriptor dereference() const { return fct(*this->base_reference()); }
-}; 
+};
 
-/**  
+/**
  * \ingroup PkgBGLIterators
- * returns an iterator range over all faces around  vertex `target(h,g)`. 
+ * returns an iterator range over all faces around  vertex `target(h,g)`.
  */
 template<typename Graph>
 Iterator_range<Face_around_target_iterator<Graph> >
@@ -960,7 +925,7 @@ faces_around_target(typename boost::graph_traits<Graph>::halfedge_descriptor h,
   return make_range(I(h,g), I(h,g,1));
 }
 
-/**  
+/**
  * \ingroup PkgBGLIterators
  * returns an iterator range over all edge-adjacent faces to the same face `face(h,g)`.
  */
@@ -972,9 +937,15 @@ faces_around_face(typename boost::graph_traits<Graph>::halfedge_descriptor h, co
   return make_range(I(h,g), I(h,g,1));
 }
 
+/**
+ * \ingroup PkgBGLIterators
+ * A bidirectional circulator with value type `boost::graph_traits<Graph>::%vertex_descriptor` over all vertices incident to the same face or border.
+ * \tparam Graph must be a model of the concept `HalfedgeGraph`
+ * \cgalModels `BidirectionalIterator`
+ */
 template <typename Graph>
 class Vertex_around_face_circulator
-#ifndef DOXYGEN_RUNNING 
+#ifndef DOXYGEN_RUNNING
   : public boost::iterator_adaptor<
              Vertex_around_face_circulator<Graph>                    // Derived
              , Halfedge_around_face_circulator<Graph>                  // Base
@@ -1000,28 +971,35 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_face_circulator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Vertex_around_face_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
   {
-    return this->base_reference()== NULL;
+    return this->base_reference()== nullptr;
   }
+
+  bool operator!= (void*) const
+  {
+    return this->base_reference()!= nullptr;
+  }
+
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::vertex_descriptor dereference() const { return fct(*this->base_reference()); }
 #endif
-}; 
+};
 
+/**
+ * \ingroup PkgBGLIterators
+ * A bidirectional iterator  with value type `boost::graph_traits<Graph>::%vertex_descriptor`
+ *  over all vertices incident to the same face or border.
+ * \tparam Graph must be a model of the concept `HalfedgeGraph`
+ * \cgalModels `BidirectionalIterator`
+ */
 template <typename Graph>
 class Vertex_around_face_iterator
 #ifndef DOXYGEN_RUNNING
@@ -1047,38 +1025,103 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_face_iterator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Vertex_around_face_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
   {
-    return this->base_reference()== NULL;
+    return this->base_reference()== nullptr;
   }
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::vertex_descriptor dereference() const { return fct(*this->base_reference()); }
 #endif
-}; 
+};
+
+
+template <typename Graph>
+class Opposite_edge_around_face_iterator
+#ifndef DOXYGEN_RUNNING
+  : public boost::iterator_adaptor<
+            Opposite_edge_around_face_iterator<Graph>                       // Derived
+             , Halfedge_around_face_iterator<Graph>                // Base
+             , typename boost::graph_traits<Graph>::edge_descriptor  // Value
+             , std::bidirectional_iterator_tag                       // CategoryOrTraversal
+             , typename boost::graph_traits<Graph>::edge_descriptor  // Reference
+             >
+#endif
+{
+  typedef typename boost::graph_traits<Graph>::halfedge_descriptor halfedge_descriptor;
+  internal::Opposite_edge<Graph> fct;
+public:
+
+  Opposite_edge_around_face_iterator()
+  {}
+
+  Opposite_edge_around_face_iterator(halfedge_descriptor h, const Graph& g, int n = 0)
+    : Opposite_edge_around_face_iterator::iterator_adaptor_(Halfedge_around_face_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), fct(g)
+  {}
+private:
+  friend class boost::iterator_core_access;
+  typename  boost::graph_traits<Graph>::edge_descriptor dereference() const { return fct(*this->base_reference()); }
+};
+
+template<typename Graph>
+Iterator_range<Opposite_edge_around_face_iterator<Graph> >
+opposite_edges_around_face(typename boost::graph_traits<Graph>::halfedge_descriptor h, const Graph& g)
+{
+  typedef Opposite_edge_around_face_iterator<Graph> I;
+  return make_range(I(h,g), I(h,g,1));
+}
+
+template <typename Graph>
+class Edge_around_face_iterator
+#ifndef DOXYGEN_RUNNING
+  : public boost::iterator_adaptor<
+            Edge_around_face_iterator<Graph>                       // Derived
+             , Halfedge_around_face_iterator<Graph>                // Base
+             , typename boost::graph_traits<Graph>::edge_descriptor  // Value
+             , std::bidirectional_iterator_tag                       // CategoryOrTraversal
+             , typename boost::graph_traits<Graph>::edge_descriptor  // Reference
+             >
+#endif
+{
+  typedef typename boost::graph_traits<Graph>::halfedge_descriptor halfedge_descriptor;
+  internal::Edge<Graph> fct;
+public:
+
+  Edge_around_face_iterator()
+  {}
+
+  Edge_around_face_iterator(halfedge_descriptor h, const Graph& g, int n = 0)
+    : Edge_around_face_iterator::iterator_adaptor_(Halfedge_around_face_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), fct(g)
+  {}
+private:
+  friend class boost::iterator_core_access;
+  typename  boost::graph_traits<Graph>::edge_descriptor dereference() const { return fct(*this->base_reference()); }
+};
+
+template<typename Graph>
+Iterator_range<Edge_around_face_iterator<Graph> >
+edges_around_face(typename boost::graph_traits<Graph>::halfedge_descriptor h, const Graph& g)
+{
+  typedef Edge_around_face_iterator<Graph> I;
+  return make_range(I(h,g), I(h,g,1));
+}
+
 
 
 /**
  * \ingroup PkgBGLIterators
- * A bidirectional circulator  with value type `boost::graph_traits<Graph>::%vertex_descriptor` over all vertices adjacent to the same vertex.
+ * A bidirectional circulator with value type `boost::graph_traits<Graph>::%vertex_descriptor` over all vertices adjacent to the same vertex.
  * It circulates over the same halfedges as the `Halfedge_around_target_circulator`.
  *
  * \tparam Graph must be a model of the concept `HalfedgeGraph`
  * \cgalModels `BidirectionalCirculator`
  */
-
 template <typename Graph>
 class Vertex_around_target_circulator
 #ifndef DOXYGEN_RUNNING
@@ -1105,33 +1148,39 @@ public:
     : Vertex_around_target_circulator::iterator_adaptor_(Halfedge_around_target_circulator<Graph>(h,g)), fct(g)
   {}
 
-#ifndef DOXYGEN_RUNNING  
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_target_circulator::*bool_type)() const;
+#ifndef DOXYGEN_RUNNING
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Vertex_around_target_circulator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
   bool operator== (void*) const
   {
-    return this->base_reference()== NULL;
+    return this->base_reference()== nullptr;
+  }
+
+  bool operator!= (void*) const
+  {
+    return this->base_reference()!= nullptr;
   }
 
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::vertex_descriptor dereference() const { return fct(*this->base_reference()); }
 #endif
-}; 
-
+};
 
 
 
+/**
+ * \ingroup PkgBGLIterators
+ * A bidirectional iterator with value type `boost::graph_traits<Graph>::%vertex_descriptor` over all vertices adjacent to the same vertex.
+ * It iterates over the same halfedges as the `Halfedge_around_target_iterator`.
+ *
+ * \tparam Graph must be a model of the concept `HalfedgeGraph`
+ * \cgalModels `BidirectionalIterator`
+ */
 template <typename Graph>
 class Vertex_around_target_iterator
 #ifndef DOXYGEN_RUNNING
@@ -1157,29 +1206,23 @@ public:
   {}
 
 #ifndef DOXYGEN_RUNNING
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Vertex_around_target_iterator::*bool_type)() const;
 
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Vertex_around_target_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::vertex_descriptor dereference() const { return fct(*this->base_reference()); }
 #endif
-}; 
+};
 
 
 template <typename Graph>
 Iterator_range<Vertex_around_target_iterator<Graph> >
 adjacent_vertices(typename boost::graph_traits<Graph>::halfedge_descriptor h, const Graph& g)
 {
-  typedef Vertex_around_face_iterator<Graph> I;
+  typedef Vertex_around_target_iterator<Graph> I;
   return make_range(I(h,g), I(h,g,1));
 }
 
@@ -1188,13 +1231,13 @@ template <typename Graph>
 Iterator_range<Vertex_around_target_iterator<Graph> >
 adjacent_vertices(typename boost::graph_traits<Graph>::vertex_descriptor v, const Graph& g)
 {
-  typedef Vertex_around_face_iterator<Graph> I;
+  typedef Vertex_around_target_iterator<Graph> I;
   return make_range(I(halfedge(v,g),g), I(halfedge(v,g),g,1));
 }
 
-/**  
+/**
  * \ingroup PkgBGLIterators
- * returns an iterator range over all vertices adjacent to the vertex `target(h,g)`. 
+ * returns an iterator range over all vertices adjacent to the vertex `target(h,g)`.
  */
 template <typename Graph>
 Iterator_range<Vertex_around_target_iterator<Graph> >
@@ -1211,9 +1254,9 @@ vertices_around_target(typename boost::graph_traits<Graph>::vertex_descriptor v,
   typedef Vertex_around_target_iterator<Graph> I;
   return make_range(I(halfedge(v,g),g), I(halfedge(v,g),g,1));
 }
-/**  
+/**
  * \ingroup PkgBGLIterators
- * returns an iterator range over all vertices adjacent to the face `face(h,g)`. 
+ * returns an iterator range over all vertices adjacent to the face `face(h,g)`.
  */
 template <typename Graph>
 Iterator_range<Vertex_around_face_iterator<Graph> >
@@ -1240,23 +1283,16 @@ private:
 public:
   Out_edge_iterator()
   {}
-  
+
   Out_edge_iterator(halfedge_descriptor h, const Graph& g, int n = 0)
     : Out_edge_iterator::iterator_adaptor_(Halfedge_around_target_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), opp(g) {}
-  
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (Out_edge_iterator::*bool_type)() const;
-  
-  void this_type_does_not_support_comparisons() const {}
-  
-  operator bool_type() const
+
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &Out_edge_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
-  
-  
+
+
 private:
   friend class boost::iterator_core_access;
   typename  boost::graph_traits<Graph>::edge_descriptor dereference() const { return opp(*this->base_reference()); }
@@ -1281,21 +1317,14 @@ private:
 public:
   In_edge_iterator()
   {}
-  
+
   In_edge_iterator(halfedge_descriptor h, const Graph& g, int n = 0)
     : In_edge_iterator::iterator_adaptor_(Halfedge_around_target_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), fct(g)
   {}
 
-  // design patter: "safe bool"
-  // will be replaced by explicit operator bool with C++11
-  typedef void (In_edge_iterator::*bool_type)() const;
-
-  void this_type_does_not_support_comparisons() const {}
-
-  operator bool_type() const
+  explicit operator bool() const
   {
-    return (! (this->base_reference() == NULL)) ?
-      &In_edge_iterator::this_type_does_not_support_comparisons : 0;
+    return (! (this->base_reference() == nullptr));
   }
 
  private:
