@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Number_types/include/CGAL/boost_mp.h $
-// $Id: boost_mp.h 96bf9c9 2023-04-07T10:45:12+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/boost_mp.h $
+// $Id: boost_mp.h cf0c6c07822 2023-08-03T14:05:37+02:00 Laurent Rineau
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -20,8 +20,18 @@
 // easy solution.
 // MSVC had trouble with versions <= 1.69:
 // https://github.com/boostorg/multiprecision/issues/98
+//
+// Disable also on Windows 32 bits
+// because CGAL/cpp_float.h assumes _BitScanForward64 is available
+// See https://learn.microsoft.com/en-us/cpp/intrinsics/bitscanforward-bitscanforward64
+//
+// Disable also with PowerPC processors, with Boost<1.80 because of that bug:
+// https://github.com/boostorg/multiprecision/pull/421
+//
 #if !defined CGAL_DO_NOT_USE_BOOST_MP && \
-    (!defined _MSC_VER || BOOST_VERSION >= 107000)
+    (!defined _MSC_VER || BOOST_VERSION >= 107000) && \
+    (!defined _WIN32 || defined _WIN64) && \
+    (BOOST_VERSION >= 108000 || (!defined _ARCH_PPC && !defined _ARCH_PPC64))
 #define CGAL_USE_BOOST_MP 1
 
 #include <CGAL/Quotient.h>
