@@ -1,25 +1,16 @@
-// Copyright (c) 1997  
+// Copyright (c) 1997
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Circulator/include/CGAL/circulator.h $
+// $Id: circulator.h 9e277981edb 2023-01-24T13:42:06+01:00 Laurent Rineau
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Circulator/include/CGAL/circulator.h $
-// $Id: circulator.h 805e019 2019-01-15T18:01:25+01:00 Andreas Fabri
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Lutz Kettner  <kettner@inf.ethz.ch>
 
@@ -30,6 +21,7 @@
 #include <CGAL/circulator_bases.h>
 #include <CGAL/assertions.h>
 #include <CGAL/use.h>
+#include <CGAL/tags.h>
 
 #include <cstddef>
 #include <functional>
@@ -82,19 +74,19 @@ namespace internal {
 
 // default to Iterator_tag, special case Circulator tags
 template<typename Tag>
-struct Get_category 
+struct Get_category
 { typedef Iterator_tag type; };
 
 template<>
-struct Get_category<CGAL::Forward_circulator_tag> 
+struct Get_category<CGAL::Forward_circulator_tag>
 { typedef Circulator_tag type; };
 
 template<>
-struct Get_category<CGAL::Bidirectional_circulator_tag> 
+struct Get_category<CGAL::Bidirectional_circulator_tag>
 { typedef Circulator_tag type; };
 
 template<>
-struct Get_category<CGAL::Random_access_circulator_tag> 
+struct Get_category<CGAL::Random_access_circulator_tag>
 { typedef Circulator_tag type; };
 
 } // internal
@@ -311,7 +303,7 @@ void Assert_is_at_least_random_access_category( const IC& /*ic*/) {
 
 template< class C> inline
 bool I_is_empty_range( const C& c1, const C&, Circulator_tag){
-    return c1 == NULL;
+    return c1 == nullptr;
 }
 
 template< class I> inline
@@ -368,7 +360,7 @@ I_min_circulator_size( const C& c) {
     Assert_random_access_category(c);
     typedef typename C::size_type  size_type;
     size_type n = 0;
-    if ( c != NULL) {
+    if ( c != nullptr) {
         n = (c-1) - c + 1;
         CGAL_assertion(n > 0);
     }
@@ -379,7 +371,7 @@ template <class C>
 typename C::size_type
 I_circulator_size( const C& c, Forward_circulator_tag) {
     // Simply count.
-    if ( c == NULL)
+    if ( c == nullptr)
         return 0;
     typedef typename C::size_type  size_type;
     size_type n = 0;
@@ -405,14 +397,14 @@ template <class C> inline
 typename C::size_type
 circulator_size( const C& c) {
   typedef typename std::iterator_traits<C>::iterator_category category;
-  return I_circulator_size( c, 
+  return I_circulator_size( c,
                             category());
 }
 template <class C>
 typename C::difference_type
 I_circulator_distance( C c, const C& d, Forward_circulator_tag) {
     // Simply count.
-    if ( c == NULL)
+    if ( c == nullptr)
         return 0;
     typedef typename C::difference_type  difference_type;
     difference_type n = 0;
@@ -443,7 +435,7 @@ template <class C> inline
 typename C::difference_type
 circulator_distance( const C& c, const C& d) {
   typedef typename std::iterator_traits<C>::iterator_category category;
-  return I_circulator_distance( c, d, 
+  return I_circulator_distance( c, d,
                                 category());
 }
 template <class C> inline
@@ -551,18 +543,18 @@ public:
         return !(*this == i);
     }
     Ref  operator*() const {
-        CGAL_assertion( m_anchor != NULL);
-        CGAL_assertion( current  != NULL);
+        CGAL_assertion( m_anchor != nullptr);
+        CGAL_assertion( current  != nullptr);
         return Ref(*current);
     }
     Ptr  operator->() const {
-        CGAL_assertion( m_anchor != NULL);
-        CGAL_assertion( current  != NULL);
+        CGAL_assertion( m_anchor != nullptr);
+        CGAL_assertion( current  != nullptr);
         return Ptr(current.operator->());
     }
     Self& operator++() {
-        CGAL_assertion( m_anchor != NULL);
-        CGAL_assertion( current  != NULL);
+        CGAL_assertion( m_anchor != nullptr);
+        CGAL_assertion( current  != nullptr);
         ++current;
         if ( current == *m_anchor)
             ++m_winding;
@@ -574,8 +566,8 @@ public:
         return tmp;
     }
     Self& operator--() {
-        CGAL_assertion( m_anchor != NULL);
-        CGAL_assertion( current != NULL);
+        CGAL_assertion( m_anchor != nullptr);
+        CGAL_assertion( current != nullptr);
         if ( current == *m_anchor)
             --m_winding;
         --current;
@@ -587,8 +579,8 @@ public:
         return tmp;
     }
     Self& operator+=( difference_type n) {
-        CGAL_assertion( m_anchor != NULL);
-        CGAL_assertion( current != NULL);
+        CGAL_assertion( m_anchor != nullptr);
+        CGAL_assertion( current != nullptr);
         if ( n < 0 && current == *m_anchor)  // We are leaving the anchor.
             --m_winding;
         current += n;
@@ -608,8 +600,8 @@ public:
         return tmp += -n;
     }
     difference_type  operator-( const Self& i) const {
-        CGAL_assertion( m_anchor  != NULL);
-        CGAL_assertion( current   != NULL);
+        CGAL_assertion( m_anchor  != nullptr);
+        CGAL_assertion( current   != nullptr);
         CGAL_assertion( m_anchor  == i.m_anchor);
         if ( m_winding != i.m_winding) {
             difference_type s = I_min_circulator_size( *m_anchor);
@@ -625,8 +617,8 @@ public:
         return tmp.operator*();
     }
     bool operator<( const Self& i) const {
-        CGAL_assertion( m_anchor  != NULL);
-        CGAL_assertion( current != NULL);
+        CGAL_assertion( m_anchor  != nullptr);
+        CGAL_assertion( current != nullptr);
         CGAL_assertion( m_anchor  == i.m_anchor);
         return (     (m_winding < i.m_winding)
                  || (    (m_winding == i.m_winding)
@@ -697,19 +689,25 @@ typedef Iterator_from_circulator< C, const_reference, const_pointer>
     }
     iterator end() {
         // the past-the-end iterator.
-        return anchor == NULL ?  iterator( &anchor, 0)
+        return anchor == nullptr ?  iterator( &anchor, 0)
                                         :  iterator( &anchor, 1);
     }
     const_iterator end() const {
         // the past-the-end const iterator.
-        return anchor == NULL ?  const_iterator( &anchor, 0)
+        return anchor == nullptr ?  const_iterator( &anchor, 0)
                                         :  const_iterator( &anchor, 1);
     }
 };
 template <class Container>
 class Circulator_from_container {
     typedef Circulator_from_container<Container>      Self;
-    typedef typename Container::iterator              iterator;
+    typedef typename Container::iterator              container_iterator;
+    typedef typename Container::const_iterator        container_const_iterator;
+    typedef std::conditional_t<
+        std::is_const<Container>::value,
+        container_const_iterator,
+        container_iterator
+        >                                             iterator;
     typedef std::iterator_traits<iterator>            iterator_traits;
 public:
     typedef typename iterator_traits::value_type      value_type;
@@ -720,7 +718,7 @@ public:
     typedef typename I_Circulator_from_iterator_traits<
         typename iterator_traits::iterator_category
         >::iterator_category                          iterator_category;
-    
+
     typedef typename Container::size_type size_type;
 private:
     Container*     ctnr;
@@ -729,32 +727,32 @@ private:
 public:
 // CREATION
 
-    Circulator_from_container() : ctnr(NULL) {}
+    Circulator_from_container() : ctnr(nullptr) {}
     Circulator_from_container( Container* c) : ctnr(c), i(c->begin()) {}
     Circulator_from_container( Container* c, iterator j)  : ctnr(c), i(j) {}
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
+    bool operator==( std::nullptr_t p) const {
         CGAL_USE(p);
-        CGAL_assertion( p == NULL);
-        return (ctnr == NULL) || (ctnr->begin() == ctnr->end());
+        CGAL_assertion( p == nullptr);
+        return (ctnr == nullptr) || (ctnr->begin() == ctnr->end());
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c) const { return i == c.i; }
     bool operator!=( const Self& c) const { return !(*this == c); }
     reference  operator*() const {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         return *i;
     }
     pointer  operator->() const {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         return i.operator->();
     }
     Self& operator++() {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         ++i;
         if ( i == ctnr->end())
@@ -767,7 +765,7 @@ public:
         return tmp;
     }
     Self& operator--() {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         if ( i == ctnr->begin())
             i = ctnr->end();
@@ -780,7 +778,7 @@ public:
         return tmp;
     }
     Self& operator+=( difference_type n) {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         typename Container::difference_type j    = i - ctnr->begin();
         typename Container::difference_type size = ctnr->size();
@@ -802,8 +800,8 @@ public:
         return tmp += -n;
     }
     difference_type operator-( const Self& c) const {
-        CGAL_assertion( ctnr != NULL);
-        CGAL_assertion( c.ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
+        CGAL_assertion( c.ctnr != nullptr);
         return i - c.i;
     }
     reference  operator[]( difference_type n) const {
@@ -852,7 +850,7 @@ private:
 public:
 // CREATION
 
-    Const_circulator_from_container() : ctnr(NULL) {}
+    Const_circulator_from_container() : ctnr(nullptr) {}
     Const_circulator_from_container( const Ctnr* c)
         : ctnr(c), i(c->begin()) {}
     Const_circulator_from_container( const Ctnr* c, const_iterator j)
@@ -862,26 +860,26 @@ public:
 
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
+    bool operator==( std::nullptr_t p) const {
         CGAL_USE(p);
-        CGAL_assertion( p == NULL);
-        return (ctnr == NULL) || (ctnr->begin() == ctnr->end());
+        CGAL_assertion( p == nullptr);
+        return (ctnr == nullptr) || (ctnr->begin() == ctnr->end());
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c) const { return i == c.i; }
     bool operator!=( const Self& c) const { return !(*this == c); }
     reference  operator*() const {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         return *i;
     }
     pointer  operator->() const {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         return i.operator->();
     }
     Self& operator++() {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         ++i;
         if ( i == ctnr->end())
@@ -894,7 +892,7 @@ public:
         return tmp;
     }
     Self& operator--() {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         if ( i == ctnr->begin())
             i = ctnr->end();
@@ -907,7 +905,7 @@ public:
         return tmp;
     }
     Self& operator+=( difference_type n) {
-        CGAL_assertion( ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
         CGAL_assertion( i != ctnr->end());
         typename Ctnr::difference_type j    = i - ctnr->begin();
         typename Ctnr::difference_type size = ctnr->size();
@@ -929,8 +927,8 @@ public:
         return tmp += -n;
     }
     difference_type operator-( const Self& c) const {
-        CGAL_assertion( ctnr != NULL);
-        CGAL_assertion( c.ctnr != NULL);
+        CGAL_assertion( ctnr != nullptr);
+        CGAL_assertion( c.ctnr != nullptr);
         return i - c.i;
     }
     reference  operator[]( difference_type n) const {
@@ -991,7 +989,7 @@ public:
     Circulator_from_iterator() : m_begin(),
                                  m_end(),
                                  current(),
-				 empty( true)
+                                 empty( true)
   {}
 
     Circulator_from_iterator( const I& bgn, const I& end)
@@ -1015,12 +1013,12 @@ public:
 //
 // OPERATIONS
 
-    bool operator==( Nullptr_t p) const {
+    bool operator==( std::nullptr_t p) const {
         CGAL_USE(p);
-        CGAL_assertion( p == NULL);
+        CGAL_assertion( p == nullptr);
         return empty;
     }
-    bool operator!=( Nullptr_t p) const { return !(*this == p); }
+    bool operator!=( std::nullptr_t p) const { return !(*this == p); }
     bool operator==( const Self& c) const { return  current == c.current;}
     bool operator!=( const Self& c) const { return !(*this == c); }
     reference  operator*() const {
