@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Interpolation/include/CGAL/constructions/constructions_for_voronoi_intersection_cartesian_2_3.h $
-// $Id: constructions_for_voronoi_intersection_cartesian_2_3.h ee57fc2 2017-10-21T01:03:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Interpolation/include/CGAL/constructions/constructions_for_voronoi_intersection_cartesian_2_3.h $
+// $Id: constructions_for_voronoi_intersection_cartesian_2_3.h 45478184de2 2022-11-15T13:39:40+01:00 albert-github
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Julia Floetotto
@@ -82,12 +73,12 @@ plane_centered_circumcenterC3(const RT &ax, const RT &ay, const RT &az,
   //
   //precondition: p,q,r aren't collinear.
   //method:
-  // - tranlation of p to the origin.
-  plane_centered_circumcenter_translateC3(ax-px, ay-py, az-pz,
-                                          nx, ny, nz,
-                                          qx-px, qy-py,qz-pz,
-                                          rx-px, ry-py,rz-pz,
-                                          x, y, z);
+  // - translation of p to the origin.
+  plane_centered_circumcenter_translateC3<RT>(ax-px, ay-py, az-pz,
+                                              nx, ny, nz,
+                                              qx-px, qy-py,qz-pz,
+                                              rx-px, ry-py,rz-pz,
+                                              x, y, z);
   x+=px;
   y+=py;
   z+=pz;
