@@ -1,20 +1,11 @@
 // Copyright (c) 2006-2008 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Number_types/include/CGAL/gmpxx_coercion_traits.h $
-// $Id: gmpxx_coercion_traits.h 0698f79 2017-10-20T23:34:14+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/gmpxx_coercion_traits.h $
+// $Id: gmpxx_coercion_traits.h 26355e2e322 2020-06-25T12:31:21+02:00 Mael Rouxel-Labbé
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Michael Hemmer   <hemmer@mpi-inf.mpg.de>
@@ -22,13 +13,12 @@
 
 
 /*! \file NiX/Gmp/Coercion_traits.h
- *  \brief Provides specializations of Coercion_traits for the Gmp types.
+ *  \brief provides specializations of Coercion_traits for the Gmp types.
  */
 
 #ifndef CGAL_GMPXX_COERCION_TRAITS_H
 #define CGAL_GMPXX_COERCION_TRAITS_H 1
 
-#include <CGAL/number_type_basic.h>
 #include <CGAL/Coercion_traits.h>
 
 #include <cstring> // needed by GMP 4.1.4 since <gmpxx.h> misses it.
