@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Principal_component_analysis/include/CGAL/linear_least_squares_fitting_segments_2.h $
-// $Id: linear_least_squares_fitting_segments_2.h f3baef9 2018-07-06T10:10:19+02:00 Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Principal_component_analysis/include/CGAL/linear_least_squares_fitting_segments_2.h $
+// $Id: linear_least_squares_fitting_segments_2.h 4e7edc7d94d 2022-01-27T11:03:42+01:00 Sebastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Pierre Alliez and Sylvain Pion and Ankit Gupta
 
@@ -28,6 +19,7 @@
 #include <CGAL/centroid.h>
 #include <CGAL/Linear_algebraCd.h>
 #include <CGAL/PCA_util.h>
+#include <CGAL/Subiterator.h>
 
 #include <iterator>
 #include <list>
@@ -45,13 +37,13 @@ namespace internal {
 template < typename InputIterator, typename K, typename DiagonalizeTraits >
 typename K::FT
 linear_least_squares_fitting_2(InputIterator first,
-                               InputIterator beyond, 
+                               InputIterator beyond,
                                typename K::Line_2& line,   // best fit line
                                typename K::Point_2& c,     // centroid
                                const typename K::Segment_2*,// used for indirection
                                const K&,                   // kernel
-			       const CGAL::Dimension_tag<1>& tag,
-			       const DiagonalizeTraits&)
+                               const CGAL::Dimension_tag<1>& tag,
+                               const DiagonalizeTraits&)
 {
   // types
   typedef typename K::FT       FT;
@@ -66,7 +58,7 @@ linear_least_squares_fitting_2(InputIterator first,
 
   // compute centroid
   c = centroid(first,beyond,K(),tag);
-  // assemble covariance matrix as a semi-definite matrix. 
+  // assemble covariance matrix as a semi-definite matrix.
   // Matrix numbering:
   // 0
   // 1 2
@@ -74,9 +66,9 @@ linear_least_squares_fitting_2(InputIterator first,
   FT mass = 0.0;
   typename DiagonalizeTraits::Covariance_matrix covariance = {{ 0., 0., 0. }};
 
-  // assemble 2nd order moment about the origin.  
+  // assemble 2nd order moment about the origin.
   FT temp[4] = {1.0, 0.5, 0.5, 1.0};
-  Matrix moment = (1.0/3.0) * init_matrix<FT>(2,temp);
+  Matrix moment = FT(1.0/3.0) * init_matrix<FT>(2,temp);
 
   for(InputIterator it = first;
       it != beyond;
@@ -88,17 +80,18 @@ linear_least_squares_fitting_2(InputIterator first,
 
     // defined for convenience.
     // FT example = CGAL::to_double(t[0].x());
-    FT delta[4] = {t[0].x(), t[1].x(), 
-		   t[0].y(), t[1].y()};
+    FT delta[4] = {t[0].x(), t[1].x(),
+                   t[0].y(), t[1].y()};
     Matrix transformation = init_matrix<FT>(2,delta);
-    FT length = std::sqrt(t.squared_length());
-    CGAL_assertion(length != 0.0);
+    using std::sqrt;
+    FT length = CGAL::approximate_sqrt(t.squared_length());
+    CGAL_assertion(!CGAL::is_zero(length));
 
     // Find the 2nd order moment for the segment wrt to the origin by an affine transformation.
-    
+
     // Transform the standard 2nd order moment using the transformation matrix
     transformation = length * transformation * moment * LA::transpose(transformation);
-    
+
     // add to covariance matrix
     covariance[0] += transformation[0][0];
     covariance[1] += transformation[0][1];
@@ -107,14 +100,16 @@ linear_least_squares_fitting_2(InputIterator first,
     mass += length;
   }
 
+  CGAL_assertion_msg (mass != FT(0), "Can't compute PCA of null measure.");
+
   // Translate the 2nd order moment calculated about the origin to
   // the center of mass to get the covariance.
-  covariance[0] += mass * (-1.0 * c.x() * c.x());
-  covariance[1] += mass * (-1.0 * c.x() * c.y());
-  covariance[2] += mass * (-1.0 * c.y() * c.y());
+  covariance[0] -= mass * CGAL::square(c.x());
+  covariance[1] -= mass * (c.x() * c.y());
+  covariance[2] -= mass * (CGAL::square(c.y()));
 
   // solve for eigenvalues and eigenvectors.
-  // eigen values are sorted in ascending order, 
+  // eigen values are sorted in ascending order,
   // eigen vectors are sorted in accordance.
   typename DiagonalizeTraits::Vector eigen_values = {{ 0. , 0. }};
   typename DiagonalizeTraits::Matrix eigen_vectors = {{ 0., 0., 0. }};
@@ -127,46 +122,41 @@ linear_least_squares_fitting_2(InputIterator first,
     // regular case
     line = Line(c, Vector(eigen_vectors[2],eigen_vectors[3]));
     return (FT)1.0 - eigen_values[0] / eigen_values[1];
-  } 
+  }
   else
   {
     // isotropic case (infinite number of directions)
-    // by default: assemble a line that goes through 
+    // by default: assemble a line that goes through
     // the centroid and with a default horizontal vector.
-    line = Line(c, Vector(1.0, 0.0));
+    line = Line(c, Vector(FT(1), FT(0)));
     return (FT)0.0;
-  } 
+  }
 } // end linear_least_squares_fitting_2 for segment set with 1D tag
 
 template < typename InputIterator, typename K, typename DiagonalizeTraits >
 typename K::FT
 linear_least_squares_fitting_2(InputIterator first,
-                               InputIterator beyond, 
+                               InputIterator beyond,
                                typename K::Line_2& line,   // best fit line
                                typename K::Point_2& c,     // centroid
                                const typename K::Segment_2*,// used for indirection
                                const K& k,                   // kernel
-			       const CGAL::Dimension_tag<0>& tag,
-			       const DiagonalizeTraits& diagonalize_traits)
+                               const CGAL::Dimension_tag<0>& tag,
+                               const DiagonalizeTraits& diagonalize_traits)
 {
   // types
   typedef typename K::Point_2  Point;
   typedef typename K::Segment_2 Segment;
- 
+  auto converter = [](const Segment& s, int idx) -> Point { return s[idx]; };
+
   // precondition: at least one element in the container.
   CGAL_precondition(first != beyond);
 
-  std::list<Point> points;  
-  for(InputIterator it = first;
-      it != beyond;
-      it++)
-  {
-    const Segment& s = *it;
-    points.push_back(s[0]);
-    points.push_back(s[1]);
-  } 
-  return linear_least_squares_fitting_2(points.begin(),points.end(),line,c,k,(Point*)NULL,tag,
-					diagonalize_traits);
+  return linear_least_squares_fitting_2
+    (make_subiterator<Point, 2> (first, converter),
+     make_subiterator<Point, 2> (beyond),
+     line,c,(Point*)nullptr,k,tag,
+     diagonalize_traits);
 
 } // end linear_least_squares_fitting_2 for segment set with 1D tag
 
