@@ -1,27 +1,23 @@
 // Copyright (c) 2003  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you may redistribute it under
-// the terms of the Q Public License version 1.0.
-// See the file LICENSE.QPL distributed with CGAL.
+// This file is part of CGAL (www.cgal.org).
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Apollonius_graph_2/include/CGAL/more_functions_on_signs.h $
+// $Id: more_functions_on_signs.h 07793738355 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Apollonius_graph_2/include/CGAL/more_functions_on_signs.h $
-// $Id: more_functions_on_signs.h 56667 2010-06-09 07:37:13Z sloriot $
-// 
-//
-// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
+// Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 
 
 #ifndef CGAL_MORE_FUNCTIONS_ON_SIGNS_H
 #define CGAL_MORE_FUNCTIONS_ON_SIGNS_H
 
+#include <CGAL/license/Apollonius_graph_2.h>
+
+
 #include <CGAL/enum.h>
 
 namespace CGAL {
