@@ -1,25 +1,16 @@
-// Copyright (c) 1997  
+// Copyright (c) 1997
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
 // Max-Planck-Institute Saarbruecken (Germany),
-// and Tel-Aviv University (Israel).  All rights reserved. 
+// and Tel-Aviv University (Israel).  All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Generator/include/CGAL/point_generators_3.h $
+// $Id: point_generators_3.h 98e471849bd 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Generator/include/CGAL/point_generators_3.h $
-// $Id: point_generators_3.h 43d2ecb 2018-01-17T16:57:46+00:00 Andreas Fabri
-// SPDX-License-Identifier: LGPL-3.0+
-// 
 //
 // Author(s)     : Lutz Kettner  <kettner@inf.ethz.ch>
 //                 Pedro Machado Manhaes de Castro  <pmmc@cin.ufpe.br>
@@ -34,12 +25,12 @@
 #include <CGAL/generators.h>
 #include <CGAL/point_generators_2.h>
 #include <CGAL/number_type_basic.h>
-#include <CGAL/internal/Generic_random_point_generator.h>
+#include <CGAL/Generator/internal/Generic_random_point_generator.h>
 #include <CGAL/boost/graph/property_maps.h>
 
 namespace CGAL {
 
-template < class P, class Creator = 
+template < class P, class Creator =
                    Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P> >
 class Random_points_in_sphere_3 : public Random_generator_base<P> {
     void generate_point();
@@ -65,12 +56,12 @@ template < class P, class Creator >
 void
 Random_points_in_sphere_3<P,Creator>::
 generate_point() {
-  // A strip between z and z+dz has an area independant of z
+  // A strip between z and z+dz has an area independent of z
     typedef typename Creator::argument_type T;
     double alpha = this->_rnd.get_double() * 2.0 * CGAL_PI;
     double z     = 2 * this->_rnd.get_double() - 1.0;
     double r     = std::sqrt( 1 - z * z);
-    r *= std::pow( this->_rnd.get_double() , 1.0/3.0 );  
+    r *= std::pow( this->_rnd.get_double() , 1.0/3.0 );
     Creator creator;
     this->d_item = creator( T(this->d_range * r * std::cos(alpha)),
                             T(this->d_range * r * std::sin(alpha)),
@@ -78,7 +69,7 @@ generate_point() {
 }
 
 
-template < class P, class Creator = 
+template < class P, class Creator =
                    Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P> >
 class Random_points_on_sphere_3 : public Random_generator_base<P> {
     void generate_point();
@@ -104,7 +95,7 @@ template < class P, class Creator >
 void
 Random_points_on_sphere_3<P,Creator>::
 generate_point() {
-  // A strip between z and z+dz has an area independant of z
+  // A strip between z and z+dz has an area independent of z
     typedef typename Creator::argument_type T;
     double alpha = this->_rnd.get_double() * 2.0 * CGAL_PI;
     double z     = 2 * this->_rnd.get_double() - 1.0;
@@ -116,7 +107,7 @@ generate_point() {
 }
 
 
-template < class P, class Creator = 
+template < class P, class Creator =
                    Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P> >
 class Random_points_in_cube_3 : public Random_generator_base<P>{
     void generate_point();
@@ -142,7 +133,7 @@ generate_point() {
     typedef typename Creator::argument_type T;
     Creator creator;
     this->d_item =
-	     creator( T(this->d_range * ( 2 * this->_rnd.get_double() - 1.0)),
+             creator( T(this->d_range * ( 2 * this->_rnd.get_double() - 1.0)),
                       T(this->d_range * ( 2 * this->_rnd.get_double() - 1.0)),
                       T(this->d_range * ( 2 * this->_rnd.get_double() - 1.0)));
 }
@@ -150,7 +141,7 @@ generate_point() {
 
 template <class OutputIterator, class Creator>
 OutputIterator
-points_on_cube_grid_3( double a, std::size_t n, 
+points_on_cube_grid_3( double a, std::size_t n,
                          OutputIterator o, Creator creator)
 {
     if  (n == 0)
@@ -198,63 +189,63 @@ points_on_cube_grid_3( double a, std::size_t n, OutputIterator o)
 {
     typedef std::iterator_traits<OutputIterator> ITraits;
     typedef typename ITraits::value_type         P;
-    return points_on_square_grid_3(a, n, o, 
+    return points_on_square_grid_3(a, n, o,
                  Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P>());
 }
 
-template < class P, class Creator = 
+template < class P, class Creator =
 Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P> >
 class Random_points_in_triangle_3 : public Random_generator_base<P> {
-	P _p,_q,_r;
-	void generate_point();
+        P _p,_q,_r;
+        void generate_point();
 public:
-	typedef P result_type;
-	typedef Random_points_in_triangle_3<P, Creator> This;
-	typedef typename Kernel_traits<P>::Kernel::Triangle_3 Triangle_3;
-	Random_points_in_triangle_3() {}
-	Random_points_in_triangle_3( const This& x,Random& rnd)
-	: Random_generator_base<P>( 1, rnd ),_p(x._p),_q(x._q),_r(x._r) {
-		generate_point();
-	}
-	Random_points_in_triangle_3( const P& p, const P& q, const P& r, Random& rnd = get_default_random())
-	: Random_generator_base<P>( 1, rnd ),_p(p),_q(q),_r(r) {
-		generate_point();
-	}
-	Random_points_in_triangle_3( const Triangle_3& triangle,Random& rnd = get_default_random())
-	: Random_generator_base<P>( 1,
-			rnd),_p(triangle[0]),_q(triangle[1]),_r(triangle[2]) {
-		generate_point();
-	}
-	This& operator++() {
-		generate_point();
-		return *this;
-	}
-	This operator++(int) {
-		This tmp = *this;
-		++(*this);
-		return tmp;
-	}
+        typedef P result_type;
+        typedef Random_points_in_triangle_3<P, Creator> This;
+        typedef typename Kernel_traits<P>::Kernel::Triangle_3 Triangle_3;
+        Random_points_in_triangle_3() {}
+        Random_points_in_triangle_3( const This& x,Random& rnd)
+        : Random_generator_base<P>( 1, rnd ),_p(x._p),_q(x._q),_r(x._r) {
+                generate_point();
+        }
+        Random_points_in_triangle_3( const P& p, const P& q, const P& r, Random& rnd = get_default_random())
+        : Random_generator_base<P>( 1, rnd ),_p(p),_q(q),_r(r) {
+                generate_point();
+        }
+        Random_points_in_triangle_3( const Triangle_3& triangle,Random& rnd = get_default_random())
+        : Random_generator_base<P>( 1,
+                        rnd),_p(triangle[0]),_q(triangle[1]),_r(triangle[2]) {
+                generate_point();
+        }
+        This& operator++() {
+                generate_point();
+                return *this;
+        }
+        This operator++(int) {
+                This tmp = *this;
+                ++(*this);
+                return tmp;
+        }
 };
 
 
 template<class P, class Creator >
 void Random_points_in_triangle_3<P, Creator>::generate_point() {
-	typedef typename Creator::argument_type T;
-	Creator creator;
-	double a1 = this->_rnd.get_double(0,1);
-	double a2 = this->_rnd.get_double(0,1);
-	if(a1>a2) std::swap(a1,a2);
-	double b1 = a1;
-	double b2 = a2-a1;
-	double b3 = 1.0-a2;
-	T ret[3];
-	for(int i = 0; i < 3; ++i) {
-	    ret[i] = T(to_double(_p[i])*b1+to_double(_q[i])*b2+to_double(_r[i])*b3);
-	}
-	this->d_item = creator(ret[0],ret[1],ret[2]);
+        typedef typename Creator::argument_type T;
+        Creator creator;
+        double a1 = this->_rnd.get_double(0,1);
+        double a2 = this->_rnd.get_double(0,1);
+        if(a1>a2) std::swap(a1,a2);
+        double b1 = a1;
+        double b2 = a2-a1;
+        double b3 = 1.0-a2;
+        T ret[3];
+        for(int i = 0; i < 3; ++i) {
+            ret[i] = T(to_double(_p[i])*b1+to_double(_q[i])*b2+to_double(_r[i])*b3);
+        }
+        this->d_item = creator(ret[0],ret[1],ret[2]);
 }
 
-template < class P, class Creator = 
+template < class P, class Creator =
                    Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P> >
 class Random_points_on_segment_3 : public Random_generator_base<P> {
     P _p;
@@ -322,55 +313,55 @@ generate_point() {
 template < class P, class Creator =
 Creator_uniform_3<typename Kernel_traits<P>::Kernel::RT,P> >
 class Random_points_in_tetrahedron_3 : public Random_generator_base<P> {
-	P _p,_q,_r,_s;
-	void generate_point();
+        P _p,_q,_r,_s;
+        void generate_point();
 public:
-	typedef P result_type;
-	typedef Random_points_in_tetrahedron_3<P, Creator> This;
-	typedef typename Kernel_traits<P>::Kernel::Tetrahedron_3 Tetrahedron_3;
-	Random_points_in_tetrahedron_3() {}
-	Random_points_in_tetrahedron_3( const This& x,Random& rnd)
-	: Random_generator_base<P>( 1, rnd ),_p(x._p),_q(x._q),_r(x._r),_s(x._s) {
-		generate_point();
-	}
-	Random_points_in_tetrahedron_3( const P& p, const P& q, const P& r, const P& s,Random& rnd = get_default_random())
-	: Random_generator_base<P>( 1, rnd ),_p(p),_q(q),_r(r),_s(s) {
-		generate_point();
-	}
-	Random_points_in_tetrahedron_3( const Tetrahedron_3& tetrahedron,Random& rnd = get_default_random())
-	: Random_generator_base<P>( 1, rnd),_p(tetrahedron[0]),_q(tetrahedron[1]),_r(tetrahedron[2]),_s(tetrahedron[3]) {
-		generate_point();
-	}
-	This& operator++() {
-		generate_point();
-		return *this;
-	}
-	This operator++(int) {
-		This tmp = *this;
-		++(*this);
-		return tmp;
-	}
+        typedef P result_type;
+        typedef Random_points_in_tetrahedron_3<P, Creator> This;
+        typedef typename Kernel_traits<P>::Kernel::Tetrahedron_3 Tetrahedron_3;
+        Random_points_in_tetrahedron_3() {}
+        Random_points_in_tetrahedron_3( const This& x,Random& rnd)
+        : Random_generator_base<P>( 1, rnd ),_p(x._p),_q(x._q),_r(x._r),_s(x._s) {
+                generate_point();
+        }
+        Random_points_in_tetrahedron_3( const P& p, const P& q, const P& r, const P& s,Random& rnd = get_default_random())
+        : Random_generator_base<P>( 1, rnd ),_p(p),_q(q),_r(r),_s(s) {
+                generate_point();
+        }
+        Random_points_in_tetrahedron_3( const Tetrahedron_3& tetrahedron,Random& rnd = get_default_random())
+        : Random_generator_base<P>( 1, rnd),_p(tetrahedron[0]),_q(tetrahedron[1]),_r(tetrahedron[2]),_s(tetrahedron[3]) {
+                generate_point();
+        }
+        This& operator++() {
+                generate_point();
+                return *this;
+        }
+        This operator++(int) {
+                This tmp = *this;
+                ++(*this);
+                return tmp;
+        }
 };
 
 template<class P, class Creator >
 void Random_points_in_tetrahedron_3<P, Creator>::generate_point() {
-	typedef typename Creator::argument_type T;
-	Creator creator;
-	double a[3];
-	for(int i = 0; i < 3; ++i) {
-		a[i]=this->_rnd.get_double(0,1);
-	}
-	std::sort(a,a+3);
-	double b[4];
-	b[0]=a[0];
-	b[1]=a[1]-a[0];
-	b[2]=a[2]-a[1];
-	b[3]=1.0-a[2];
-	T ret[3];
-	for(int i = 0; i < 3; ++i) {
-	    ret[i] = T(to_double(_p[i])*b[0]+to_double(_q[i])*b[1]+to_double(_r[i])*b[2]+to_double(_s[i])*b[3]);
-	}
-	this->d_item = creator(ret[0],ret[1],ret[2]);
+        typedef typename Creator::argument_type T;
+        Creator creator;
+        double a[3];
+        for(int i = 0; i < 3; ++i) {
+                a[i]=this->_rnd.get_double(0,1);
+        }
+        std::sort(a,a+3);
+        double b[4];
+        b[0]=a[0];
+        b[1]=a[1]-a[0];
+        b[2]=a[2]-a[1];
+        b[3]=1.0-a[2];
+        T ret[3];
+        for(int i = 0; i < 3; ++i) {
+            ret[i] = T(to_double(_p[i])*b[0]+to_double(_q[i])*b[1]+to_double(_r[i])*b[2]+to_double(_s[i])*b[3]);
+        }
+        this->d_item = creator(ret[0],ret[1],ret[2]);
 }
 
 
@@ -548,6 +539,26 @@ public:
 
   const Tr& tr;
 };
+
+template<typename Triangle, typename PointRange>
+class Triangle_3_from_soup
+{
+  typedef typename boost::range_value<PointRange>::type  Point_3;
+  typedef typename Kernel_traits<Point_3>::Kernel        Kernel;
+public:
+  typedef typename Kernel::Triangle_3                    result_type;
+
+  Triangle_3_from_soup(const PointRange& pts) : points(pts) { }
+
+  result_type operator()(const Triangle& t) const
+  {
+    return result_type(points[t[0]], points[t[1]], points[t[2]]);
+  }
+
+private:
+  const PointRange& points;
+};
+
 }//end namespace internal
 
 template <class C3t3,
@@ -697,6 +708,52 @@ struct Random_points_in_triangles_3
   }
 };
 
+
+template <class PointRange,
+          class Triangle = std::vector<std::size_t>,
+          class Creator = Creator_uniform_3<
+                            typename Kernel_traits< typename PointRange::value_type >::Kernel::RT,
+                            typename PointRange::value_type> >
+struct Random_points_in_triangle_soup
+    : public Generic_random_point_generator<Triangle,
+                                            internal::Triangle_3_from_soup<Triangle, PointRange>,
+                                            Random_points_in_triangle_3<typename PointRange::value_type>,
+                                            typename PointRange::value_type>
+{
+  typedef Generic_random_point_generator<Triangle,
+                                         internal::Triangle_3_from_soup<Triangle, PointRange>,
+                                         Random_points_in_triangle_3<typename PointRange::value_type>,
+                                         typename PointRange::value_type> Base;
+  typedef typename PointRange::value_type                                 Point_3;
+  typedef typename Kernel_traits<Point_3>::Kernel                         Kernel;
+  typedef Triangle                                                        Id;
+  typedef Point_3                                                         result_type;
+  typedef Random_points_in_triangle_soup<PointRange, Triangle, Creator>   This;
+
+  template<typename TriangleRange>
+  Random_points_in_triangle_soup(const TriangleRange& triangles,
+                                 const PointRange& points,
+                                 Random& rnd = get_default_random())
+    : Base(triangles,
+           internal::Triangle_3_from_soup<Triangle, PointRange>(points),
+           internal::Apply_approx_sqrt<typename Kernel_traits<Point_3>::Kernel::Compute_squared_area_3>(),
+           rnd)
+  { }
+
+  This& operator++()
+  {
+    Base::generate_point();
+    return *this;
+  }
+
+  This operator++(int)
+  {
+    This tmp = *this;
+    ++(*this);
+    return tmp;
+  }
+};
+
 } //namespace CGAL
 
 #include <CGAL/enable_warnings.h>
