@@ -1,20 +1,11 @@
 // Copyright (c) 2008-2009 GeometryFactory and INRIA
 // All rights reserved.
 //
-// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; either version 3 of the License,
-// or (at your option) any later version.
+// This file is part of CGAL (www.cgal.org)
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Property_map/include/CGAL/property_map.h $
-// $Id: property_map.h e925b1a 2018-10-30T15:50:17+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Property_map/include/CGAL/property_map.h $
+// $Id: property_map.h 9242a810c43 2023-02-07T11:31:55+01:00 Sébastien Loriot
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri and Laurent Saboret
 
@@ -24,68 +15,64 @@
 #include <CGAL/value_type_traits.h>
 
 #include <boost/version.hpp>
-#if BOOST_VERSION >= 104000
-  #include <boost/property_map/property_map.hpp>
-#else
-  #include <boost/property_map.hpp>
-  #include <boost/vector_property_map.hpp>
-
-#endif
+#include <boost/property_map/property_map.hpp>
 #include <boost/tuple/tuple.hpp>
 #include <CGAL/tuple.h>
 
-#include <utility> // defines std::pair
-
+#include <CGAL/boost/iterator/counting_iterator.hpp>
+#include <CGAL/boost/iterator/transform_iterator.hpp>
+#include <CGAL/Iterator_range.h>
 #include <CGAL/Cartesian_converter_fwd.h>
 #include <CGAL/Kernel_traits_fwd.h>
 #include <CGAL/assertions.h>
+#include <CGAL/Default.h>
+
+#include <algorithm>
+#include <iterator>
+#include <tuple>
+#include <type_traits>
+#include <utility>
+#include <vector>
 
 namespace CGAL {
 
 /// \cond SKIP_DOXYGEN
 
-/// This class is almost the same as boost::static_property_map
-/// The difference is that it is writable, although put() does nothing
-template <typename K, typename V>
-class Static_property_map
+/// A boolean property map return a const value at compile time
+template <typename Key, bool default_value>
+struct Static_boolean_property_map
 {
-public:
-  typedef K key_type;
-  typedef V value_type;
-  typedef const V& reference;
+  typedef Key key_type;
+  typedef bool value_type;
+  typedef bool reference;
   typedef boost::read_write_property_map_tag category;
 
-private:
-  V v;
-
-public:
-  Static_property_map(V pv)
-    :v(pv){}
   inline friend
   value_type
-  get(const Static_property_map& pm, const key_type&)
+  get(Static_boolean_property_map, const key_type&)
   {
-    return pm.v;
+    return default_value;
   }
 
   inline friend
   void
-  put(Static_property_map&, const key_type&, const value_type&)
+  put(Static_boolean_property_map, const key_type&, value_type)
   {}
 };
 
 
 template <typename PM1, typename PM2>
 class OR_property_map {
+  PM1 pm1;
+  PM2 pm2;
+
+ public:
+
   typedef typename PM1::key_type key_type;
   typedef typename PM1::value_type value_type;
   typedef typename PM1::reference reference;
   typedef boost::read_write_property_map_tag category;
 
-  PM1 pm1;
-  PM2 pm2;
-
- public:
   OR_property_map() {} // required by boost::connected_components
 
   OR_property_map(PM1 pm1, PM2 pm2)
@@ -93,14 +80,14 @@ class OR_property_map {
   {}
 
   inline friend
-    value_type
-    get(const OR_property_map& pm, const key_type& k)
+  value_type
+  get(const OR_property_map& pm, const key_type& k)
   {
     return get(pm.pm1,k) || get(pm.pm2,k);
   }
 
   inline friend
-    void
+  void
   put(OR_property_map& pm, const key_type& k, const value_type& v)
   {
     put(pm.pm1,k, v);
@@ -115,42 +102,6 @@ make_OR_property_map(const PM1& pm1, const PM2& pm2)
   return OR_property_map<PM1, PM2>(pm1, pm2);
 }
 
-// A property map that uses the result of a property map as key.
-template <class KeyMap, class ValueMap>
-struct Property_map_binder{
-  typedef typename boost::property_traits<KeyMap>::key_type key_type;
-  typedef typename boost::property_traits<ValueMap>::value_type value_type;
-  typedef typename boost::property_traits<ValueMap>::reference reference;
-  typedef boost::read_write_property_map_tag category;
-
-  KeyMap key_map;
-  ValueMap value_map;
-
-  Property_map_binder(const KeyMap& key_map, const ValueMap& value_map)
-    : key_map(key_map)
-    , value_map(value_map)
-  {}
-
-  friend
-  reference get(const Property_map_binder& map, key_type k)
-  {
-    return get(map.value_map, get(map.key_map,k));
-  }
-  friend
-  void put(const Property_map_binder& map, key_type k, const value_type& v)
-  {
-    put(map.value_map, get(map.key_map,k), v);
-  }
-};
-
-template <class KeyMap, class ValueMap>
-Property_map_binder<KeyMap, ValueMap>
-bind_property_maps(const KeyMap& src, const ValueMap& tgt)
-{
-  return Property_map_binder<KeyMap, ValueMap>(src, tgt);
-}
-
-
 /// Property map that accesses a value from an iterator
 ///
 /// \cgalModels `ReadablePropertyMap`
@@ -167,33 +118,197 @@ struct Input_iterator_property_map{
   /// Free function to use a get the value from an iterator using Input_iterator_property_map.
   inline friend
   reference
-  get(Input_iterator_property_map<InputIterator>,InputIterator it){ return *it; }
+  get(Input_iterator_property_map<InputIterator>, const InputIterator& it){ return *it; }
 };
 
+#ifdef DOXYGEN_RUNNING
+/// \ingroup PkgPropertyMapRef
+/// Property map that composes two property maps,
+/// that is a call on an instance `Compose_property_map compose_property_map(key_map, value_map)` of `get(compose_property_map, k)` returns `get(value_map, get(key_map, k))`.
+template <class KeyMap, class ValueMap>
+struct Compose_property_map
+{
+  ///< Use the key type of `KeyMap` as keytype
+  typedef typename boost::property_traits<KeyMap>::key_type key_type;
+  ///< Use the value type of `ValueMap` as value type
+  typedef typename boost::property_traits<ValueMap>::value_type value_type;
+  ///< Use the reference type of `ValueMap` as reference
+  typedef typename boost::property_traits<ValueMap>::reference reference;
+  ///< Use the category of the `ValueMap`
+  typedef typename boost::property_traits<ValueMap>::category category;
+
+  /// Constructor
+  Compose_property_map(KeyMap key_map = KeyMap(),
+                       ValueMap value_map = ValueMap());
+};
+#else
+template <class KeyMap, class ValueMap, class Category = typename boost::property_traits<ValueMap>::category>
+struct Compose_property_map;
+
+template <class KeyMap, class ValueMap>
+struct Compose_property_map<KeyMap, ValueMap, boost::readable_property_map_tag>
+{
+  typedef typename boost::property_traits<KeyMap>::key_type key_type;
+  typedef typename boost::property_traits<ValueMap>::value_type value_type;
+  typedef typename boost::property_traits<ValueMap>::reference reference;
+  typedef typename boost::property_traits<ValueMap>::category category;
+
+  KeyMap key_map;
+  ValueMap value_map;
+
+  Compose_property_map(KeyMap key_map = KeyMap(),
+                       ValueMap value_map = ValueMap())
+    : key_map(key_map), value_map(value_map)
+  {}
+
+  Compose_property_map(Default,
+                       ValueMap value_map = ValueMap())
+    : value_map(value_map)
+  {}
+
+  friend
+  reference get(Compose_property_map map, const key_type& k)
+  {
+    return get(map.value_map, get(map.key_map,k));
+  }
+};
+
+template <class KeyMap, class ValueMap>
+struct Compose_property_map<KeyMap, ValueMap, boost::writable_property_map_tag>
+{
+  typedef typename boost::property_traits<KeyMap>::key_type key_type;
+  typedef typename boost::property_traits<ValueMap>::value_type value_type;
+  typedef typename boost::property_traits<ValueMap>::reference reference;
+  typedef typename boost::property_traits<ValueMap>::category category;
+
+  KeyMap key_map;
+  ValueMap value_map;
+
+  Compose_property_map(KeyMap key_map = KeyMap(),
+                       ValueMap value_map = ValueMap())
+    : key_map(key_map), value_map(value_map)
+  {}
+
+  Compose_property_map(Default,
+                       ValueMap value_map = ValueMap())
+    : value_map(value_map)
+  {}
+
+  friend
+  void put(Compose_property_map map, const key_type& k, const value_type& v)
+  {
+    put(map.value_map, get(map.key_map,k), v);
+  }
+};
+
+template <class KeyMap, class ValueMap>
+struct Compose_property_map<KeyMap, ValueMap, boost::read_write_property_map_tag>
+{
+  typedef typename boost::property_traits<KeyMap>::key_type key_type;
+  typedef typename boost::property_traits<ValueMap>::value_type value_type;
+  typedef typename boost::property_traits<ValueMap>::reference reference;
+  typedef typename boost::property_traits<ValueMap>::category category;
+
+  KeyMap key_map;
+  ValueMap value_map;
+
+  Compose_property_map(KeyMap key_map = KeyMap(),
+                       ValueMap value_map = ValueMap())
+    : key_map(key_map), value_map(value_map)
+  {}
+
+  Compose_property_map(Default,
+                       ValueMap value_map = ValueMap())
+    : value_map(value_map)
+  {}
+
+  friend
+  reference get(Compose_property_map map, const key_type& k)
+  {
+    return get(map.value_map, get(map.key_map,k));
+  }
+
+  friend
+  void put(const Compose_property_map& map, const key_type& k, const value_type& v)
+  {
+    put(map.value_map, get(map.key_map,k), v);
+  }
+};
+
+template <class KeyMap, class ValueMap>
+struct Compose_property_map<KeyMap, ValueMap, boost::lvalue_property_map_tag>
+{
+  typedef typename boost::property_traits<KeyMap>::key_type key_type;
+  typedef typename boost::property_traits<ValueMap>::value_type value_type;
+  typedef typename boost::property_traits<ValueMap>::reference reference;
+  typedef typename boost::property_traits<ValueMap>::category category;
+
+  KeyMap key_map;
+  ValueMap value_map;
+
+  Compose_property_map(KeyMap key_map = KeyMap(),
+                       ValueMap value_map = ValueMap())
+    : key_map(key_map), value_map(value_map)
+  {}
+
+  Compose_property_map(Default,
+                       ValueMap value_map = ValueMap())
+    : value_map(value_map)
+  {}
+
+  friend
+  reference get(Compose_property_map map, const key_type& k)
+  {
+    return get(map.value_map, get(map.key_map,k));
+  }
+
+  friend
+  void put(Compose_property_map map, key_type k, const value_type& v)
+  {
+    put(map.value_map, get(map.key_map,k), v);
+  }
+
+  decltype(auto)
+  operator[](const key_type& k) const
+  {
+    return value_map[get(key_map, k)];
+  }
+};
+#endif
+/// \ingroup PkgPropertyMapRef
+/// \relates Compose_property_map
+/// returns `Compose_property_maps<KeyMap, ValueMap>(km,vm)`
+template <class KeyMap, class ValueMap>
+Compose_property_map<KeyMap, ValueMap>
+make_compose_property_map(const KeyMap& km, const ValueMap& vm)
+{
+  return Compose_property_map<KeyMap, ValueMap>(km, vm);
+}
+
 /// \ingroup PkgPropertyMapRef
 /// Property map that converts a `T*` pointer (or in general an iterator
 /// over `T` elements) to the `T` object.
 ///
 /// \cgalModels `LvaluePropertyMap`
-template <typename T>
+template <typename T, typename Iter = T*>
 struct Dereference_property_map
-  : public boost::put_get_helper<T&, Dereference_property_map<T> >
+  : public boost::put_get_helper<typename std::iterator_traits<Iter>::reference, Dereference_property_map<T, Iter> >
 {
-  typedef T* key_type; ///< typedef to 'T*'
-  typedef T value_type; ///< typedef to 'T'
-  typedef const value_type& reference; ///< typedef to 'T&'
+  typedef Iter key_type; ///< typedef to 'T*'
+  typedef std::remove_const_t<T> value_type; ///< typedef to 'T'
+  typedef typename std::iterator_traits<Iter>::reference reference; ///< typedef to 'T&'
   typedef boost::lvalue_property_map_tag category; ///< `boost::lvalue_property_map_tag`
 
   /// Access a property map element.
   ///
   /// @tparam Iter Type convertible to `key_type`.
-  template <class Iter>
-  value_type& operator[](Iter it) const { return reference(*it); }
+  template <class Iter_> // template kept for backward compatibility
+  reference operator[](const Iter_& it) const { return *it; }
 };
 
 /// Free function to create a `Dereference_property_map` property map.
 ///
-/// \relates Dereference_property_map 
+/// \relates Dereference_property_map
 template <class Iter> // Type convertible to `key_type`
 Dereference_property_map<typename CGAL::value_type_traits<Iter>::type>
 make_dereference_property_map(Iter)
@@ -204,30 +319,63 @@ make_dereference_property_map(Iter)
 
 /// \ingroup PkgPropertyMapRef
 /// A `LvaluePropertyMap` property map mapping a key to itself (by reference).
+/// It is mutable if `T` is not `const` and non-mutable otherwise.
 ///
 /// \cgalModels `LvaluePropertyMap`
 template <typename T>
 struct Identity_property_map
+{
+/// \cond SKIP_IN_MANUAL
+  typedef Identity_property_map<T> Self;
+
+  typedef T key_type;
+  typedef T value_type;
+  typedef T& reference;
+  typedef boost::lvalue_property_map_tag category;
+
+  T& operator[](T& k) const { return k; }
+  const T& operator[](const T& k) const { return k; }
+  T operator[](T&& k) const { return std::forward<T>(k); }
+
+  friend T& get(const Self&, T& k) { return k; }
+  friend const T& get(const Self&, const T& k) { return k; }
+  friend T get(const Self&, T&& k) { return std::forward<T>(k); }
+  friend void put(const Self&, T& k, const T& v) { k = v; }
+/// \endcond
+};
+
+/// \cond SKIP_IN_MANUAL
+template <typename T>
+struct Identity_property_map<const T>
+{
+  typedef Identity_property_map<const T> Self;
+
+  typedef T key_type;
+  typedef T value_type;
+  typedef const T& reference;
+  typedef boost::lvalue_property_map_tag category;
+
+  const value_type& operator[](key_type& k) const { return k; }
+  friend const value_type& get(const Self&, const key_type& k) { return k; }
+};
+
+template <typename T>
+struct Identity_property_map_no_lvalue
 {
   typedef T key_type; ///< typedef to `T`
   typedef T value_type; ///< typedef to `T`
-  typedef const T& reference; ///< typedef to `T&`
-  typedef boost::lvalue_property_map_tag category; ///< `boost::lvalue_property_map_tag`
-  /// Access a property map element.
-  /// @param k a key which is returned as mapped value.
-  value_type& operator[](key_type& k) const { return k; }
+  typedef T reference; ///< typedef to `T`
+  typedef boost::readable_property_map_tag category; ///< `boost::readable_property_map_tag`
 
-  typedef Identity_property_map<T> Self;
-  /// \name Put/get free functions
-  /// @{
-  friend reference get(const Self&,const key_type& k) {return k;}
-  friend void put(const Self&,key_type& k, const value_type& v) {k=v;}
-  /// @}
+  typedef Identity_property_map_no_lvalue<T> Self;
+
+  friend value_type get(const Self&, const key_type& k) {return k;}
 };
+/// \endcond
 
 /// Free function to create a `Identity_property_map` property map.
 ///
-/// \relates Identity_property_map 
+/// \relates Identity_property_map
 template <class T> // Key and value type
 Identity_property_map<T>
   make_identity_property_map(T)
@@ -237,34 +385,35 @@ Identity_property_map<T>
 
 
 /// \ingroup PkgPropertyMapRef
-/// Property map that accesses the first item of a `std::pair`. 
-/// \tparam Pair Instance of `std::pair`. 
+/// Property map that accesses the first item of a `std::pair`.
+/// \tparam Pair Instance of `std::pair`.
 /// \cgalModels `LvaluePropertyMap`
 ///
 /// \sa `CGAL::Second_of_pair_property_map<Pair>`
 template <typename Pair>
 struct First_of_pair_property_map
 {
+  typedef First_of_pair_property_map<Pair> Self;
+
   typedef Pair key_type; ///< typedef to `Pair`
   typedef typename Pair::first_type value_type; ///< typedef to `Pair::first_type`
-  typedef const value_type& reference; ///< typedef to `value_type&`
+  typedef const value_type& reference; ///< typedef to `const value_type&`
   typedef boost::lvalue_property_map_tag category; ///< boost::lvalue_property_map_tag
 
   /// Access a property map element.
   /// @param pair a key whose first item is accessed
-  value_type& operator[](key_type& pair) const { return pair.first; }
+  const value_type& operator[](const key_type& pair) const { return pair.first; }
 
-  typedef First_of_pair_property_map<Pair> Self;
   /// \name Put/get free functions
   /// @{
-  friend reference get(const Self&,const key_type& k) {return k.first;}
-  friend void put(const Self&,key_type& k, const value_type& v) {k.first=v;}
+  friend reference get(const Self&, const key_type& k) { return k.first; }
+  friend void put(const Self&, key_type& k, const value_type& v) { k.first = v; }
   /// @}
 };
 
-/// Free function to create a `First_of_pair_property_map` property map. 
+/// Free function to create a `First_of_pair_property_map` property map.
 ///
-/// \relates First_of_pair_property_map 
+/// \relates First_of_pair_property_map
 template <class Pair> // Pair type
 First_of_pair_property_map<Pair>
   make_first_of_pair_property_map(Pair)
@@ -273,37 +422,38 @@ First_of_pair_property_map<Pair>
 }
 
 /// \ingroup PkgPropertyMapRef
-/// 
-/// Property map that accesses the second item of a `std::pair`. 
-/// 
-/// \tparam Pair Instance of `std::pair`. 
-/// 
+///
+/// Property map that accesses the second item of a `std::pair`.
+///
+/// \tparam Pair Instance of `std::pair`.
+///
 /// \cgalModels `LvaluePropertyMap`
-/// 
+///
 /// \sa `CGAL::First_of_pair_property_map<Pair>`
 template <typename Pair>
 struct Second_of_pair_property_map
 {
+  typedef Second_of_pair_property_map<Pair> Self;
+
   typedef Pair key_type; ///< typedef to `Pair`
   typedef typename Pair::second_type value_type; ///< typedef to `Pair::second_type`
-  typedef const value_type& reference; ///< typedef to `value_type&`
+  typedef const value_type& reference; ///< typedef to `const value_type&`
   typedef boost::lvalue_property_map_tag category; ///< boost::lvalue_property_map_tag
 
   /// Access a property map element.
   /// @param pair a key whose second item is accessed
-  value_type& operator[](key_type& pair) const { return pair.second; }
+  const value_type& operator[](const key_type& pair) const { return pair.second; }
 
-  typedef Second_of_pair_property_map<Pair> Self;
   /// \name Put/get free functions
   /// @{
-  friend reference get(const Self&,const key_type& k) {return k.second;}
-  friend void put(const Self&,key_type& k, const value_type& v) {k.second=v;}
+  friend reference get(const Self&, const key_type& k) { return k.second; }
+  friend void put(const Self&, key_type& k, const value_type& v) { k.second = v; }
   /// @}
 };
 
 /// Free function to create a Second_of_pair_property_map property map.
 ///
-/// \relates Second_of_pair_property_map 
+/// \relates Second_of_pair_property_map
 template <class Pair> // Pair type
 Second_of_pair_property_map<Pair>
   make_second_of_pair_property_map(Pair)
@@ -312,54 +462,54 @@ Second_of_pair_property_map<Pair>
 }
 
 /// \ingroup PkgPropertyMapRef
-/// 
+///
 /// Property map that accesses the Nth item of a `boost::tuple` or a `std::tuple`.
-/// 
+///
 /// \tparam N %Index of the item to access.
 /// \tparam Tuple Instance of `boost::tuple` or `std::tuple`.
-/// 
+///
 /// \cgalModels `LvaluePropertyMap`
 template <int N, typename Tuple>
 struct Nth_of_tuple_property_map
 {
+  typedef Nth_of_tuple_property_map<N,Tuple> Self;
+
   typedef Tuple key_type; ///< typedef to `Tuple`
-  #ifdef DOXYGEN_RUNNING
+#ifdef DOXYGEN_RUNNING
   typedef unspecified_type value_type;  ///< typedef to the N-th type of the tuple
-  #else
+#else
   typedef typename boost::tuples::element<N,Tuple>::type value_type;
-  #endif
-  typedef const value_type& reference; ///< typedef to `value_type&`
+#endif
+  typedef const value_type& reference; ///< typedef to `const value_type&`
   typedef boost::lvalue_property_map_tag category; ///< `boost::lvalue_property_map_tag`
+
   /// Access a property map element.
   /// @param tuple a key whose Nth item is accessed
-  value_type& operator[](key_type& tuple) const { return tuple.template get<N>(); }
+  const value_type& operator[](const key_type& tuple) const { return tuple.template get<N>(); }
 
-  typedef Nth_of_tuple_property_map<N,Tuple> Self;
   /// \name Put/get free functions
   /// @{
-  friend reference get(const Self&,const key_type& k) {return k.template get<N>();}
-  friend void put(const Self&,key_type& k, const value_type& v) {k.template get<N>()=v;}
+  friend reference get(const Self&, const key_type& k) { return k.template get<N>(); }
+  friend void put(const Self&, key_type& k, const value_type& v) { k.template get<N>() = v; }
   /// @}
 };
 
-#ifndef CGAL_CFG_NO_CPP0X_TUPLE
 template <int N, typename ... T>
 struct Nth_of_tuple_property_map<N,std::tuple<T...> >
 {
   typedef std::tuple<T...> Tuple;
+  typedef Nth_of_tuple_property_map<N,Tuple> Self;
+
   typedef Tuple key_type;
-  typedef typename cpp11::tuple_element<N,Tuple>::type value_type;
+  typedef typename std::tuple_element<N,Tuple>::type value_type;
   typedef const value_type& reference;
   typedef boost::lvalue_property_map_tag category;
 
-  value_type& operator[](key_type& tuple) const { return get<N>(tuple); }
+  const value_type& operator[](const key_type& tuple) const { return get<N>(tuple); }
 
-  typedef Nth_of_tuple_property_map<N,Tuple> Self;
-  friend reference get(const Self&,const key_type& k) {return std::get<N>(k);}
-  friend void put(const Self&,key_type& k, const value_type& v) {std::get<N>(k)=v;}
+  friend reference get(const Self&, const key_type& k) { return std::get<N>(k); }
+  friend void put(const Self&, key_type& k, const value_type& v) { std::get<N>(k) = v; }
 };
-#endif
-
 
 /// Free function to create a Nth_of_tuple_property_map property map.
 ///
@@ -385,7 +535,11 @@ struct Property_map_to_unary_function{
   {}
 
   template <class KeyType>
+  #if defined(__INTEL_COMPILER) && defined(__INTEL_COMPILER_BUILD_DATE) && (__INTEL_COMPILER_BUILD_DATE < 20210000)
   result_type
+  #else
+  decltype(auto)
+  #endif
   operator()(const KeyType& a) const
   {
     return get(map,a);
@@ -408,7 +562,7 @@ struct Pointer_property_map{
 
 /// \ingroup PkgPropertyMapRef
 /// Starting from boost 1.55, the use of raw pointers as property maps has been deprecated.
-/// This function is a shortcut to the recommanded replacement:
+/// This function is a shortcut to the recommended replacement:
 /// `boost::make_iterator_property_map(<pointer>, boost::typed_identity_property_map<std::size_t>())`
 /// Note that the property map is a mutable `LvaluePropertyMap` with `std::size_t` as key.
 template <class T>
@@ -428,7 +582,7 @@ typename Pointer_property_map<T>::type
 make_property_map(std::vector<T>& v)
 {
   if(v.empty()){
-    return make_property_map(static_cast<T*>(NULL));
+    return make_property_map(static_cast<T*>(nullptr));
   }
   return make_property_map(&v[0]);
 }
@@ -467,18 +621,18 @@ struct Constant_property_map
 
   typedef KeyType                                       key_type;
   typedef ValueType                                     value_type;
-  typedef value_type&                                   reference;
+  typedef const value_type&                             reference;
   typedef boost::read_write_property_map_tag            category;
 
   Constant_property_map(const value_type& default_value = value_type()) : default_value (default_value) { }
 
   /// Free function that returns `pm.default_value`.
-  inline friend value_type
-  get (const Constant_property_map& pm, const key_type&){ return pm.default_value; }
+  inline friend
+  reference get (const Constant_property_map& pm, const key_type&) { return pm.default_value; }
 
   /// Free function that does nothing.
-  inline friend void
-  put (const Constant_property_map&, const key_type&, const value_type&) { }
+  inline friend
+  void put (const Constant_property_map&, const key_type&, const value_type&) { }
 };
 
 /// \ingroup PkgPropertyMapRef
@@ -501,17 +655,17 @@ struct Boolean_property_map
   /// Constructor taking a copy of the set. Note that `set_` must be valid
   /// while the property map is in use.
   Boolean_property_map(Set& set_) : set_ptr(&set_) {}
-  Boolean_property_map() : set_ptr(NULL) {}
+  Boolean_property_map() : set_ptr(nullptr) {}
 
   friend bool get(const Boolean_property_map<Set>& pm, const key_type& k)
   {
-    CGAL_assertion(pm.set_ptr!=NULL);
+    CGAL_assertion(pm.set_ptr!=nullptr);
     return pm.set_ptr->count(k) != 0;
   }
 
   friend void put(Boolean_property_map<Set>& pm, const key_type& k, bool v)
   {
-    CGAL_assertion(pm.set_ptr!=NULL);
+    CGAL_assertion(pm.set_ptr!=nullptr);
     if (v)
       pm.set_ptr->insert(k);
     else
@@ -553,8 +707,7 @@ struct Cartesian_converter_property_map
 
   friend value_type get(const Cartesian_converter_property_map<GeomObject, Vpm>& pm, const key_type& k)
   {
-    return
-     CGAL::Cartesian_converter<K1, K2>()(get(pm.vpm, k));
+    return CGAL::Cartesian_converter<K1, K2>()(get(pm.vpm, k));
   }
 
   friend void put(Cartesian_converter_property_map<GeomObject, Vpm>& pm, const key_type& k, const value_type& v)
@@ -572,6 +725,136 @@ make_cartesian_converter_property_map(Vpm vpm)
   return Cartesian_converter_property_map<GeomObject, Vpm>(vpm);
 }
 
+/// \ingroup PkgPropertyMapRef
+/// A property map with `std::size_t` as key-type that can be used
+/// to access the i'th element in a container with random access.
+/// \cgalModels `LvaluePropertyMap`, constness being than of `Container`.
+template<typename Container>
+class Random_access_property_map
+{
+  Container& m_container;
+
+public:
+  using Iterator =  std::conditional_t<std::is_const<Container>::value,
+                                       typename Container::const_iterator,
+                                       typename Container::iterator>;
+  typedef std::size_t key_type;
+  typedef typename std::iterator_traits<Iterator>::value_type value_type;
+  typedef typename std::iterator_traits<Iterator>::reference reference;
+  typedef boost::lvalue_property_map_tag category;
+
+
+  Random_access_property_map(Container& container)
+    : m_container(container){}
+
+  friend reference get (Random_access_property_map map, key_type index)
+  {
+    return map.m_container[index];
+  }
+
+  template <class Key>
+  friend void put (Random_access_property_map map, Key index, const value_type& value,
+                   std::enable_if_t<!std::is_const<Container>::value>* = 0)
+  {
+    map.m_container[index]=value;
+  }
+
+  decltype(auto)
+  operator[](key_type index) const
+  {
+    return m_container[index];
+  }
+};
+
+/// \ingroup PkgPropertyMapRef
+/// \relates Random_access_property_map
+/// returns `Random_access_property_map<Container>(container)`
+template <class Container>
+Random_access_property_map<Container>
+make_random_access_property_map(Container& container)
+{
+  return Random_access_property_map<Container>(container);
+}
+
+/// \cond SKIP_IN_MANUAL
+// Syntaxic sugar for transform_iterator+pmap_to_unary_function
+template <typename Iterator, typename Pmap>
+typename boost::transform_iterator<CGAL::Property_map_to_unary_function<Pmap>, Iterator>
+make_transform_iterator_from_property_map (Iterator it, Pmap pmap)
+{
+  return boost::make_transform_iterator (it, CGAL::Property_map_to_unary_function<Pmap>(pmap));
+}
+
+// Syntaxic sugar for make_range+transform_iterator+pmap_to_unary_function
+template <typename Range, typename Pmap>
+CGAL::Iterator_range<typename boost::transform_iterator<CGAL::Property_map_to_unary_function<Pmap>,
+                                                        typename Range::const_iterator> >
+make_transform_range_from_property_map (const Range& range, Pmap pmap)
+{
+  return CGAL::make_range
+    (make_transform_iterator_from_property_map (range.begin(), pmap),
+     make_transform_iterator_from_property_map (range.end(), pmap));
+}
+
+// Syntaxic sugar for make_range+transform_iterator+pmap_to_unary_function
+template <typename Range, typename Pmap>
+CGAL::Iterator_range<typename boost::transform_iterator<CGAL::Property_map_to_unary_function<Pmap>,
+                                                        typename Range::iterator> >
+make_transform_range_from_property_map (Range& range, Pmap pmap)
+{
+  return CGAL::make_range
+    (make_transform_iterator_from_property_map (range.begin(), pmap),
+     make_transform_iterator_from_property_map (range.end(), pmap));
+}
+
+template <typename SizeType>
+CGAL::Iterator_range<boost::counting_iterator<SizeType> >
+make_counting_range (const SizeType begin, const SizeType end)
+{
+  return CGAL::make_range (boost::counting_iterator<SizeType>(begin),
+                           boost::counting_iterator<SizeType>(end));
+}
+
+/// \endcond
+
+/// \cond SKIP_IN_MANUAL
+/*
+  This property map is used to turn a property map using the value
+  type of a random access iterator as key type to the same property
+  map but using the index of the element iterated to.
+
+  It basically allows, when accessing the ith element of a range, to
+  do `get(map, i)` instead of `get(map, range[i])`.
+ */
+template<typename RandomAccessIterator, typename PropertyMap>
+struct Random_index_access_property_map
+{
+  typedef std::size_t key_type;
+  typedef typename boost::property_traits<PropertyMap>::value_type value_type;
+  typedef typename boost::property_traits<PropertyMap>::reference reference;
+  typedef typename boost::property_traits<PropertyMap>::category category;
+
+  RandomAccessIterator m_begin;
+  PropertyMap m_map;
+
+  Random_index_access_property_map (RandomAccessIterator begin = RandomAccessIterator(),
+                                    PropertyMap map = PropertyMap())
+    : m_begin(begin), m_map(map) {}
+
+  friend reference get (const Random_index_access_property_map& map, const key_type& index,
+                        std::enable_if_t<std::is_convertible<category, boost::readable_property_map_tag>::value>* = 0)
+  {
+    return get(map.m_map, *std::next(map.m_begin, index));
+  }
+
+  friend void put (Random_index_access_property_map& map, const key_type& index, const value_type& value,
+                   std::enable_if_t<std::is_convertible<category, boost::writable_property_map_tag>::value>* = 0)
+  {
+    put (map.m_map, *std::next(map.m_begin, index), value);
+  }
+};
+/// \endcond
+
 } // namespace CGAL
 
 
