@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Tetrahedral_remeshing/include/CGAL/tetrahedral_remeshing.h $
-// $Id: tetrahedral_remeshing.h 1b6d590 2022-12-14T10:18:16+01:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Tetrahedral_remeshing/include/CGAL/tetrahedral_remeshing.h $
+// $Id: tetrahedral_remeshing.h 0f45fedf53d 2023-10-18T11:59:30+02:00 Sébastien Loriot
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -392,15 +392,14 @@ void tetrahedral_isotropic_remeshing(
     = choose_parameter(get_parameter(np, internal_np::smooth_constrained_edges),
       false);
 
-  typedef typename Tr::Cell_handle Cell_handle;
   typedef typename internal_np::Lookup_named_param_def <
-  internal_np::cell_selector_t,
+              internal_np::cell_selector_t,
               NamedParameters,
-              Constant_property_map<Cell_handle, bool>//default
+              Tetrahedral_remeshing::internal::All_cells_selected<Tr>//default
               > ::type SelectionFunctor;
   SelectionFunctor cell_select
     = choose_parameter(get_parameter(np, internal_np::cell_selector),
-                       Constant_property_map<Cell_handle, bool>(true));
+                       Tetrahedral_remeshing::internal::All_cells_selected<Tr>());
 
   typedef std::pair<typename Tr::Vertex_handle, typename Tr::Vertex_handle> Edge_vv;
   typedef typename internal_np::Lookup_named_param_def <
