@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Number_types/include/CGAL/utils_classes.h $
-// $Id: utils_classes.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Number_types/include/CGAL/utils_classes.h $
+// $Id: utils_classes.h f34745c4d87 2024-03-14T09:14:47+01:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -266,6 +266,17 @@ class Is_valid
     };
 };
 
+namespace internal
+{
+// utility class to be used for calling exact(Lazy) when doing accumulation with EPECK
+template <class NT>
+struct Evaluate
+{
+  void operator()(const NT&)
+  {}
+};
+} // internal namespace
+
 } //namespace CGAL
 
 #endif // CGAL_UTILS_CLASSES_H
