@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.2/Point_set_processing_3/include/CGAL/vcm_estimate_normals.h $
-// $Id: vcm_estimate_normals.h 2f81a21 2019-07-28T18:38:59+02:00 Sébastien Loriot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/v5.6.2/Point_set_processing_3/include/CGAL/vcm_estimate_normals.h $
+// $Id: vcm_estimate_normals.h d3b13fb11cf 2022-12-05T19:00:39+01:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Jocelyn Meyron and Quentin Mérigot
 //
@@ -29,7 +20,7 @@
 #include <CGAL/Point_set_processing_3/internal/Voronoi_covariance_3/voronoi_covariance_3.h>
 
 #include <CGAL/property_map.h>
-#include <CGAL/point_set_processing_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Delaunay_triangulation_3.h>
 #include <CGAL/Kd_tree.h>
 #include <CGAL/Search_traits_3.h>
@@ -38,7 +29,7 @@
 #include <CGAL/Orthogonal_k_neighbor_search.h>
 #include <CGAL/Fuzzy_sphere.h>
 
-#include <CGAL/boost/graph/Named_function_parameters.h>
+#include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 
 #include <CGAL/Default_diagonalize_traits.h>
@@ -240,16 +231,25 @@ vcm_convolve (ForwardIterator first,
    \tparam PointRange is a model of `Range`. The value type of
    its iterator is the key type of the named parameter `point_map`.
 
-   \param points input point range.
+   \param points input point range
    \param ccov output range of covariance matrices.
    \param offset_radius offset_radius.
    \param convolution_radius convolution_radius.
-   \param np optional sequence of \ref psp_namedparameters "Named Parameters" among the ones listed below.
+   \param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
    \cgalNamedParamsBegin
-     \cgalParamBegin{point_map} a model of `ReadablePropertyMap` with value type `geom_traits::Point_3`.
-     If this parameter is omitted, `CGAL::Identity_property_map<geom_traits::Point_3>` is used.\cgalParamEnd
-     \cgalParamBegin{geom_traits} an instance of a geometric traits class, model of `Kernel`\cgalParamEnd
+     \cgalParamNBegin{point_map}
+       \cgalParamDescription{a property map associating points to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadWritePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Point_3`}
+       \cgalParamDefault{`CGAL::Identity_property_map<geom_traits::Point_3>`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{geom_traits}
+       \cgalParamDescription{an instance of a geometric traits class}
+       \cgalParamType{a model of `Kernel`}
+       \cgalParamDefault{a \cgal Kernel deduced from the point type, using `CGAL::Kernel_traits`}
+     \cgalParamNEnd
    \cgalNamedParamsEnd
 
    \sa `CGAL::vcm_is_on_feature_edge()`
@@ -257,26 +257,27 @@ vcm_convolve (ForwardIterator first,
 
 */
 template <typename PointRange,
-          typename NamedParameters>
+          typename NamedParameters = parameters::Default_named_parameters>
 void
 compute_vcm (const PointRange& points,
-             std::vector< cpp11::array<double, 6> > &ccov,
+             std::vector< std::array<double, 6> > &ccov,
              double offset_radius,
              double convolution_radius,
-             const NamedParameters& np)
+             const NamedParameters& np = parameters::default_values())
 {
     using parameters::choose_parameter;
     using parameters::get_parameter;
 
     // basic geometric types
-    typedef typename Point_set_processing_3::GetPointMap<PointRange, NamedParameters>::type PointMap;
-    typedef typename Point_set_processing_3::GetK<PointRange, NamedParameters>::Kernel Kernel;
+    typedef Point_set_processing_3_np_helper<PointRange, NamedParameters> NP_helper;
+    typedef typename NP_helper::Const_point_map PointMap;
+    typedef typename NP_helper::Geom_traits Kernel;
+
+    PointMap point_map = NP_helper::get_const_point_map(points, np);
+    Kernel kernel = NP_helper::get_geom_traits(points, np);
 
-    PointMap point_map = choose_parameter(get_parameter(np, internal_np::point_map), PointMap());
-    Kernel kernel;
-    
     // First, compute the VCM for each point
-    std::vector< cpp11::array<double, 6> > cov;
+    std::vector< std::array<double, 6> > cov;
     std::size_t N = 20;
     internal::vcm_offset (points.begin(), points.end(),
                           point_map,
@@ -298,43 +299,6 @@ compute_vcm (const PointRange& points,
     }
 }
 
-/// \cond SKIP_IN_MANUAL
-// variant with default NP
-template <typename PointRange>
-void
-compute_vcm (const PointRange& points,
-             std::vector< cpp11::array<double, 6> > &ccov,
-             double offset_radius,
-             double convolution_radius)
-{
-  compute_vcm (points, ccov, offset_radius, convolution_radius,
-               CGAL::Point_set_processing_3::parameters::all_default (points));
-}
-
-#ifndef CGAL_NO_DEPRECATED_CODE
-// deprecated API
-template < class ForwardIterator,
-           class PointMap,
-           class Kernel
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::compute_vcm(), please update your code")
-void
-compute_vcm (ForwardIterator first,
-             ForwardIterator beyond,
-             PointMap point_map,
-             std::vector< cpp11::array<double, 6> > &ccov,
-             double offset_radius,
-             double convolution_radius,
-             const Kernel & kernel)
-{
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  compute_vcm (points, ccov, offset_radius, convolution_radius,
-               CGAL::parameters::point_map (point_map).
-               geom_traits (kernel));
-}
-#endif // CGAL_NO_DEPRECATED_CODE
-/// \endcond
-  
 /// \cond SKIP_IN_MANUAL
 template <typename PointRange,
           typename NamedParameters
@@ -351,20 +315,19 @@ vcm_estimate_normals_internal (PointRange& points,
     using parameters::get_parameter;
 
     // basic geometric types
-    typedef typename Point_set_processing_3::GetPointMap<PointRange, NamedParameters>::type PointMap;
-    typedef typename Point_set_processing_3::GetNormalMap<PointRange, NamedParameters>::type NormalMap;
-    typedef typename Point_set_processing_3::GetK<PointRange, NamedParameters>::Kernel Kernel;
+    typedef Point_set_processing_3_np_helper<PointRange, NamedParameters> NP_helper;
+    typedef typename NP_helper::Point_map PointMap;
+    typedef typename NP_helper::Normal_map NormalMap;
+    typedef typename NP_helper::Geom_traits Kernel;
     typedef typename GetDiagonalizeTraits<NamedParameters, double, 3>::type DiagonalizeTraits;
 
-    CGAL_static_assertion_msg(!(boost::is_same<NormalMap,
-                                typename Point_set_processing_3::GetNormalMap<PointRange, NamedParameters>::NoMap>::value),
-                              "Error: no normal map");
+    CGAL_assertion_msg(NP_helper::has_normal_map(points, np), "Error: no normal map");
+
+    PointMap point_map = NP_helper::get_point_map(points, np);
+    NormalMap normal_map = NP_helper::get_normal_map(points, np);
+
+    typedef std::array<double, 6> Covariance;
 
-    PointMap point_map = choose_parameter(get_parameter(np, internal_np::point_map), PointMap());
-    NormalMap normal_map = choose_parameter(get_parameter(np, internal_np::normal_map), NormalMap());
-    
-    typedef cpp11::array<double, 6> Covariance;
-    
     // Compute the VCM and convolve it
     std::vector<Covariance> cov;
     if (nb_neighbors_convolve == -1) {
@@ -400,7 +363,7 @@ vcm_estimate_normals_internal (PointRange& points,
     // And finally, compute the normals
     int i = 0;
     for (typename PointRange::iterator it = points.begin(); it != points.end(); ++it) {
-        cpp11::array<double, 3> enormal = {{ 0,0,0 }};
+        std::array<double, 3> enormal = {{ 0,0,0 }};
         DiagonalizeTraits::extract_largest_eigenvector_of_covariance_matrix
           (cov[i], enormal);
 
@@ -414,7 +377,7 @@ vcm_estimate_normals_internal (PointRange& points,
 /// @endcond
 
 
-/**  
+/**
    \ingroup PkgPointSetProcessing3Algorithms
    Estimates normal directions of the range of `points`
    using the Voronoi Covariance Measure with a radius for the convolution.
@@ -426,80 +389,53 @@ vcm_estimate_normals_internal (PointRange& points,
    \tparam PointRange is a model of `Range`. The value type of
    its iterator is the key type of the named parameter `point_map`.
 
-   \param points input point range.
+   \param points input point range
    \param offset_radius offset_radius.
    \param convolution_radius convolution_radius.
-   \param np optional sequence of \ref psp_namedparameters "Named Parameters" among the ones listed below.
+   \param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
    \cgalNamedParamsBegin
-     \cgalParamBegin{point_map} a model of `ReadablePropertyMap` with value type `geom_traits::Point_3`.
-     If this parameter is omitted, `CGAL::Identity_property_map<geom_traits::Point_3>` is used.\cgalParamEnd
-     \cgalParamBegin{normal_map} a model of `WritablePropertyMap` with value type
-     `geom_traits::Vector_3`.\cgalParamEnd
-       \cgalParamBegin{diagonalize_traits} a model of `DiagonalizeTraits`. It can be omitted:
-       if Eigen 3 (or greater) is available and `CGAL_EIGEN3_ENABLED` is defined then an overload
-       using `Eigen_diagonalize_traits` is provided. Otherwise, the internal implementation
-       `CGAL::Diagonalize_traits` is used.\cgalParamEnd
-     \cgalParamBegin{geom_traits} an instance of a geometric traits class, model of `Kernel`\cgalParamEnd
-   \cgalNamedParamsEnd
+     \cgalParamNBegin{point_map}
+       \cgalParamDescription{a property map associating points to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadWritePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Point_3`}
+       \cgalParamDefault{`CGAL::Identity_property_map<geom_traits::Point_3>`}
+     \cgalParamNEnd
 
+     \cgalParamNBegin{normal_map}
+       \cgalParamDescription{a property map associating normals to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadWritePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Vector_3`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{diagonalize_traits}
+       \cgalParamDescription{the solver used for diagonalizing covariance matrices}
+       \cgalParamType{a class model of `DiagonalizeTraits`}
+       \cgalParamDefault{If Eigen 3 (or greater) is available and `CGAL_EIGEN3_ENABLED` is defined
+                         then an overload using `Eigen_diagonalize_traits` is provided.
+                         Otherwise, the internal implementation `CGAL::Diagonalize_traits` is used}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{geom_traits}
+       \cgalParamDescription{an instance of a geometric traits class}
+       \cgalParamType{a model of `Kernel`}
+       \cgalParamDefault{a \cgal Kernel deduced from the point type, using `CGAL::Kernel_traits`}
+     \cgalParamNEnd
+   \cgalNamedParamsEnd
 */
 template <typename PointRange,
-          typename NamedParameters
+          typename NamedParameters = parameters::Default_named_parameters
 >
 void
 vcm_estimate_normals (PointRange& points,
                       double offset_radius,
                       double convolution_radius,
-                      const NamedParameters& np
+                      const NamedParameters& np = parameters::default_values()
 )
 {
   vcm_estimate_normals_internal(points, offset_radius, convolution_radius, np);
 }
 
-/// \cond SKIP_IN_MANUAL
-// variant with default NP
-template <typename PointRange>
-void
-vcm_estimate_normals (PointRange& points,
-                      double offset_radius, ///< offset radius.
-                      double convolution_radius) ///< convolution radius.
-{
-  return vcm_estimate_normals
-    (points, offset_radius, convolution_radius,
-     CGAL::Point_set_processing_3::parameters::all_default(points));
-}
-
-#ifndef CGAL_NO_DEPRECATED_CODE
-// deprecated API
-template < typename ForwardIterator,
-           typename PointMap,
-           typename NormalMap,
-           typename VCMTraits
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::vcm_estimate_normals(), please update your code")
-void
-vcm_estimate_normals (ForwardIterator first, ///< iterator over the first input point.
-                      ForwardIterator beyond, ///< past-the-end iterator over the input points.
-                      PointMap point_map, ///< property map: value_type of ForwardIterator -> Point_3.
-                      NormalMap normal_map, ///< property map: value_type of ForwardIterator -> Vector_3.
-                      double offset_radius, ///< offset radius.
-                      double convolution_radius, ///< convolution radius.
-                      VCMTraits
-)
-{
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  vcm_estimate_normals
-    (points,
-     offset_radius, convolution_radius,
-     CGAL::parameters::point_map (point_map).
-     normal_map (normal_map).
-     diagonalize_traits (VCMTraits()));
-}
-#endif // CGAL_NO_DEPRECATED_CODE
-/// \endcond
-
-
 /**
    \ingroup PkgPointSetProcessing3Algorithms
    Estimates normal directions of the range of `points`
@@ -512,159 +448,53 @@ vcm_estimate_normals (ForwardIterator first, ///< iterator over the first input
    \tparam PointRange is a model of `Range`. The value type of
    its iterator is the key type of the named parameter `point_map`.
 
-   \param points input point range.
+   \param points input point range
    \param offset_radius offset_radius.
    \param k number of neighbor points used for convolution.
-   \param np optional sequence of \ref psp_namedparameters "Named Parameters" among the ones listed below.
+   \param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
    \cgalNamedParamsBegin
-     \cgalParamBegin{point_map} a model of `ReadablePropertyMap` with value type `geom_traits::Point_3`.
-     If this parameter is omitted, `CGAL::Identity_property_map<geom_traits::Point_3>` is used.\cgalParamEnd
-     \cgalParamBegin{normal_map} a model of `WritablePropertyMap` with value type
-     `geom_traits::Vector_3`.\cgalParamEnd
-       \cgalParamBegin{diagonalize_traits} a model of `DiagonalizeTraits`. It can be omitted:
-       if Eigen 3 (or greater) is available and `CGAL_EIGEN3_ENABLED` is defined then an overload
-       using `Eigen_diagonalize_traits` is provided. Otherwise, the internal implementation
-       `CGAL::Diagonalize_traits` is used.\cgalParamEnd
-     \cgalParamBegin{geom_traits} an instance of a geometric traits class, model of `Kernel`\cgalParamEnd
+     \cgalParamNBegin{point_map}
+       \cgalParamDescription{a property map associating points to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadWritePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Point_3`}
+       \cgalParamDefault{`CGAL::Identity_property_map<geom_traits::Point_3>`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{normal_map}
+       \cgalParamDescription{a property map associating normals to the elements of the point set `points`}
+       \cgalParamType{a model of `ReadWritePropertyMap` whose key type is the value type
+                      of the iterator of `PointRange` and whose value type is `geom_traits::Vector_3`}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{diagonalize_traits}
+       \cgalParamDescription{the solver used for diagonalizing covariance matrices}
+       \cgalParamType{a class model of `DiagonalizeTraits`}
+       \cgalParamDefault{If Eigen 3 (or greater) is available and `CGAL_EIGEN3_ENABLED` is defined
+                         then an overload using `Eigen_diagonalize_traits` is provided.
+                         Otherwise, the internal implementation `CGAL::Diagonalize_traits` is used}
+     \cgalParamNEnd
+
+     \cgalParamNBegin{geom_traits}
+       \cgalParamDescription{an instance of a geometric traits class}
+       \cgalParamType{a model of `Kernel`}
+       \cgalParamDefault{a \cgal Kernel deduced from the point type, using `CGAL::Kernel_traits`}
+     \cgalParamNEnd
    \cgalNamedParamsEnd
 */
 template < typename PointRange,
-           typename NamedParameters
+           typename NamedParameters = parameters::Default_named_parameters
 >
 void
 vcm_estimate_normals (PointRange& points,
                       double offset_radius,
                       unsigned int k,
-                      const NamedParameters& np
+                      const NamedParameters& np = parameters::default_values()
 )
 {
   vcm_estimate_normals_internal(points, offset_radius, 0, np, k);
 }
 
-/// \cond SKIP_IN_MANUAL
-// variant with default NP
-template <typename PointRange>
-void
-vcm_estimate_normals (PointRange& points,
-                      double offset_radius, ///< offset radius.
-                      unsigned int k)
-{
-  return vcm_estimate_normals
-    (points, offset_radius, k,
-     CGAL::Point_set_processing_3::parameters::all_default(points));
-}
-
-#ifndef CGAL_NO_DEPRECATED_CODE
-// deprecated API
-template < typename ForwardIterator,
-           typename PointMap,
-           typename NormalMap,
-           typename VCMTraits
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::vcm_estimate_normals(), please update your code")
-void
-vcm_estimate_normals (ForwardIterator first, ///< iterator over the first input point.
-                      ForwardIterator beyond, ///< past-the-end iterator over the input points.
-                      PointMap point_map, ///< property map: value_type of ForwardIterator -> Point_3.
-                      NormalMap normal_map, ///< property map: value_type of ForwardIterator -> Vector_3.
-                      double offset_radius, ///< offset radius.
-                      unsigned int k, ///< number of neighbor points used for the convolution.
-                      VCMTraits
-)
-{
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  vcm_estimate_normals
-    (points,
-     offset_radius, k,
-     CGAL::parameters::point_map (point_map).
-     normal_map (normal_map).
-     diagonalize_traits (VCMTraits()));
-}
-
-// deprecated API  
-template < typename ForwardIterator,
-           typename PointMap,
-           typename NormalMap
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::vcm_estimate_normals(), please update your code")
-void
-vcm_estimate_normals (ForwardIterator first,
-                      ForwardIterator beyond,
-                      PointMap point_map,
-                      NormalMap normal_map,
-                      double offset_radius,
-                      double convolution_radius)
-{
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  vcm_estimate_normals
-    (points,
-     offset_radius, convolution_radius,
-     CGAL::parameters::point_map (point_map).
-     normal_map (normal_map));
-}
-
-// deprecated API  
-template < typename ForwardIterator,
-           typename PointMap,
-           typename NormalMap
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::vcm_estimate_normals(), please update your code")
-void
-vcm_estimate_normals (ForwardIterator first,
-                      ForwardIterator beyond,
-                      PointMap point_map,
-                      NormalMap normal_map,
-                      double offset_radius,
-                      unsigned int nb_neighbors_convolve)
-{
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  vcm_estimate_normals
-    (points,
-     offset_radius, nb_neighbors_convolve,
-     CGAL::parameters::point_map (point_map).
-     normal_map (normal_map));
-}
-
-
-// deprecated API  
-template < typename ForwardIterator,
-           typename NormalMap
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::vcm_estimate_normals(), please update your code")
-void
-vcm_estimate_normals (ForwardIterator first,
-                      ForwardIterator beyond,
-                      NormalMap normal_map,
-                      double offset_radius,
-                      double convolution_radius) {
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  vcm_estimate_normals
-    (points,
-     offset_radius, convolution_radius,
-     CGAL::parameters::normal_map (normal_map));
-}
-
-// deprecated API  
-template < typename ForwardIterator,
-           typename NormalMap
->
-CGAL_DEPRECATED_MSG("you are using the deprecated V1 API of CGAL::vcm_estimate_normals(), please update your code")
-void
-vcm_estimate_normals (ForwardIterator first,
-                      ForwardIterator beyond,
-                      NormalMap normal_map,
-                      double offset_radius,
-                      unsigned int nb_neighbors_convolve) {
-  CGAL::Iterator_range<ForwardIterator> points (first, beyond);
-  vcm_estimate_normals
-    (points,
-     offset_radius, nb_neighbors_convolve,
-     CGAL::parameters::normal_map (normal_map));
-}
-#endif // CGAL_NO_DEPRECATED_CODE
-/// \endcond
-
 } // namespace CGAL
 
 #include <CGAL/enable_warnings.h>
